\qt@newcmd\qurantrans@en@i{%
In the Name of Allah, the Most Gracious, the Most Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
Al-Hamd be to Allah, the Lord of all that exists.\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
Ar-Rahman (the Most Gracious), Ar-Rahim (the Most Merciful).\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
The Owner of the Day of Recompense.\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
You we worship, and You we ask for help.\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us to the straight path.\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The way of those upon whom You have bestowed Your grace, not (that) of those who earned Your anger, nor of those who went astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
That is Book in which there is no Rayb, guidance for the Muttaqin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Those Who have faith in the Ghayb and perform Salah, and spend out of what we have provided for them.\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And who have faith in what is revealed to you and in what was revealed before you, and in the Hereafter they are certain.\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
They are on guidance from their Lord, and they are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
Verily, those who disbelieve, it is the same to them whether you warn them or do not warn them, they will not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah has set a seal on their hearts and on their hearing, and on their eyes there is a covering. Theirs will be a great torment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
And of mankind, there are some who say: ``We believe in Allah and the Last Day" while in fact they do not believe.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They try to deceive Allah and those who believe, while they only deceive themselves, and perceive (it) not!\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is a disease and Allah has increased their disease. A painful torment is theirs because they used to tell lies.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it is said to them: ``Do not make mischief on the earth," they say: ``We are only peacemakers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Verily, they are the ones who make mischief, but they perceive not.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said to them: Believe as the people believe," They say: ``Shall we believe as the fools have believed" Verily, they are the fools, but they do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they meet those who believe, they say: ``We believe," but when they are alone with their Shayatin (devils), they say: ``Truly, we are with you; verily, we were but mocking."\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
Allah mocks at them and leaves them increasing in their deviation to wander blindly.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
These are they who have purchased error with guidance, so their commerce was profitless. And they were not guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their likeness is as the likeness of one who kindled a fire; then, when it illuminated all around him, Allah removed their light and left them in darkness. (So) they could not see.\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
They are deaf, dumb, and blind, so they return not (to the right path).\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or like a rainstorm in the sky, bringing darkness, thunder, and lightning. They thrust their fingers in their ears to keep out the stunning thunderclap for fear of death. But Allah ever encompasses the disbelievers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning almost snatches away their sight, whenever it flashes for them, they walk therein, and when darkness covers them, they stand still. And if Allah willed, He could have taken away their hearing and their sight. Certainly, Allah has power over all things.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O mankind! Worship your Lord (Allah), Who created you and those who were before you so that you may acquire Taqwa.\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
Who has made the earth a resting place for you, and the sky as a canopy, and sent down water (rain) from the sky and brought forth therewith fruits as a provision for you. Then do not set up rivals unto Allah (in worship) while you know (that He alone has the right to be worshipped).\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you (Arab pagans, Jews, and Christians) are in doubt concerning that which We have sent down (i.e. the Qur'an) to Our servant (Muhammad), then produce a Surah (chapter) of the like thereof and call your witnesses (supporters and helpers) besides Allah, if you are truthful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if you do it not, and you can never do it, then fear the Fire (Hell) whose fuel is men and stones, prepared for the disbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give glad tidings to those who believe and do righteous good deeds, that for them will be Gardens under which rivers flow (Paradise). Every time they will be provided with a fruit therefrom, they will say: ``This is what we were provided with before," and they will be given things in resemblance (i.e. in the same form but different in taste) and they shall have therein Azwajun Mutahharatun (purified mates or wives), and they will abide therein forever.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Verily, Allah is not ashamed to set forth a parable even of a mosquito or so much more when it is bigger (or less when it is smaller) than it. And as for those who believe, they know that it is the truth from their Lord, but as for those who disbelieve, they say: ``What did Allah intend by this parable" By it He misleads many, and many He guides thereby. And He misleads thereby only the Fasiqin (the rebellious, disobedient to Allah).\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Those who break Allah's covenant after ratifying it, and sever what Allah has ordered to be joined and do mischief on earth, it is they who are the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How can you disbelieve in Allah seeing that you were dead and He gave you life Then He will give you death, then again will bring you to life (on the Day of Resurrection) and then unto Him you will return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
He it is Who created for you all that is on earth. Then He Istawa ila the heaven and made them seven heavens and He is the Knower of everything.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And (remember) when your Lord said to the angels: ``Verily, I am going to place (mankind) generations after generations on earth." They said: ``Will You place therein those who will make mischief therein and shed blood, ـ while we glorify You with praises and thanks and sanctify You." He (Allah) said: ``I know that which you do not know."\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam all the names (of everything), then He showed them to the angels and said, ``Tell Me the names of these if you are truthful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They (angels) said: ``Glory is to You, we have no knowledge except what you have taught us. Verily, You are the Knower, the Wise."\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said: ``O Adam! Inform them of their names," and when he had informed them of their names, He said: ``Did I not tell you that I know the Ghayb (unseen) in the heavens and the earth, and I know what you reveal and what you have been concealing"\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And (remember) when We said to the angels: ``Prostrate yourselves before Adam." And they prostrated except Iblis (Shaytan), he refused and was proud and was one of the disbelievers (disobedient to Allah).\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said: ``O Adam! Dwell you and your wife in the Paradise and eat both of you freely with pleasure and delight, of things therein wherever you will, but come not near this tree or you both will be of the Zalimin (wrongdoers). ``\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
Then the Shaytan made them slip therefrom (the Paradise), and got them out from that in which they were. We said: ``Get you down, all, with enmity between yourselves. On earth will be a dwelling place for you and an enjoyment for a time."\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam received from his Lord Words. And his Lord pardoned him (accepted his repentance). Verily, He is the One Who forgives (accepts repentance), the Most Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said: ``Get down all of you from this place (the Paradise), then whenever there comes to you Hudan (guidance) from Me, and whoever follows My guidance, there shall be no fear on them, nor shall they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
But those who disbelieve and belie Our Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) ـ such are the dwellers of the Fire. They shall abide therein forever."\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Children of Israel! Remember My favor which I bestowed upon you, and fulfill (your obligations to) My covenant (with you) so that I fulfill (My obligations to) your covenant (with Me), and fear none but Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in what I have sent down (this Qur'an), confirming that which is with you (the Tawrah and the Injil), and be not the first to disbelieve therein, and buy not with My verses (the Tawrah and the Injil) a small price (i.e. getting a small gain by selling My verses), and fear Me and Me alone.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And mix not truth with falsehood, nor conceal the truth while you know (the truth).\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And perform As-Salah, and give Zakah, and bow down along with Ar-Raki`in.\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Enjoin you Al-Birr (piety and righteousness and every act of obedience to Allah) on the people and you forget (to practise it) yourselves, while you recite the Scripture (Tawrah)! Have you then no sense.\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help in patience and As-Salat (the prayer) and truly, it is extremely heavy and hard except for Al-Khashi`in.\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
(They are those) who are certain that they are going to meet their Lord, and that unto Him they are going to return.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel! Remember My favor which I bestowed upon you and that I preferred you over the `Alamin (nations)\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
And fear a Day (of Judgement) when a person shall not avail another, nor will intercession be accepted from him, nor will compensation be taken from him, nor will they be helped.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And (remember) when We delivered you from Fir`awn's (Pharaoh) people, who were afflicting you with a horrible torment, killing your sons and sparing your women, and therein was a mighty trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And (remember) when We separated the sea for you and saved you and drowned Fir`awn's (Pharaoh) people while you were watching.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And (remember) when We appointed for Musa (Moses) forty nights, and (in his absence) you took the calf (for worship), and you were Zalimun (polytheists and wrongdoers).\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Then after that We forgave you so that you might be grateful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And (remember) when We gave Musa the Scripture (the Tawrah) and the criterion (of right and wrong) so that you may be guided aright.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And (remember) when Musa said to his people: ``O my people! Verily, you have wronged yourselves by worshipping the calf. So turn in repentance to your Creator and kill yourselves (the innocent kill the wrongdoers among you), that will be better for you with your Creator." Then He accepted your repentance. Truly, He is the One Who accepts repentance, the Most Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And (remember) when you said: ``O Musa! We shall never believe in you until we see Allah plainly." But you were seized with a bolt of lightning while you were looking.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We raised you up after your death, so that you might be grateful.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We shaded you with clouds and sent down on you Al-Manna and the quail, (saying): ``Eat of the good lawful things We have provided for you," (but they rebelled). And they did not wrong Us but they wronged themselves.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And (remember) when We said: ``Enter this town (Jerusalem) and eat bountifully therein with pleasure and delight wherever you wish, and enter the gate in prostration (or bowing with humility) and say: `Forgive us,' and We shall forgive you your sins and shall increase (reward) for the good-doers."\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
But those who did wrong changed the word from that which had been told to them for another, so We sent upon the wrongdoers Rijz (a punishment) from the heaven because of their rebellion.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And (remember) when Musa asked for water for his people, We said: ``Strike the stone with your stick." Then gushed forth therefrom twelve springs. Each (group of) people knew its own place for water. ``Eat and drink of that which Allah has provided and do not act corruptly, making mischief on the earth."\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And (remember) when you said, ``O Musa! We cannot endure one kind of food. So invoke your Lord for us to bring forth for us of what the earth grows, its herbs, its cucumber its Fum, its lentils and its onions." He said, ``Would you exchange that which is better for that which is lower Go you down to any town and you shall find what you want!" And they were covered with humiliation and misery, and they drew on themselves the wrath of Allah. That was because they used to disbelieve in the Ayat (proofs, evidence) of Allah and killed the Prophets wrongfully. That was because they disobeyed and used to transgress the bounds (in their disobedience to Allah, i.e. commit crimes and sins.)\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Verily, those who believe and those who are Jews and Christians, and Sabians (Sabi'in), whoever believes in Allah and the Last Day and does righteous good deeds shall have their reward with their Lord, on them shall be no fear, nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And (O Children of Isra'il, remember) when We took your covenant and We raised above you the Mount (saying): ``Hold fast to that which We have given you, and remember that which is therein so that you may acquire Taqwa.\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then after that you turned away. Had it not been for the grace and mercy of Allah upon you, indeed you would have been among the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And indeed you knew those amongst you who transgressed in the matter of the Sabbath (i.e. Saturday). We said to them: ``Be you monkeys, despised and rejected."\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
So We made this punishment an example for those in front of it and those behind it, and a lesson for Al-Muttaqin (the pious).\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And (remember) when Musa said to his people: ``Verily, Allah commands you that you slaughter a cow." They said, ``Do you make fun of us" He said, ``I take Allah's refuge from being among Al-Jahilin (the ignorant or the foolish)."\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said, ``Call upon your Lord for us that He may make plain to us what it is!" He said, ``He says, `Verily, it is a cow neither too old nor too young, but (it is) between the two conditions', so do what you are commanded."\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said, ``Call upon your Lord for us to make plain to us its colour." He said, ``He says, `It is a yellow cow, bright in its colour, pleasing the beholders.' ``\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said, ``Call upon your Lord for us to make plain to us what it is. Verily, to us all cows are alike. And surely, if Allah wills, we will be guided."\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He (Musa) said, ``He says, `It is a cow neither trained to till the soil nor water the fields, sound, having no blemish in it.' `` They said, ``Now you have brought the truth." So they slaughtered it though they were near to not doing it.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And (remember) when you killed a man and disagreed among yourselves as to the crime. But Allah brought forth that which you were Taktumun.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
So We said: ``Strike him (the dead man) with a piece of it (the cow)." Thus Allah brings the dead to life and shows you His Ayat (proofs, evidences, etc.) so that you may understand.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then after that your hearts were hardened and became as stones or even worse in hardness. And indeed, there are stones out of which rivers gush forth, and indeed, there are of them (stones) which split asunder so that water flows from them, and indeed, there are of them (stones) which fall down for fear of Allah. And Allah is not unaware of what you do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Do you (faithful believers) covet that they will believe in your religion inspite of the fact that a party of them (Jewish rabbis) used to hear the Word of Allah (the Tawrah), then they used to change it knowingly after they understood it\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they (Jews) meet those who believe (Muslims), they say, ``We believe," but when they meet one another in private, they say, ``Shall you (Jews) tell them (Muslims) what Allah has revealed to you that they (Muslims) may argue with you (Jews) about it before your Lord" Have you (Jews) then no understanding\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
Know they (Jews) not that Allah knows what they conceal and what they reveal\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And there are among them (Jews) `Ummyyun (unlettered) people, who know not the Book, but they trust upon Amani (false desires) and they but guess.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
Then woe to those who write the book with their own hands and then say, ``This is from Allah," to purchase with it a little price! Woe to them for what their hands have written and woe to them for that they earn thereby.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they (Jews) say, ``The Fire shall not touch us but for a few numbered days." Say (O Muhammad to them): ``Have you taken a covenant from Allah, so that Allah will not break His covenant Or is it that you say of Allah what you know not"\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Yes! Whosoever earns evil and his sin has surrounded him, they are dwellers of the Fire (i.e. Hell); they will dwell therein forever.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
And those who believe and do righteous good deeds, they are dwellers of Paradise, they will dwell therein forever.\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And (remember) when We took a covenant from the Children of Israel, (saying): Worship none but Allah (alone) and be dutiful and good to parents, and to kindred, and to orphans and (the poor), and speak good to people and perform As-Salah and give Zakah. Then you slid back, except a few of you, while you are backsliders.\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And (remember) when We took your covenant (saying): Shed not the blood of your (people), nor turn out your own people from their dwellings. Then, (this) you ratified and (to this) you bore witness.\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
After this, it is you who kill one another and drive out a party of you from their homes, assist (their enemies) against them, in sin and transgression. And if they come to you as captives, you ransom them, although their expulsion was forbidden to you. Then do you believe in a part of the Book and reject the rest Then what is the recompense of those who do so among you, except disgrace in the life of this world, and on the Day of Resurrection they shall be consigned to the most grievous torment. And Allah is not unaware of what you do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
Those are they who have bought the life of this world at the price of the Hereafter. Their torment shall not be lightened nor shall they be helped.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
And indeed, We gave Musa the Book and followed him up with a succession of Messengers. And We gave `Isa, the son of Maryam, clear signs and supported him with Ruh-il-Qudus. Is it that whenever there came to you a Messenger with what you yourselves desired not, you grew arrogant Some you disbelieved and some you killed.\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they say, ``Our hearts are Ghulf." Nay, Allah has cursed them for their disbelief, so little is that which they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when there came to them (the Jews), a Book (this Qur'an) from Allah confirming what is with them (the Tawrah) and the Injil (Gospel), although aforetime they had invoked Allah (for the coming of Muhammad) in order to gain victory over those who disbelieved, then when there came to them that which they had recognised, they disbelieved in it. So let the curse of Allah be on the disbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
How bad is that for which they have sold their own selves, that they should disbelieve in that which Allah has revealed (the Qur'an), grudging that Allah should reveal of His grace unto whom He wills of His servants. So they have drawn on themselves wrath upon wrath. And for the disbelievers, there is disgracing torment.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it is said to them (the Jews), ``Believe in what Allah has sent down," they say, ``We believe in what was sent down to us." And they disbelieve in that which came after it, while it is the truth confirming what is with them. Say (O Muhammad to them): ``Why then have you killed the Prophets of Allah aforetime, if you indeed have been believers"\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
And indeed Musa came to you with clear proofs, yet you worshipped the calf after he left, and you were Zalimun.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And (remember) when We took your covenant and We raised above you the Mount (saying), ``Hold firmly to what We have given you and hear (Our Word)." They said, ``We have heard and disobeyed." And their hearts absorbed (the worship of) the calf because of their disbelief. Say: ``Worst indeed is that which your faith enjoins on you if you are believers."\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say to (them): ``If the abode of the Hereafter with Allah is indeed for you especially and not for others of mankind, then long for death if you are truthful."\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never long for it because of what their hands have sent before them (i.e. what they have done). And Allah is Aware of the Zalimin.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
And verily, you will find them (the Jews) the greediest of mankind for life and (even greedier) than those who ascribe partners to Allah. One of them wishes that he could be given a life of a thousand years. But the grant of such life will not save him even a little from (due) punishment. And Allah is Seer of what they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say (O Muhammad): ``Whoever is an enemy to Jibril (Gabriel) (let him die in his fury), for indeed he has brought it (this Qur'an) down to your heart by Allah's permission, confirming what came before it (i.e. the Tawrah and the Injil) and guidance and glad tidings for the believers.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
``Whoever is an enemy to Allah, His Angels, His Messengers, Jibril and Mika'il, then verily, Allah is an enemy to the disbelievers."\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
And indeed We have sent down to you manifest Ayat and none disbelieve in them but Fasiqun (those who rebel against Allah's command).\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it not (the case) that every time they make a covenant, some party among them throw it aside Nay! (the truth is:) most of them believe not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And when there came to them a Messenger from Allah (i.e. Muhammad) confirming what was with them, a party of those who were given the Scripture threw away the Book of Allah behind their backs as if they did not know!\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
They followed what the Shayatin (devils) gave out (falsely of the magic) in the lifetime of Sulayman (Solomon). Sulayman did not disbelieve, but the Shayatin (devils) disbelieved, teaching men magic and such things that came down at Babylon to the two angels, Harut and Marut, but neither of these two (angels) taught anyone (such things) till they had said, ``We are for trial, so disbelieve not (by learning this magic from us)." And from these (angels) people learn that by which they cause separation between man and his wife, but they could not thus harm anyone except by Allah's leave. And they learn that which harms them and profits them not. And indeed they knew that the buyers of it (magic) would have no share in the Hereafter. And how bad indeed was that for which they sold their own selves, if they but knew.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
And if they had believed and guarded themselves from evil and kept their duty to Allah, far better would have been the reward from their Lord, if they but knew!\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O you who believe! Say not (to the Messenger) Ra`ina but say Unzurna (make us understand) and hear. And for the disbelievers there is a painful torment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
Neither those who disbelieve among the People of the Scripture (Jews and Christians) nor Al-Mushrikin (the idolaters) like that there should be sent down unto you any good from your Lord. But Allah chooses for His mercy whom He wills. And Allah is the Owner of great bounty.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
Whatever a verse (revelation) do Nansakh (We abrogate) or Nunsiha (cause to be forgotten), We bring a better one or similar to it. Know you not that Allah is Able to do all things\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Know you not that it is Allah to Whom belongs the dominion of the heavens and the earth And besides Allah you have neither any Wali (protector or guardian) nor any helper.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Or do you want to ask your Messenger (Muhammad) as Musa (Moses) was asked before (i.e. show us openly our Lord) And he who changes faith for disbelief, verily, he has gone astray from the right way.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the People of the Scripture (Jews and Christians) wish that they could turn you away as disbelievers after you have believed, out of envy from their own selves, even after the truth (that Muhammad is Allah's Messenger) has become manifest unto them. But forgive and overlook, till Allah brings His command. Verily, Allah is able to do all things.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And perform the Salah and give the Zakah, and whatever of good you send forth for yourselves before you, you shall find it with Allah. Certainly, Allah is the Seer of what you do.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say, ``None shall enter Paradise unless he be a Jew or a Christian." These are their own desires. Say (O Muhammad), ``Produce your Burhan if you are truthful."\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Yes! But whoever submits his face (himself) to Allah (i.e. follows Allah's religion of Islamic Monotheism) and he is a Muhsin then his reward is with his Lord (Allah), on such shall be no fear, nor shall they grieve.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews said that the Christians follow nothing (i.e. are not on the right religion); and the Christians said that the Jews follow nothing (i.e. are not on the right religion); though they both recite the Scripture. Like unto their word, said those (the pagans) who know not. Allah will judge between them on the Day of Resurrection about that wherein they have been differing.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who are more unjust than those who forbid that Allah's Name be mentioned (i.e. prayers and invocations) in Allah's Masjids and strive for their ruin It was not fitting that such should themselves enter them (Allah's Masjids) except in fear. For them there is disgrace in this world, and they will have a great torment in the Hereafter.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
And to Allah belong the east and the west, so wherever you turn (yourselves or your faces) there is the Face of Allah (and He is High above, over His Throne). Surely, Allah is Sufficient (for His creatures' needs), Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
And they (Jews, Christians and pagans) say: Allah has begotten a son (children or offspring). Glory is to Him (Exalted is He above all that they associate with Him). Nay, to Him belongs all that is in the heavens and on earth, and all are Qanitun to Him.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
The Originator of the heavens and the earth. When He decrees a matter, He only says to it: ``Be! ـ and it is.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
And those who have no knowledge say: ``Why does not Allah speak to us (face to face) or why does not a sign come to us" So said the people before them words of similar import. Their hearts are alike, We have indeed made plain the signs for people who believe with certainty.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Verily, We have sent you (O Muhammad) with the truth (Islam), a bringer of glad tidings (for those who believe in what you brought, that they will enter Paradise) and a warner (for those who disbelieve in what you brought, that they will enter the Hellfire). And you will not be asked about the dwellers of the blazing Fire.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
Never will the Jews nor the Christians be pleased with you (O Muhammad) till you follow their religion. Say: ``Verily, the guidance of Allah (i.e. Islamic Monotheism) that is the (only) guidance. And if you (O Muhammad) were to follow their (Jews and Christians) desires after what you have received of Knowledge (i.e. the Qur'an), then you would have against Allah neither any Wali (protector or guardian) nor any helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom we gave the Book recite it as it should be recited (Yatlunahu Haqqa Tilawatihi) they are the ones who believe therein. And whoso disbelieve in it, those are they who are the losers.) Ibn Jarir said, ``Allah said,\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Israel! Remember My favor which I bestowed upon you and that I preferred you over the nations.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
And fear the Day (of Judgement) when no person shall avail another, nor shall compensation be accepted from him, nor shall intercession be of use to him, nor shall they be helped.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And (remember) when the Lord of Ibrahim (Abraham) tried him with (certain) commands, which he fulfilled. He (Allah) said (to him), ``Verily, I am going to make you an Imam (a leader) for mankind (to follow you)." (Ibrahim) said, ``And of my offspring (to make leaders)." (Allah) said, ``My covenant (prophethood) includes not Zalimin (polytheists and wrongdoers)."\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And (remember) when We made the House (the Ka`bah at Makkah) a place of resort for mankind and a place of safety. And take you (people) the Maqam (place) of Ibrahim as a place of prayer. And We commanded Ibrahim (Abraham) and Isma`il (Ishmael) that they should purify My House (the Ka`bah at Makkah) for those who are circumambulating it, or staying (I`tikaf), or bowing or prostrating themselves (there, in prayer).\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And (remember) when Ibrahim said, ``My Lord, make this city (Makkah) a place of security and provide its people with fruits, such of them as believe in Allah and the Last Day." He (Allah) answered: ``As for him who disbelieves, I shall leave him in contentment for a while, then I shall compel him to the torment of the Fire, and worst indeed is that destination!"\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And (remember) when Ibrahim and (his son) Isma`il were raising the foundations of the House (the Ka`bah at Makkah), (saying), ``Our Lord! Accept (this service) from us. Verily, You are the Hearer, the Knower."\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
``Our Lord! And make us submissive unto You and of our offspring a nation submissive unto You, and show us our Manasik, and accept our repentance. Truly, You are the One Who accepts repentance, the Most Merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
``Our Lord! Send amongst them a Messenger of their own, who shall recite unto them Your verses and instruct them in the Book (this Qur'an), and purify them. Verily, You are the Mighty, the Wise."\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who turns away from the religion of Ibrahim (i.e. Islamic Monotheism) except him who fools himself Truly, We chose him in this world and verily, in the Hereafter he will be among the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, ``Submit (i.e. be a Muslim)!" He said, ``I have submitted myself (as a Muslim) to the Lord of the `Alamin (mankind, Jinn and all that exists)."\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And this (submission to Allah, Islam) was enjoined by Ibrahim (Abraham) upon his sons and by Ya`qub (Jacob) (saying), ``O my sons! Allah has chosen for you the (true) religion, then die not except as Muslims."\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Or were you witnesses when death approached Ya`qub (Jacob) When he said unto his sons, ``What will you worship after me" They said, ``We shall worship your AIlah (God ـ Allah) the Ilah of your fathers, Ibrahim (Abraham), Isma`il (Ishmael), Ishaq (Isaac), One Ilah, and to Him we submit (in Islam)."\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That was a nation who has passed away. They shall receive the reward of what they earned and you of what you earn. And you will not be asked of what they used to do.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
And they say, ``Be Jews or Christians, then you will be guided." Say (to them O Muhammad), ``Nay, (we follow) only the religion of Ibrahim, Hanif (Islamic Monotheism), and he was not of Al-Mushrikin (those who worshipped others along with Allah).\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say (O Muslims): ``We believe in Allah and that which has been sent down to us and that which has been sent down to Ibrahim (Abraham), Isma`il (Ishmael), Ishaq (Isaac), Ya`qub (Jacob), and to Al-Asbat (the offspring of the twelve sons of Ya`qub), and that which has been given to Musa (Moses) and `Isa (Jesus), and that which has been given to the Prophets from their Lord. We make no distinction between any of them, and to Him we have submitted (in Islam)."\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
So if they believe in the like of that which you believe then they are rightly guided; but if they turn away, then they are only in opposition. So Allah will suffice for you against them. And He is the Hearer, the Knower.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
[Our Sibghah (religion) is] the Sibghah of Allah (Islam) and which Sibghah can be better than Allah's And we are His worshippers.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say (O Muhammad to the Jews and Christians), ``Dispute you with us about Allah while He is our Lord and your Lord And we are to be rewarded for our deeds and you for your deeds. And we are sincere to Him (i.e. we worship Him alone and none else, and we obey His orders)."\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or say you that Ibrahim, Isma`il, Ishaq, Ya`qub and Al-Asbat, were Jews or Christians Say, ``Do you know better or does Allah And who is more unjust than he who conceals the testimony he has from Allah And Allah is not unaware of what you do."\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That was a nation who has passed away. They shall receive the reward of what they earned, and you of what you earn. And you will not be asked of what they used to do.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The fools (idolators, hypocrites, and Jews) among the people will say: ``What has turned them (Muslims) from their Qiblah [prayer direction (towards Jerusalem)] to which they used to face in prayer." Say (O Muhammad): ``To Allah belong both, east and the west. He guides whom He wills to the straight way."\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
Thus We have made you [true Muslims ـ real believers of Islamic Monotheism, true followers of Prophet Muhammad and his Sunnah (legal ways)], a Wasat (just and the best) nation, that you be witnesses over mankind and the Messenger (Muhammad) be a witness over you. And We made the Qiblah which you used to face, only to test those who followed the Messenger (Muhammad) from those who would turn on their heels (i.e., disobey the Messenger). Indeed it was great (heavy, difficult) except for those whom Allah guided. And Allah would never make your faith (prayers) to be lost (i.e., your prayers offered towards Jerusalem). Truly, Allah is full of kindness, the Most Merciful towards mankind.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
Verily, We have seen the turning of your (Muhammad's) face towards the heaven. Surely, We shall turn you to a Qiblah (prayer direction) that shall please you, so turn your face in the direction of Al-Masjid Al-Haram (at Makkah). And wheresoever you people are, turn your faces (in prayer) in that direction. Certainly, the people who were given the Scripture (i.e., Jews and Christians) know well that, that (your turning towards the direction of the Ka`bah at Makkah in prayers) is the truth from their Lord. And Allah is not unaware of what they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
And even if you were to bring to the People of the Scripture (Jews and Christians) all the Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.), they would not follow your Qiblah (prayer direction), nor are you going to follow their Qiblah. And they will not follow each other's Qiblah. Verily, if you follow their desires after that which you have received of knowledge (from Allah), then indeed you will be one of the wrongdoers.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
Those to whom We gave the Scripture (Jews and Christians) recognise him (Muhammad or the Ka`bah at Makkah) as they recognize their sons. But verily, a party of them conceal the truth while they know it ـ [i.e., the qualities of Muhammad which are written in the Tawrah and the Injil.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
This is) the truth from your Lord. So be you not one of those who doubt.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
For every nation there is a direction to which they face (in their prayers). So hasten towards all that is good. Wheresoever you may be, Allah will bring you together (on the Day of Resurrection). Truly, Allah is able to do all things.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
And from wheresoever you start forth (for prayers), turn your face in the direction of Al-Masjid Al-Haram (at Makkah), that is indeed the truth from your Lord. And Allah is not unaware of what you do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
And from wheresoever you start forth (for prayers), turn your face in the direction of Al-Masjid Al-Haram (at Makkah), and wheresoever you are, turn your faces towards it (when you pray) so that men may have no argument against you except those of them that are wrongdoers, so fear them not, but fear Me! ـ And so that I may complete My blessings on you and that you may be guided.\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
Similarly (to complete My blessings on you), We have sent among you a Messenger (Muhammad) of your own, reciting to you Our verses (the Qur'an) and purifying you, and teaching you the Book (the Qur'an) and the Hikmah (i.e., Sunnah, Islamic laws and Fiqh ـ jurisprudence), and teaching you that which you did not know.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
Therefore remember Me (by praying, glorifying). I will remember you, and be grateful to Me (for My countless favors on you) and never be ungrateful to Me.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O you who believe! Seek help in patience and As-Salah (the prayer). Truly, Allah is with As-Sabirin (the patient).\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And say not of those who are killed in the way of Allah, ``They are dead." Nay, they are living, but you perceive (it) not.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
And certainly, We shall test you with something of fear, hunger, loss of wealth, lives and fruits, but give glad tidings to As-Sabirin (the patient).\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Who, when afflicted with calamity, say: ``Truly, to Allah we belong and truly, to Him we shall return."\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
They are those on whom are the Salawat (i.e., who are blessed and will be forgiven) from their Lord, and (they are those who) receive His mercy, and it is they who are the guided ones.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Verily, As-Safa and Al-Marwah are of the symbols of Allah. So it is not a sin on him who performs Hajj or `Umrah (pilgrimage) of the House to perform Tawaf between them. And whoever does good voluntarily, then verily, Allah is All-Recognizer, All-Knower.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Verily, those who conceal the clear proofs, evidences and the guidance, which We have sent down, after We have made it clear for the People in the Book, they are the ones cursed by Allah and cursed by the cursers.\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except those who repent and do righteous deeds, and openly declare (the truth which they concealed). These, I will accept their repentance. And I am the One Who accepts repentance, the Most Merciful.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
Verily, those who disbelieve, and die while they are disbelievers, it is they on whom is the curse of Allah and of the angels and of mankind, combined.\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
They will abide therein (under the curse in Hell), their punishment will neither be lightened nor will they be reprieved.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
And your Ilah (God) is One Ilah (God ـ Allah), La ilaha illa Huwa (there is none who has the right to be worshipped but He), the Most Gracious, the Most Merciful.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
Verily, in the creation of the heavens and the earth, and in the alternation of night and day, and the ships which sail through the sea with that which is of use to mankind, and the water (rain) which Allah sends down from the sky and makes the earth alive therewith after its death, and the moving (living) creatures of all kinds that He has scattered therein, and in the veering of winds and clouds which are held between the sky and the earth, are indeed Ayat (proofs, evidences, signs, etc.) for people of understanding.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
And of mankind are some who take (for worship) others besides Allah as rivals (to Allah). They love them as they love Allah. But those who believe, love Allah more (than anything else). If only, those who do wrong could see, when they will see the torment, that all power belongs to Allah and that Allah is severe in punishment.\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
When those who were followed disown (declare themselves innocent of) those who followed (them), and they see the torment, then all their relations will be cut off from them.\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
And those who followed will say: ``If only we had one more chance to return (to the worldly life), we would disown (declare ourselves as innocent from) them as they have disowned (declared themselves as innocent from) us. `` Thus Allah will show them their deeds as regrets for them. And they will never get out of the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O mankind! Eat of that which is lawful and good on the earth, and follow not the footsteps of Shaytan (Satan). Verily, he is to you an open enemy.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He (Satan) commands you only what is evil and Fahsha' (sinful), and that you should say about Allah what you know not.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
When it is said to them: ``Follow what Allah has sent down." They say: ``Nay! We shall follow what we found our fathers following." (Would they do that!) even though their fathers did not understand anything nor were they guided\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
And the example of those who disbelieve is as that of him who shouts to those (flock of sheep) that hear nothing but calls and cries. (They are) deaf, dumb and blind. So they do not understand.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O you who believe (in the Oneness of Allah ـ Islamic Monotheism)! Eat of the lawful things that We have provided you with, and be grateful to Allah, if it is indeed He Whom you worship.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He has forbidden you only the Maitah (dead animals), and blood, and the flesh of swine, and that which is slaughtered as a sacrifice for other than Allah. But if one is forced by necessity without willful disobedience nor transgressing due limits, then there is no sin on him. Truly, Allah is Oft-Forgiving, Most Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Verily, those who conceal what Allah has sent down of the Book, and purchase a small gain therewith (of worldly things), they eat into their bellies nothing but fire. Allah will not speak to them on the Day of Resurrection, nor purify them, and theirs will be a painful torment.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
Those are they who have purchased error at the price of guidance, and torment at the price of forgiveness. So how bold they are (for evil deeds which will push them) to the Fire.\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That is because Allah has sent down the Book (the Qur'an) in truth. And verily, those who disputed as regards the Book are far away in opposition.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
It is not Birr that you turn your faces towards east and (or) west; but Birr is the one who believes in Allah, the Last Day, the Angels, the Book, the Prophets and gives his wealth, in spite of love for it, to the kinsfolk, to the orphans, and to Al-Masakin (the poor), and to the wayfarer, and to those who ask, and to set servants free, performs As-Salah (Iqamat-As-Salah), and gives the Zakah, and who fulfill their covenant when they make it, and who are patient in extreme poverty and ailment (disease) and at the time of fighting (during the battles). Such are the people of the truth and they are Al-Muttaqun (the pious).\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O you who believe! Al-Qisas (the Law of equality) is prescribed for you in case of murder: the free for the free, the slave for the slave, and the female for the female. But if the killer is forgiven by the brother (or the relatives) of the killed (against blood money), then it should be sought in a good manner, and paid to him respectfully. This is an alleviation and a mercy from your Lord. So after this, whoever transgresses the limits (i.e. kills the killer after taking the blood money), he shall have a painful torment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
And there is (a saving of) life for you in Al-Qisas (the Law of equality in punishment), O men of understanding, that you may acquire Taqwa.\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
It is prescribed for you, when death approaches any of you, if he leaves wealth, that he makes a bequest to parents and next of kin, according to reasonable manners. (This is) a duty upon Al-Muttaqin (the pious).\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then whoever changes it after hearing it, the sin shall be on those who make the change. Truly, Allah is All-Hearer, All-Knower.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
But he who fears from a testator some unjust act or wrongdoing, and thereupon he makes peace between the parties concerned, there shall be no sin on him. Certainly, Allah is Oft-Forgiving, Most Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O you who believe! Fasting is prescribed for you as it was prescribed for those before you, that you may acquire Taqwa.\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
Fast for a fixed number of days, but if any of you is ill or on a journey, the same number (should be made up) from other days. And as for those who can fast with difficulty, (e.g., an old man), they have (a choice either to fast or) to feed a Miskin (poor person) (for every day). But whoever does good of his own accord, it is better for him. And that you fast is better for you if only you know.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadan in which was revealed the Qur'an, a guidance for mankind and clear proofs for the guidance and the criterion (between right and wrong). So whoever of you sights (the crescent on the first night of) the month (of Ramadan, i.e., is present at his home), he must observe Sawm (fasting) that month, and whoever is ill or on a journey, the same number [of days which one did not observe Sawm (fasting) must be made up] from other days. Allah intends for you ease, and He does not want to make things difficult for you. (He wants that you) must complete the same number (of days), and that you must magnify Allah [i.e., to say Takbir (Allahu Akbar: Allah is the Most Great)] for having guided you so that you may be grateful to Him.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My servants ask you (O Muhammad concerning Me, then answer them), I am indeed near (to them by My knowledge). I respond to the invocations of the supplicant when he calls on Me (without any mediator or intercessor). So let them obey Me and believe in Me, so that they may be led aright.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
It is made lawful for you to have sexual relations with your wives on the night of As-Siyam (fasting). They are Libas [i.e., body-cover, or screen] for you and you are Libas for them. Allah knows that you used to deceive yourselves, so He turned to you (accepted your repentance) and forgave you. So now have sexual relations with them and seek that which Allah has ordained for you (offspring), and eat and drink until the white thread (light) of dawn appears to you distinct from the black thread (darkness of night), then complete your fast till the nightfall. And do not have sexual relations with them (your wives) while you are in I`tikaf in the Masjids. These are the limits (set) by Allah, so approach them not. Thus does Allah make clear His Ayat to mankind that they may acquire Taqwa.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And eat up not one another's property unjustly (in any illegal way, e.g., stealing, robbing, deceiving), nor give bribery to the rulers (judges before presenting your cases) that you may knowingly eat up a part of the property of others sinfully.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask you (O Muhammad) about the crescents. Say: ``These are signs to mark fixed periods of time for mankind and for the pilgrimage." It is not Al-Birr (piety, righteousness, etc.) that you enter the houses from the back, but Al-Birr is from Taqwa. So enter houses through their proper doors, and have Taqwa of Allah that you may be successful.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
And fight in the way of Allah those who fight you, but transgress not the limits. Truly, Allah likes not the transgressors.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And kill them wherever you find them, and turn them out from where they have turned you out. And Al-Fitnah is worse than killing. And fight not with them at Al-Masjid Al-Haram (the sanctuary at Makkah), unless they (first) fight you there. But if they attack you, then kill them. Such is the recompense of the disbelievers.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
But if they cease, then Allah is Oft-Forgiving, Most Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
And fight them until there is no more Fitnah (disbelief and worshipping of others along with Allah) and the religion (all and every kind of worship) is for Allah (Alone). But if they cease, let there be no transgression except against Az-Zalimin (the polytheists and wrongdoers).\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
The sacred month is for the sacred month, and for the prohibited things, there is the Law of equality (Qisas). Then whoever transgresses against you, you transgress likewise against him. And fear Allah, and know that Allah is with Al-Muttaqin.\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And spend in the cause of Allah and do not throw yourselves into destruction, and do good. Truly, Allah loves Al-Muhsinin (those who do good).\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
And complete Hajj and `Umrah for Allah. But if you are prevented, then sacrifice a Hady that you can afford, and do not shave your heads until the Hady reaches the place of sacrifice. And whosoever of you is ill or has an ailment on his scalp (necessitating shaving), he must pay a Fidyah (ransom) of either fasting or giving Sadaqah or a sacrifice. Then if you are in safety and whosoever performs the `Umrah (in the months of Hajj), before (performing) the Hajj, he must slaughter a Hady such as he can afford, but if he cannot (afford it), he should fast for three days during Hajj and seven days after his return, making ten days in all. This is for him whose family is not present at Al-Masjid Al-Haram (i.e., non-resident of Makkah). And fear Allah much and know that Allah is severe in punishment.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
The Hajj (pilgrimage) is (in) the well-known months. So whosoever intends to perform Hajj therein (by assuming Ihram), then he should not have sexual relations (with his wife), nor commit sin, nor dispute unjustly during the Hajj. And whatever good you do, Allah knows it. And take provisions for the journey, but the best provision is At-Taqwa (piety, righteousness). So fear Me, O men of understanding!\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
There is no sin on you if you seek the bounty of your Lord (during pilgrimage by trading). Then when you leave `Arafat, remember Allah (by glorifying His praises, i.e., prayers and invocations) at the Mash`ar-il-Haram. And remember Him (by invoking Allah for all good) as He has guided you, and verily you were before, of those who were astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then depart from the place whence all the people depart and ask Allah for His forgiveness. Truly, Allah is Oft-Forgiving, Most-Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
So when you have accomplished your Manasik, remember Allah as you remember your forefathers or with far more remembrance. But of mankind there are some who say: ``Our Lord! Give us (Your bounties) in this world!" and for such there will be no portion in the Hereafter.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
And of them there are some who say: ``Our Lord! Give us in this world that which is good and in the Hereafter that which is good, and save us from the torment of the Fire!"\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
For them there will be alloted a share for what they have earned. And Allah is swift at reckoning.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember Allah during the Appointed Days. But whosoever hastens to leave in two days, there is no sin on him and whosoever stays on, there is no sin on him, if his aim is to do good and obey Allah (fear Him), and know that you will surely be gathered unto Him.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
And of mankind there is he whose speech may please you (O Muhammad), in this worldly life, and he calls Allah to witness as to that which is in his heart, yet he is the most quarrelsome of the opponents.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
And when he turns away (from you O Muhammad), his effort in the land is to make mischief therein and to destroy the crops and the cattle, and Allah likes not mischief.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it is said to him, ``Fear Allah", he is led by arrogance to (more) crime. So enough for him is Hell, and worst indeed is that place to rest!\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And of mankind is he who would sell himself, seeking the pleasure of Allah. And Allah is full of kindness to (His) servants.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O you who believe! Enter Silm perfectly, and follow not the footsteps of Shaytan (Satan). Verily, he is to you a plain enemy.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
Then if you slide back after the clear signs (Prophet Muhammad, and this Qur'an and Islam) have come to you, then know that Allah is All-Mighty, All-Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Do they then wait for anything other than that Allah should come to them over the shadows of the clouds and the angels (Then) the case would be already judged. And to Allah return all matters (for decision).\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many clear Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) We gave them. And whoever changes Allah's favor after it has come to him, [e.g., renounces the religion of Allah (Islam) and accepts Kufr (disbelief)] then surely, Allah is severe in punishment.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Beautified is the life of this world for those who disbelieve, and they mock at those who believe. But those who have Taqwa, will be above them on the Day of Resurrection. And Allah gives (of His bounty, blessings, favors, and honors on the Day of Resurrection) to whom He wills without limit.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind was one community and Allah sent Prophets with glad tidings and warnings, and with them He sent down the Scripture in truth to judge between people in matters wherein they differed. And only those to whom (the Scripture) was given differed concerning it, after clear proofs had come unto them, through hatred, one to another. Then Allah by His leave guided those who believed to the truth of that wherein they differed. And Allah guides whom He wills to the straight path.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or think you that you will enter Paradise without such (trials) as came to those who passed away before you They were afflicted with severe poverty and ailments and were so shaken that even the Messenger and those who believed along with him said, ``When (will come) the help of Allah" Yes! Certainly, the help of Allah is near!\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask you (O Muhammad) what they should spend. Say: ``Whatever you spend of good must be for parents and kindred and orphans and Al-Masakin (the poor) and the wayfarer, and whatever you do of good deeds, truly, Allah knows it well."\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Fighting is ordained for you (Muslims) though you dislike it, and it may be that you dislike a thing which is good for you and that you like a thing which is bad for you. Allah knows but you do not know.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you concerning fighting in the Sacred Months. Say, ``Fighting therein is a great (transgression) but a greater (transgression) with Allah is to prevent mankind from following the way of Allah, to disbelieve in Him, to prevent access to Al-Masjid Al-Haram (at Makkah), and to drive out its inhabitants, and Al-Fitnah is worse than killing." And they will never cease fighting you until they turn you back from your religion (Islamic Monotheism) if they can. And whosoever of you turns back from his religion and dies as a disbeliever, then his deeds will be lost in this life and in the Hereafter, and they will be the dwellers of the Fire. They will abide therein forever.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Verily, those who have believed, and those who have emigrated (for Allah's religion) and have striven hard in the way of Allah, all these hope for Allah's mercy. And Allah is Oft-Forgiving, Most-Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you (O Muhammad) concerning alcoholic drink and gambling. Say: ``In them is a great sin, and (some) benefits for men, but the sin of them is greater than their benefit." And they ask you what they ought to spend. Say: ``That which is (spare) beyond your needs." Thus Allah makes clear to you His Laws in order that you may give thought.\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
In (to) this worldly life and in the Hereafter. And they ask you concerning orphans. Say: ``The best thing is to work honestly in their property, and if you mix your affairs with theirs, then they are your brothers. And Allah knows (the one) who means mischief (e.g., to swallow their property) from (the one) who means good (e.g., to save their property). And if Allah had wished, He could have put you into difficulties. Truly, Allah is All-Mighty, All-Wise."\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
And do not marry Al-Mushrikat (idolatresses) till they believe (worship Allah Alone). And indeed a slave woman who believes is better than a (free) Mushrikah (idolatress), even though she pleases you. And give not (your daughters) in marriage to Al-Mushrikin till they believe (in Allah Alone) and verily, a believing servant is better than a (free) Mushrik (idolator), even though he pleases you. Those (Mushrikin) invite you to the Fire, but Allah invites (you) to Paradise and forgiveness by His leave, and makes His Ayat (proofs, evidences, verses, lessons, signs, revelations, etc.) clear to mankind that they may remember.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
They ask you concerning menstruation. Say: ``That is an Adha, therefore, keep away from women during menses and go not in unto them till they are purified." And when they have purified themselves, then go in unto them as Allah has ordained for you. Truly, Allah loves those who turn unto Him in repentance and loves those who purify themselves.\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your wives are a tilth for you, so go to your tilth, when or how you will, and send (good deeds, or ask Allah to bestow upon you pious offspring) for your own selves beforehand. And fear Allah, and know that you are to meet Him (in the Hereafter), and give good tidings to the believers (O Muhammad).\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And make not Allah's (Name) an excuse in your oaths against doing good and acting piously, and making peace among mankind. And Allah is All-Hearer, All-Knower (i.e., do not swear much and if you have sworn against doing something good then give an expiation for the oath and do good).\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah will not call you to account for that which is unintentional in your oaths, but He will call you to account for that which your hearts have earned. And Allah is Oft-Forgiving, Most-Forbearing.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
Those who take an oath not to have sexual relation with their wives must wait for four months, then if they return, verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they decide upon divorce, then Allah is All-Hearer, All-Knower.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
And divorced women shall wait (as regards their marriage) for three menstrual periods, and it is not lawful for them to conceal what Allah has created in their wombs, if they believe in Allah and the Last Day. And their husbands have the better right to take them back in that period, if they wish for reconciliation. And they (women) have rights (over their husbands as regards living expenses) similar (to those of their husbands) over them (as regards obedience and respect) to what is reasonable, but men have a degree (of responsibility) over them. And Allah is All-Mighty, All-Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
The divorce is twice, after that either you retain her on reasonable terms or release her with kindness. And it is not lawful for you (men) to take back (from your wives) any of what you gave them (the Mahr, bridal-money given by the husband to his wife at the time of marriage), except when both parties fear that they would be unable to keep the limits ordained by Allah (e.g., to deal with each other on a fair basis). Then if you fear that they would not be able to keep the limits ordained by Allah, then there is no sin on either of them if she gives back (the Mahr or a part of it). These are the limits ordained by Allah, so do not transgress them. And whoever transgresses the limits ordained by Allah, then such are the wrongdoers.\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
And if he has divorced her (the third time), then she is not lawful unto him thereafter until she has married another husband. Then, if the other husband divorces her, it is no sin on both of them that they reunite, provided they feel that they can keep the limits ordained by Allah. These are the limits of Allah, which He makes plain for the people who have knowledge.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
And when you have divorced women and they have fulfilled the term of their prescribed period, either take them back on a reasonable basis or set them free on a reasonable basis. But do not take them back to hurt them, and whoever does that, then he has wronged himself. And treat not the verses (Laws) of Allah in jest, but remember Allah's favors on you (i.e., Islam), and that which He has sent down to you of the Book (i.e., the Qur'an) and Al-Hikmah (the Prophet's Sunnah ـ legal ways ـ Islamic jurisprudence) whereby He instructs you. And fear Allah, and know that Allah is All-Aware of everything.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
And when you have divorced women and they have fulfilled the term of their prescribed period, do not prevent them from marrying their (former) husbands, if they mutually agree on reasonable basis. This (instruction) is an admonition for him among you who believes in Allah and the Last Day. That is more virtuous and purer for you. Allah knows and you know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
The mothers should suckle their children for two whole years, (that is) for those (parents) who desire to complete the term of suckling, but the father of the child shall bear the cost of the mother's food and clothing on a reasonable basis. No person shall have a burden laid on him greater than he can bear. No mother shall be treated unfairly on account of her child, nor father on account of his child. And on the (father's) heir is incumbent the like of that (which was incumbent on the father). If they both decide on weaning, by mutual consent, and after due consultation, there is no sin on them. And if you decide on a foster suckling-mother for your children, there is no sin on you, provided you pay (the mother) what you agreed (to give her) on a reasonable basis. And fear Allah and know that Allah is All-Seer of what you do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
And those of you who die and leave wives behind them, they (the wives) shall wait (as regards their marriage) for four months and ten days, then when they have fulfilled their term, there is no sin on you if they (the wives) dispose of themselves in a (just and) honorable manner (i.e., they can marry). And Allah is well-acquainted with what you do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
And there is no sin on you if you make a hint of betrothal or conceal it in yourself, Allah knows that you will remember them, but do not make a promise (of contract) with them in secret except that you speak an honorable saying. And do not be determined on the marriage bond until the term prescribed is fulfilled. And know that Allah knows what is in your minds, so fear Him. And know that Allah is Oft-Forgiving, Most Forbearing.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
There is no sin on you, if you divorce women while yet you have not touched them, nor appointed for them their due (dowry). But give them a Mut`ah (a suitable gift), the rich according to his means, and the poor according to his means, a gift of reasonable amount is a duty on the doers of good.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
And if you divorce them before you have touched (had a sexual relation with) them, and you have appointed for them their due (dowry), then pay half of that, unless they (the women) agree to remit it, or he (the husband), in whose hands is the marriage tie, agrees to remit it. And to remit is nearer to At-Taqwa (piety, righteousness). And do not forget liberality between yourselves. Truly, Allah is All-Seer of what you do.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Guard strictly (five obligatory) As-Salawat (the prayers) especially the Middle Salah. And stand before Allah with obedience.\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if you fear (an enemy), (perform Salah) on foot or riding. And when you are in safety, then remember Allah (pray) in the manner He has taught you, which you knew not (before).\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
And those of you who die and leave behind wives should bequeath for their wives a year's maintenance (and residence) without turning them out, but if they (wives) leave, there is no sin on you for that which they do of themselves, provided it is honorable (e.g., lawful marriage). And Allah is All-Mighty, All-Wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
And for divorced women, maintenance (should be provided) on reasonable (scale). This is a duty on Al-Muttaqin (the pious).\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Thus Allah makes clear His Ayat (Laws) to you, in order that you may understand.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Did you (O Muhammad) not think of those who went forth from their homes in the thousands, fearing death Allah said to them, ``Die". And then He restored them to life. Truly, Allah is full of bounty to mankind, but most men thank not.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
And fight in the way of Allah and know that Allah is All-Hearer, All-Knower.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is he that will lend to Allah a goodly loan so that He may multiply it to him many times And it is Allah that decreases or increases (your provisions), and unto Him you shall return.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Have you not thought about the group of the Children of Israel after (the time of) Musa When they said to a Prophet of theirs, ``Appoint for us a king and we will fight in Allah's way." He said, ``Would you then refrain from fighting, if fighting was prescribed for you" They said, ``Why should we not fight in Allah's way while we have been driven out of our homes and our children (families have been taken as captives)" But when fighting was ordered for them, they turned away, all except a few of them. And Allah is All-Aware of the wrongdoers.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
And their Prophet said to them, ``Indeed Allah has appointed Talut (Saul) as a king over you." They said, ``How can he be a king over us when we are fitter than him for the kingdom, and he has not been given enough wealth." He said: ``Verily, Allah has chosen him above you and has increased him abundantly in knowledge and stature. And Allah grants His kingdom to whom He wills. And Allah is All-Sufficient for His creatures' needs, All-Knower."\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their Prophet said to them: ``Verily! The sign of His kingdom is that there shall come to you At-Tabut, wherein is Sakinah (peace and reassurance) from your Lord and a remnant of that which Musa (Moses) and Harun (Aaron) left behind, carried by the angels. Verily, in this is a sign for you if you are indeed believers.\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
Then when Talut set out with the army, he said: ``Verily, Allah will try you by a river. So whoever drinks thereof, he is not of me; and whoever tastes it not, he is of me, except him who takes (thereof) in the hollow of his hand." Yet, they drank thereof, all, except a few of them. So when he had crossed it (the river), he and those who believed with him, they said: ``We have no power this day against Jalut (Goliath) and his hosts." But those who knew with certainty that they were going to meet Allah, said: ``How often has a small group overcome a mighty host by Allah's leave" And Allah is with As-Sabirin (the patient).\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they advanced to meet Jalut (Goliath) and his forces, they invoked: ``Our Lord! Pour forth on us patience, and set firm our feet and make us victorious over the disbelieving people."\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
So they routed them by Allah's leave and Dawud (David) killed Jalut (Goliath), and Allah gave him (Dawud) the kingdom [after the death of Talut and Samuel] and Al-Hikmah (prophethood), and taught him of that which He willed. And if Allah did not check one set of people by means of another, the earth would indeed be full of mischief. But Allah is full of bounty to the `Alamin (mankind, Jinn and all that exists).\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the verses of Allah, We recite them to you (O Muhammad) in truth, and surely, you are one of the Messengers (of Allah).\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
Those Messengers! We preferred some of them to others; to some of them Allah spoke (directly); others He raised to degrees (of honor); and to `Isa, the son of Maryam, We gave clear proofs and evidences, and supported him with Ruh-il-Qudus [Jibril]. If Allah had willed, succeeding generations would not have fought against each other, after clear Verses of Allah had come to them, but they differed ـ some of them believed and others disbelieved. If Allah had willed, they would not have fought against one another, but Allah does what He wills.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O you who believe! Spend of that with which We have provided for you, before a Day comes when there will be no bargaining, nor friendship, nor intercession. And it is the disbelievers who are the wrongdoers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah! None has the right to be worshipped but He, the Ever Living, the One Who sustains and protects all that exists. Neither slumber nor sleep overtakes Him. To Him belongs whatever is in the heavens and whatever is on the earth. Who is he that can intercede with Him except with His permission He knows what happens to them (His creatures) in this world, and what will happen to them in the Hereafter. And they will never compass anything of His Knowledge except that which He wills. His Kursi extends over the heavens and the earth, and He feels no fatigue in guarding and preserving them. And He is the Most High, the Most Great.\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There is no compulsion in religion. Verily, the right path has become distinct from the wrong path. Whoever disbelieves in Taghut and believes in Allah, then he has grasped the most trustworthy handhold that will never break. And Allah is All-Hearer, All-Knower.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the Wali (Protector or Guardian) of those who believe. He brings them out from darknesses into light. But as for those who disbelieve, their Awliya' (supporters and helpers) are Taghut (false deities and false leaders), they bring them out from light into darknesses. Those are the dwellers of the Fire, and they will abide therein forever.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Have you not looked at him who disputed with Ibrahim about his Lord (Allah), because Allah had given him the kingdom When Ibrahim said (to him): ``My Lord is He Who gives life and causes death." He said, ``I give life and cause death." Ibrahim said, ``Verily, Allah brings the sun from the east; then bring it you from the west." So the disbeliever was utterly defeated. And Allah guides not the people, who are wrongdoers.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or like the one who passed by a town in ruin up to its roofs. He said: ``How will Allah ever bring it to life after its death" So Allah caused him to die for a hundred years, then raised him up (again). He said: ``How long did you remain (dead)" He (the man) said: ``(Perhaps) I remained (dead) a day or part of a day." He said: ``Nay, you have remained (dead) for a hundred years, look at your food and your drink, they show no change; and look at your donkey! And thus We have made of you a sign for the people. Look at the bones, how We bring them together and clothe them with flesh." When this was clearly shown to him, he said, ``I know (now) that Allah is able to do all things."\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And (remember) when Ibrahim said, ``My Lord! Show me how You give life to the dead." He (Allah) said: ``Do you not believe" He (Ibrahim) said: ``Yes (I believe), but to be stronger in faith." He said: ``Take four birds, then cause them to incline towards you (then slaughter them, cut them into pieces), and then put a portion of them on every hill, and call them, they will come to you in haste. And know that Allah is All-Mighty, All-Wise."\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The parable of those who spend their wealth in the way of Allah, is that of a grain (of corn); it grows seven ears, and each ear has a hundred grains. Allah gives manifold increase to whom He wills. And Allah is All-Sufficient for His creatures' needs, All-Knower.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth in the cause of Allah, and do not follow up their gifts with reminders of their generosity or with injury, their reward is with their Lord. On them shall be no fear, nor shall they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
Kind words and forgiving of faults are better than Sadaqah (charity) followed by injury. And Allah is Rich (free of all needs) and He is Most Forbearing.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O you who believe! Do not render in vain your Sadaqah (charity) by reminders of your generosity or by injury, like him who spends his wealth to be seen of men, and he does not believe in Allah, nor in the Last Day. His likeness is the likeness of a smooth rock on which is a little dust; on it falls heavy rain which leaves it bare. They are not able to do anything with what they have earned. And Allah does not guide the disbelieving people.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the parable of those who spend their wealth seeking Allah's pleasure while they in their own selves are sure and certain that Allah will reward them (for their spending in His cause), is that of a garden on a height; heavy rain falls on it and it doubles its yield of harvest. And if it does not receive heavy rain, light rain suffices it. And Allah is All-Seer (knows well) of what you do.) This is the example of the believers who give away charity seeking only Allah's pleasure,\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would any of you wish to have a garden with date palms and vines, with rivers flowing underneath, and all kinds of fruits for him therein, while he is striken with old age, and his children are weak (not able to look after themselves), then it is struck with a fiery whirlwind, so that it is burnt Thus does Allah make clear His Ayat to you that you may give thought.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O you who believe! Spend of the good things which you have (legally) earned, and of that which We have produced from the earth for you, and do not aim at that which is bad to spend from it, (though) you would not accept it save if you close your eyes and tolerate therein. And know that Allah is Rich (free of all needs), and worthy of all praise.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Shaytan threatens you with poverty and orders you to commit Fahsha' (evil deeds) whereas Allah promises you forgiveness from Himself and bounty, and Allah is All-Sufficient for His creatures' needs, All-Knower.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He grants Hikmah to whom He wills, and he, to whom Hikmah is granted, is indeed granted abundant good. But none remember (will receive admonition) except men of understanding.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever you spend for spendings (e.g., in Sadaqah) or whatever vow you make, be sure Allah knows it all. And for the wrongdoers there are no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you disclose your Sadaqat (almsgiving), it is well; but if you conceal them and give them to the poor, that is better for you. (Allah) will expiate you some of your sins. And Allah is Well-Acquainted with what you do.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
Not upon you (Muhammad) is their guidance, but Allah guides whom He wills. And whatever you spend in good, it is for yourselves, when you spend not except seeking Allah's Face. And whatever you spend in good, it will be repaid to you in full, and you shall not be wronged.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
(Charity is) for Fuqara' (the poor), who in Allah's cause are restricted (from travel), and cannot move about in the land (for trade or work). The one who knows them not, thinks that they are rich because of their modesty. You may know them by their mark, they do not beg of people at all. And whatever you spend in good, surely Allah knows it well.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth (in Allah's cause) by night and day, in secret and in public, they shall have their reward with their Lord. On them shall be no fear, nor shall they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who eat Riba will not stand (on the Day of Resurrection) except like the standing of a person beaten by Shaytan leading him to insanity. That is because they say: ``Trading is only like Riba," whereas Allah has permitted trading and forbidden Riba. So whosoever receives an admonition from his Lord and stops eating Riba, shall not be punished for the past; his case is for Allah (to judge); but whoever returns (to Riba), such are the dwellers of the Fire ـ they will Abide therein.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah will destroy Riba and will give increase for Sadaqat. And Allah likes not the disbelievers, sinners.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Truly, those who believe, and do deeds of righteousness, and perform the Salah and give Zakah, they will have their reward with their Lord. On them shall be no fear, nor shall they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O you who believe! Have Taqwa of Allah and give up what remains from Riba, if you are (really) believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
And if you do not do it, then take a notice of war from Allah and His Messenger but if you repent, you shall have your capital sums. Deal not unjustly, and you shall not be dealt with unjustly.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if the debtor is having a hard time, then grant him time till it is easy for him to repay; but if you remit it by way of charity, that is better for you if you did but know.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And have Taqwa the Day when you shall be brought back to Allah. Then every person shall be paid what he earned, and they shall not be dealt with unjustly.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O you who believe! When you contract a debt for a fixed period, write it down. Let a scribe write it down in justice between you. Let not the scribe refuse to write, as Allah has taught him, so let him write. Let him (the debtor) who incurs the liability dictate, and he must have Taqwa of Allah, his Lord, and diminish not anything of what he owes. But if the debtor is of poor understanding, or weak, or is unable to dictate for himself, then let his guardian dictate in justice. And get two witnesses out of your own men. And if there are not two men (available), then a man and two women, such as you agree for witnesses, so that if one of them (two women) errs, the other can remind her. And the witnesses should not refuse when they are called (for evidence). You should not become weary to write it (your contract), whether it be small or big, for its fixed term, that is more just with Allah; more solid as evidence, and more convenient to prevent doubts among yourselves, save when it is a present trade which you carry out on the spot among yourselves, then there is no sin on you if you do not write it down. But take witnesses whenever you make a commercial contract. Let neither scribe nor witness suffer any harm, but if you do (such harm), it would be wickedness in you. So have Taqwa of Allah; and Allah teaches you. And Allah is the All-Knower of everything.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
And if you are on a journey and cannot find a scribe, then let there be a pledge taken (mortgaging), then if one of you entrusts the other, let the one who is entrusted discharge his trust, and let him have Taqwa of Allah, his Lord. And conceal not the evidence, for he who hides it, surely, his heart is sinful. And Allah is All-Knower of what you do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah belongs all that is in the heavens and all that is on the earth, and whether you disclose what is in yourselves or conceal it, Allah will call you to account for it. Then He forgives whom He wills and punishes whom He wills. And Allah is able to do all things.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger believes in what has been sent down to him from his Lord, and (so do) the believers. Each one believes in Allah, His Angels, His Books, and His Messengers. (They say,) ``We make no distinction between one another of His Messengers ـ and they say, ``We hear, and we obey. (We seek) Your forgiveness, our Lord, and to You is the return (of all)."\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah burdens not a person beyond his scope. He gets reward for that (good) which he has earned, and he is punished for that (evil) which he has earned. ``Our Lord! Punish us not if we forget or fall into error, our Lord! Lay not on us a burden like that which You did lay on those before us (Jews and Christians); our Lord! Put not on us a burden greater than we have strength to bear. Pardon us and grant us forgiveness. Have mercy on us. You are our Mawla (Patron, Supporter and Protector) and give us victory over the disbelieving people.") The Hadiths on the Virtue of These Two Ayat, May Allah Benefit Us by Them Al-Bukhari recorded that Abu Mas`ud said that the Messenger of Allah said,\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif-Lam-Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah! None has the right to be worshipped but He, the Ever Living, the One Who sustains and protects all that exists.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
It is He Who has sent down the Book to you with truth, confirming what came before it. And He sent down the Tawrah and the Injil,\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Aforetime, as a guidance to mankind. And He sent down the criterion. Truly, those who disbelieve in the Ayat of Allah, for them there is a severe torment; and Allah is All-Mighty, All-Able of Retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Truly, nothing is hidden from Allah, in the earth or in the heaven.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
He it is Who shapes you in the wombs as He wills. None has the right to be worshipped but He, the Almighty, the All-Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He Who has sent down to you the Book. In it are verses that are entirely clear, they are the foundations of the Book; and others not entirely clear. So as for those in whose hearts there is a deviation (from the truth) they follow (only) that which is not entirely clear thereof, seeking Al-Fitnah, and seeking its Ta'wil, but none knows its Ta'wil except Allah. And those who are firmly grounded in knowledge say: ``We believe in it; all of it is from our Lord." And none receive admonition except men of understanding.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
(They say): ``Our Lord! Let not our hearts deviate (from the truth) after You have guided us, and grant us mercy from You. Truly, You are the Bestower."\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
``Our Lord! Verily, it is You Who will gather mankind together on the Day about which there is no doubt. Verily, Allah never breaks His Promise."\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
Verily, those who disbelieve, neither their properties nor their offspring will avail them whatsoever against Allah; and it is they who will be fuel of the Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
Like the behavior of the people of Fir`awn and those before them; they belied Our Ayat. So Allah punished them for their sins. And Allah is severe in punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say to those who disbelieve: ``You will be defeated and gathered together to Hell, and worst indeed is that place of rest."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
There has already been a sign for you in the two armies that met. One was fighting in the cause of Allah, and as for the other, in disbelief. They saw them with their own eyes twice their number. And Allah supports with His aid whom He wills. Verily, in this is a lesson for those who understand.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Beautified for men is the love of things they covet; women, children, Qanatir Al-Muqantarah of gold and silver, branded beautiful horses (Musawwamah), cattle and fertile land. This is the pleasure of the present world's life; but Allah has the excellent return with Him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say: ``Shall I inform you of things far better than those For those who have Taqwa there are Gardens (Paradise) with their Lord, underneath which rivers flow. Therein (is their) eternal (home) and Azwajun Mutahharatun (purified mates or wives). And Allah will be pleased with them. And Allah is All-Seer of the servants."\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say: ``Our Lord! We have indeed believed, so forgive us our sins and save us from the punishment of the Fire."\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
(They are) the patient, the true believers, and obedient with sincere devotion in worship to Allah. Those who spend [in good] and those who pray and beg Allah's pardon in the last hours of the night.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah bears witness that none has the right to be worshipped but He, and the angels, and those having knowledge (also bear witness to this); (He always) maintains His creation in justice. None has the right to be worshipped but He, the Almighty, the All-Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
Truly, the religion with Allah is Islam. Those who were given the Scripture (Jews and Christians) did not differ except out of rivalry, after knowledge had come to them. And whoever disbelieves in the Ayat of Allah, then surely, Allah is Swift in reckoning.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
So if they dispute with you say: ``I have submitted myself to Allah, and (so have) those who follow me." And say to those who were given the Scripture (Jews and Christians) and to those who are illiterate (Arab pagans): ``Do you (also) submit yourselves" If they do, they are rightly guided; but if they turn away, your duty is only to convey the Message; and Allah sees the servants.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Verily, those who disbelieve in the Ayat of Allah and kill the Prophets without right, and kill those men who order just dealings, then announce to them a painful torment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
They are those whose works will be lost in this world and in the Hereafter, and they will have no helpers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Have you not seen those who have been given a portion of the Scripture They are being invited to the Book of Allah to settle their dispute, then a party of them turned away, and they are averse.\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
This is because they say: ``The Fire shall not touch us but for a number of days." And that which they used to invent in their religion has deceived them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
How (will it be) when We gather them together on the Day about which there is no doubt (i.e. the Day of Resurrection). And each person will be paid in full what he has earned And they will not be dealt with unjustly.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say: ``O Allah! Possessor of the power, You give power to whom You will, and You take power from whom You will, and You endue with honor whom You will, and You humiliate whom You will. In Your Hand is the good. Verily, You are able to do all things.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
You make the night to enter into the day, and You make the day to enter into the night, You bring the living out of the dead, and You bring the dead out of the living. And You give wealth and sustenance to whom You will, without limit.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not the believers take the disbelievers as friends instead of the believers, and whoever does that, will never be helped by Allah in any way, unless you indeed fear a danger from them. And Allah warns you against Himself, and to Allah is the final return.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say: ``Whether you hide what is in your breasts or reveal it, Allah knows it, and He knows what is in the heavens and what is in the earth. And Allah is able to do all things."\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
On the Day when every person will be confronted with the good he has done, and all the evil he has done, he will wish that there were a great distance between him and his evil. And Allah warns you against Himself and Allah is full of kindness with the servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say (O Muhammad to mankind): ``If you (really) love Allah, then follow me (i.e. Muhammad), Allah will love you and forgive you your sins. And Allah is Oft-Forgiving, Most Merciful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say: ``Obey Allah and the Messenger." But if they turn away, then Allah does not like the disbelievers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Allah chose Adam, Nuh (Noah), the family of Ibrahim and the family of `Imran above the nations.\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
Offspring, one of the other, and Allah is All-Hearer, All-Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
(Remember) when the wife of `Imran said: ``O my Lord! I have vowed to You what is in my womb to be dedicated for Your services, so accept this from me. Verily, You are the All-Hearer, the All-Knowing."\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
Then when she gave birth to her, she said: ``O my Lord! I have given birth to a female child, ـ and Allah knew better what she bore, ـ ``And the male is not like the female, and I have named her Maryam, and I seek refuge with You for her and for her offspring from Shaytan, the outcast."\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
So her Lord (Allah) accepted her with goodly acceptance. He made her grow in a good manner and put her under the care of Zakariyya. Every time he entered the Mihrab to (visit) her, he found her supplied with sustenance. He said: ``O Maryam! From where have you gotten this" She said, ``This is from Allah." Verily, Allah provides sustenance to whom He wills, without limit.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
At that time Zakariyya invoked his Lord, saying: ``O my Lord! Grant me from You, a good offspring. You are indeed the All-Hearer of invocation."\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
Then the angels called him, while he was standing in prayer in the Mihrab, (saying): ``Allah gives you glad tidings of Yahya, believing in the Word from Allah, and Sayyidan, and Hasuran, a Prophet, from among the righteous."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said: ``O my Lord! How can I have a son when I am very old, and my wife is barren" (Allah) said: ``Thus Allah does what He wills."\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said: ``O my Lord! Make a sign for me." (Allah) said: ``Your sign is that you shall not speak to the people for three days except by signals. And remember your Lord much, and glorify (Him) in the afternoon and in the morning."\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And (remember) when the angels said: ``O Maryam! Verily, Allah has chosen you, purified you, and chosen you above the women of the nations."\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
``O Maryam! Submit yourself with obedience (Aqnuti) to your Lord and prostrate yourself, and bow down along with Ar-Raki`in."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
This is a part of the news of the Ghayb (Unseen) which We reveal to you. You were not with them, when they cast lots with their pens as to which of them should be charged with the care of Maryam; nor were you with them when they disputed.\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
(Remember) when the angels said: ``O Maryam! Verily, Allah gives you the glad tidings of a Word from Him, his name will be Al-Masih, `Isa, the son of Maryam, held in honor in this world and in the Hereafter, and he will be one of those who are near to Allah."\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
``He will speak to the people, in the cradle and in manhood, and he will be one of the righteous."\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said: ``O my Lord! How shall I have a son when no man has touched me." He said: ``So (it will be) for Allah creates what He wills. When He has decreed something, He says to it only: `Be! ـ and it is."\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He will teach him the Book and Al-Hikmah, and the Tawrah and the Injil.\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
And will make him a Messenger to the Children of Israel (saying): ``I have come to you with a sign from your Lord, that I design for you out of clay, a figure like that of a bird, and breathe into it, and it becomes a bird by Allah's leave; and I heal the blind, and the leper, and I bring the dead to life by Allah's leave. And I inform you of what you eat, and what you store in your houses. Surely, therein is a sign for you, if you believe."\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
``(And I have come) confirming that which was before me of the Tawrah, and to make lawful to you part of what was forbidden to you, and I have come to you with a proof from your Lord. So have Taqwa of Allah and obey me."\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
``Truly, Allah is my Lord and your Lord, so worship Him (Alone). This is the straight path."\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
Then when `Isa came to know of their disbelief, he said: ``Who will be my helpers in Allah's cause" Al-Hawariyyun said: ``We are the helpers of Allah; we believe in Allah, and bear witness that we are Muslims."\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
``Our Lord! We believe in what You have sent down, and we follow the Messenger [`Isa]; so write us down among those who bear witness."\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And they (disbelievers) plotted and Allah planned too. And Allah is the Best of those who plot\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
And (remember) when Allah said: ``O `Isa! I will take you and raise you to Myself and purify [save] you from those who disbelieve, and I will make those who follow you superior to those who disbelieve till the Day of Resurrection. Then you will return to Me and I will judge between you in the matters in which you used to dispute."\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
``As to those who disbelieve, I will punish them with severe torment in this world and in the Hereafter, and they will have no helpers."\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
And as for those who believe and do righteous good deeds, Allah will pay them their reward in full. And Allah does not like the wrongdoers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This is what We recite to you of the verses and the Wise Reminder.\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
Verily, the likeness of `Isa before Allah is the likeness of Adam. He created him from dust, then said to him: ``Be!" and he was.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
(This is) the truth from your Lord, so be not of those who doubt.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
Then whoever disputes with you concerning him after the knowledge that has come to you, say: ``Come, let us call our sons and your sons, our women and your women, ourselves and yourselves, then we pray and we invoke Allah's curse upon the liars."\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
Verily, this is the true narrative, and there is no god except Allah. And indeed, Allah is the Almighty, the All-Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
And if they turn away, then surely, Allah is All-Aware of those who do mischief.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say: ``O people of the Scripture: Come to a word that is just between us and you, that we worship none but Allah the same, and that we associate no partners with Him, and that none of us shall take others as lords besides Allah." Then, if they turn away, say: ``Bear witness that we are Muslims."\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O people of the Scripture! Why do you dispute about Ibrahim, while the Tawrah and the Injil were not revealed till after him Have you then no sense\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Verily, you are those who have disputed about that of which you have knowledge. Why do you then dispute concerning that of which you have no knowledge It is Allah Who knows, and you know not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Ibrahim was neither a Jew nor a Christian, but he was a true Muslim Hanifa and he was not of the Mushrikin\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Verily, among mankind who have the best claim to Ibrahim are those who followed him, and this Prophet and those who have believed. And Allah is the Wali (Protector and Helper) of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A party of the People of the Scripture wish to lead you astray. But they shall not lead astray anyone except themselves, and they perceive not.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
``O People of the Scripture! Why do you disbelieve in the Ayat of Allah, while you bear witness."\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
``O People of the Scripture! Why do you mix truth with falsehood and conceal the truth while you know"\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
And a party of the People of the Scripture say: ``Believe in the morning in that which is revealed to the believers, and reject it at the end of the day, so that they may turn back.\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
And believe no one except the one who follows your religion." Say (O Prophet): ``Verily, right guidance is the guidance of Allah." (And they say:) ``Do not believe that anyone can receive like that which you have received, otherwise they would engage you in argument before your Lord." Say: ``All the bounty is in the Hand of Allah; He grants to whom He wills. And Allah is All-Sufficient for His creatures' needs, All-Knower."\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He selects for His Mercy whom He wills and Allah is the Owner of great bounty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
Among the People of the Scripture is he who, if entrusted with a Qintar (a great amount of wealth), will readily pay it back; and among them there is he who, if entrusted with a single silver coin, will not repay it unless you constantly stand demanding, because they say: ``There is no blame on us to betray and take the properties of the illiterates (Arabs)." But they tell a lie against Allah while they know it.\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
Yes, whoever fulfills his pledge and fears Allah much; verily, then Allah loves the Muttaqin (the pious).\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Verily, those who purchase a small gain at the cost of Allah's covenant and their oaths, they shall have no portion in the Hereafter (Paradise). Neither will Allah speak to them nor look at them on the Day of Resurrection, nor will He purify them, and they shall have a painful torment.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And verily, among them is a party who distort the Book with their tongues, so that you may think it is from the Book, but it is not from the Book, and they say: This is from Alla0h, but it is not from Alla0h؛ and they speak a lie against Alla0h while they know it.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not (possible) for any human being to whom Allah has given the Book and Al-Hukm and prophethood to say to the people: ``Be my worshippers rather than Allah's." On the contrary (he would say): ``Be you Rabbaniyyun, because you are teaching the Book, and you are studying it."\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
Nor would he order you to take angels and Prophets for lords. Would he order you to disbelieve after you have submitted to Allah's will\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And (remember) when Allah took the covenant of the Prophets, saying: ``Take whatever I gave you from the Book and Hikmah, and afterwards there will come to you a Messenger confirming what is with you; you must, then, believe in him and help him." Allah said: ``Do you agree (to it) and will you take up Isri" They said: ``We agree." He said: ``Then bear witness; and I am with you among the witnesses."\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
Then whoever turns away after this, they are the rebellious.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
Do they seek other than the religion of Allah, while to Him submitted all creatures in the heavens and the earth, willingly or unwillingly. And to Him shall they all be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say: ``We believe in Allah and in what has been sent down to us, and what was sent down to Ibrahim, Isma`il, Ishaq, Ya`qub and Al-Asbat, and what was given to Musa, `Isa and the Prophets from their Lord. We make no distinction between one another among them and to Him (Allah) we have submitted."\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And whoever seeks a religion other than Islam, it will never be accepted of him, and in the Hereafter he will be one of the losers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah guide a people who disbelieved after their belief and after they bore witness that the Messenger is true and after clear proofs came to them And Allah guides not the people who are wrongdoers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
They are those whose recompense is that on them (rests) the curse of Allah, of the angels and of all mankind.\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
They will abide therein. Neither will their torment be lightened nor will it be delayed or postponed.\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except for those who repent after that and do righteous deeds. Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Verily, those who disbelieved after their belief and then went on increasing in their disbelief never will their repentance be accepted. And they are those who are astray.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Verily, those who disbelieved, and died while they were disbelievers, the (whole) earth full of gold will not be accepted from anyone of them if they offered it as a ransom. For them is a painful torment and they will have no helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
By no means shall you attain Al-Birr, unless you spend of that which you love; and whatever of good you spend, Allah knows it well.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful to the Children of Israel, except what Isra'il made unlawful for himself before the Tawrah was revealed. Say: ``Bring here the Tawrah and recite it, if you are truthful. ``\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
Then after that, whosoever shall invent a lie against Allah, then it is these that are the wrongdoers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say:"Allah has spoken the truth; follow the religion of Ibrahim the Hanif (monotheist), and he was not of the Mushrikin (idolators)."\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Verily, the first House (of worship) appointed for mankind was that at Bakkah (Makkah), full of blessing, and a guidance for Al-`Alamin (mankind and Jinn).\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it are manifest signs (for example), the Maqam (station) of Ibrahim; whosoever enters it, he attains security. And Hajj to the House is a duty that mankind owes to Allah, for those who are able to undertake the journey; and whoever disbelieves, then Allah stands not in need of any of the `Alamin.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say: ``O People of the Scripture (Jews and Christians)! Why do you reject the Ayat of Allah, while Allah is Witness to what you do"\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say: ``O People of the Scripture (Jews and Christians)! Why do you stop those who have believed, from the path of Allah, seeking to make it seem crooked, while you (yourselves) are witnesses And Allah is not unaware of what you do."\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O you who believe! If you obey a group of those who were given the Scripture (Jews and Christians), they would (indeed) render you disbelievers after you have believed!\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
And how would you disbelieve, while unto you are recited the verses of Allah, and among you is His Messenger And whoever depends upon Allah, then he is indeed guided to the right path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O you who believe! Have Taqwa of Allah as is His due, and die not except as (true) Muslims.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold fast, all of you together, to the Rope of Allah, and be not divided among yourselves, and remember Allah's favor on you, for you were enemies of one another but He joined your hearts together, so that, by His grace, you became brethren, and you were on the brink of a pit of Fire, and He saved you from it. Thus Allah makes His Ayat clear to you, that you may be guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
Let there arise out of you a group of people inviting to all that is good (Islam), enjoining Al-Ma`ruf (all that Islam orders) and forbidding Al-Munkar (all that Islam has forbidden). And it is they who are the successful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And be not as those who divided and differed among themselves after the clear proofs had come to them. It is they for whom there is an awful torment.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day (i.e. the Day of Resurrection) when some faces will become white and some faces will become black; as for those whose faces will become black (to them will be said): ``Did you reject faith after accepting it Then taste the torment (in Hell) for rejecting faith."\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
And for those whose faces will become white, they will be in Allah's mercy (Paradise), therein they shall dwell forever.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the Ayat of Allah. We recite them to you in truth, and Allah wills no injustice to the `Alamin.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
And to Allah belongs all that is in the heavens and all that is in the earth. And all matters go back (for decision) to Allah.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are the best of peoples ever raised up for mankind; you enjoin Al-Ma`ruf (all that Islam has ordained) and forbid Al-Munkar (all that Islam has forbidden), and you believe in Allah. And had the People of the Scripture (Jews and Christians) believed, it would have been better for them; among them are some who have faith, but most of them are Fasiqun (rebellious).\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will do you no harm, barring a trifling annoyance; and if they fight against you, they will show you their backs, and they will not be helped.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
They are stricken with humility wherever they may be, except when under a covenant (of protection) from Allah, and a covenant from men; they have drawn on themselves the wrath of Allah, and destitution is put over them. This is because they disbelieved in the Ayat of Allah and killed the Prophets without right. This is because they disobeyed (Allah) and used to transgress (the limits set by Allah).\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
Not all of them are alike; a party of the People of the Scripture stand for the right, they recite the verses of Allah during the hours of the night, prostrating themselves in prayer.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in Allah and the Last Day; they enjoin Al-Ma`ruf and forbid Al-Munkar; and they hasten in (all) good works; and they are among the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
And whatever good they do, nothing will be rejected of them; for Allah knows well the Muttaqin (the pious).\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
Surely, those who disbelieve, neither their properties nor their offspring will avail them against Allah. They are the dwellers of the Fire, therein they will abide.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The parable of what they spend in this world is that of a wind of Sir; it struck the harvest of a people who did wrong against themselves and destroyed it. Allah wronged them not, but they wronged themselves.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O you who believe! Take not as (your) Bitanah (advisors, helpers) those other than your own, since they will not fail to do their best to corrupt you. They desire to harm you severely. Hatred has already appeared from their mouths, but what their breasts conceal is far worse. Indeed We have made plain to you the Ayat if you understand.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Lo! You are the ones who love them but they love you not, and you believe in all the Scriptures. And when they meet you, they say, ``We believe." But when they are alone, they bite their Anamil at you in rage. Say: ``Perish in your rage. Certainly, Allah knows what is in the breasts (all the secrets). ``\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If a good befalls you, it grieves them, but if some evil overtakes you, they rejoice at it. But if you remain patient and have Taqwa, not the least harm will their cunning do to you. Surely, Allah surrounds all that they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And (remember) when you left your household in the morning to post the believers at their stations for the battle (of Uhud). And Allah is All-Hearer, All-Knower.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
When two parties from among you were about to lose heart, but Allah was their Wali (Supporter and Protector). And in Allah should the believers put their trust.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
And Allah has already made you victorious at Badr, when you were a weak little force. So have Taqwa of Allah that you may be grateful.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
(Remember) when you said to the believers, ``Is it not enough for you that your Lord should help you with three thousand angels sent down"\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
``But, if you hold on to patience and have Taqwa, and the enemy comes rushing at you; your Lord will help you with five thousand angels having marks (of distinction)."\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
Allah made it not but as a message of good news for you and as an assurance to your hearts. And there is no victory except from Allah, the All-Mighty, the All-Wise.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
That He might cut off a part of those who disbelieve, or expose them to infamy, so that they retire frustrated.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
Not for you is the decision; whether He turns in mercy to (pardon) them or punishes them; verily, they are the wrongdoers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
And to Allah belongs all that is in the heavens and all that is in the earth. He forgives whom He wills, and punishes whom He wills. And Allah is Oft-Forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O you who believe! Do not consume Riba doubled and multiplied, but fear Allah that you may be successful.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And fear the Fire, which is prepared for the disbelievers.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the Messenger that you may obtain mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And march forth in the way (which leads to) forgiveness from your Lord, and for Paradise as wide as the heavens and the earth, prepared for the Muttaqin (the pious).\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Those who spend (in Allah's cause) in prosperity and in adversity, who repress anger, and who pardon men; verily, Allah loves the Muhsinin (the good-doers).\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, when they have committed Fahishah (immoral sin) or wronged themselves with evil, remember Allah and ask forgiveness for their sins; and none can forgive sins but Allah, and do not persist in what (wrong) they have done, while they know.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
For such, the reward is forgiveness from their Lord, and Gardens with rivers flowing underneath (Paradise), wherein they shall abide forever. How excellent is this reward for the doers (of good).\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Many similar ways (and mishaps of life) were faced [by nations (believers and disbelievers) that have passed away] before you, so travel through the earth, and see what was the end of those who denied.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This is a plain statement for mankind, a guidance and instruction for the Muttaqin.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
So do not become weak, nor be sad, and you will be triumphant if you are indeed believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound has touched you, be sure a similar wound has touched the others. And so are the days, that We give to men by turns, that Allah may know (test) those who believe, and that He may take martyrs from among you. And Allah likes not the wrongdoers.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
And that Allah may test those who believe and destroy the disbelievers..\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Do you think that you will enter Paradise before Allah knows (tests) those of you who performed Jihad and knows (tests) those who are patient\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
You did indeed wish for death before you met it. Now you have seen it openly with your own eyes.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is no more than a Messenger, and indeed Messengers have passed away before him. If he dies or is killed, will you then turn back on your heels And he who turns back on his heels, not the least harm will he do to Allah; and Allah will reward the grateful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
And no person can ever die except by Allah's leave and at an appointed term. And whoever desires a reward in the world, We shall give him of it; and whoever desires a reward in the Hereafter, We shall give him thereof. And We shall reward the grateful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
And many a Prophet fought and along with him many Ribbiyyun. But they never lost heart for that which befall them in Allah's way, nor did nor they weaken nor degrade themselves. And Allah loves the patient.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
And they said nothing but: ``Our Lord! Forgive us our sins and our transgressions, establish our feet firmly, and give us victory over the disbelieving folk."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
So Allah gave them the reward of this world, and the excellent reward of the Hereafter. And Allah loves the good-doers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O you who believe! If you obey those who disbelieve, they will send you back on your heels, and you will turn back as losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
Nay, Allah is your protector, and He is the best of helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We shall cast terror into the hearts of those who disbelieve, because they joined others in worship with Allah, for which He sent no authority; their abode will be the Fire and how evil is the abode of the wrongdoers.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
And Allah did indeed fulfill His promise to you when you were killing them (your enemy) with His permission; until Fashiltum and fell to disputing about the order, and disobeyed after He showed you what you love. Among you are some that desire this world and some that desire the Hereafter. Then He made you flee from them, that He might test you. But surely, He forgave you, and Allah is Most Gracious to the believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
(And remember) when you ran away without even casting a side glance at anyone, and the Messenger was in your rear calling you back. There did Allah give you one distress after another by way of requital, to teach you not to grieve for that which had escaped you, nor for what struck you. And Allah is Well-Aware of all that you do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then after the distress, He sent down security for you. Slumber overtook a party of you, while another party was thinking about themselves and thought wrongly of Allah -- the thought of ignorance. They said, ``Have we any part in the affair" Say: ``Indeed the affair belongs wholly to Allah." They hide within themselves what they dare not reveal to you, saying: ``If we had anything to do with the affair, none of us would have been killed here." Say: ``Even if you had remained in your homes, those for whom death was decreed would certainly have gone forth to the place of their death," but that Allah might test what is in your breasts; and to purify that which was in your hearts (sins), and Allah is All-Knower of what is in the breasts.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Those of you who turned back on the day the two hosts met, Shaytan only caused them to err because of some of what they had earned. But Allah, indeed, has forgiven them. Surely, Allah is Oft-Forgiving, Most Forbearing.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O you who believe! Be not like those who disbelieve and who say to their brethren when they travel through the earth or go out to fight: ``If they had stayed with us, they would not have died or been killed," so that Allah may make it a cause of regret in their hearts. It is Allah that gives life and causes death. And Allah is All-Seer of what you do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
And if you are killed or die in the way of Allah, forgiveness and mercy from Allah are far better than all that they amass.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
And whether you die or are killed, verily, unto Allah you shall be gathered.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
And by the mercy of Allah, you dealt with them gently. And had you been severe and harsh-hearted, they would have broken away from about you; so pardon them, and ask forgiveness for them; and consult them in the affairs. Then when you have taken a decision, put your trust in Allah, certainly, Allah loves those who put their trust (in Him).\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah helps you, none can overcome you; and if He forsakes you, who is there after Him that can help you And in Allah (Alone) let believers put their trust.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not for any Prophet to illegally take a part of the booty, and whosoever deceives his companions over the booty, he shall bring forth on the Day of Resurrection that which he took. Then every person shall be paid in full what he has earned, and they shall not be dealt with unjustly.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
Is then one who follows (seeks) the pleasure of Allah like the one who draws on himself the wrath of Allah His abode is Hell, and worse indeed is that destination!\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are in varying grades with Allah, and Allah is All-Seer of what they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Indeed, Allah conferred a great favor on the believers when He sent among them a Messenger from among themselves, reciting unto them His verses (the Qur'an), and purifying them, and instructing them (in) the Book (the Qur'an) and Al-Hikmah [the wisdom and the Sunnah], while before that they had been in manifest error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
(What is the matter with you) When a single disaster smites you, although you smote (your enemies) with one twice as great, you say: ``From where does this come to us" Say, ``It is from yourselves." And Allah has power over all things.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
And what you suffered on the day the two armies met, was by the leave of Allah, in order that He might test the believers.\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And that He might test the hypocrites, it was said to them: ``Come, fight in the way of Allah or defend yourselves." They said: ``Had we known that fighting will take place, we would certainly have followed you." They were that day, nearer to disbelief than to faith, saying with their mouths what was not in their hearts. And Allah has full knowledge of what they conceal.\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
(They are) the ones who said about their killed brethren while they themselves sat (at home): ``If only they had listened to us, they would not have been killed." Say: ``Avert death from your own selves, if you speak the truth."\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
Think not of those as dead who are killed in the way of Allah. Nay, they are alive, with their Lord, and they have provision.\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
They rejoice in what Allah has bestowed upon them of His bounty and rejoice for the sake of those who have not yet joined them, but are left behind (not yet martyred) that on them no fear shall come, nor shall they grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They rejoice in a grace and a bounty from Allah, and that Allah will not waste the reward of the believers.\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those who answered (the Call of) Allah and the Messenger after being wounded; for those of them who did good deeds and feared Allah, there is a great reward.\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those to whom the people said, ``Verily, the people have gathered against you, therefore, fear them." But it (only) increased them in faith, and they said: ``Allah is Sufficient for us, and He is the Best Disposer of affairs."\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with grace and bounty from Allah. No harm touched them; and they followed the pleasure of Allah. And Allah is the Owner of great bounty.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
It is only Shaytan that suggests to you the fear of his friends; so fear them not, but fear Me, if you are indeed believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
And let not those grieve you who rush with haste to disbelieve; verily, not the least harm will they do to Allah. It is Allah's will to give them no portion in the Hereafter. For them there is a great torment.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Verily, those who purchase disbelief at the price of faith, not the least harm will they do to Allah. For them, there is a painful torment.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And let not the disbelievers think that Our postponing their punishment is good for them. We postpone the punishment only so that they may increase in sinfulness. And for them is a disgraceful torment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah will not leave the believers in the state in which you are now, until He distinguishes the wicked from the good. Nor will Allah disclose to you the secrets of the Unseen, but Allah chooses of His Messengers whom He wills. So believe in Allah and His Messengers. And if you believe and have Taqwa of Allah, then for you there is a great reward.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And let not those who are stingy with that which Allah has bestowed on them of His bounty think that it is good for them. Nay, it will be worse for them; the things that they were stingy with shall be tied to their necks like a collar on the Day of Resurrection. And Allah's is the inheritance of the heavens and the earth; and Allah is Well-Acquainted with all that you do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Indeed, Allah has heard the statement of those who say: ``Truly, Allah is poor and we are rich!" We shall record what they have said and their killing of the Prophets unjustly, and We shall say: ``Taste you the torment of the burning (Fire)."\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
This is because of that which your hands have sent before you. And certainly, Allah is never unjust to (His) servants.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
Those who said: ``Verily, Allah has taken our promise not to believe in any Messenger unless he brings to us an offering which the fire (from heaven) shall devour. `` Say: ``Verily, there came to you Messengers before me, with Al-Bayinat and even with with what you speak of; why then did you kill them, if you are truthful"\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
Then if they reject you, so were Messengers rejected before you, who came with Al-Bayinat and the Scriptures and the Book of Enlightenment.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Everyone shall taste death. And only on the Day of Resurrection shall you be paid your wages in full. And whoever is moved away from the Fire and admitted to Paradise, he indeed is successful. The life of this world is only the enjoyment of deception.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You shall certainly be tried and tested in your wealth and properties and in yourselves, and you shall certainly hear much that will grieve you from those who received the Scripture before you (Jews and Christians) and from those who ascribe partners to Allah; but if you persevere patiently, and have Taqwa, then verily, that will be a determining factor in all affairs.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
(And remember) when Allah took a covenant from those who were given the Scripture (Jews and Christians) to make it (the truth) known and clear to mankind, and not to hide it, but they threw it away behind their backs, and purchased with it some miserable gain! And indeed worst is that which they bought.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
Think not that those who rejoice in what they have done (or brought about), and love to be praised for what they have not done, think not that they are rescued from the torment, and for them is a painful torment.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
And to Allah belongs the dominion of the heavens and the earth, and Allah has power over all things.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Verily, in the creation of the heavens and the Earth, and in the alternation of night and day, there are indeed signs for men of understanding.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Those who remember Allah standing, sitting, and lying down on their sides, and think deeply about the creation of the heavens and the earth, (saying): ``Our Lord! You have not created this without purpose, glory to You! Give us salvation from the torment of the Fire.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
``Our Lord! Verily, whom You admit to the Fire, indeed, You have disgraced him; and never will the wrongdoers find any helpers.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
``Our Lord! Verily, we have heard the call of one calling to faith: `Believe in your Lord,' and we have believed. Our Lord! Forgive us our sins and expiate from us our evil deeds, and make us die along with Al-Abrar (the most righteous).\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
``Our Lord! Grant us what You promised us through Your Messengers and disgrace us not on the Day of Resurrection, for You never break (Your) Promise."\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
So their Lord accepted of them (their supplication and answered them), ``Never will I allow to be lost the work of any of you, be he male or female. You are (members) one of another, so those who emigrated and were driven out from their homes, and suffered harm in My cause, and who fought and were killed (in My cause), verily, I will expiate from them their evil deeds and admit them into Gardens under which rivers flow (in Paradise); a reward from Allah, and with Allah is the best of rewards."\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Let not the free disposal (and affluence) of the disbelievers throughout the land deceive you.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
A brief enjoyment; then their ultimate abode is Hell; and worst indeed is that place for rest.\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
But, for those who have Taqwa of their Lord, are Gardens under which rivers flow (in Paradise); therein are they to dwell, an entertainment from Allah; and that which is with Allah is the best for Al-Abrar (the most righteous).\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And there are, certainly, among the People of the Scripture (Jews and Christians), those who believe in Allah and in that which has been revealed to you, and in that which has been revealed to them, humbling themselves before Allah. They do not sell the verses of Allah for a small price, for them is a reward with their Lord. Surely, Allah is swift in account.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O you who believe! Endure and be more patient, and Rabitu, and have Taqwa of Allah, so that you may be successful.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O mankind! Have Taqwa of your Lord, Who created you from a single person, and from him He created his mate, and from them both He created many men and women, and have Taqwa of Allah through Whom you demand your mutual (rights), and revere the wombs. Surely, Allah is always watching over you.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
And give unto orphans their property and do not exchange (your) bad things for (their) good ones; and devour not their substance (by adding it) to your substance. Surely, this is a great sin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
And if you fear that you shall not be able to deal justly with the orphan girls, then marry (other) women of your choice, two or three, or four; but if you fear that you shall not be able to deal justly (with them), then only one or (the captives and the servants) that your right hands possess. That is nearer to prevent you from Ta`ulu.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give to the women (whom you marry) their Saduqat (or dowry) Nihlah (with a good heart), but if they, of their own good pleasure, remit any part of it to you, take it, and enjoy it without fear of any harm.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
And give not unto the unwise your wealth which Allah has made a means of support for you, but feed and clothe them therewith, and speak to them words of kindness and justice.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
And test orphans until they reach the age of marriage; if then you find sound judgment in them, release their property to them, but consume it not wastefully and hastily, fearing that they should grow up. And whoever among guardians is rich, he should take no wages, but if he is poor, let him have for himself what is just and reasonable (according to his work). And when you release their property to them, take a witness in their presence; and Allah is All-Sufficient in taking account.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
There is a share for men and a share for women from what is left by parents and those nearest in relation, whether the property be small or large -- a legal share.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
And when the relatives, and the orphans, and the poor are present at the time of division, give them from the property, and speak to them words of kindness and justice.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
And let those (executors and guardians) have the same fear in their minds as they would have for their own, if they had left weak offspring behind. So, let them have Taqwa of Allah and speak truthfully.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Verily, those who unjustly eat up the property of orphans, they eat up only a fire into their bellies, and they will be burnt in the blazing Fire!\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
Allah commands you for your children's (inheritance): to the male, a portion equal to that of two - females; if only daughters, two or more, their share is two thirds of the inheritance; if only one, her share is half. For parents, a sixth share of inheritance to each if the deceased left children; if no children, and the parents are the (only) heirs, the mother has a third; if the deceased left brothers or (sisters), the mother has a sixth. (The distribution in all cases is) after the payment of legacies he may have bequeathed or debts. You know not which of them, whether your parents or your children, are nearest to you in benefit, (these fixed shares) are ordained by Allah. And Allah is Ever All-Knower, All-Wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
In that which your wives leave, your share is half if they have no child; but if they leave a child, you get a fourth of that which they leave after payment of legacies that they may have bequeathed or debts. In that which you leave, their (your wives) share is a fourth if you leave no child; but if you leave a child, they get an eighth of that which you leave after payment of legacies that you may have bequeathed or debts. If the man or woman whose inheritance is in Kalalah has left neither ascendants nor descendants, but has left a brother or a sister, each one of the two gets a sixth; but if more than two, they share in a third; after payment of legacies he (or she) may have bequeathed or debts, so that no loss is caused (to anyone). This is a Commandment from Allah; and Allah is Ever All-Knowing, Most Forbearing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the limits (set by) Allah, and whosoever obeys Allah and His Messenger, will be admitted to Gardens under which rivers flow (in Paradise), to abide therein, and is the great success.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
And whosoever disobeys Allah and His Messenger, and transgresses His (set) limits, He will cast him into the Fire, to abide therein; and he shall suffer a disgraceful torment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
And those of your women who commit illegal sexual intercourse, take the evidence of four witnesses from among you against them; and if they testify, confine them (i.e. women) to houses until death comes to them or Allah ordains for them some (other) way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
And the two persons among you who commit illegal sexual intercourse, punish them both. And if they repent and do righteous good deeds, leave them alone. Surely, Allah is Ever the One Who accepts repentance, (and He is) Most Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
Allah accepts only the repentance of those who do evil in ignorance and foolishness and repent soon [afterwards]; it is they to whom Allah will forgive and Allah is Ever All-Knower, All-Wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
And of no effect is the repentance of those who continue to do evil deeds until death faces one of them and he says: ``Now I repent;" nor of those who die while they are disbelievers. For them, We have prepared a painful torment.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O you who believe! You are not permitted to inherit women against their will, nor to prevent them from marriage in order to get part of (the dowry) what you have given them, unless they commit open Fahishah. And live with them honorably. If you dislike them, it may be that you dislike a thing and Allah brings through it a great deal of good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
But if you intend to replace a wife by another and you have given one of them a Qintar, take not the least bit of it back; would you take it wrongfully without a right and (with) a manifest sin\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how could you take it (back) while you have gone in unto each other, and they have taken from you a firm and strong covenant\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And marry not women whom your fathers married, except what has already passed; indeed it was shameful and Maqtan, and an evil way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Forbidden to you (for marriage) are: your mothers, your daughters, your sisters, your father's sisters, your mother's sisters, your brother's daughters, your sister's daughters, your foster mothers who suckled you, your foster milk suckling sisters, your wives' mothers, your stepdaughters under your guardianship, born of your wives unto whom you have gone in -- but there is no sin on you if you have not gone in unto them (to marry their daughters), -- the wives of your sons who (spring) from your own loins, and two sisters in wedlock at the same time, except for what has already passed; verily, Allah is Oft- Forgiving, Most Merciful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
Also (forbidden are) women already married, except those (slaves) whom your right hands possess. Thus has Allah ordained for you. All others are lawful, provided you seek them (with a dowry) from your property, desiring chastity, not fornication. So with those among them whom you have enjoyed, give them their required due, but if you agree mutually (to give more) after the requirement (has been determined), there is no sin on you. Surely, Allah is Ever All-Knowing, All-Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
And whoever of you have not the means wherewith to wed free believing women, they may wed believing girls from among those whom your right hands possess, and Allah has full knowledge about your faith, you are one from another. Wed them with the permission of their own folk (guardians) and give them their due in a good manner; they should be chaste, not fornicators, nor promiscuous. And after they have been taken in wedlock, if they commit Fahishah, their punishment is half that for free (unmarried) women. This is for him among you who is afraid of being harmed in his religion or in his body; but it is better for you that you practice self-restraint, and Allah is Oft-Forgiving, Most Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah wishes to make clear (what is lawful and what is unlawful) to you, and to show you the ways of those before you, and accept your repentance, and Allah is All-Knower, All-Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
Allah wishes to accept your repentance, but those who follow their lusts, wish that you (believers) should deviate tremendously away (from the right path)\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
Allah wishes to lighten (the burden) for you; and man was created weak.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O you who believe! Eat not up your property among yourselves unjustly except it be a trade amongst you, by mutual consent. And do not kill yourselves (nor kill one another). Surely, Allah is Most Merciful to you.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
And whoever commits that through aggression and injustice, We shall cast him into the Fire, and that is easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you avoid the great sins which you are forbidden to do, We shall remit from you your (small) sins, and admit you to a Noble Entrance (i.e. Paradise).\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
And wish not for the things in which Allah has made some of you to excel others. For men there is reward for what they have earned, (and likewise) for women there is reward for what they have earned, and ask Allah of His bounty. Surely, Allah is Ever All-Knower of everything.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And to everyone, We have appointed Mawali of that left by parents and relatives. To those also with whom you have made a pledge (brotherhood), give them their due portion (by wills). Truly, Allah is Ever a Witness over all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are the protectors and maintainers of women, because Allah has made one of them to excel the other, and because they spend (to support them) from their means. Therefore the righteous women are Qanitat, and guard in the husband's absence what Allah orders them to guard. As to those women on whose part you see ill conduct, admonish them, and abandon them in their beds, and beat them, but if they return to obedience, do not seek a means against them. Surely, Allah is Ever Most High, Most Great.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
If you fear a breach between the two, appoint (two) arbitrators, one from his family and the other from her's; if they both wish for peace, Allah will cause their reconciliation. Indeed Allah is Ever All-Knower, Well-Acquainted with all things.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
Worship Allah and join none with Him in worship, and do good to parents, kinsfolk, orphans, the poor, the neighbor who is near of kin, the neighbor who is a stranger, the companion by your side, the wayfarer (you meet), and those (slaves) whom your right hands possess. Verily, Allah does not like such as are proud and boastful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
Those who are stingy and encourage people to be stingy and hide what Allah has bestowed upon them of His bounties. And We have prepared for the disbelievers a disgraceful torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And (also) those who spend of their wealth to be seen of men, and believe not in Allah and the Last Day, and whoever takes Shaytan as an intimate; then what a dreadful intimate he has!\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
And what loss have they if they had believed in Allah and in the Last Day, and they spend out of what Allah has given them for sustenamce And Allah is Ever All-Knower of them.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Surely! Allah wrongs not even of the weight of a speck of dust, but if there is any good (done), He doubles it, and gives from Him a great reward.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
How (will it be) then, when We bring from each nation a witness and We bring you (O Muhammad) as a witness against these people\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
On that day those who disbelieved and disobeyed the Messenger will wish that they were buried in the earth, but they will never be able to hide a single fact from Allah.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O you who believe! Do not approach Salah while you are in a druken state until you know what you are saying, nor while Junub (sexually impure), except while passing through, until you bathe (your entire body), and if you are ill, or on a journey, or one of you comes from the Gha'it (toilet), or from Lamastum (touching) women, but you do not find water, then perform Tayammum with clean earth, rubbing your faces and hands. Truly, Allah is Ever Oft-Pardoning, Oft-Forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Have you not seen those (the Jews) who were given a portion of the Book, purchasing the wrong path, and wishing that you should go astray from the right path.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
Allah has full knowledge of your enemies, and Allah is sufficient as a Wali (Protector), and Allah is sufficient as a Helper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Among those who are Jews, there are some who displace words from (their) right places and say: ``We hear your word and disobey," and ``Hear and let you hear nothing." And Ra`ina with a twist of their tongues and as a mockery of the religion. And if only they had said: ``We hear and obey", and ``Do make us understand," it would have been better for them, and more proper; but Allah has cursed them for their disbelief, so they believe not except a few.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O you who have been given the Scripture (Jews and Christians)! Believe in what We have revealed confirming what is with you, before We efface faces and turn them backwards or curse them as We cursed the people of the Sabbath. And the commandment of Allah is always executed.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
Verily, Allah forgives not that partners should be set up with Him (in worship), but He forgives except that to whom He wills; and whoever sets up partners with Allah in worship, he has indeed invented a tremendous sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Have you not seen those who claim sanctity for themselves Nay, but Allah sanctifies whom He wills, and they will not be dealt with injustice even equal to the extent of a Fatil.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
Look, how they invent a lie against Allah, and enough is that as a manifest sin.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Have you not seen those who were given a portion of the Scripture They believe in Jibt and Taghut and say to those who disbelieve, ``These people are better guided on the way, `` than the believers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
They are those whom Allah has cursed, and he whom Allah curses, you will not find for him (any) helper.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or have they a share in the dominion Then in that case they would not give mankind even a Naqir.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy men for what Allah has given them of His bounty Then, We have already given the family of Ibrahim the Book and Al-Hikmah, and conferred upon them a great kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
Of them were (some) who believed in it, and of them were (some) who rejected it; and enough is Hell for burning (them).\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Surely, those who disbelieved in Our Ayat, We shall burn them in Fire. As often as their skins are roasted through, We shall change them for other skins that they may taste the punishment. Truly, Allah is Ever Most Powerful, All-Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
But those who believe and do deeds of righteousness, We shall admit them to Gardens under which rivers flow (Paradise), abiding therein forever. Therein they shall have Azwajun Mutahharatun (purified mates), and We shall admit them to shades, wide and ever deepening.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
Verily, Allah commands that you should render back the trusts to those, to whom they are due; and that when you judge between men, you judge with justice. Verily, how excellent is the teaching which He (Allah) gives you! Truly, Allah is Ever All-Hearer, All-Seer.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O you who believe! Obey Allah and obey the Messenger, and those of you who are in authority. If you differ in anything among yourselves, refer it to Allah and His Messenger, if you believe in Allah and in the Last Day. That is better and more suitable for final determination.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Have you not seen those (hyprocrites) who claim that they believe in that which has been sent down to you, and that which was sent down before you, and they wish to go for judgment (in their disputes) to the Taghut while they have been ordered to reject them. But Shaytan wishes to lead them far astray.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it is said to them: ``Come to what Allah has sent down and to the Messenger," you see the hypocrites turn away from you with aversion.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
How then, when a catastrophe befalls them because of what their hands have sent forth, they come to you swearing by Allah, ``We meant no more than goodwill and conciliation!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
They (hypocrites) are those of whom Allah knows what is in their hearts; so turn aside from them (do not punish them) but admonish them, and speak to them an effective word to reach their inner selves.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
We sent no Messenger, but to be obeyed by Allah's leave. If they, when they were unjust to themselves, had come to you and begged Allah's forgiveness, and the Messenger had begged forgiveness for them, indeed, they would have found Allah All-Forgiving, Most Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by your Lord, they can have no faith, until they make you judge in all disputes between them, and find in themselves no resistance against your decisions, and accept (them) with full submission.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
And if We had ordered them (saying), ``Kill yourselves (i.e. the innnocent ones kill the guilty ones) or leave your homes," very few of them would have done it; but if they had done what they were told, it would have been better for them, and would have strengthened their conviction;\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And indeed We would then have bestowed upon them a great reward from Ourselves.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And indeed We would have guided them to the straight way.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
And whoever obeys Allah and the Messenger, then they will be in the company of those on whom Allah has bestowed His grace, of the Prophets, the Siddiqin, the martyrs, and the righteous. And how excellent these companions are!\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
Such is the bounty from Allah, and Allah is sufficient as All-Knower.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O you who believe! Take your precautions, and either go forth (on an expedition) in parties, or go forth all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
There is certainly among you he who would linger behind. If a misfortune befalls you, he says, ``Indeed Allah has favored me in that I was not present among them."\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But if a bounty comes to you from Allah, he would surely say ـ as if there had never been ties of affection between you and him, ``Oh! I wish I had been with them; then I would have achieved a great success."\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
So fight those who trade the life of this world with the Hereafter, in the cause of Allah, and whoever fights in the cause of Allah, and is killed or gets victory, We shall bestow on him a great reward.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And what is wrong with you that you fight not in the cause of Allah, and for those weak, ill-treated and oppressed among men, women, and children, whose cry is: ``Our Lord! Rescue us from this town whose people are oppressors; and raise for us from You one who will protect, and raise for us from You one who will help."\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who believe, fight in the cause of Allah, and those who disbelieve, fight in the cause of the Taghut. So fight against the friends of Shaytan; ever feeble indeed is the plot of Shaytan.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Have you not seen those who were told to hold back their hands (from fighting) and perform Salah and give Zakah, but when the fighting was ordained for them, behold! a section of them fear men as they fear Allah or even more. They say: ``Our Lord! Why have You ordained for us fighting Would that You granted us respite for a short period" Say: ``Short is the enjoyment of this world. The Hereafter is (far) better for him who fears Allah, and you shall not be dealt with unjustly even equal to the Fatil.\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
``Wheresoever you may be, death will overtake you even if you are in fortresses built up strong and high!" And if some good reaches them, they say, ``This is from Allah," but if some evil befalls them, they say, ``This is from you." Say: ``All things are from Allah," so what is wrong with these people that they fail to understand any word\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
Whatever of good reaches you, is from Allah, but whatever of evil befalls you, is from yourself. And We have sent you as a Messenger to mankind, and Allah is sufficient as a Witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
He who obeys the Messenger, has indeed obeyed Allah, but he who turns away, then We have not sent you as a watcher over them.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
They say: ``We are obedient," but when they leave you, a section of them spends all night in planning other than what you say. But Allah records their nightly (plots). So turn aside from them (do not punish them), and put your trust in Allah. And Allah is Ever All-Sufficient as a Disposer of affairs.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Do they not then consider the Qur'an carefully Had it been from other than Allah, they would surely, have found therein contradictions in abundance.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
When there comes to them some matter touching (public) safety or fear, they make it known (among the people); if only they had referred it to the Messenger or to those charged with authority among them, the proper investigators would have understood it from them (directly). Had it not been for the grace and mercy of Allah upon you, you would have followed Shaytan, except a few of you.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
Then fight in the cause of Allah, you are not tasked (held responsible) except for yourself, and incite the believers (to fight along with you), it may be that Allah will restrain the evil might of the disbelievers. And Allah is Stronger in might and Stronger in punishing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whosoever intercedes for a good cause, will have the reward thereof; and whosoever intercedes for an evil cause, will have a share in its burden. And Allah is Ever All-Able to do everything.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
When you are greeted with a greeting, greet in return with what is better than it, or (at least) return it equally. Certainly, Allah is Ever a Careful Account Taker of all things.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah! None has the right to be worshipped but He. Surely, He will gather you together on the Day of Resurrection about which there is no doubt. And who is truer in statement than Allah\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
Then what is the matter with you that you are divided into two parties about the hypocrites Allah has cast them back because of what they have earned. Do you want to guide him whom Allah has made to go astray And he whom Allah has made to go astray, you will never find for him a way.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish that you reject faith, as they have rejected, and thus that you all become equal (like one another). So take not Awliya' from them, till they emigrate in the way of Allah. But if they turn back, take (hold of) them and kill them wherever you find them, and take neither Awliya' nor helpers from them.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except those who join a group, between you and whom there is a treaty (of peace), or those who approach you with their breasts restraining from fighting you as well as fighting their own people. Had Allah willed, indeed He would have given them power over you, and they would have fought you. So, if they withdraw from you, and fight not against you, and offer you peace, then Allah has made no way for you against them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will find others that wish to have security from you and security from their people. Every time they are sent back to Fitnah, they yield thereto. If they withdraw not from you, nor offer you peace, nor restrain their hands, take (hold of) them and kill them wherever you Thaqiftumuhum. In their case, We have provided you with a clear warrant against them.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
It is not for a believer to kill a believer except by mistake; and whosoever kills a believer by mistake, he must set free a believing slave and submit compensation (blood money) to the deceased's family unless they remit it. If the deceased belonged to a people at war with you and he was a believer, the freeing of a believing slave (is prescribed); and if he belonged to a people with whom you have a treaty of mutual alliance, then compensation (blood money) must be paid to his family, and a believing slave must be freed. And whoso finds this beyond his means, he must fast for two consecutive months in order to seek repentance from Allah. And Allah is Ever All-Knowing, All-Wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
And whoever kills a believer intentionally, his recompense is Hell to abide therein; and the wrath and the curse of Allah are upon him, and a great punishment is prepared for him.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O you who believe! When you go (to fight) in the cause of Allah, verify (the truth), and say not to anyone who greets you: ``You are not a believer;" seeking the perishable goods of the worldly life. There is much more benefit with Allah. Even as he is now, so were you yourselves before, till Allah conferred on you His Favors, therefore, be cautious in discrimination. Allah is Ever Well-Aware of what you do.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Not equal are those of the believers who sit (at home), except those who are disabled, and those who strive hard and fight in the cause of Allah with their wealth and their lives. Allah has preferred in grades those who strive hard and fight with their wealth and their lives above those who sit (at home). Unto each, Allah has promised good (Paradise), but Allah has preferred those who strive hard and fight, above those who sit (at home), by a huge reward.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Degrees of (higher) grades from Him, and forgiveness and mercy. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
Verily, as for those whom the angels take (in death) while they are wronging themselves, they (angels) say (to them): ``In what (condition) were you" They reply: ``We were weak and oppressed on the earth." They (angels) say: ``Was not the earth of Allah spacious enough for you to emigrate therein" Such men will find their abode in Hell - what an evil destination!\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Except the weak ones among men, women and children who cannot devise a plan, nor are they able to direct their way.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
These are they whom Allah is likely to forgive them, and Allah is Ever Oft-Pardoning, Oft-Forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
He who emigrates in the cause of Allah, will find on earth many dwelling places and plenty to live by. And whosoever leaves his home as an emigrant unto Allah and His Messenger, and death overtakes him, his reward is then surely incumbent upon Allah. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when you Darabtum in the land, there is no sin on you if you shorten the Salah if you fear that the disbelievers may put you in trial, verily, the disbelievers are ever unto you open enemies.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
When you (O Messenger Muhammad) are among them, and lead them in Salah, let one party of them stand up [in prayer] with you, taking their arms with them; when they finish their prostrations, let them take their positions in the rear and let the other party come up which have not yet prayed, and let them pray with you, taking all the precautions and bearing arms. Those who disbelieve wish, if you were negligent of your arms and your baggage, to attack you in a single rush, but there is no sin on you if you put away your arms because of the inconvenience of rain or because you are ill, but take every precaution for yourselves. Verily, Allah has prepared a humiliating torment for the disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
When you have finished the Salah, remember Allah standing, sitting down, and on your sides, but when you are free from danger, perform the Salah. Verily, Salah is kitaban on the believers at fixed hours.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And don't be weak in the pursuit of the enemy; if you are suffering (hardships) then surely they (too) are suffering (hardships) as you are suffering, but you have a hope from Allah (for the reward, i.e. Paradise) that for which they hope not; and Allah is Ever All-Knowing, All-Wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Surely, We have sent down to you (O Muhammad) the Book in truth that you might judge between men by that which Allah has shown you, so be not a pleader for the treacherous.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
And seek the forgiveness of Allah, certainly, Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And argue not on behalf of those who deceive themselves. Verily, Allah does not like anyone who is a betrayer, sinner.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They may hide (their crimes) from men, but they cannot hide (them) from Allah; for He is with them (by His knowledge), when they plot by night in words that He does not approve. And Allah ever encompasses what they do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Lo! You are those who have argued for them in the life of this world, but who will argue for them on the Day of Resurrection against Allah, or who will then be their defender\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
And whoever does evil or wrongs himself but afterwards seeks Allah's forgiveness, he will find Allah Oft-Forgiving, Most Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And whoever earns sin, he earns it only against himself. And Allah is Ever All-Knowing, All-Wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
And whoever earns a fault or a sin and then blames it on someone innocent, he has indeed burdened himself with falsehood and a manifest sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
Had not the grace of Allah and His mercy been upon you, a party of them would certainly have made a decision to mislead you, but they mislead none except their own selves, and no harm can they do to you in the least. Allah has sent down to you the Book, and the Hikmah, and taught you that which you knew not. And ever great is the grace of Allah unto you.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
There is no good in most of their secret talks save (in) him who orders Sadaqah, or goodness, or conciliation between mankind; and he who does this, seeking the good pleasure of Allah, We shall give him a great reward.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
And whoever contradicts and opposes the Messenger after the right path has been shown clearly to him, and follows other than the believers' way, We shall keep him in the path he has chosen, and burn him in Hell what an evil destination!\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
Verily, Allah forgives not (the sin of) setting up partners (in worship) with Him, but He forgives whom He wills, sins other than that, and whoever sets up partners in worship with Allah, has indeed strayed far away.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
They invoke nothing but female deities besides Him (Allah), and they invoke nothing but Shaytan, a persistent rebel!\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
Allah cursed him. And he [Shaytan] said: ``I will take an appointed portion of your servants."\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
``Verily, I will mislead them, and surely, I will arouse in them false desires; and certainly, I will order them to slit the ears of cattle, and indeed I will order them to change the nature created by Allah." And whoever takes Shaytan as a Wali instead of Allah, has surely suffered a manifest loss.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
He [Shaytan] makes promises to them, and arouses in them false desires; and Shaytan's promises are nothing but deceptions.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
The dwelling of such (people) is Hell, and they will find no way of escape from it.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
And those who believe and do righteous good deeds, We shall admit them to the Gardens under which rivers flow (i.e. in Paradise) to dwell therein forever. Allah's promise is the truth; and whose words can be truer than those of Allah\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
It will not be in accordance with your desires, nor those of the People of the Scripture, whosoever works evil, will have the recompense thereof, and he will not find any protector or helper besides Allah.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whoever does righteous good deeds, male or female, and is a believer, such will enter Paradise and not the least injustice, even to the size of a Naqir, will be done to them.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who can be better in religion than one who submits his face (himself) to Allah; and he is a Muhsin (a doer of good). And follows the religion of Ibrahim the Hanif (Monotheist). And Allah did take Ibrahim as a Khalil (an intimate friend)!\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
And to Allah belongs all that is in the heavens and all that is in the earth. And Allah is Ever Encompassing all things.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
They ask your legal instruction concerning women. Say: ``Allah instructs you about them, and about what is recited unto you in the Book concerning the orphan girls whom you give not what they deserve and yet whom you desire to marry, and the children who are weak and oppressed, and that you stand firm for justice to orphans. And whatever good you do, Allah is Ever All-Aware of it.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
And if a woman fears cruelty or desertion on her husband's part, there is no sin on them both if they make terms of peace between themselves; and making peace is better. And human souls are swayed by greed. But if you do good and have Taqwa, verily, Allah is Ever Well-Acquainted with what you do.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
You will never be able to do perfect justice between wives even if it is your ardent desire, so do not incline too much to one of them so as to leave the other hanging. And if you do justice, and do all that is right and have Taqwa, then Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they separate (by divorce), Allah will provide abundance for everyone of them from His bounty. And Allah is Ever All-Sufficient for His creatures' needs, All-Wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
And to Allah belongs all that is in the heavens and all that is in the earth. And verily, We have recommended to the People of the Scripture before you, and to you that you have Taqwa of Allah. But if you disbelieve, then unto Allah belongs all that is in the heavens and all that is in the earth, and Allah is Ever Rich (free of any needs), Worthy of all praise.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
And to Allah belongs all that is in the heavens and all that is in the earth. And Allah is Ever All-Sufficient as Disposer of affairs.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He wills, He can take you away, O people, and bring others. And Allah is Ever All-Potent over that.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoever desires the rewards of this life, then with Allah is the reward of this worldly life and of the Hereafter. And Allah is Ever All-Hearer, All-Seer.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O you who believe! Stand out firmly for justice, as witnesses to Allah, even though it be against yourselves, or your parents, or your kin, be he rich or poor, Allah is a better Protector to both. So follow not the lusts, lest you may avoid justice; and if you Talwu or Tu`ridu, it, verily, Allah is Ever Well-Acquainted with what you do.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O you who believe! Believe in Allah, and His Messenger, and the Book (the Qur'an) which He has sent down to His Messenger, and the Scripture which He sent down to those before; and whosoever disbelieves in Allah, His Angels, His Books, His Messengers, and the Last Day, then indeed he has strayed far away.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Verily, those who believe, then disbelieve, then believe (again), and (again) disbelieve, and go on increasing in disbelief; Allah will not forgive them, nor guide them on the (right) way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give to the hypocrites the tidings that there is for them a painful torment.\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who take disbelievers for friends instead of believers, do they seek honor with them Verily, then to Allah belongs all honor.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
And it has already been revealed to you in the Book that when you hear the verses of Allah being denied and mocked at, then sit not with them, until they engage in talk other than that; certainly in that case you would be like them. Surely, Allah will collect the hypocrites and disbelievers all together in Hell.\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who wait and watch about you; if you gain a victory from Allah, they say: ``Were we not with you" But if the disbelievers gain a success, they say (to them): ``Did we not gain mastery over you and did we not protect you from the believers" Allah will judge between you (all) on the Day of Resurrection. And never will Allah grant to the disbelievers a way (to triumph) over the believers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Verily, the hypocrites seek to deceive Allah, but it is He Who deceives them. And when they stand up for Salah, they stand with laziness and to be seen of men, and they do not remember Allah but little.\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
(They are) swaying between this and that, belonging neither to these nor to those; and he whom Allah sends astray, you will not find for him a way.\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O you who believe! Do not take disbelievers as friends instead of believers. Do you wish to offer Allah a manifest Sultan against yourselves\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Verily, the hyprocrites will be in the lowest depth (grade) of the Fire; no helper will you find for them.\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except those who repent, do righteous good deeds, depend on Allah, and purify their religion for Allah, then they will be with the believers. And Allah will grant the believers a great reward.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
Why should Allah punish you if you have thanked (Him) and have believed in Him. And Allah is Ever All-Appreciative (of good), All-Knowing.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah does not like that the evil should be uttered in public except by him who has been wronged. And Allah is Ever All-Hearer, All-Knower.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
Whether you disclose a good deed or conceal it, or pardon an evil, verily, Allah is Ever Pardoning, All-Powerful.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Verily, those who disbelieve in Allah and His Messengers and wish to make distinction between Allah and His Messengers saying, ``We believe in some but reject others," and wish to adopt a way in between.\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
They are in truth disbelievers. And We have prepared for the disbelievers a humiliating torment.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
And those who believe in Allah and His Messengers and make no distinction between any of them (Messengers), We shall give them their rewards; and Allah is Ever Forgiving, Most Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The People of the Scripture (Jews) ask you to cause a book to descend upon them from heaven. Indeed, they asked Musa for even greater than that, when they said: ``Show us Allah in public," but they were struck with a bolt of lightning for their wickedness. Then they worshipped the calf even after Al-Bayyinat had come to them. (Even) so We forgave them. And We gave Musa a clear proof of authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And for their covenant, We raised over them the mount and (on the other occasion) We said: ``Enter the gate prostrating (or bowing) with humility;" and We commanded them: ``Transgress not on the Sabbath (Saturday)." And We took from them a firm covenant.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
Because of their breaking the covenant, and their rejecting the Ayat of Allah, and their killing the Prophets unjustly, and their saying: ``Our hearts are Ghulf," nay, Allah has set a seal upon their hearts because of their disbelief, so they believe not but a little.\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And because of their disbelief and uttering against Maryam a grave false charge.\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
And because of their saying, ``We killed Al-Masih `Isa, son of Maryam, the Messenger of Allah," but they killed him not, nor crucified him, but it appeared as that to them, and those who differ therein are full of doubts. They have no (certain) knowledge, they follow nothing but conjecture. For surely; they killed him not.\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
But Allah raised him up unto Himself. And Allah is Ever All-Powerful, All-Wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
And there is none of the People of the Scripture, but must believe in him, before his death. And on the Day of Resurrection, he will be a witness against them.\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
For the wrongdoing of the Jews, We made unlawful for them certain good foods which had been lawful for themـand for their hindering many from Allah's way;\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
And their taking of Riba though they were forbidden from taking it, and their devouring men's substance wrongfully. And We have prepared for the disbelievers among them a painful torment.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those among them who are well-grounded in knowledge, and the believers, believe in what has been sent down to you and what was sent down before you; and those who perform the Salah, and give Zakah and believe in Allah and in the Last Day, it is they to whom We shall give a great reward.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
Verily, We have sent the revelation to you as We sent the revelation to Nuh and the Prophets after him; We (also) sent the revelation to Ibrahim, Isma`il, Ishaq, Ya`qub, and Al-Asbat, (the offspring of the twelve sons of Ya`qub) `Isa, Ayyub, Yunus, Harun, and Sulayman; and to Dawud We gave the Zabur.\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
And Messengers We have mentioned to you before, and Messengers We have not mentioned to you, and to Musa Allah spoke directly.\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
Messengers as bearers of good news and warning, in order that mankind should have no plea against Allah after the (coming of) Messengers. And Allah is Ever All-Powerful, All-Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah bears witness to that which He has sent down unto you; He has sent it down with His knowledge, and the angels bear witness. And Allah is All-Sufficient as a Witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Verily, those who disbelieve and prevent (others) from the path of Allah; they have certainly strayed far away.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Verily, those who disbelieve and did wrong; Allah will not forgive them, nor will He guide them to a way.\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the way of Hell, to dwell therein forever; and this is ever easy for Allah.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O mankind! Verily, there has come to you the Messenger with the truth from your Lord. So believe in him, it is better for you. But if you disbelieve, then certainly to Allah belongs all that is in the heavens and the earth. And Allah is Ever All-Knowing, All-Wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O People of the Scripture! Do not exceed the limits in your religion, nor say of Allah except the truth. Al-Masih `Isa, son of Maryam, was (no more than) a Messenger of Allah and His Word, which He bestowed on Maryam and a spirit from [created by] Him; so believe in Allah and His Messengers. Say not: ``Three!" Cease! (it is) better for you. For Allah is (the only) One God, hallowed be He above having a son. To Him belongs all that is in the heavens and all that is in the earth. And Allah is All-Sufficient as a Disposer of affairs.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
Al-Masih will never be too proud to be a servant of Allah, nor the angels who are the near (to Allah). And whosoever rejects His worship and is proud, then He will gather them all together unto Himself.\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
So, as for those who believed and did deeds of righteousness, He will give them their (due) rewards and more out of His bounty. But as for those who refused His worship and were proud, He will punish them with a painful torment. And they will not find for themselves besides Allah any protector or helper.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O mankind! Verily, there has come to you a convincing proof from your Lord; and We sent down to you a manifest light.\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
So, as for those who believed in Allah and held fast to [depend on] Him, He will admit them to His mercy and grace (i.e. Paradise), and guide them to Himself by a straight path.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They ask you for a legal verdict. Say: ``Allah directs (thus) about Al-Kalalah. If it is a man that dies leaving a sister, but no child, she shall have half the inheritance, and [in her case] he will be her heir if she has no children. If there are two sisters, they shall have two-thirds of the inheritance; if there are brothers and sisters, the male will have twice the share of the female. (Thus) does Allah make clear to you (His Law) lest you go astray. And Allah is the All-Knower of everything."\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O you who believe! Fulfill (your) obligations. Lawful to you (for food) are all the beasts of cattle except that which will be announced to you (herein), game (also) being unlawful when you assume Ihram. Verily, Allah commands that which He wills.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O you who believe! Violate not the sanctity of the symbols of Allah, nor of the Sacred Month, nor of the Hady brought for sacrifice, nor the garlands, nor the people coming to the Sacred House (Makkah), seeking the bounty and good pleasure of their Lord. But when you finish the Ihram, then hunt, and let not the hatred of some people in (once) stopping you from Al-Masjid Al-Haram (at Makkah) lead you to transgression. Help you one another in Al-Birr and At-Taqwa, but do not help one another in sin and transgression. And have Taqwa of Allah. Verily, Allah is severe in punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Forbidden to you (for food) are: Al-Maytah (the dead animals), blood, the flesh of swine, and that which has been slaughtered as a sacrifice for other than Allah, and that which has been killed by strangling, or by a violent blow, or by a headlong fall, or by the goring of horns ـand that which has been (partly) eaten by a wild animal ـunless you are able to slaughter it (before its death) - and that which is sacrificed (slaughtered) on An-Nusub (stone altars). (Forbidden) also is to make decisions with Al-Azlam (arrows) (all) that is Fisq (disobedience and sin). This day, those who disbelieved have given up all hope of your religion; so fear them not, but fear Me. This day, I have perfected your religion for you, completed My favor upon you, and have chosen for you Islam as your religion. But as for him who is forced by severe hunger, with no inclination to sin (such can eat these above mentioned animals), then surely, Allah is Oft-Forgiving, Most Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you what is lawful for them. Say: ``Lawful unto you are At-Tayyibat (the good things). And those Jawarih (beasts and birds of prey) which you have trained as hounds, training and teaching them (to catch) in the manner as directed to you by Allah; so eat of what they catch for you, but pronounce the Name of Allah over it, and have Taqwa of Allah. Verily, Allah is swift in reckoning."\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
Made lawful to you this day are At-Tayyibat. The food of the People of the Scripture is lawful to you, and your food is lawful to them. (Lawful to you in marriage) are chaste women from the believers and chaste women from those who were given the Scripture before your time when you have given them their due, desiring chastity, not illegal sexual intercourse, nor taking them as girlfriends (or lovers). And whosoever rejects faith, then fruitless is his work; and in the Hereafter he will be among the losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O you who believe! When you stand (intend) to offer the Salah (the prayer), then wash your faces and your hands (forearms) up to the elbows, rub (by passing wet hands over) your heads, and (wash) your feet up to the ankles. If you are in a state of Janaba, purify yourselves (bathe your whole body). But if you are ill or on a journey or any of you comes from the Gha'it (toilet) or you have touched women and you find no water, then perform Tayammum with clean earth and rub therewith your faces and hands. Allah does not want to place you in difficulty, but He wants to purify you, and to complete His Favor to you that you may be thankful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And remember Allah's favor to you and His covenant with which He bound you when you said: ``We hear and we obey." And have Taqwa of Allah. Verily, Allah is All-Knower of that which is in the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O you who believe! Stand out firmly for Allah as just witnesses; and let not the enmity and hatred of others make you avoid justice. Be just, that is nearer to Taqwa; and have Taqwa of Allah. Verily, Allah is Well-Acquainted with what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah has promised those who believe and do deeds of righteousness, that for them there is forgiveness and a great reward (i.e. Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
And they who disbelieve and deny Our Ayat are those who will be the dwellers of the Hell-fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O you who believe! Remember the favor of Allah unto you when some people desired (made a plan) to stretch out their hands against you, but (Allah) held back their hands from you. So have Taqwa of Allah. And in Allah let the believers put their trust.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
Indeed, Allah took the covenant from the Children of Israel (Jews), and We appointed twelve leaders among them. And Allah said: ``I am with you if you perform the Salah and give the Zakah and believe in My Messengers; honor and assist them, and lend to Allah a good loan, verily, I will remit your sins and admit you to Gardens under which rivers flow (in Paradise). But if any of you after this, disbelieved, he has indeed gone astray from the straight way."\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
So, because of their breach of their covenant, We cursed them and made their hearts grow hard. They changed the words from their (right) places and have abandoned a good part of the Message that was sent to them. And you will not cease to discover deceit in them, except a few of them. But forgive them and overlook (their misdeeds). Verily, Allah loves the doers of good.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And from those who call themselves Christians, We took their covenant, but they have abandoned a good part of the Message that was sent to them. So We planted amongst them enmity and hatred till the Day of Resurrection; and Allah will inform them of what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O People of the Scripture! Now has come to you Our Messenger explaining to you much of that which you used to hide from the Scripture and passing over much. Indeed, there has come to you from Allah a light and a plain Book.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
Wherewith Allah guides all those who seek His Pleasure to ways of peace, and He brings them out of darkness by His permission unto light and guides them to a straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
Surely, in disbelief are they who say that Allah is the Messiah, son of Maryam. Say: ``Who then has the least power against Allah, if He were to destroy the Messiah, son of Maryam, his mother, and all those who are on the earth together" And to Allah belongs the dominion of the heavens and the earth, and all that is between them. He creates what He wills. And Allah is able to do all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
And the Jews and the Christians say: ``We are the children of Allah and His loved ones." Say: ``Why then does He punish you for your sins" Nay, you are but human beings of those He has created, He forgives whom He wills and He punishes whom He wills. And to Allah belongs the dominion of the heavens and the earth and all that is between them; and to Him is the return (of all).\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O People of the Scripture! Now has come to you Our Messenger making (things) clear unto you, after a break in (the series of) Messengers, lest you say: ``There came to us no bringer of glad tidings and no warner." But now has come unto you a bringer of glad tidings and a warner. And Allah is able to do all things.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And (remember) when Musa said to his people: ``O my people! Remember the favor of Allah to you: when He made Prophets among you, made you kings and gave you what He had not given to any other among the nations (Al-`Alamin)."\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
``O my people! Enter the Holy Land which Allah has assigned to you and turn not back; for then you will be returned as losers."\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said: ``O Musa! In it are a people of great strength, and we shall never enter it, till they leave it; when they leave, then we will enter."\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Two men of those who feared (Allah and) on whom Allah had bestowed His grace said: ``Assault them through the gate; for when you are in, victory will be yours. And put your trust in Allah if you are believers indeed."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said: ``O Musa! We shall never enter it as long as they are there. So go, you and your Lord, and fight you two, we are sitting right here."\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
He [Musa] said: ``O my Lord! I have power only over myself and my brother, so Ifruq us from the rebellious people!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
(Allah) said: ``Therefore it is forbidden to them for forty years; in distraction they will wander through the land. So do not greive for the rebellious people."\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And recite to them the story of the two sons of Adam in truth; when each offered a sacrifice, it was accepted from the one but not from the other. The latter said to the former: ``I will surely, kill you." The former said: ``Verily, Allah accepts only from those who have Taqwa.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
``If you do stretch your hand against me to kill me, I shall never stretch my hand against you to kill you, for I fear Allah; the Lord of all that exists."\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
``Verily, I intend to let you draw my sin on yourself as well as yours, then you will be one of the dwellers of the Fire, and that is the recompense of the wrongdoers."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
So the soul of the other encouraged him and made fair-seeming to him the murder of his brother; he murdered him and became one of the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent a crow who scratched the ground to show him how to hide the dead body of his brother. He said: ``Woe to me! Am I not even able to be as this crow and to hide the dead body of my brother" Then he became one of those who regretted.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
Because of that, We ordained for the Children of Israel that if anyone killed a person not in retaliation of murder, or (and) to spread mischief in the land - it would be as if he killed all mankind, and if anyone saved a life, it would be as if he saved the life of all mankind. And indeed, there came to them Our Messengers with Al-Bayyinat, even then after that many of them continued to exceed the limits in the land!\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
The recompense of those who wage war against Allah and His Messenger and do mischief in the land is only that they shall be killed or crucified, or their hands and their feet be cut off on opposite sides, or be exiled from the land. That is their disgrace in this world, and a great torment is theirs in the Hereafter.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Except for those who (having fled away and then) came back (as Muslims) with repentance before they fall into your power; in that case, know that Allah is Oft-Forgiving, Most Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O you who believe! Have Taqwa of Allah and seek the Wasilah to Him, and strive hard in His cause, so that you may be successful.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
Verily, those who disbelieve, if they had all that is in the earth, and as much again therewith to ransom themselves thereby from the torment on the Day of Resurrection, it would never be accepted of them. And theirs would be a painful torment.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will long to get out of the Fire, but never will they get out therefrom; and theirs will be a lasting torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
And (as for) the male thief and the female thief, cut off their hands as a recompense for that which both committed, a punishment by way of example from Allah. And Allah is All-Powerful, All-Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whosoever repents after his crime and does righteous good deeds, then verily, Allah will pardon him. Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Know you not that to Allah (Alone) belongs the dominion of the heavens and the earth! He forgives whom He wills and He punishes whom He wills. And Allah is able to do all things.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger! Let not those who hurry to fall into disbelief grieve you, of such who say, ``We believe" with their mouths but their hearts have no faith. And of the Jews are men who listen much and eagerly to lies, listening to others who have not come to you. They change the words from their places; they say, ``If you are given this, take it, but if you are not given this, then beware!" And whomsoever Allah wants to put in Fitnah, you can do nothing for him against Allah. Those are the ones whose hearts Allah does not want to purify; for them there is a disgrace in this world, and in the Hereafter a great torment.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
They (like to) listen to falsehood, to devour Suht. So if they come to you, either judge between them, or turn away from them. If you turn away from them, they cannot hurt you in the least. And if you judge, judge with justice between them. Verily, Allah loves those who act justly.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
But how do they come to you for a decision while they have the Tawrah, in which is the decision of Allah; yet even after that they turn away. For they are not believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Verily, We did send down the Tawrah, therein was guidance and light, by which the Prophets who submitted themselves to Allah's will, judged for the Jews. And the Rabbaniyyun and the Ahbar, for to them was entrusted the protection of Allah's Book, and they were witnesses thereto. Therefore fear not men but fear Me and sell not My verses for a miserable price. And whosoever does not judge by what Allah has revealed, such are the disbelievers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And We ordained therein for them ``Life for life, eye for eye, nose for nose, ear for ear, tooth for tooth, and wounds equal for equal. `` But if anyone remits the retaliation by way of charity, it shall be for him an expiation. And whosoever does not judge by that which Allah has revealed, such are the unjust.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And in their footsteps, We sent `Isa, son of Maryam, confirming the Tawrah that had come before him, and We gave him the Injil, in which was guidance and light and confirmation of the Tawrah that had come before it, a guidance and an admonition for those who have Taqwa.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
Let the people of the Injil judge by what Allah has revealed therein. And whosoever does not judge by what Allah has revealed, such are the rebellious.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And We have sent down to you the Book (this Qur'an) in truth, confirming the Scripture that came before it and Muhayminan over it (old Scriptures). So judge between them by what Allah has revealed, and follow not their vain desires, diverging away from the truth that has come to you. To each among you, We have prescribed a law and a clear way. If Allah willed, He would have made you one nation, but that (He) may test you in what He has given you; so compete in good deeds. The return of you (all) is to Allah; then He will inform you about that in which you used to differ.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And so judge between them by what Allah has revealed and follow not their vain desires, but beware of them lest they turn you far away from some of that which Allah has sent down to you. And if they turn away, then know that Allah's will is to punish them for some sins of theirs. And truly, most men are rebellious.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Do they then seek the judgement of (the days of) ignorance And who is better in judgement than Allah for a people who have firm faith.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O you who believe! Do not take friends from the Jews and the Christians, as they are but friends of each other. And if any among you befriends them, then surely, he is one of them. Verily, Allah guides not those people who are the wrongdoers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
And you see those in whose hearts there is a disease, they hurry to their friendship, saying: ``We fear lest some misfortune of a disaster may befall us. `` Perhaps Allah may bring a victory or a decision according to His will. Then they will become regretful for what they have been keeping as a secret in themselves.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
And those who believe will say: ``Are these the men who swore their strongest oaths by Allah that they were with you" All that they did has been in vain, and they have become the losers.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O you who believe! Whoever from among you turns back from his religion (Islam), Allah will bring a people whom He will love and they will love Him; humble towards the believers, stern towards the disbelievers, fighting in the way of Allah, and never fearing the blame of the blamers. That is the grace of Allah which He bestows on whom He wills. And Allah is All-Sufficient for His creatures' needs, All-Knower.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Verily, your Protector is Allah, His Messenger, and the believers, those who perform the Salah, and give Zakah, and they bow down.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
And whosoever takes Allah, His Messenger, and those who have believed, as protectors, then the party of Allah will be the victorious.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O you who believe! Do not take as friends those who take your religion for a mockery and fun from those who received the Scriptures before you, and (nor) the disbelievers; and have Taqwa of Allah if you indeed are true believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when you proclaim the call for the Salah, they take it (but) as a mockery and fun; that is because they are a people who understand not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say: ``O People of the Scripture! Do you criticize us for no other reason than that we believe in Allah, and in what has been sent down to us and in that which has been sent down before (us), and that most of you are rebellious"\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say: ``Shall I inform you of something worse than that, regarding the recompense from Allah: those who incurred the curse of Allah and His wrath, and those of whom He transformed into monkeys and swine, and those who worshipped Taghut; such are worse in rank, and far more astray from the straight path."\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
When they come to you, they say: ``We believe." But in fact they enter with disbelief and they go out with the same. And Allah knows all that they were hiding.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
And you see many of them hurrying for sin and transgression, and eating illegal things. Evil indeed is that which they have been doing.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do not the Rabbaniyyun and the Ahbar forbid them from uttering sinful words and from eating illegal things. Evil indeed is that which they have been performing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
The Jews say: ``Allah's Hand is tied up." Be their hands tied up and be they accursed for what they uttered. Nay, both His Hands are widely outstretched. He spends as He wills. Verily, the revelation that has come to you from your Lord makes many of them increase in rebellion and disbelief. We have put enmity and hatred among them till the Day of Resurrection. Every time they kindled the fire of war, Allah extinguished it; and they (ever) strive to make mischief on the earth. And Allah does not like the mischief-makers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
And if only the People of the Scripture had believed and had Taqwa, We would indeed have expiated for them their sins and admitted them to Gardens of pleasure (in Paradise).\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
And if only they had acted according to the Tawrah, the Injil, and what has (now) been sent down to them from their Lord (the Qur'an), they would surely have gotten provision from above them and from underneath their feet. And among them is a Muqtasid Ummah, but for most of them; evil is their work.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger! Convey what has been sent down to you from your Lord. And if you do not, then you have not conveyed His Message. Allah will protect you from mankind. Verily, Allah guides not the people who disbelieve.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say: ``O People of the Scripture! You have nothing till you act according to the Tawrah, the Injil, and what has (now) been sent down to you from your Lord (the Qur'an)." Verily, the revelation that has come to you from your Lord makes many of them increase in rebellion and disbelief. So do not grieve for the people who disbelieve.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Surely, those who believe, and those who are the Jews and the Sabians and the Christians, whosoever believed in Allah and the Last Day, and worked righteousness, on them shall be no fear, nor shall they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
Verily, We took the covenant of the Children of Israel and sent Messengers to them. Whenever there came to them a Messenger with what they themselves desired not, a group of them they called liars, and others among them they killed.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
They thought there will be no Fitnah (trial or punishment), so they became blind and deaf; after that Allah turned to them (with forgiveness); yet again many of them became blind and deaf. And Allah is the All-Seer of what they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
Surely, they have disbelieved who say: ``Allah is the Messiah [`Isa], son of Maryam." But the Messiah said: ``O Children of Israel! worship Allah, my Lord and your Lord." Verily, whosoever sets up partners (in worship) with Allah, then Allah has forbidden Paradise for him, and the Fire will be his abode. And for the wrongdoers there are no helpers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
Surely, they have disbelieved who say: ``Allah is the third of three." And there is no god but One God (Allah). And if they cease not from what they say, verily, a painful torment will befall on the disbelievers among them.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
Will they not repent to Allah and ask His forgiveness For Allah is Oft-Forgiving, Most Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah [`Isa], son of Maryam, was no more than a Messenger; many were the Messengers that passed away before him. His mother [Maryam] was a Siddiqah. They both used to eat food. Look how We make the Ayat clear to them; yet look how they are deluded away (from the truth).\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say: ``How do you worship besides Allah something which has no power either to harm or to benefit you But it is Allah Who is the All-Hearer, All-Knower."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say: ``O People of the Scripture! Exceed not the limits in your religion beyond the truth, and do not follow the vain desires of people who went astray before and who misled many, and strayed (themselves) from the right path."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Those among the Children of Israel who disbelieved were cursed by the tongue of Dawud and `Isa, son of Maryam. That was because they disobeyed (Allah and the Messengers) and were ever transgressing (beyond the bounds).\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They used not to forbid one another from the evil they committed. Vile indeed was what they used to do.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
You see many of them taking the disbelievers as their friends. Evil indeed is that which they have sent forward before themselves; for that (reason) Allah is wrath with them, and in torment they will abide.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
And had they believed in Allah, and in the Prophet and in what has been revealed to him, never would they have taken them as friends; but many of them are rebellious.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
Verily, you will find the strongest among men in enmity to the believers the Jews and those who commit Shirk, and you will find the nearest in love to the believers those who say: ``We are Christians." That is because among them are priests and monks, and they are not proud.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they listen to what has been sent down to the Messenger, you see their eyes overflowing with tears because of the truth they have recognized. They say: ``Our Lord! We believe; so write us down among the witnesses."\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
``And why should we not believe in Allah and in that which has come to us of the truth And we wish that our Lord will admit us along with the righteous people."\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
So because of what they said, Allah awarded them with Gardens under which rivers flow, they will abide therein forever. Such is the reward of good-doers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who disbelieved and belied Our Ayat, they shall be the dwellers of Hell.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O you who believe! Make not unlawful the good things which Allah has made lawful to you, and transgress not. Verily, Allah does not like the transgressors.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
And eat of the things which Allah has provided for you, lawful and good, and have Taqwa of Allah in Whom you believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah will not punish you for what is unintentional in your oaths, but He will punish you for your deliberate oaths; for its expiation feed ten poor, on a scale of the Awsat of that with which you feed your own families; or clothe them; or free a slave. But whosoever cannot afford, then he should fast for three days. That is the expiation for the oaths when you have sworn. And protect your oaths. Thus Allah makes clear to you His Ayat that you may be grateful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O you who believe! Khamr, Maysir, Ansab, and Azlam are a Rijs of Shaytan's handiwork. So avoid that in order that you may be successful.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Shaytan wants only to excite enmity and hatred between you with Khamr and Maysir, and hinder you from the remembrance of Allah and from the Salah (the prayer). So, will you not then abstain\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
And obey Allah and obey the Messenger, and beware. Then if you turn away, you should know that it is Our Messenger's duty to convey in the clearest way.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
Those who believe and do righteous good deeds, there is no sin on them for what they ate, if they have Taqwa and believe and do righteous good deeds, and they (again) have Taqwa and believe, and then (once again) have Taqwa and perform good. And Allah loves the good-doers.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O you who believe! Allah will certainly make a trial for you with something in the game that is well within reach of your hands and your lances, that Allah may test who fears Him in the unseen. Then whoever transgresses thereafter, for him there is a painful torment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O you who believe! Kill not game while you are in a state of Ihram, and whosoever of you kills it intentionally, the penalty is an offering, brought to the Ka`bah, of livestock equivalent to the one he killed, as adjudged by two just men among you; or, for expiation, he should feed the poor, or its equivalent in fasting, that he may taste the heaviness (punishment) of his deed. Allah has forgiven what is past, but whosoever commits it again, Allah will take retribution from him. And Allah is Almighty, All-Able of Retribution.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Lawful to you is water game and its use for food -- for the benefit of yourselves and those who travel, but forbidden is (the pursuit of) land game as long as you are in a state of Ihram. And have Taqwa of Allah to Whom you shall be gathered back.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah has made the Ka`bah, the Sacred House, an asylum of security and benefits for mankind, and also the Sacred Month and the animals of offerings and the garlanded, that you may know that Allah has knowledge of all that is in the heavens and all that is in the earth, and that Allah is the All-Knower of each and everything.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that Allah is severe in punishment and that Allah is Oft-Forgiving, Most Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
The Messenger's duty is but to convey. And Allah knows all that you reveal and all that you conceal.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say: ``Not equal are the bad things and the good things, even though the abundance of the bad may please you. `` So have Taqwa of Allah, O men of understanding in order that you may be successful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O you who believe! Ask not about things which, if made plain to you, may cause you trouble. But if you ask about them while the Qur'an is being revealed, they will be made plain to you. Allah has forgiven that, and Allah is Oft-Forgiving, Most Forbearing.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
Before you, a community asked such questions, then on that account they became disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah has not instituted things like Bahirah or a Sa'ibah or a Wasilah or a Ham. But those who disbelieve invent lies against Allah, and most of them have no understanding.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said to them: ``Come to what Allah has revealed and unto the Messenger." They say: ``Enough for us is that which we found our fathers following," even though their fathers had no knowledge whatsoever and no guidance.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O you who believe! Take care of yourselves. If you follow the right guidance, no hurt can come to you from those who are in error. The return of you all is to Allah, then He will inform you about (all) that you used to do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O you who believe! When death approaches any of you, and you make a bequest, then take the testimony of two just men of your own folk or two others from outside, if you are traveling through the land and the calamity of death befalls you. Detain them both after the Salah (the prayer), (then) if you are in doubt (about their truthfulness), let them both swear by Allah (saying): ``We wish not for any worldly gain in this, even though he (the beneficiary) be our near relative. We shall not hide the testimony of Allah, for then indeed we should be of the sinful."\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
If it then becomes known that these two had been guilty of sin, let two others stand forth in their places, nearest in kin from among those who claim a lawful right. Let them swear by Allah (saying): ``We affirm that our testimony is truer than that of both of them, and that we have not trespassed (the truth), for then indeed we should be of the wrongdoers."\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
That should make it closer (to the fact) that their testimony would be in its true nature and shape, or else they would fear that (other) oaths would be admitted after their oaths. And have Taqwa of Allah and listen (with obedience to Him). And Allah guides not the rebellious people.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
On the Day when Allah will gather the Messengers together and say to them: ``What was the response you received (from men to your teaching)" They will say: ``We have no knowledge, verily, only You are the Knower of all that is hidden."\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
(Remember) when Allah will say (on the Day of Resurrection): ``O `Isa, son of Maryam! Remember My favor to you and to your mother when I supported you with Ruh - il-Qudus [Jibril] so that you spoke to the people in the cradle and in maturity; and when I taught you the Book, the Hikmah, the Tawrah and the Injil; and when you made out of the clay, as it were, the figure of a bird, by My permission, and you breathed into it, and it became a bird by My permission, and you healed those born blind, and the lepers by My permission, and when you brought forth the dead by My permission; and when I restrained the Children of Israel from you since you came unto them with clear proofs, and the disbelievers among them said: `This is nothing but evident magic."'\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
``And when I Awhaytu [put in the hearts of] Al- Hawariyyin to believe in Me and My Messenger, they said: `We believe. And bear witness that we are Muslims."'\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
(Remember) when Al-Hawariyun said: ``O `Isa, son of Maryam! Can your Lord send down to us a Ma'idah from heaven" `Isa said: ``Have Taqwa of Allah, if you are indeed believers."\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said: ``We wish to eat thereof and to be stronger in faith, and to know that you have indeed told us the truth and that we ourselves be its witnesses. ``\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
`Isa, son of Maryam, said: ``O Allah, our Lord! Send us from heaven a table spread (with food) that there may be for us -- for the first and the last of us -- a festival and a sign from You; and provide us sustenance, for You are the Best of sustainers."\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said: ``I am going to send it down unto you, but if any of you after that disbelieves, then I will punish him with a torment such as I have not inflicted on anyone among the `Alamin."\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And (remember) when Allah will say (on the Day of Resurrection): ``O `Isa, son of Maryam! Did you say unto men: `Worship me and my mother as two gods besides Allah"' He will say: ``Glory be to You! It was not for me to say what I had no right (to say). Had I said such a thing, You would surely have known it. You know what is in my inner self though I do not know what is in Yours, truly, You, only You, are the Knower of all that is hidden and unseen."\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
``Never did I say to them ought except what You (Allah) did command me to say: `Worship Allah, my Lord and your Lord.' And I was a witness over them while I dwelled amongst them, but when You took me [up], You were the Watcher over them, and You are a Witness to all things."\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
``If You punish them, they are Your servants, and if You forgive them, verily You, only You are the Almighty, the All-Wise."\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah will say: ``This is a Day on which the truthful will profit from their truth: Theirs are Gardens under which rivers flow (in Paradise) -- they shall abide therein forever. Allah is pleased with them and they with Him. That is the great success.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah belongs the dominion of the heavens and the earth and all that is therein, and He is able to do all things.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen All praise be to Allah, Who created the heavens and the earth, and originated the darkness and the light, yet those who disbelieve hold others as equal with their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
He it is Who has created you from clay, and then has decreed a stated term. And there is with Him another determined term, yet you doubt.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
And He is Allah, in the heavens and the earth, He knows what you conceal and what you reveal, and He knows what you earn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
And never an Ayah comes to them from the Ayat of their Lord, but that they have been turning away from it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
Indeed, they rejected the truth when it came to them, but there will come to them the news of that which they used to mock at.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not seen how many a generation before them We have destroyed whom We had established on the earth such as We have not established you And We poured out on them rain from the sky in abundance, and made the rivers flow under them. Yet We destroyed them for their sins, and created after them other generations.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
And even if We had sent down unto you a Message written on paper so that they could touch it with their hands, the disbelievers would have said: ``This is nothing but obvious magic!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
And they say: ``Why has not an angel been sent down to him" Had We sent down an angel, the matter would have been judged at once, and no respite would be granted to them.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
And had We appointed him an angel, We indeed would have made him a man, and We would have certainly caused them confusion in a matter which they have already covered with confusion.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
And indeed Messengers were mocked before you, but their scoffers were surrounded by the very thing that they used to mock at.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say: ``Travel in the land and see what was the end of those who rejected truth."\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say: ``To whom belongs all that is in the heavens and the earth" Say: ``To Allah." He has prescribed mercy for Himself. Indeed He will gather you together on the Day of Resurrection, about which there is no doubt. Those who destroy themselves will not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
And to Him belongs whatsoever exists in the night and the day, and He is the All-Hearing, the All-Knowing."\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say: ``Shall I take as a guardian any other than Allah, the Creator of the heavens and the earth And it is He Who feeds but is not fed." Say: ``Verily, I am commanded to be the first of those who submit. ``And be not you of the idolators.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say: ``I fear, if I disobey my Lord, the torment of a Mighty Day."\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
Who is averted from (such a torment) on that Day; then He (Allah) has surely been Merciful to him. And that would be the obvious success.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
And if Allah touches you with harm, none can remove it but He, and if He touches you with good, then He is able to do all things.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
And He is the Irresistible, above His servants, and He is the All-Wise, Well-Acquainted with all things.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say: ``What thing is the most great in witness" Say: ``Allah is Witness between you and I; this Qur'an has been revealed to me that I may therewith warn you and whomsoever it may reach. Can you verily bear witness that besides Allah there are other gods" Say ``I bear no (such) witness!" Say: ``Only He is God, alone, and truly I am innocent of what you join in worship with Him."\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Scripture recognize him, as they recognize their own children. Those who have lost (destroyed) themselves will not believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who does more wrong than he who invents a lie against Allah or rejects His Ayat Verily, the wrongdoers shall never be successful.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And on the Day when We shall gather them all together, We shall say to those who joined partners in worship (with Us): ``Where are your partners (false deities) whom you used to assert (as partners in worship with Allah)"\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
There will then be (left) no Fitnah for them but to say: ``By Allah, our Lord, we were not those who joined others (in worship with Allah)."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
Look! How they lie against themselves! But the (lie) which they invented will disappear from them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And of them there are some who listen to you; but We have set veils on their hearts, so they understand it not, and deafness in their ears; if they see every one of the Ayat they will not believe therein; to the point that when they come to you to argue with you, those who disbelieve say: ``These are nothing but tales of the men of old."\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they prevent others from him and they themselves keep away from him, and (by doing so) they destroy none but themselves, yet they perceive (it) not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If you could but see when they will be held over the (Hell) Fire! They will say: ``Would that we were but sent back (to the world)! Then we would not deny the Ayat of our Lord, and we would be of the believers!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
Nay, what they had been concealing before has become manifest to them. But if they were returned (to the world), they would certainly revert to that which they were forbidden. And indeed they are liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they said: ``There is no (other life) but our (present) life of this world, and never shall we be resurrected."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If you could but see when they will stand before their Lord! He will say: ``Is not this the truth" They will say: ``Yes, by our Lord!" He will then say: ``So taste you the torment because you used not to believe."\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
They indeed are losers who denied their meeting with Allah, until all of a sudden, the Hour (signs of death) is upon them, and they say: ``Alas for us that we gave no thought to it," while they will bear their burdens on their backs; and evil indeed are the burdens that they will bear!\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
And the life of this world is nothing but play and amusement. But far better is the abode of the Hereafter for those have Taqwa. Will you not then understand\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know indeed the grief which their words cause you; it is not you that they deny, but it is the verses of Allah that the wrongdoers deny.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
Verily, (many) Messengers were denied before you, but with patience they bore the denial, and they were hurt, till Our help reached them, and none can alter the Words of Allah. Surely, there has reached you the information about the Messengers (before you).\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
If their aversion is hard on you, then if you were able to seek a tunnel in the ground or a ladder to the sky, so that you may bring them a sign. And had Allah willed, He could have gathered them together upon true guidance, so be not you one of the ignorant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
It is only those who listen, that will respond, but as for the dead, Allah will raise them up, then to Him they will be returned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they said: ``Why is not a sign sent down to him from his Lord" Say: ``Allah is certainly able to send down a sign, but most of them know not."\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
There is not a moving creature on earth, nor a bird that flies with its two wings, but are Umam like you. We have neglected nothing in the Book, then unto their Lord they (all) shall be gathered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
Those who reject Our Ayat are deaf and dumb in darkness. Allah sends astray whom He wills and He guides on the straight path whom He wills.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say: ``Tell me if Allah's torment comes upon you, or the Hour comes upon you, would you then call upon any one other than Allah (Reply) if you are truthful!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
Nay! To Him alone you call, and, if He willed, He would remove that (distress) for which you call upon Him, and you forget at that time whatever partners you joined with Him (in worship)!\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
Verily, We sent (Messengers) to many nations before you. And We seized them with extreme poverty and loss of health so that they might believe with humility.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
When Our torment reached them, why then did they not believe with humility But their hearts became hardened, and Shaytan made fair-seeming to them that which they used to do.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
So, when they forgot (the warning) with which they had been reminded, We opened to them the gates of every (pleasant) thing, until in the midst of their enjoyment in that which they were given, all of a sudden, We took them to punishment, and lo! They were plunged into destruction with deep regrets and sorrows.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
So the roots of the people who did wrong were cut off. And all the praises and thanks be to Allah, the Lord of the all that exists.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say: ``Tell me, if Allah took away your hearing and your sight, and sealed up your hearts, is there a god other than Allah who could restore them to you" See how variously We explain the Ayat, yet they turn aside.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say: ``Tell me, if the punishment of Allah comes to you suddenly, or openly, will any be destroyed except the wrongdoing people"\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
And We send not the Messengers but as givers of glad tidings and as warners. So whosoever believes and does righteous good deeds, upon such shall come no fear, nor shall they grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But those who reject Our Ayat, the torment will strike them for their rebelling.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say: ``I don't tell you that with me are the treasures of Allah, nor (that) I know the Unseen; nor do I tell you that I am an angel. I but follow what is revealed to me." Say: ``Are the blind and the one who sees equal Will you not then consider"\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn therewith those who fear that they will be gathered before their Lord, when there will be neither a protector nor an intercessor for them besides Him, so that they may have Taqwa.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And turn not away those who invoke their Lord, morning and evening seeking His Face. You are accountable for them in nothing, and they are accountable for you in nothing, that you may turn them away, and thus become of the wrongdoers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
Thus We have tried some of them with others, that they might say: ``Is it these (poor believers) that Allah has favored from amongst us" Does not Allah know best those who are grateful\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
When those who believe in Our Ayat come to you, say: ``Salamun `Alaykum" (peace be on you); your Lord has written mercy for Himself, so that, if any of you does evil in ignorance, and thereafter repents and does righteous good deeds, then surely, He is Oft-Forgiving, Most Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
And thus do We explain the Ayat in detail, that the way of the criminals, may become manifest.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say: ``I have been forbidden to worship those whom you invoke (worship) besides Allah." Say: ``I will not follow your vain desires. If I did, I would go astray, and I would not be one of the rightly guided."\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say: ``I am on clear proof from my Lord, but you deny it. I do not have what you are hastily seeking (the torment). The decision is only for Allah, He declares the truth, and He is the best of judges."\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say: ``If I had that which you are asking for impatiently (the torment), the matter would have been settled at once between you and I, but Allah knows best the wrongdoers."\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
And with Him are the keys of the Ghayb (all that is hidden), none knows them but He. And He knows whatever there is on the land and in the sea; not a leaf falls, but he knows it. There is not a grain in the darkness of the earth nor anything fresh or dry, but is written in a Clear Record.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
It is He, Who takes your souls by night (when you are asleep), and has knowledge of all that you have done by day, then he raises (wakes) you up again, that a term appointed be fulfilled, then (in the end), unto Him will be your return. Then He will inform you of what you used to do.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
He is the Qahir over His servants, and He sends guardians over you, until when death approaches one of you, Our messengers take his soul, and they never neglect their duty.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then they are returned to Allah, their Master, the Just Lord. Surely, His is the judgment and He is the swiftest in taking account.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say: ``Who rescues you from the dark recesses of the land and the sea, when you call upon Him begging and in secret (saying): `If He (Allah) only saves us from these (dangers), we shall truly be grateful."\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say: ``Allah rescues you from these (dangers) and from all distress, and yet you commit Shirk."\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say: ``He has the power to send torment on you from above or from under your feet, or to Yalbisakum in party strife, and make you taste the violence of one another." See how variously We explain the Ayat, so that they may understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
But your people have denied it (the Qur'an) though it is the truth. Say: ``I am not responsible for your affairs."\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every news there is a reality and you will come to know.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
And when you see those who engage in false conversation about Our verses (of the Qur'an) by mocking at them, stay away from them till they turn to another topic. And if Shaytan causes you to forget, then after the remembrance, sit not you in the company of those people who are the wrongdoers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
There is no responsibility for them upon those who have Taqwa, but (their duty) is to remind them, that they may (attain) Taqwa.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
And leave alone those who take their religion as play and amusement, and are deceived by the life of this world. But remind (them) with it (the Qur'an) lest a soul Tubsal for that which one has earned, when he will find for himself no protector or intercessor besides Allah, and even if he offers every ransom, it will not be accepted from him. Such are they who are given up to destruction because of that which they have earned. For them will be a drink of boiling water and a painful torment because they used to disbelieve.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say: ``Shall we invoke others besides Allah (false deities), that can do us neither good nor harm, and shall we turn on our heels after Allah has guided us -- Like one whom the Shayatin (devils) have made to go astray, confused (wandering) through the land, his companions calling him to guidance (saying): `Come to us."' Say: ``Verily, Allah's guidance is the only guidance, and we have been commanded to submit (ourselves) to the Lord of all that exists.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
And to perform the Salah, and have Taqwa of Him, and it is He to Whom you shall be gathered.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
It is He Who has created the heavens and the earth in truth, and on the Day He will say: ``Be!" it shall become. His Word is the truth. His will be the dominion on the Day when the Sur will be blown. All-Knower of the unseen and the seen. He is the All-Wise, Well-Aware.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And (remember) when Ibrahim said to his father Azar: ``Do you take idols as gods Verily, I see you and your people in manifest error."\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
Thus did we show Ibrahim the kingdom of the heavens and the earth that he be one of those who have faith with certainty.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
When the night overcame him he saw a Kawkab. He said: ``This is my lord." But when it Afala, he said: ``I like not those that set."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
When he saw the moon rising up, he said: ``This is my lord." But when it set, he said: ``Unless my Lord guides me, I shall surely be among the misguided people."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
When he saw the sun rising up, he said: ``This is my lord. This is greater." But when it Afalat, he said: ``O my people! I am indeed free from all that you join as partners in worship with Allah.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
Verily, I have turned my face towards Him Who has created the heavens and the earth, Hanifan, and I am not of the idolators."\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
His people disputed with him. He said: ``Do you dispute with me about Allah while He has guided me, and I fear not those whom you associate with Allah in worship. (Nothing can happen to me) except when my Lord wills something. My Lord comprehends in His knowledge all things. Will you not then remember\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
And how should I fear those whom you associate in worship with Allah, while you fear not that you have joined in worship with Allah things for which He has not sent down to you any Sultan. (So) which of the two parties has more right to be in security If you but know."\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
It is those who believe and confuse not their belief with Zulm (wrong), for them (only) there is security and they are the guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
And that was Our proof which We gave Ibrahim against his people. We in degrees raise whom We will. Certainly your Lord is All-Wise, All-Knowing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We bestowed upon him Ishaq and Ya`qub, each of them We guided, and before him, We guided Nuh and among his progeny Dawud, Sulayman, Ayyub, Yusuf, Musa, and Harun. Thus do We reward the good-doers.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And Zakariyya, and Yahya and `Isa and Iliyas, each one of them was of the righteous.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Isma`il and Al-Yasa`, and Yunus and Lut, and each one of them We preferred above the `Alamin (mankind and Jinns, of their times).\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And also some of their fathers and their progeny and their brethren, We chose them, and We guided them to a straight path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
This is the guidance of Allah with which He guides whomsoever He wills of His servants. But if they had joined in worship others with Allah, all that they used to do would have been of no benefit to them.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
They are those whom We gave the Book, Al-Hukm, and prophethood. But if they disbelieve therein, then, indeed We have entrusted it to a people who are not disbelievers therein.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
They are those whom Allah had guided. So follow their guidance. Say: ``No reward I ask of you for this (the Qur'an). It is only a reminder for the `Alamin (mankind and Jinns)."\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
They did not estimate Allah with an estimation due to Him when they said: ``Nothing did Allah send down to any human being (by inspiration)." Say: ``Who then sent down the Book which Musa brought, a light and a guidance to mankind which you (the Jews) have made into (separate) papersheets, disclosing (some of it) and concealing much. And you were taught that which neither you nor your fathers knew." Say: ``Allah (sent it down)." Then leave them to play in their vain discussions.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is a blessed Book which We have sent down, confirming what came before it, so that you may warn the Mother of Towns and all those around it. Those who believe in the Hereafter believe in it, and they are constant in guarding their Salah.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
And who can be more unjust than he who invents a lie against Allah, or says: ``I have received inspiration," whereas he is not inspired in anything; and who says, ``I will reveal the like of what Allah has revealed." And if you could but see when the wrongdoers are in the agonies of death, while the angels are stretching forth their hands (saying): ``Deliver your souls! This day you shall be recompensed with the torment of degradation because of what you used to utter against Allah other than the truth. And you used to reject His Ayat with disrespect!"\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
And truly you have come unto Us alone, as We created you the first time. You have left behind you all that which We had bestowed on you. We see not with you your intercessors whom you claimed to be your partners. Now you and they have been cut off, and all that you used to claim has vanished from you.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Verily! It is Allah Who causes the seed grain and the fruit stone to split and sprout. He brings forth the living from the dead, and it is He Who brings forth the dead from the living. Such is Allah, then how are you deluded away from the truth\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
(He is the) Cleaver of the daybreak. He has appointed the night for resting, and the sun and the moon for reckoning. Such is the measuring of the Almighty, the All-Knowing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
It is He Who has set the stars for you, so that you may guide your course with their help through the darkness of the land and the sea. We have (indeed) explained in detail Our Ayat for people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
It is He Who has created you from a single person, and has given you a place of residing and a place of storage. Indeed, We have explained in detail Our revelations for people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
It is He Who sends down water from the sky, and with it We bring forth vegetation of all kinds, and out of it We bring forth green stalks, from which We bring forth thick clustered grain. And out of the date-palm and its sprouts come forth clusters of dates hanging low and near, and gardens of grapes, olives and pomegranates, each similar, yet different. Look at their fruits when they begin to bear, and Yan`ih. Verily! In these things there are signs for people who believe.) Allah said,\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
Yet, they join the Jinns as partners in worship with Allah, though He has created them, and they attribute, falsely without knowledge - sons and daughters to Him. Be He Glorified and Exalted above what that they attribute to Him.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
He is the Badi` (Originator) of the heavens and the earth. How can He have children when He has no wife He created all things and He is the All-Knower of everything.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
Such is Allah, your Lord! None has the right to be worshipped but He, the Creator of all things. So worship Him (alone), and He is the Guardian over all things.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
No vision can grasp Him, but His grasp is over all vision. He is the Most Subtle, Well-Acquainted (with all things).\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
Verily, Basa'ir (proofs) have come to you from your Lord, so whosoever sees, will do so for (the good of) himself, and whosoever blinds himself, will do so against himself, and I am not a Hafiz over you.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
Thus We explain variously the verses so that they (the disbelievers) may say: ``You have Darasta (studied)" and that We may make the matter clear for the people who have knowledge.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow what has been inspired (revealed) to you from your Lord, none has the right to be worshipped but He, and turn aside from the idolators.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
Had Allah willed, they would not have taken others besides Him in worship. And We have not made you Hafiz over them nor are you set over them to dispose of their affairs.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
And insult not those whom they worship besides Allah, lest they insult Allah wrongfully without knowledge. Thus We have made fair seeming to each people its own doings; then to their Lord is their return and He shall inform them of all that they used to do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
And they swear their strongest oaths by Allah, that if there came to them a sign, they would surely believe therein. Say: ``Signs are but with Allah and what will make you perceive that (even) if it came, they will not believe"\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
And We shall turn their hearts and their eyes away, as they refused to believe therein for the first time, and We shall leave them in their trespass to wander blindly.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
And even if We had sent down unto them angels, and the dead had spoken unto them, and We had gathered together all things before them, they would not have believed, unless Allah willed, but most of them behave ignorantly.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
And so We have appointed for every Prophet enemies -- Shayatin among mankind and Jinn, inspiring one another with adorned speech as a delusion. If your Lord had so willed, they would not have done it; so leave them alone with their fabrications.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
And Tasgha to it that the hearts of those who do not believe in the Hereafter may incline to such (deceit), and that they may remain pleased with it, and that they may commit what they are committing.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
[Say:] ``Shall I seek a judge other than Allah while it is He Who has sent down unto you the Book, explained in detail." Those unto whom We gave the Scripture know that it is revealed from your Lord in truth. So be not you of those who doubt.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
And the Word of your Lord has been fulfilled in truth and in justice. None can change His Words. And He is the All-Hearer, the All-Knower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
And if you obey most of those on the earth, they will mislead you far away from Allah's path. They follow nothing but conjecture, and they do nothing but lie.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Verily, your Lord! It is He Who knows best who strays from His way, and He knows best the rightly guided.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
So eat of that on which Allah's Name has been mentioned, if you are believers in His Ayat.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
And why should you not eat of that on which Allah's Name has been mentioned, while He has explained to you in detail what is forbidden to you, except under compulsion of necessity And surely, many do lead astray by their own desires through lack of knowledge. Certainly your Lord knows best the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
Leave sin, open and secret. Verily, those who commit sin will get due recompense for that which they used to commit.) Mujahid said that,\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
Eat not of that on which Allah's Name has not been pronounced, for surely it is disobedience. And certainly, the Shayatin do inspire their friends to dispute with you, and if you obey them, then you would indeed be polytheists.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
Is he who was dead, and We gave him life, and set for him a light, whereby he can walk among men -- like him who is in the darkness from which he can never come out Thus it is made fair seeming to the disbelievers that which they used to do.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And thus We have set up in every town great ones of its wicked people to plot therein. But they plot not except against themselves, and they perceive (it) not.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And when there comes to them a sign they say: ``We shall not believe until we receive the like of that which the Messengers of Allah received." Allah knows best with whom to entrust His Message. Humiliation and disgrace from Allah and a severe torment will overtake the criminals for that which they used to plot.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
And whomsoever Allah wills to guide, He opens his breast to Islam; and whomsoever He wills to send astray, He makes his breast closed and constricted, as if he is climbing up to the sky. Thus Allah puts the wrath on those who believe not.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
And this is the path of your Lord leading straight. We have detailed Our Ayat for a people who take heed.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them will be the abode of peace with their Lord. And He will be their Wali because of what they used to do.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
And on the Day when He will gather them together (and say): ``O you assembly of Jinn! Many did you mislead of men," and their friends among the people will say: ``Our Lord! We benefited one from the other, but now we have reached our appointed term which You did appoint for us. `` He will say: ``The Fire be your dwelling place, you will dwell therein forever, except as Allah may will. Certainly your Lord is All-Wise, All-Knowing."\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
And thus We do make the wrongdoers supporters of one another, because of that which they used to earn.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
O you assembly of Jinn and humans! ``Did not there come to you Messengers from amongst you, reciting unto you My verses and warning you of the meeting of this Day of yours" They will say: ``We bear witness against ourselves." It was the life of this world that deceived them. And they will bear witness against themselves that they were disbelievers.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
This is because your Lord would not destroy the (populations of) towns for their wrongdoing while their people were unaware.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
For all there will be degrees according to what they did. And your Lord is not unaware of what they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
And your Lord is Al-Ghani, full of mercy; if He wills, He can destroy you; and in your place make whom He wills as your successors, as He raised you from the seed of other people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Surely, that which you are promised, will verily come to pass, and you cannot escape.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say: ``O my people! Work according to your way, surely, I too am working, and you will come to know for which of us will be the (happy) end in the Hereafter. Certainly the wrongdoers will not be successful."\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
And they assign to Allah a share of the tilth and cattle which He has created, and they say: ``This is for Allah," according to their claim, ``and this is for our partners." But the share of their ``partners" reaches not Allah, while the share of Allah reaches their ``partners"! Evil is the way they judge!\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
And so to many of the idolators, their ``partners" have made fair seeming the killing of their children, in order to lead them to their own destruction and cause confusion in their religion. And if Allah had willed, they would not have done so. So leave them alone with their fabrications.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And according to their claim, they say that such and such cattle and crops are Hijr (forbidden), and none should eat of them except those whom we allow. And (they say) there are cattle forbidden to be used for burden, and cattle on which (at slaughtering) the Name of Allah is not pronounced; lying against Him (Allah). He will recompense them for what they used to fabricate.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say: ``What is in the bellies of such and such cattle is for our males alone, and forbidden to our females, but if it is born dead, then all have shares therein." He will punish them for their attribution (of such false orders to Allah). Verily, He is All-Wise, All-Knower.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Indeed lost are they who have killed their children, foolishly, without knowledge, and (they) have forbidden that which Allah has provided for them, inventing a lie against Allah. They have indeed gone astray and were not guided.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
And it is He Who produces gardens Ma`rushat and not Ma`rushat, and date palms, and crops of different shape and taste, and olives, and pomegranates, similar, and different. Eat of their fruit when they ripen, but pay the due thereof on the day of their harvest, and waste not by extravagance. Verily, He likes not the wasteful.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the cattle (are some) for burden and (some smaller) for Farsh. Eat of what Allah has provided for you, and follow not the footsteps of Shaytan. Surely, he is to you an open enemy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
Eight pairs: of the sheep two (male and female), and of the goats two (male and female). Say: ``Has He forbidden the two males or the two females, or (the young) which the wombs of the two females enclose Inform me with knowledge if you are truthful. ``\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And of the camels two, and of oxen two. Say: ``Has He forbidden the two males or the two females or (the young) which the wombs of the two females enclose Or were you present when Allah ordered you such a thing Then who does more wrong than one who invents a lie against Allah, to lead mankind astray without knowledge. Certainly Allah guides not the people who are wrongdoers."\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say: ``I find not in that which has been revealed to me anything forbidden to be eaten by one who wishes to eat it, unless it be Maytah (a dead animal) or blood poured forth, or the flesh of swine; for that surely, is unclean (Rijs), or immorally slaughtered in the name of other than Allah. But whosoever is forced by necessity without willful disobedience, nor transgressing due limits; (for him) certainly, your Lord is Oft-Forgiving, Most Merciful."\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And unto those who are Jews, We forbade every (animal) with undivided hoof, and We forbade them the fat of the ox and the sheep except what adheres to their backs or their Hawaya, or is mixed up with a bone. Thus We recompensed them for their rebellion. And verily, We are Truthful.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
If they deny you say: ``Your Lord is the Owner of vast mercy, and never will His wrath be turned back from the people who are criminals."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
Those who committed Shirk say: ``If Allah had willed, we would not have commited Shirk, nor would our fathers, and we would not have forbidden anything (against His will)." Likewise belied those who were before them, till they tasted Our wrath. Say: ``Have you any knowledge (proof) that you can produce before us Verily, you follow the Zann and you do nothing but lie."\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say: ``With Allah is the perfect proof and argument; had He so willed, He would indeed have guided you all."\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say: ``Bring forward your witnesses, who can testify that Allah has forbidden this." Then if they testify, do not testify with them. And do not follow the vain desires of those who belie Our Ayat, and such as believe not in the Hereafter, and they hold others as equal with their Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say: ``Come, I will recite what your Lord has prohibited you from: Join not anything in worship with Him; be kind and dutiful to your parents; kill not your children because of poverty -- We provide sustenance for you and for them. Come not near to Al-Fawahish (immoral sins) whether committed openly or secretly; and kill not anyone whom Allah has forbidden, except for a just cause. This He has commanded you that you may understand."\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
``And come not near to the orphan's property, except to improve it, until he (or she) attains the age of full strength; and give full measure and full weight with justice." -- We burden not any person, but that which he can bear -- ``And whenever you speak, say the truth even if a near relative is concerned, and fulfill the covenant of Allah. This He commands you, that you may remember."\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
``And verily, this is My straight path, so follow it, and follow not (other) paths, for they will separate you away from His path. This He has ordained for you that you may have Taqwa."\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then, We gave Musa the Book [the Tawrah], complete for that which is best, and explaining all things in detail and a guidance and a mercy that they might believe in the meeting with their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this is a blessed Book (the Qur'an) which We have sent down, so follow it and have Taqwa, so that you may receive mercy.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
Lest you should say: ``The Book was sent down only to two sects before us, and for our part, we were in fact unaware of what they studied."\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest you should say: ``If only the Book had been sent down to us, we would surely have been better guided than they." So now has come unto you a clear proof from your Lord, and a guidance and a mercy. Who then does more wrong than one who rejects the Ayat of Allah and Sadafa away therefrom We shall requite those who turn away from Our Ayat with an evil torment, because of their turning away.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Do they then wait for anything other than that the angels should come to them, or that your Lord should come, or that some of the Signs of your Lord should come! The day that some of the signs of your Lord do come, no good will it do to a person to believe then, if he believed not before, nor earned good with his faith. Say: ``Wait you! We (too) are waiting."\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Verily, those who divide their religion and break up into sects, you have no concern with them in the least. Their affair is only with Allah, Who then will tell them what they used to do.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoever brings a good deed shall have ten times the like thereof to his credit, and whoever brings an evil deed shall have only the recompense of the like thereof, and they will not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say: ``Truly, my Lord has guided me to a straight path, a right religion, the religion of Ibrahim, Hanifan (monotheism) and he was not of the Mushrikin."\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say: ``Verily, my Salah, my sacrifice, my living, and my dying are for Allah, the Lord of all that exists."\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
``He has no partner. And of this I have been commanded, and I am the first of the Muslims."\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say: ``Shall I seek a lord other than Allah, while He is the Lord of all things No person earns any (sin) except against himself (only), and no bearer of burdens shall bear the burden of another. Then unto your Lord is your return, so He will tell you that wherein you have been differing."\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
And it is He Who has made you generations coming after generations, replacing each other on the earth. And He has raised you in ranks, some above others that He may try you in that which He has bestowed on you. Surely, your Lord is Swift in retribution, and certainly He is Oft-Forgiving, Most Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif-Lam-Mim-Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
(This is the) Book (the Qur'an) sent down unto you, so let not your breast be narrow therefrom, that you warn thereby; and a reminder unto the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow what has been sent down unto you from your Lord, and follow not any Awliya' (protectors), besides Him (Allah). Little do you remember!\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
And a great number of towns We destroyed. Our torment came upon them by night or while they were taking their midday nap.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
No cry did they utter when Our torment came upon them but this: ``Verily, we were wrongdoers."\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
Then surely, We shall question those (people) to whom it was sent and verily, We shall question the Messengers.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
Then surely, We shall narrate unto them (their whole story) with knowledge, and indeed We have not been absent.\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
And the weighing on that Day will be the true (weighing). So, as for those whose scale (of good deeds) will be heavy, they will be the successful (by entering Paradise).\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
And as for those whose scale will be light, they are those who will lose themselves for their wrongful behavior with Our Ayat.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
And surely, We gave you authority on the earth and appointed for you therein livelihoods. Little thanks do you give.\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
And surely, We created you and then gave you shape; then We told the angels, ``Prostrate yourselves to Adam," and they prostrated, except Iblis (Shaytan), he refused to be of those who prostrated.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
(Allah) said: ``What prevented you (O Iblis) that you did not prostrate, when I commanded you" Iblis said: ``I am better than him (Adam), You created me from fire, and him You created from clay."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
(Allah) said: ``(O Iblis) get down from this (Paradise), it is not for you to be arrogant here. Get out, for you are of those humiliated and disgraced."\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
(Iblis) said: ``Allow me respite till the Day they are raised up (the Day of Resurrection)."\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
(Allah) said: ``You are of those respited."\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
(Iblis) said: ``Because You have `Aghwaytni', surely, I will sit in wait against them (human beings) on Your straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
``Then I will come to them from before them and behind them, from their right and from their left, and You will not find most of them to be thankful."\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
(Allah) said (to Iblis): ``Get out from this (Paradise), Madh'uman Madhura. Whoever of them (mankind) will follow you, then surely, I will fill Hell with you all."\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
``And O Adam! Dwell you and your wife in Paradise, and eat thereof as you both wish, but approach not this tree otherwise you both will be of the wrongdoers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
Then Shaytan whispered suggestions to them both in order to uncover that which was hidden from them of their private parts (before); he said: ``Your Lord did not forbid you this tree save you should become angels or become of the immortals."\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he Qasamahuma: ``Verily, I am one of the sincere well-wishers for you both."\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he misled them with deception. Then when they tasted of the tree, that which was hidden from them of their shame (private parts) became manifest to them and they began to cover themselves with the leaves of Paradise. And their Lord called out to them (saying): ``Did I not forbid you that tree and tell you: Verily, Shaytan is an open enemy unto you"\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said: ``Our Lord! We have wronged ourselves. If You forgive us not, and bestow not upon us Your mercy, we shall certainly be of the losers."\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
(Allah) said: ``Get down, one of you an enemy to the other. On earth will be a dwelling place for you and an enjoyment for a time."\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said: ``Therein you shall live, and therein you shall die, and from it you shall be brought out (resurrected)."\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O Children of Adam! We have bestowed Libas (raiment) upon you to cover yourselves with, and as Rish (adornment); and the Libas (raiment) of Taqwa, that is better. Such are among the Ayat of Allah, that they may remember.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O Children of Adam! Let not Shaytan deceive you, as he got your parents out of Paradise, stripping them of their raiment, to show them their private parts. Verily, he and his tribe see you from where you cannot see them. Verily, We made the Shayatin friends of those who believe not.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they commit a Fahishah, they say: ``We found our fathers doing it, and Allah has commanded it for us." Say: ``Nay, Allah never commands Fahishah. Do you say about Allah what you know not"\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say: ``My Lord has commanded justice and that you should face Him only, in every Masjid and invoke Him only, making your religion sincere to Him. As He brought you (into being) in the beginning, so shall you be brought into being again."\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
A group He has guided, and a group deserved to be in error; (because) surely, they took the Shayatin as supporters instead of Allah, and think that they are guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O Children of Adam! Take your adornment to every Masjid, and eat and drink, but waste not by extravagance, certainly He (Allah) likes not the wasteful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say: ``Who has forbidden the adornment with clothes given by Allah, which He has produced for His servants, and At-Tayyibat (good things) of sustenance" Say: ``They are, in the life of this world, for those who believe, (and) exclusively for them (believers) on the Day of Resurrection." Thus We explain the Ayat in detail for people who have knowledge.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say: ``(But) the things that my Lord has indeed forbidden are the Fawahish (immoral deeds) whether committed openly or secretly, and Ithm, and transgression without right, and joining partners with Allah for which He has given no authority, and saying things about Allah of which you have no knowledge."\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
And every Ummah has its appointed term; when their term comes, neither can they delay it nor can they advance it an hour (or a moment).\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O Children of Adam! If there come to you Messengers from among you, reciting to you My Ayat, then whosoever has Taqwa and becomes righteous, on them shall be no fear nor shall they grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
But those who reject Our Ayat and treat them with arrogance, they are the dwellers of the Fire, they will abide therein forever.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
Who is more unjust than one who invents a lie against Allah or rejects His Ayat For such their appointed portion will reach them from the Book (of Decrees) until Our messengers (the angel of death and his assistants) come to them to take their souls, they (the angels) will say: ``Where are those whom you used to invoke and worship besides Allah," they will reply, ``They have vanished and deserted us." And they will bear witness against themselves, that they were disbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
(Allah) will say: ``Enter you in the company of nations who passed away before you, of men and Jinn, into the Fire." Every time a new nation enters, it curses its sister nation (that went before) until they are all together in the Fire. The last of them will say to the first of them: ``Our Lord! These misled us, so give them a double torment of the Fire." He will say: ``For each one there is double (torment), but you know not."\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
The first of them will say to the last of them: ``You were not better than us, so taste the torment for what you used to earn."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Verily, those who belie Our Ayat and treat them with arrogance, for them the gates of the heavens will not be opened, and they will not enter Paradise until the Jamal goes through the eye of the needle. Thus do We recompense the criminals.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
Theirs will be Mihad from the Fire, and over them Ghawash. Thus do We recompense the wrongdoers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
But those who believed, and worked righteousness -- We burden not any person beyond his scope -- such are the dwellers of Paradise. They will abide therein.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We shall remove from their breasts any Ghill; rivers flowing under them, and they will say: ``All the praises and thanks be to Allah, Who has guided us to this, and never could we have found guidance, were it not that Allah had guided us! Indeed, the Messengers of our Lord did come with the truth." And it will be cried out to them: ``This is the Paradise which you have inherited for what you used to do."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the dwellers of Paradise will call out to the dwellers of the Fire (saying): ``We have indeed found true what our Lord had promised us; have you also found true what your Lord promised (warned)" They shall say: ``Yes." Then a crier will proclaim between them: ``The curse of Allah is on the wrongdoers."\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
Those who hindered (men) from the path of Allah, and would seek to make it crooked, and they were disbelievers in the Hereafter.\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
And between them will be a (barrier) screen and on Al-A`raf will be men, who would recognize all, by their marks. And they will call out to the dwellers of Paradise, ``Peace be on you" and at that time they will not yet have entered it (Paradise), but they will hope to enter (it).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes will be turned towards the dwellers of the Fire, they will say: ``Our Lord! Place us not with the people who are wrongdoers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the men on Al-A`raf will call unto the men whom they would recognize by their marks, saying: ``Of what benefit to you was your gathering, and your arrogance"\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
``Are they those, of whom you swore that Allah would never show them mercy (Behold! It has been said to them): `Enter Paradise, no fear shall be on you, nor shall you grieve."'\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
And the dwellers of the Fire will call to the dwellers of Paradise: ``Pour on us some water or anything that Allah has provided you with." They will say: ``Both (water and provision) Allah has forbidden for the disbelievers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
``Who took their religion as amusement and play, and the life of the world deceived them." So this Day We shall forget them as they forgot their meeting of this Day, and as they used to reject Our Ayat.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
Certainly, We have brought to them a Book (the Qur'an) which We have explained in detail with knowledge, a guidance and a mercy to a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Await they just for the final fulfillment of the event On the Day the event is finally fulfilled, those who neglected it before will say: ``Verily, the Messengers of our Lord did come with the truth, now are there any intercessors for us that they might intercede on our behalf Or could we be sent back (to the first life of the world) so that we might do (good) deeds other than those (evil) deeds which we used to do" Verily, they have lost themselves and that which they used to fabricate has gone away from them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Indeed, your Lord is Allah, Who created the heavens and the earth in Six Days, and then He rose over (Istawa) the Throne. He brings the night as a cover over the day, seeking it rapidly, and (He created) the sun, the moon, the stars subjected to His command. Surely, His is the creation and commandment. Blessed is Allah, the Lord of all that exists!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Invoke your Lord Tadarru`an and Khufyah. He likes not the aggressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
And do not do mischief on the earth, after it has been set in order, and invoke Him with fear and hope. Surely, Allah's mercy is (ever) near unto the good-doers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
And it is He Who sends the winds as heralds of glad tidings, going before His mercy (rain). Till when they have carried a heavy-laden cloud, We drive it to a land that is dead, then We cause water (rain) to descend thereon. Then We produce every kind of fruit therewith. Similarly, We shall raise up the dead, so that you may remember or take heed.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
The vegetation of a good land comes forth (easily) by the permission of its Lord; and that which is bad, brings forth nothing but (a little) with difficulty. Thus do We explain variously the Ayat for a people who give thanks.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
Indeed, We sent Nuh to his people and he said: ``O my people! Worship Allah! You have no other god but Him. Certainly, I fear for you the torment of a Great Day!"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
The leaders of his people said: ``Verily, we see you in plain error."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
[Nuh] said: ``O my people! There is no error in me, but I am a Messenger from the Lord of all that exists!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
I convey unto you the Messages of my Lord and give sincere advice to you. And I know from Allah what you know not."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
``Do you wonder that there has come to you a Reminder from your Lord through a man from among you, that he may warn you, so that you may fear Allah and that you may receive (His) mercy"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they belied him, so We saved him and those along with him in the Fulk, and We drowned those who belied Our Ayat. They were indeed a blind people.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And to `Ad (the people, We sent) their brother Hud. He said: ``O my people! Worship Allah! You have no other god but Him. Will you then not have Taqwa"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
The leaders of those who disbelieved among his people said: ``Verily, we see you in foolishness, and verily, we think you are one of the liars."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
(Hud) said: ``O my people! There is no foolishness in me, but (I am) a Messenger from the Lord of all that exists!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
``I convey unto you the Messages of my Lord, and I am a trustworthy adviser (or well-wisher) for you.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
``Do you wonder that there has come to you a Reminder (and an advice) from your Lord through a man from among you to warn you And remember that He made you successors (generations after generations) after the people of Nuh and increased you amply in stature. So remember the graces (bestowed upon you) from Allah so that you may be successful."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said: ``You have come to us that we should worship Allah Alone and forsake that which our fathers used to worship. So bring us that wherewith you have threatened us if you are of the truthful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
(Hud) said: ``Rijs (torment) and wrath have already fallen on you from your Lord. Dispute you with me over names which you have named -- you and your fathers -- with no authority from Allah Then wait, I am with you among those who wait."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
So We saved him and those who were with him out of mercy from Us, and We severed the roots of those who belied Our Ayat; and they were not believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to Thamud (people, We sent) their brother Salih. He said: ``O my people! Worship Allah! You have no other god but Him. Indeed there has come to you a clear sign from your Lord. This she-camel of Allah is a sign unto you; so you leave her to graze in Allah's earth, and touch her not with harm, lest a painful torment should seize you.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
And remember when He made you successors (generations) after `Ad and gave you habitations in the land, you build for yourselves palaces in plains, and carve out homes in the mountains. So remember the graces (bestowed upon you) from Allah, and do not go about making mischief on the earth.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
The leaders of those who were arrogant among his people said to those who were counted weak -- to such of them as believed: ``Know you that Salih is one sent from his Lord." They said: ``We indeed believe in that with which he has been sent."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Those who were arrogant said: ``Verily, we disbelieve in that which you believe in."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they killed the she-camel and insolently defied the commandment of their Lord, and said: ``O Salih! Bring about your threats if you are indeed one of the Messengers (of Allah)."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
So the earthquake seized them, and they lay (dead), prostrate in their homes.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
Then he [Salih] turned from them, and said: ``O my people! I have indeed conveyed to you the Message of my Lord, and have given you good advice, but you like not good advisers."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And (remember) Lut, when he said to his people: ``Do you commit lewdness such as none preceding you has committed in all of the nations\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
``Verily, you practice your lusts on men instead of women. Nay, but you are a people transgressing beyond bounds."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
And the answer of his people was only that they said: ``Drive them out of your town, these are indeed men who want to be pure (from sins)!"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
Then We saved him and his family, except his wife; she was of the Ghabirin (those who lagged behind).\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained down on them a rain (of stones). Then see what was the end of the criminals.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to (the people of) Madyan, (We sent) their brother Shu`ayb. He said: ``O my people! Worship Allah! You have no other God but Him. Verily, a clear proof (sign) from your Lord has come unto you; so give full measure and full weight and wrong not men in their things, and do not do mischief on the earth after it has been set in order, that will be better for you, if you are believers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
``And sit not on every road, threatening, and hindering from the path of Allah those who believe in Him, and seeking to make it crooked. And remember when you were but few, and He multiplied you. And see what was the end of the mischief-makers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
``And if there is a party of you who believes in that with which I have been sent and a party who does not believe, so be patient until Allah judges between us, and He is the best of judges."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
The chiefs of those who were arrogant among his people said: ``We shall certainly drive you out, O Shu`ayb and those who have believed with you from our town, or else you (all) shall return to our religion." He said: ``Even though we hate it"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
``We should have invented a lie against Allah if we returned to your religion, after Allah has rescued us from it. And it is not for us to return to it unless Allah, our Lord, should will. Our Lord comprehends all things in His knowledge. In Allah (Alone) we put our trust. Our Lord! Judge between us and our people in truth, for You are the best of those who give judgment."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
The chiefs of those who disbelieved among his people said (to their people): ``If you follow Shu`ayb, be sure then you will be the losers!"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
So the earthquake seized them and they lay (dead), prostrate in their homes.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who belied Shu`ayb, became as if they had never dwelt there (in their homes). Those who belied Shu`ayb, they were the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
Then he (Shu`ayb) turned from them and said: ``O my people! I have indeed conveyed my Lord's Messages unto you and I have given you good advice. Then how can I grieve over people who are disbelievers."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
And We sent no Prophet unto any town (and they denied him), but We seized its people with Ba'sa' and Darra', so that they might humble themselves (to Allah).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We changed the evil for the good, until they `Afaw (increased), and said: ``Our fathers were touched with evil and with good." So We seized them all of a sudden while they were unaware.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
And if the people of the towns had believed and had Taqwa, certainly, We should have opened for them blessings from the heaven and the earth, but they belied (the Messengers). So We took them (with punishment) for what they used to earn.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Did the people of the towns then feel secure against the coming of Our punishment by night while they were asleep\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Or, did the people of the towns then feel secure against the coming of Our punishment in the forenoon while they were playing\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Did they then feel secure against Allah's plan None feels secure from Allah's plan except the people who are the losers.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Is it not a guidance for those who inherit the earth from its previons inhabitants that had We willed, We would have punished them for their sins. And We seal up their hearts so that they hear not\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Those were the towns whose story We relate unto you. And there came indeed to them their Messengers with clear proofs, but they were not such who would believe in what they rejected before. Thus Allah does seal up the hearts of the disbelievers.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
And most of them We found not true to their covenant, but most of them We found indeed rebellious.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then after them We sent Musa with Our signs to Fir`awn and his chiefs, but they wrongfully rejected them. So see how was the end of the mischief-makers\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
And Musa said: ``O Fir`awn! Verily, I am a Messenger from the Lord of all that exists."\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
``Proper it is for me that I say nothing concerning Allah but the truth. Indeed I have come unto you from your Lord with a clear proof. So let the Children of Israel depart along with me."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
[Fir`awn] said: ``If you have come with a sign, show it forth, if you are one of those who tell the truth."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
Then [Musa] threw his staff and behold! it was a [Thu`ban] serpent, manifest!\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew out his hand, and behold! it was white (with radiance) for the beholders.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
The chiefs of the people of Fir`awn said: ``This is indeed a well-versed sorcerer."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
``He wants to get you out of your land, so what do you advise"\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said: ``Put him and his brother off (for a time), and send callers to the cities to collect"\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
``That they bring to you all well-versed sorcerers."\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And so the sorcerers came to Fir`awn. They said: ``Indeed there will be a (good) reward for us if we are the victors."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said: ``Yes, and moreover you will (in that case) be of the nearest (to me)."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said: ``O Musa! Either you throw (first), or shall we have the (first) throw"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He [Musa] said: ``Throw you (first)." So when they threw, they bewitched the eyes of the people, and struck terror into them, and they displayed a great trick.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We revealed to Musa (saying): ``Throw your stick," and behold! It swallowed up straight away all the falsehood which they showed.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
Thus truth was confirmed, and all that they did was made of no effect.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
So they were defeated there and returned disgraced.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the sorcerers fell down prostrate.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said: ``We believe in the Lord of all that exists.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
``The Lord of Musa and Harun."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Fir`awn said: ``You have believed in him [Musa] before I gave you permission. Surely, this is a plot which you have plotted in the city to drive out its people, but you shall come to know."\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
``Surely, I will cut off your hands and your feet from opposite sides, then I will crucify you all."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said: ``Verily, we are returning to our Lord."\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
``And you take vengeance on us only because we believed in the Ayat of our Lord when they reached us! Our Lord! pour out on us patience, and cause us to die as Muslims."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
The chiefs of Fir`awn's people said: ``Will you leave Musa and his people to spread mischief in the land, and to abandon you and your gods" He said: ``We will kill their sons, and let their women live, and we have indeed irresistible power over them."\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Musa said to his people: ``Seek help in Allah and be patient. Verily, the earth is Allah's. He gives it as a heritage to whom He wills of His servants; and the (blessed) end is for the pious and righteous persons."\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said: ``We suffered troubles before you came to us, and since you have come to us." He said: ``It may be that your Lord will destroy your enemy and make you successors on the earth, so that He may see how you act"\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And indeed We punished the people of Fir`awn with years of drought and lack of fruits (crops), that they might remember (take heed).\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
But whenever good came to them, they said: ``This is for us." And if evil afflicted them, they considered it an omen about Musa and those with him. Be informed! Verily, their omens are with Allah but most of them know not.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
They said [to Musa]: ``Whatever Ayat you may bring to us, to work therewith your sorcery on us, we shall never believe in you."\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We sent on them: the Tuwfan, the locusts, the Qummal, the frogs, and the blood (as a succession of) manifest signs, yet they remained arrogant, and they were of those people who were criminals.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And when the punishment struck them, they said: ``O Musa! Invoke your Lord for us because of His promise to you. If you remove the punishment from us, we indeed shall believe in you, and we shall let the Children of Israel go with you."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We removed the punishment from them for a fixed term, which they had to reach, behold! They broke their word!\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
So We took retribution from them. We drowned them in the sea, because they belied Our Ayat and were heedless with them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We made the people who were considered weak to inherit the eastern parts of the land and the western parts thereof which We have blessed. And the fair Word of your Lord was fulfilled for the Children of Israel, because of their endurance. And We destroyed what Fir`awn and his people produced, and what they erected.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We brought the Children of Israel (with safety) across the sea, and they came upon a people devoted to some of their idols (in worship). They said: ``O Musa! Make for us a god as they have gods." He said: ``Verily, you are an ignorant people."\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
[Musa added:] ``Verily, these people will be destroyed for that which they are engaged in (idols' worship). And all that they are doing is in vain."\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said: ``Shall I seek for you an ilah (a god) other than Allah, while He has given you superiority over the nations."\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And (remember) when We rescued you from Fir`awn's people, who were afflicting you with the worst torment, killing your sons and letting your women live. And in that was a great trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We appointed for Musa thirty nights and added ten, and he completed the term, appointed by his Lord, of forty nights. And Musa said to his brother Harun: ``Replace me among my people, act in the right way and follow not the way of the mischief-makers."\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Musa came at the time and place appointed by Us, and his Lord (Allah) spoke to him; he said: ``O my Lord! Show me (Yourself), that I may look upon You." Allah said: ``You cannot see Me, but look upon the mountain; if it stands still in its place then you shall see Me." So when his Lord appeared to the mountain, He made it collapse to dust, and Musa fell down unconscious. Then when he recovered his senses he said: ``Glory be to You, I turn to You in repentance and I am the first of the believers."\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
(Allah) said: ``O Musa I have chosen you above men by My Messages, and by My speaking (to you). So hold that which I have given you and be of the grateful."\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him on the Tablets the exhortation all things and the explanation for all things (and said): Hold unto these with firmness, and enjoin your people to take the better therein. I shall show you the home of the rebellious.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I shall turn away from My Ayat those who behave arrogantly on the earth, without a right, and (even) if they see all the Ayat, they will not believe in them. And if they see the way of righteousness, they will not adopt it as the way, but if they see the way of error, they will adopt that way, that is because they have rejected Our Ayat and were heedless of them.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who deny Our Ayat and the meeting in the Hereafter, vain are their deeds. Are they requited with anything except what they used to do\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
And the people of Musa made in his absence, out of their ornaments, the image of a calf (for worship). It had a sound. Did they not see that it could neither speak to them nor guide them to the way They took it (for worship) and they were wrongdoers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
And when they regretted and saw that they had gone astray, they said: ``If our Lord have not mercy upon us and forgive us, we shall certainly be of the losers"\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Musa returned to his people, angry and grieved, he said: ``What an evil thing is that which you have done during my absence. Did you hasten in matter of your Lord" And he threw down the Tablets and seized his brother by (the hair of) his head and dragged him towards him. He (Harun) said: ``O son of my mother! Indeed the people judged me weak and were about to kill me, so make not the enemies rejoice over me, nor put me among the people who are wrongdoers."\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
He (Musa) said: ``O my Lord! Forgive me and my brother, and admit us into Your mercy, for You are the Most Merciful of those who show mercy."\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Certainly, those who took the calf (for worship), wrath from their Lord and humiliation will come upon them in the life of this world. Thus do We recompense those who invent lies.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
But those who committed evil deeds and then repented afterwards and believed, verily, your Lord after (all) that is indeed Oft-Forgiving, Most Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when the anger of Musa calmed, he took up the Tablets; and in their inscription was guidance and mercy for those who fear their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Musa chose out of his people seventy (of the best) men for Our appointed time and place of meeting, and when they were seized with a violent earthquake, he said: ``O my Lord, if it had been Your Will, You could have destroyed them and me before; would You destroy us for the deeds of the foolish among us It is only Your trial by which You lead astray whom You will, and keep guided whom You will. You are our protector, so forgive us and have mercy on us: for You are the best of those who forgive.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
``And ordain for us good in this world, and in the Hereafter. Certainly we have Hudna unto You." He said: (As to) My punishment I afflict therewith whom I will and My mercy embraces all things. That (mercy) I shall ordain for those who have Taqwa, and give Zakah; and those who believe in Our Ayat.\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
Those who follow the Messenger, the Prophet who can neither read nor write whom they find written of with them in the Tawrah and the Injil, -- he commands them to do good; and forbids them from evil; he makes lawful for them the good things, and forbids them from the evil things, he releases them from their heavy burdens and from the fetters that were upon them. So those who believe in him, honor him, help him, and follow the light which has been sent down with him, it is they who will be successful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say: ``O mankind! Verily, I am sent to you all as the Messenger of Allah -- to Whom belongs the dominion of the heavens and the earth. None has the right to be worshipped but He. It is He Who gives life and causes death. So believe in Allah and His Messenger, the Prophet who can neither read nor write, who believes in Allah and His Words, and follow him so that you may be guided."\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
And of the people of Musa there is a community who lead (the men) with truth and establish justice therewith.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We divided them into twelve tribes (as distinct) nations. We revealed to Musa when his people asked him for water (saying): ``Strike the stone with your stick," and there gushed forth out of it twelve springs, each group knew its own place for water. We shaded them with the clouds and sent down upon them the manna and the quail (saying): ``Eat of the good things with which We have provided you." They harmed Us not but they used to harm themselves.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And (remember) when it was said to them: ``Dwell in this town (Jerusalem) and eat therefrom wherever you wish, and say, `(O Allah) forgive our sins'; and enter the gate prostrating (bowing with humility). We shall forgive you your wrongdoings. We shall increase (the reward) for the good-doers."\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
But those among them who did wrong, changed the word that had been told to them. So We sent on them a torment from the heaven in return for their wrongdoings.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And ask them about the town that was by the sea; when they transgressed in the matter of the Sabbath: when their fish came to them openly on the Sabbath day, and did not come to them on the day they had no Sabbath. Thus We made a trial for them, for they used to rebel against Allah's command.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a community among them said: ``Why do you preach to a people whom Allah is about to destroy or to punish with a severe torment" (The preachers) said: ``In order to be free from guilt before your Lord (Allah), and perhaps they may fear Allah."\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
So when they forgot the reminder that had been given to them, We rescued those who forbade evil, but with a severe torment We seized those who did wrong, because they used to rebel against Allah's command.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
So when they exceeded the limits of what they were prohibited, We said to them: ``Be you monkeys, despised."\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And (remember) when your Lord declared that He would certainly keep on sending against them, till the Day of Resurrection, those who would afflict them with a humiliating torment. Verily, your Lord is quick in retribution and certainly He is Oft-Forgiving, Most Merciful.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We have broken them (the Jews) up into various separate groups on the earth: some of them are righteous and some are away from that. And We tried them with good (blessings) and evil (calamities) in order that they might turn (to Allah).\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
Then after them succeeded an (evil) generation, which inherited the Book, but they chose (for themselves) the goods of this low life saying: ``(Everything) will be forgiven to us." And if (again) the offer of the like (evil pleasures of this world) came their way, they would (again) seize them (would commit those sins). Was not the covenant of the Book taken from them that they would not say about Allah anything but the truth And they have studied what is in it (the Book). And the home in the Hereafter is better for those who have Taqwa. Do not you then understand\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
And as to those who hold fast to the Book (act on its teachings) and perform the Salah, certainly We shall never waste the reward of those who do righteous deeds.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And (remember) when We Nataqna the mountain over them as if it had been a canopy, and they thought that it was going to fall on them. (We said): ``Hold firmly to what We have given you [the Tawrah], and remember that which is therein (act on its commandments), so that you may fear Allah and obey Him."\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And (remember) when your Lord brought forth from the Children of Adam, from their loins, their seed and made them testify as to themselves (saying): ``Am I not your Lord" They said: ``Yes! We testify," lest you should say on the Day of Resurrection: ``Verily, we were unaware of this."\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or lest you should say: ``It was only our fathers aforetime who took others as partners in worship along with Allah, and we were (merely their) descendants after them; will You then destroy us because of the deeds of men who practiced falsehood"\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
Thus do We explain the Ayat in detail, so that they may turn (unto the truth).\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And recite to them the story of him to whom We gave Our Ayat, but he threw them away; so Shaytan followed him up, and he became of those who went astray.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And had We willed, We would surely have elevated him therewith, but he clung to the earth and followed his own vain desires. So his parable is the parable of a dog: if you drive him away, he pants, or if you leave him alone, he (still) pants. Such is the parable of the people who reject Our Ayat. So relate the stories, perhaps they may reflect.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
Evil is the parable of the people who rejected Our Ayat, and used to wrong themselves.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whomsoever Allah guides, he is the guided one, and whomsoever He sends astray, -- then those! They are the losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
And surely, We have created many of the Jinn and mankind for Hell. They have hearts wherewith they understand not, and they have eyes wherewith they see not, and they have ears wherewith they hear not (the truth). They are like cattle, nay even more astray; those! They are the heedless ones.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
And (all) the Most Beautiful Names belong to Allah, so call on Him by them, and leave the company of those who belie His Names. They will be requited for what they used to do.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And of those whom We have created, there is a community who guides (others) with the truth, and establishes justice therewith.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
Those who reject Our Ayat, We shall gradually seize them with punishment in ways they perceive not.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And I respite them; certainly My plan is strong.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Do they not reflect There is no madness in their companion. He is but a plain warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Do they not look in the dominion of the heavens and the earth and all things that Allah has created; and that it may be that the end of their lives is near. In what message after this will they then believe\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Whomsoever Allah sends astray, none can guide him; and He lets them wander blindly in their transgressions.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you about the Hour (Day of Resurrection): ``When will be its appointed time" Say: ``The knowledge thereof is with my Lord (Alone). None can reveal its time but He. Heavy is its burden through the heavens and the earth. It shall not come upon you except all of a sudden." They ask you as if you have a good knowledge of it. Say: ``The knowledge thereof is with Allah (Alone), but most of mankind know not."\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say: ``I possess no power over benefit or harm to myself except as Allah wills. If I had the knowledge of the Ghayb (Unseen), I should have secured for myself an abundance of wealth, and no evil should have touched me. I am but a warner, and a bringer of glad tidings unto people who believe."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He Who has created you from a single person, and (then) He has created from him his wife, in order that he might enjoy the pleasure of living with her. When he covered [had sexual relation with] her, she became pregnant and she carried it about (lightly). Then when it became heavy, they both invoked Allah, their Lord (saying): ``If You give us a Salih (good in every aspect) child, we shall indeed be among the grateful."\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He gave them a Salih child, they ascribed partners to Him (Allah) in that which He has given to them. High be Allah, Exalted above all that they ascribe as partners to Him.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they attribute as partners to Allah those who created nothing but they themselves are created\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
No help can they give them, nor can they help themselves.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if you call them to guidance, they follow you not. It is the same for you whether you call them or you keep silent.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Verily, those whom you call upon besides Allah are servants like you. So call upon them and let them answer you if you are truthful.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Have they feet wherewith they walk Or have they hands wherewith they hold Or have they eyes wherewith they see Or have they ears wherewith they hear Say: ``Call your (so-called) partners (of Allah) and then plot against me, and give me no respite!\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
Verily, my protector is Allah Who has revealed the Book (the Qur'an), and He protects the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
And those whom you call upon besides Him (Allah) cannot help you nor can they help themselves.\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
And if you call them to guidance, they hear not and you will see them looking at you, yet they see not."\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Show forgiveness, enjoin Al-'Urf (the good), and turn away from the foolish (don't punish them).\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
And if an evil whisper comes to you from Shaytan, then seek refuge with Allah. Verily, He is All-Hearer, All-Knower.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Verily, those who have Taqwa, when an evil thought comes to them from Shaytan, they remember (Allah), and (indeed) they then see (aright).\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
But (as for) their brothers (the devils' brothers) they (the devils) plunge them deeper into error, and they never stop short.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
And if you do not bring them a miracle, they say: ``Why have you not brought it" Say: ``I but follow what is revealed to me from my Lord. This (the Qur'an) is nothing but evidences from your Lord, and a guidance and a mercy for a people who believe."\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
So, when the Qur'an is recited, listen to it, and be silent that you may receive mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember your Lord within yourself, humbly and with fear and without loudness in words in the mornings and in the afternoons, and be not of those who are neglectful.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Surely, those who are with your Lord (angels) are never too proud to perform acts of worship to Him, but they glorify His praise and prostrate themselves before Him.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you about Al-Anfal (the spoils of war). Say: ``Al-Anfal are for Allah and the Messenger." So have Taqwa of Allah and settle all matters of difference among you, and obey Allah and His Messenger, if you are believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
The believers are only those who, when Allah is mentioned, feel a fear in their hearts and when His Ayat are recited unto them, they increase their faith; and they put their trust in their Lord;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
Who perform the Salah and spend out of what We have provided them.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
It is they who are the believers in truth. For them are grades of dignity with their Lord, and forgiveness and a generous provision (Paradise).\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
As your Lord caused you to go out from your home with the truth; and verily, a party among the believers disliked it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Disputing with you concerning the truth after it was made manifest, as if they were being driven to death, while they were looking (at it).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
And (remember) when Allah promised you (Muslims) one of the two parties, that it should be yours; you wished that the one not armed should be yours, but Allah willed to justify the truth by His Words and to cut off the roots of the disbelievers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
That He might cause the truth to triumph and bring falsehood to nothing, even though the criminals hate it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
(Remember) when you sought help of your Lord and He answered you (saying): ``I will help you with a thousand of the angels Murdifin."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
Allah made it only as glad tidings, and that your hearts be at rest therewith. And there is no victory except from Allah. Verily, Allah is Almighty, All-Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
(Remember) when He covered you with a slumber as a security from Him, and He caused water (rain) to descend on you from the sky, to clean you thereby and to remove from you the Rijz (whispering or dirt) of Shaytan, and to strengthen your hearts, and make your feet firm thereby.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
(Remember) when your Lord revealed to the angels, ``Verily, I am with you, so keep firm those who have believed. I will cast terror into the hearts of those who have disbelieved, so strike them over the necks, and smite over all their fingers and toes."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
This is because they defied and disobeyed Allah and His Messenger. And whoever defies and disobeys Allah and His Messenger, then verily, Allah is severe in punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
This is (the torment), so taste it; and surely, for the disbelievers is the torment of the Fire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O you who believe! When you meet those who disbelieve, in a battlefield, never turn your backs to them.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
And whoever turns his back to them on such a day -- unless it be a stratagem of war, or to retreat to a troop (of his own) -- he indeed has drawn upon himself wrath from Allah. And his abode is Hell, and worst indeed is that destination!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
You killed them not, but Allah killed them. And you threw not when you did throw, but Allah threw, that He might test the believers by a fair trial from Him. Verily, Allah is All-Hearer, All-Knower.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
This (is the fact) and surely Allah weakens the deceitful plots of the disbelievers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
(O disbelievers) if you ask for a judgement, now has the judgement come unto you; and if you cease (to do wrong), it will be better for you, and if you return (to the attack), so shall We return, and your forces will be of no avail to you, however numerous they be; and verily, Allah is with the believers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O you who believe! Obey Allah and His Messenger, and turn not away from him while you are hearing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And be not like those who say: ``We have heard," but they hear not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Verily, the worst of living creatures with Allah are the deaf and the dumb (the disbelievers), who understand not.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
Had Allah known of any good in them, He would indeed have made them listen; and even if He had made them listen, they would but have turned away with aversion.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O you who believe! Answer Allah and (His) Messenger when he (the Messenger) calls you to that which will give you life, and know that Allah comes between a person and his heart. And verily to Him you shall (all) be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear the Fitnah (affliction and trial) which affects not in particular (only) those of you who do wrong, and know that Allah is severe in punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember when you were few and were reckoned weak in the land, and were afraid that men might kidnap you, but He provided a safe place for you, strengthened you with His help, and provided you with good things (for livelihood) so that you might be grateful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O you who believe! Betray not Allah and His Messenger, nor betray knowingly your Amanat (things entrusted to you).\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your possessions and your children are but a trial and that surely, with Allah is a mighty reward.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O you who believe! If you obey and fear Allah, He will grant you Furqan, and will expiate for you your sins, and forgive you; and Allah is the Owner of the great bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
And (remember) when the disbelievers plotted against you to imprison you, or to kill you, or to expel you (from your home, Makkah); they were plotting and Allah too was plotting; and Allah is the best of plotters.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our Ayat are recited to them, they say: ``We have heard (the Qur'an); if we wish we can say the like of this. This is nothing but the tales of the ancients."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And (remember) when they said: ``O Allah! If this (the Qur'an) is indeed the truth (revealed) from You, then rain down stones on us from the sky or bring on us a painful torment."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
And Allah would not punish them while you (Muhammad) are among them, nor will He punish them while they seek (Allah's) forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
And why should not Allah punish them while they hinder (men) from Al-Masjid Al-Haram, and they are not its guardians None can be its guardians except those who have Taqwa, but most of them know not.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
Their Salah at the House was nothing but Muka' and Tasdiyah. Therefore taste the punishment because you used to disbelieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Verily, those who disbelieve spend their wealth to hinder (men) from the path of Allah, and so will they continue to spend it; but in the end it will become an anguish for them. Then they will be overcome. And those who disbelieve will be gathered unto Hell.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
In order that Allah may distinguish the wicked from the good, and put the wicked one over another, heap them together and cast them into Hell. Those! it is they who are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to those who have disbelieved, if they cease, their past will be forgiven. But if they return (thereto), then the examples of those (punished) before them have already preceded (as a warning).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight them until there is no more Fitnah, and the religion (worship) will all be for Allah alone. But if they cease, then certainly, Allah is All-Seer of what they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
And if they turn away, then know that Allah is your protector -- (what) an excellent protector and (what) an excellent helper!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that whatever of war booty that you may gain, verily, one-fifth of it is assigned to Allah, and to the Messenger, and to the near relatives (of the Messenger), the orphans, the poor, and the wayfarer, if you have believed in Allah and in that which We sent down to Our servant on the Day of Criterion, the Day when the two forces met; and Allah is able to do all things.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
(And remember) when you (the Muslim army) were on the near side of the valley, and they on the farther side, and the caravan on the ground lower than you. Even if you had made a mutual appointment to meet, you would certainly have failed in the appointment, but (you met) that Allah might accomplish a matter already ordained (in His knowledge), so that those who were to be destroyed (for rejecting the faith) might be destroyed after a clear evidence, and those who were to live (believers) might live after a clear evidence. And surely, Allah is All-Hearer, All-Knower.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
(And remember) when Allah showed them to you as few in your dream; if He had shown them to you as many, you would surely have been discouraged, and you would surely have disputed in making a decision. But Allah saved (you). Certainly, He is the All-Knower of that is in the breasts.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
And (remember) when you met, He showed them to you as few in your eyes and He made you appear as few in their eyes, so that Allah might accomplish a matter already ordained, and to Allah return all matters (for decision).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O you who believe! When you meet (an enemy) force, take a firm stand against them and remember Allah much, so that you may be successful.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His Messenger, and do not dispute (with one another) lest you lose courage and your strength departs, and be patient. Surely, Allah is with the patients.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
And be not like those who come out of their homes boastfully and to be seen of men, and hinder (men) from the path of Allah; and Allah is Muhit (eneompassing and thoroughly comprehending) all that they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
And (remember) when Shaytan made their (evil) deeds seem fair to them and said, ``No one of mankind can overcome you this day (of the battle of Badr) and verily, I am your neighbor (for each and every help)." But when the two forces came in sight of each other, he ran away and said ``Verily, I have nothing to do with you. Verily, I see what you see not. Verily, I fear Allah for Allah is severe in punishment."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
When the hypocrites and those in whose hearts was a disease (of disbelief) said: ``These people (Muslims) are deceived by their religion." But whoever puts his trust in Allah, then surely, Allah is All-Mighty, All-Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
And if you could see when the angels take away the souls of those who disbelieve (at death); they smite their faces and their backs, (saying): ``Taste the punishment of the blazing Fire. ``\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
``This is because of that which your hands forwarded. And verily, Allah is not unjust to His servants."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
Similar to the behavior of the people of Fir`awn, and of those before them -- they rejected the Ayat of Allah, so Allah punished them for their sins. Verily, Allah is All-Strong, severe in punishment.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
That is so because Allah will never change a grace which He has bestowed on a people until they change what is in themselves. And verily, Allah is All-Hearer, All-Knower.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
Similar to the behavior of the people of Fir`awn, and those before them. They belied the Ayat of their Lord, so We destroyed them for their sins, and We drowned the people of Fir`awn for they were all wrongdoers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
Verily, the worst of living creatures before Allah are those who disbelieve, -- so they shall not believe.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
They are those with whom you made a covenant, but they break their covenant every time and they do not have Taqwa.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
So if you gain the mastery over them in war, then disperse those who are behind them, so that they may learn a lesson.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
If you fear treachery from any people, throw back (their covenant) to them (so as to be) on equal terms. Certainly Allah likes not the treacherous.) make a heading, Allah says to His Prophet,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
And let not those who disbelieve think that they can outstrip (escape from the punishment). Verily, they will never be able to save themselves (from Allah's punishment).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
And make ready against them all you can of power, including steeds of war to threaten the enemy of Allah and your enemy, and others besides them, whom you may not know but whom Allah does know. And whatever you shall spend in the cause of Allah shall be repaid unto you, and you shall not be treated unjustly.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
But if they incline to peace, you also incline to it, and trust in Allah. Verily, He is the All-Hearer, the All-Knower.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
And if they intend to deceive you, then verily, Allah is All-Sufficient for you. He it is Who has supported you with His help and with the believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And He has united their (believers') hearts. If you had spent all that is in the earth, you could not have united their hearts, but Allah has united them. Certainly He is All-Mighty, All-Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet! Allah is sufficient for you and for the believers who follow you.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet! Urge the believers to fight. If there are twenty steadfast persons among you, they will overcome two hundred, and if there be a hundred steadfast persons they will overcome a thousand of those who disbelieve, because they (the disbelievers) are people who do not understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Now Allah has lightened your (task), for He knows that there is weakness in you. So if there are of you a hundred steadfast persons, they shall overcome two hundred, and if there are a thousand of you, they shall overcome two thousand by the leave of Allah. And Allah is with the patient.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not (fitting) for a Prophet that he should have prisoners of war until he has fought (his enemies thoroughly) in the land. You desire the goods of this world, but Allah desires (for you) the Hereafter. And Allah is All-Mighty, All-Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
Were it not a previous ordainment from Allah, a severe torment would have touched you for what you took.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
So enjoy what you have gotten of booty in war, lawful and good, and have Taqwa of Allah. Certainly, Allah is Oft-Forgiving, Most Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet! Say to the captives that are in your hands: ``If Allah knows any good in your hearts, He will give you something better than what has been taken from you, and He will forgive you, and Allah is Oft-Forgiving, Most Merciful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they intend to betray you, they indeed betrayed Allah before. So He gave (you) power over them. And Allah is All-Knower, All-Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Verily, those who believed, and emigrated and strove hard and fought with their property and their lives in the cause of Allah as well as those who gave (them) asylum and help, -- these are (all) allies to one another. And as to those who believed but did not emigrate, you owe no duty of protection to them until they emigrate, but if they seek your help in religion, it is your duty to help them except against a people with whom you have a treaty of mutual alliance; and Allah is the All-Seer of what you do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And those who disbelieve are allies of one another, (and) if you (Muslims) do not do so (protect one another), there will be Fitnah on the earth, and great corruption.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
And those who believed, and emigrated and strove hard in the cause of Allah (Al-Jihad), as well as those who gave (them) asylum and aid -- these are the believers in truth, for them is forgiveness and a generous provision.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who believed afterwards, and emigrated and strove hard along with you, they are of you. But kindred by blood are nearer to one another (regarding inheritance) in the decree ordained by Allah. Verily, Allah is the All-Knower of everything.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen Freedom from (all) obligations (is declared) from Allah and His Messenger () to those of the Mushrikin (idolaters), with whom you made a treaty.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
So travel freely (O Mushrikin) for four months (as you will) throughout the land, but know that you cannot escape (from the punishment of) Allah; and Allah will disgrace the disbelievers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And a declaration from Allah and His Messenger to mankind on the greatest day of Hajj that Allah is free from obligations to the Mushrikin and so is His Messenger. So if you repent, it is better for you, but if you turn away, then know that you cannot escape Allah. And give tidings of a painful torment for those who disbelieve.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Except those of the Mushrikin with whom you have a treaty, and who have not subsequently failed you in aught, nor have supported anyone against you. So fulfill their treaty for them until the end of their term. Surely, Allah loves those who have Taqwa.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
So when the Sacred Months have passed, then fight the Mushrikin wherever you find them, and capture them and besiege them, and lie in wait for them in each and every ambush. But if they repent and perform the Salah, and give the Zakah, then leave their way free. Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if anyone of the Mushrikin seeks your protection then grant him protection so that he may hear the Word of Allah (the Qur'an) and then escort him to where he can be secure, that is because they are men who know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be a covenant with Allah and with His Messenger for the Mushrikin except those with whom you made a covenant near Al-Masjid Al-Haram (at Makkah) So long as they are true to you, stand you true to them. Verily, Allah loves those who have Taqwa.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How When if you are overpowered by them, they regard not the ties, either of kinship, (Ill) or of covenant (Dhimmah) With their mouths they please you, but their hearts are averse to you, and most of them are rebellious.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have purchased with the Ayat of Allah a little gain, and they hindered men from His way; evil indeed is that which they used to do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
With regard to a believer, they respect not the ties, either of kinship or of covenant! It is they who are the transgressors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But if they repent, perform the Salah and give the Zakah, then they are your brethren in religion. (In this way) We explain the Ayat in detail for a people who know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
But if they violate their oaths after their covenant, and attack your religion with disapproval and criticism, then fight (you) against the leaders of disbelief -- for surely, their oaths are nothing to them -- so that they may stop (evil actions).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Will you not fight a people who have violated their oaths and intended to expel the Messenger while they did attack you first Do you fear them Allah has more right that you should fear Him if you are believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight against them so that Allah will punish them by your hands, and disgrace them and give you victory over them, and heal the breasts of a believing people,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And remove the anger of their (believers') hearts. Allah accepts the repentance of whom He wills. Allah is All-Knowing, All-Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Do you think that you shall be left alone while Allah has not yet tested those among you who have striven hard and fought, and have not taken Walijah besides Allah and His Messenger, and the believers. Allah is well-acquainted with what you do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the Mushrikin, to maintain the Masjids of Allah, while they witness against themselves of disbelief. The works of such are in vain and in Fire shall they abide.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
The Masjids of Allah shall be maintained only by those who believe in Allah and the Last Day; perform the Salah, and give Zakah and fear none but Allah. It is they who are on true guidance.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Do you consider the providing of drinking water to the pilgrims and the maintenance of Al-Masjid Al-Haram as equal to the worth of those who believe in Allah and the Last Day, and strive hard and fight in the cause of Allah They are not equal before Allah. And Allah guides not those people who are the wrongdoers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
Those who believed and emigrated and strove hard and fought in Allah's cause with their wealth and their lives, are far higher in degree with Allah. They are the successful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord gives them glad tidings of mercy from Him, and His being pleased (with them), and of Gardens (Paradise) for them wherein are everlasting delights.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
They will dwell therein forever. Verily, with Allah is a great reward.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O you who believe! Take not as supporters your fathers and your brothers if they prefer disbelief to belief. And whoever of you befriends them, then he is one of the wrongdoers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say: If your fathers, your sons, your brothers, your spouses, your kindred, the wealth that you have gained, the commerce in which you fear a decline, and the dwellings in which you delight are dearer to you than Allah and His Messenger, and striving hard and fighting in His cause, then wait until Allah brings about His decision (torment). And Allah guides not the people who are rebellious.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
Truly, Allah has given you victory on many battlefields, and on the day of Hunayn (battle) when you rejoiced at your great number, but it availed you naught and the earth, vast as it is, was straitened for you, then you turned back in flight.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then Allah did send down His Sakinah (tranquillity) on His Messenger, and on the believers, and sent down forces (angels) which you saw not, and punished the disbelievers. Such is the recompense of disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then after that Allah will accept the repentance of whom He wills. And Allah is Oft-Forgiving, Most Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O you who believe! Verily, the Mushrikin are impure. So let them not come near Al-Masjid Al-Haram after this year; and if you fear poverty, Allah will enrich you if He wills, out of His bounty. Surely, Allah is All-Knowing, All-Wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight against those who believe not in Allah, nor in the Last Day, nor forbid that which has been forbidden by Allah and His Messenger, and those who acknowledge not the religion of truth among the People of the Scripture, until they pay the Jizyah with willing submission, and feel themselves subdued.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
And the Jews say: ``Uzayr (Ezra) is the son of Allah," and the Christians say: ``The Messiah is the son of Allah." That is their saying with their mouths, resembling the saying of those who disbelieved aforetime. May Allah fight them, how they are deluded away from the truth!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They (Jews and Christians) took their rabbis and their monks to be their lords besides Allah, and (they also took as their Lord) the Messiah, son of Maryam, while they were commanded to worship none but One God, none has the right to be worshipped but He. Praise and hallowed be He above what they associate (with Him)."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They want to extinguish Allah's Light with their mouths, but Allah will not allow except that His Light should be perfected even though the disbelievers hate (it).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He Who has sent His Messenger with guidance and the religion of truth, to make it superior over all religions even though the idolators hate (it).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O you who believe! Verily, there are many of the Ahbar (rabbis) and the Ruhban (monks) who devour the wealth of mankind in falsehood, and hinder (them) from the way of Allah. And those who hoard up gold and silver and spend them not in the way of Allah, announce unto them a painful torment.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
On the Day when that will be heated in the fire of Hell and with it will be branded their foreheads, their flanks, and their backs, (and it will be said unto them:) ``This is the treasure which you hoarded for yourselves. Now taste of what you used to hoard."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Verily, the number of months with Allah is twelve months (in a year), so was it ordained by Allah on the Day when He created the heavens and the earth; of them four are sacred. That is the right religion, so wrong not yourselves therein, and fight against the Mushrikin idolaters collectively as they fight against you collectively. But know that Allah is with those who have Taqwa.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
The postponing (of a Sacred Month) is indeed an addition to disbelief: thereby the disbelievers are led astray, for they make it lawful one year and forbid it another year in order to adjust the number of months forbidden by Allah, and make such forbidden ones lawful. The evil of their deeds is made fair-seeming to them. And Allah guides not the people who disbelieve.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O you who believe! What is the matter with you, that when you are asked to march forth in the cause of Allah, you cling heavily to the earth Are you pleased with the life of this world rather than the Hereafter But little is the enjoyment of the life of this world compared to the Hereafter.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you march not forth, He will punish you with a painful torment and will replace you by another people; and you cannot harm Him at all, and Allah is able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you help him (Muhammad) not (it does not matter), for Allah did indeed help him when the disbelievers drove him out, the second of the two; when they were both in the cave, he said to his companion: ``Be not sad (or afraid), surely, Allah is with us." Then Allah sent down His Sakinah (calmness, tranquillity, peace) upon him, and strengthened him with forces (angels) which you saw not, and made the word of those who disbelieved the lowermost, while the Word of Allah that became the uppermost; and Allah is All-Mighty, All-Wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
March forth, whether you are light or heavy, and strive hard with your wealth and your lives in the cause of Allah. This is better for you, if you but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had it been a near gain and an easy journey, they would have followed you, but the distance was long for them; and they would swear by Allah: ``If we only could, we would certainly have come forth with you." They destroy themselves, and Allah knows that they are liars.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
May Allah forgive you. Why did you grant them leave, until those who told the truth were manifest to you, and you had known the liars\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day, would not ask your leave to be exempted from fighting with their properties and their lives; and Allah is the All-Knower of those who have Taqwa.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
It is only those who believe not in Allah and the Last Day and whose hearts are in doubt that ask your leave. So in their doubts they waver.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
And if they had intended to march out, certainly, they would have made some preparation for it; but Allah was averse to their being sent forth, so He made them lag behind, and it was said (to them): ``Sit among those who sit (at home)."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they marched out with you, they would have added to you nothing except disorder, and they would have hurried about in your midst (spreading corruption) and sowing sedition among you -- and there are some among you who would have listened to them. And Allah is the All-Knower of the wrongdoers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
Verily, they had plotted sedition before, and had upset matters for you, until the truth (victory) came and the decree of Allah became manifest though they hated it.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
And among them is he who says: ``Grant me leave and put me not into trial." Surely, they have fallen into trial. And verily, Hell is surrounding the disbelievers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalls you, it grieves them, but if a calamity overtakes you, they say: ``We took our precaution beforehand," and they turn away rejoicing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say: ``Nothing shall ever happen to us except what Allah has ordained for us. He is our Mawla (protector)." And in Allah let the believers put their trust.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say: ``Do you wait for us (anything) except one of the two best things; while we await for you either that Allah will afflict you with a punishment from Himself or at our hands. So wait, we too are waiting with you."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say: ``Spend willingly or unwillingly, it will not be accepted from you. Verily, you are ever a people who are rebellious."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And nothing prevents their contributions from being accepted from them except that they disbelieved in Allah and in His Messenger, and that they came not to the Salah except in a lazy state, and that they offer not contributions but unwillingly.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
So let not their wealth nor their children amaze you; in reality Allah's plan is to punish them with these things in the life of this world, and that their souls shall depart (die) while they are disbelievers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
They swear by Allah that they are truly of you while they are not of you, but they are a people (hypocrites) who are afraid (that you may kill them).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
Should they find a refuge, or caves, or a place of concealment, they would turn straightway thereto with a swift rush.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And of them are some who accuse you concerning (the distribution of) the alms. If they are given part thereof, they are pleased, but if they are not given thereof, behold! They are enraged!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
Would that they were content with what Allah and His Messenger gave them and had said: ``Allah is sufficient for us. Allah will give us of His bounty, and so will His Messenger. We implore Allah (to enrich us)."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
As-Sadaqat (i.e., Zakah) are only for the Fuqara', and Al-Masakin and those employed to collect (the funds); and to attract the hearts of those who have been inclined (towards Islam); and to free the captives; and for those in debt; and for Allah's cause, and for Ibn As-Sabil; a duty imposed by Allah. And Allah is All-Knower, All-Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And among them are men who annoy the Prophet and say: ``He is (lending his) ear (to every news)." Say: ``He listens to what is best for you; he believes in Allah; has faith in the believers; and is a mercy to those of you who believe." But those who annoy Allah's Messenger, will have a painful torment.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear by Allah to you (Muslims) in order to please you, but it is more fitting that they should please Allah and His Messenger, if they are believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Know they not that whoever opposes and shows hostility to Allah and His Messenger, certainly for him will be the fire of Hell to abide therein. That is the extreme disgrace.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
The hypocrites fear lest a Surah should be revealed about them, showing them what is in their hearts. Say: ``(Go ahead and) mock! But certainly Allah will bring to light all that you fear."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
If you ask them (about this), they declare: ``We were only talking idly and joking." Say: ``Was it at Allah, and His Ayat and His Messenger that you were mocking"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make no excuse; you disbelieved after you had believed. If We pardon some of you, We will punish others among you because they were criminals.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrites, men and women, are one from another; they enjoin evil, and forbid the good, and they close their hands. They have forgotten Allah, so He has forgotten them. Verily, the hypocrites are the rebellious.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah has promised the hypocrites -- men and women -- and the disbelievers, the fire of Hell; therein shall they abide. It will suffice them. Allah has cursed them and for them is the lasting torment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
Like those before you: they were mightier than you in power, and more abundant in wealth and children. They had enjoyed their portion (a while), so enjoy your portion (a while) as those before you enjoyed their portion (a while); and you indulged in play and pastime as they indulged in play and pastime. Such are they whose deeds are in vain in this world and in the Hereafter. Such are they who are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Has not the story reached them of those before them -- The people of Nuh,`Ad, Thamud, the people of Ibrahim, the dwellers of Madyan and the overturned cities; to them came their Messengers with clear proofs. So it was not Allah Who wronged them, but they used to wrong themselves.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The believers, men and women, are supporters of one another; they enjoin good, and forbid evil; they perform the Salah, and give the Zakah, and obey Allah and His Messenger. Allah will have His mercy on them. Surely, Allah is All-Mighty, All-Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah has promised the believers -- men and women, -- Gardens under which rivers flow to dwell therein forever, and beautiful mansions in gardens of `Adn (Eden; Paradise). But the greatest bliss is the good pleasure of Allah. That is the supreme success.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet! Strive hard against the disbelievers and the hypocrites, and be harsh against them, their abode is Hell, -- and worst indeed is that destination.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they said nothing (bad), but really they said the word of disbelief, and they disbelieved after accepting Islam, and they resolved that (plot) which they were unable to carry out, and they could not find any cause to do so except that Allah and His Messenger had enriched them of His bounty. If then they repent, it will be better for them, but if they turn away; Allah will punish them with a painful torment in this worldly life and in the Hereafter. And there is none for them on earth as a protector or a helper.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
And of them are some who made a covenant with Allah (saying): ``If He bestowed on us of His bounty, we will verily, give Sadaqah and will be certainly among the righteous."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
Then when He gave them of His bounty, they became stingy, and turned away, averse.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He punished them by putting hypocrisy into their hearts till the Day whereon they shall meet Him, because they broke that (covenant) with Allah which they had promised to Him and because they used to tell lies.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Know they not that Allah knows their secret ideas, and their Najwa (secret counsels), and that Allah is the All-Knower of things unseen.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who defame such of the believers who give charity voluntarily, and such who could not find to give charity except what is available to them -- so they mock at them (believers); Allah will throw back their mockery on them, and they shall have a painful torment.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Whether you (O Muhammad) ask forgiveness for them (hypocrites) or ask not forgiveness for them -- (and even) if you ask seventy times for their forgiveness -- Allah will not forgive them because they have disbelieved in Allah and His Messenger. And Allah guides not those people who are rebellious.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who stayed away (from Tabuk expedition) rejoiced in their staying behind the Messenger of Allah; they hated to strive and fight with their properties and their lives in the cause of Allah, and they said: ``March not forth in the heat." Say: ``The fire of Hell is more intense in heat;" if only they could understand!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
So let them laugh a little and (they will) cry much as a recompense of what they used to earn (by committing sins).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If Allah brings you back to a party of them (the hypocrites), and they ask your permission to go out (to fight), say: ``Never shall you go out with me nor fight an enemy with me; you were pleased to sit (inactive) on the first occasion, then you sit (now) with those who lag behind."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And never (O Muhammad) pray (funeral prayer) for any of them (hypocrites) who dies, nor stand at his grave. Certainly they disbelieved in Allah and His Messenger, and died while they were Fasiqun.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
And let not their wealth or their children amaze you. Allah only wants to punish them with these things in this world, and that their souls shall depart (die) while they are disbelievers.) We mentioned before the explanation of a similar Ayah, all the thanks and praises are due to Allah.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And when a Surah is revealed, enjoining them to believe in Allah and to strive hard and fight along with His Messenger, the wealthy among them ask your leave to exempt them and say, ``Leave us (behind), we would be with those who sit (at home)."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They are content to be with those who sit behind. Their hearts are sealed up, so they understand not.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger and those who believed with him strove hard and fought with their wealth and their lives. Such are they for whom are the good things, and it is they who will be successful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
For them Allah has prepared Gardens (Paradise) under which rivers flow, to dwell therein forever. That is the supreme success.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And those who made excuses from the bedouins came asking your permission to exempt them (from the battle), and those who had lied to Allah and His Messenger sat at home (without asking the permission for it); a painful torment will seize those of them who disbelieve.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is no blame on those who are weak or ill or who find no resources to spend, if they are sincere and true (in duty) to Allah and His Messenger. No means (of complaint) can there be against the doers of good. And Allah is Oft-Forgiving, Most Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor (is there blame) on those who came to you to be provided with mounts, when you said: ``I can find no mounts for you," they turned back, with their eyes overflowing with tears of grief that they could not find anything to spend.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The means (of complaint) is only against those who are rich, and yet ask exemption. They are content to be with (the women) who sit behind (at home) and Allah has sealed up their hearts so that they know not (what they are losing).\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They (the hypocrites) will present their excuses to you (Muslims), when you return to them. Say ``Present no excuses, we shall not believe you. Allah has already informed us of the news concerning you. Allah and His Messenger will observe your deeds. In the end you will be brought back to the All-Knower of the unseen and the seen, then He (Allah) will inform you of what you used to do."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear by Allah to you (Muslims) when you return to them, that you may turn away from them. So turn away from them. Surely, they are Rijs (impure), and Hell is their dwelling place -- a recompense for that which they used to earn.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They (the hypocrites) swear to you (Muslims) that you may be pleased with them, but if you are pleased with them, certainly Allah is not pleased with the people who are Fasiqin (rebellious).\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The bedouins are the worst in disbelief and hypocrisy, and more likely to not know the limits which Allah has revealed to His Messenger. And Allah is All-Knower, All-Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And of the bedouins there are some who look upon what they spend (in Allah's cause) as a fine and watch for calamities for you, on them be the calamity of evil. And Allah is All-Hearer, All-Knower.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
And of the bedouins there are some who believe in Allah and the Last Day, and look upon what they spend (in Allah's cause) as means of nearness to Allah, and a cause of receiving the Messenger's invocations. Indeed these (expenditures) are a means of nearness for them. Allah will admit them to His mercy. Certainly Allah is Oft-Forgiving, Most Merciful.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And the foremost to embrace Islam of the Muhajirin and the Ansar and also those who followed them exactly (in faith). Allah is well-pleased with them as they are well-pleased with Him. He has prepared for them Gardens under which rivers flow (Paradise), to dwell therein forever. That is the supreme success.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And among the bedouins around you, some are hypocrites, and so are some among the people of Al-Madinah who persist in hypocrisy; you know them not, We know them. We shall punish them twice, and thereafter they shall be brought back to a great (horrible) torment.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And (there are) others who have acknowledged their sins, they have mixed a deed that was righteous with another that was evil. Perhaps Allah will turn unto them in forgiveness. Surely, Allah is Oft-Forgiving, Most Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take Sadaqah from their wealth in order to purify them and sanctify them with it, and Salli for them. Verily, your Salat are a Sakan for them; and Allah is All-Hearer, All-Knower.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Know they not that Allah accepts repentance from His servants and accepts the Sadaqat, and that Allah alone is the One Who forgives and accepts repentance, Most Merciful\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say ``Do deeds! Allah will see your deeds, and (so will) His Messenger and the believers. And you will be brought back to the All-Knower of the unseen and the seen. Then He will inform you of what you used to do."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And others are made to await for Allah's Decree, whether He will punish them or will forgive them. And Allah is All-Knowing, All-Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And as for those who put up a Masjid by way of harm and disbelief and to disunite the believers and as an outpost for those who warred against Allah and His Messenger aforetime, they will indeed swear that their intention is nothing but good. Allah bears witness that they are certainly liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Never stand you therein. Verily, the Masjid whose foundation was laid from the first day on Taqwa is more worthy that you stand therein (to pray). In it are men who love to clean and purify themselves. And Allah loves those who make themselves clean and pure.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Is it then he who laid the foundation of his building on Taqwa to Allah and His good pleasure better, or he who laid the foundation of his building on the brink of an undetermined precipice ready to crumble down, so that it crumbled to pieces with him into the fire of Hell. And Allah guides not the people who are the wrongdoers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
The building which they built will never cease to be a cause of hypocrisy and doubt in their hearts unless their hearts are cut to pieces. And Allah is All-Knowing, All-Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Verily, Allah has purchased of the believers their lives and their properties for (the price) that theirs shall be the Paradise. They fight in Allah's cause, so they kill and are killed. It is a promise in truth which is binding on Him in the Tawrah and the Injil and the Qur'an. And who is truer to his covenant than Allah Then rejoice in the bargain which you have concluded. That is the supreme success.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
Those who repent, who worship (Him), who praise (Him), who fast, who bow down, who prostrate themselves, who enjoin good and forbid evil, and who observe the limits set by Allah. And give glad tidings to the believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not (proper) for the Prophet and those who believe to ask Allah's forgiveness for the Mushrikin, even though they be of kin, after it has become clear to them that they are the dwellers of the Fire (because they died in a state of disbelief).\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And Ibrahim's invoking (of Allah) for his father's forgiveness was only because of a promise he [Ibrahim] had made to him (his father). But when it became clear to him [Ibrahim] that he (his father) is an enemy of Allah, he dissociated himself from him. Verily, Ibrahim was Awwah and forbearing.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
And Allah will never lead a people astray after He has guided them until He makes clear to them what they should avoid. Verily, Allah is the All-Knower of everything.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Indeed to Allah belongs the dominion of the heavens and the earth, He gives life and He causes death. And besides Allah you have neither any protector nor any helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
Allah has forgiven the Prophet, the Muhajirin and the Ansar who followed him in the time of distress (Tabuk expedition), after the hearts of a party of them had nearly deviated (from the right path), but He accepted their repentance. Certainly, He is unto them full of kindness, Most Merciful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And (Allah has forgiven) the three who stayed behind, until for them the earth, vast as it is, was straitened and their souls were straitened to them, and they perceived that there is no fleeing from Allah, and no refuge but with Him. Then, He forgave them, that they might beg for His pardon. Verily, Allah is the One Who forgives and accepts repentance, Most Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O you who believe! Have Taqwa of Allah, and be with those who are true (in words and deeds).\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It was neither befitting for the people of Al-Madinah and the bedouins of the neighborhood to remain behind Allah's Messenger nor to prefer their own lives to his life. That is because they suffer neither Zama' nor Nasab, nor Makhmasah in the cause of Allah, nor did they take any step to raise the anger of disbelievers nor inflict any injury upon an enemy, but is written to their credit as a deed of righteousness. Surely, Allah wastes not the reward of the doers of good.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Neither do they spend any contribution -- small or great -- nor cross a valley, but is written to their credit that Allah may recompense them with the best of what they used to do.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
And it is not (proper) for the believers to go out (to fight - Jihad) all together. Of every troop of them, a party only should go forth, that they may get instructions in religion, and that they may warn their people when they return to them, so that they may beware (of evil).\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O you who believe! Fight those of the disbelievers who are close to you, and let them find harshness in you; and know that Allah is with those who have Taqwa.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever there comes down a Surah, some of them (hypocrites) say: ``Which of you has had his faith increased by it" As for those who believe, it has increased their faith, and they rejoice.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But as for those in whose hearts is a disease, it will add Rijs (doubt) to their Rijs (doubt); and they die while they are disbelievers.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
See they not that they are put in trial once or twice every year Yet, they turn not in repentance, nor do they learn a lesson (from it).\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever there comes down a Surah, they look at one another (saying): ``Does any one see you" Then they turn away. Allah has turned their hearts because they are a people that understand not.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
Verily, there has come unto you a Messenger from among yourselves. It grieves him that you should receive any injury or difficulty. He is eager for you; for the believers [he is] full of pity, kind, and merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
But if they turn away, say: ``Allah is sufficient for me. There is no God but He, in Him I put my trust and He is the Lord of the Mighty Throne."\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif-Lam-Ra. These are the verses of the Book (the Qur'an) Al-Hakim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Is it a wonder for mankind that We have sent Our revelation to a man from among themselves (saying): ``Warn mankind, and give good news to those who believe that they shall have with their Lord the rewards of their good deeds" (But) the disbelievers say: ``This is indeed an evident sorcerer!"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
``Surely, your Lord is Allah Who created the heavens and the earth in six Days and then rose over (Istawa) the Throne, arranging the affair [of all things]. No intercessor (can plead with Him) except after He permits. That is Allah, your Lord; so worship Him (alone). Then, will you not remember\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him is the return of all of you. The promise of Allah is true. It is He Who begins the creation and then will repeat it, that He may reward with justice those who believed and did deeds of righteousness. But those who disbelieved will have a drink of boiling fluids and painful torment because they used to disbelieve.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He Who made the sun a shining thing and the moon as a light and measured out for it stages that you might know the number of years and the reckoning. Allah did not create this but in truth. He explains the Ayat in detail for people who have knowledge.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Verily, in the alternation of the night and the day and in all that Allah has created in the heavens and the earth are Ayat for those who have Taqwa.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Verily, those who hope not for their meeting with Us, but are pleased and satisfied with the life of the present world, and those who are heedless of Our Ayat,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
Those, their abode will be the Fire, because of what they used to earn.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Verily, those who believe and do deeds of righteousness, their Lord will guide them through their faith; under them will flow rivers in the Gardens of delight (Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their way of request therein will be: ``Glory to You, O Allah!" and ``Salam" (peace, safety from evil) will be their greetings therein! And the close of their request will be: ``All praise is due to Allah, the Lord of all that exists."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
And were Allah to hasten for mankind the evil as He hastens for them the good then they would have been ruined. So We leave those who expect not their meeting with Us, in their trespasses, wandering blindly in distraction.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And when harm touches man, he invokes Us, lying on his side, or sitting or standing. But when We have removed his harm from him, he passes on as if he had never invoked Us for a harm that touched him! Thus it is made fair seeming to the wasteful that which they used to do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
And indeed, We destroyed generations before you when they did wrong, while their Messengers came to them with clear proofs, but they were not such as to believe! Thus do We requite the people who are criminals.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We made you successors after them, generations after generations in the land, that We might see how you would work.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our clear Ayat are recited unto them, those who hope not for their meeting with Us, say: ``Bring us a Qur'an other than this, or change it." Say: ``It is not for me to change it on my own accord; I only follow that which is revealed unto me. Verily, I fear the torment of the Great Day (the Day of Resurrection) if I were to disobey my Lord."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say: ``If Allah had so willed, I should not have recited it to you nor would He have made it known to you. Verily, I have stayed among you a lifetime before this. Have you then no sense"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
So who does more wrong than he who forges a lie against Allah or denies His Ayat Surely, the criminals will never be successful!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
And they worship besides Allah things that harm them not, nor profit them, and they say: ``These are our intercessors with Allah." Say: ``Do you inform Allah of that which He knows not in the heavens and on the earth" Glorified and Exalted is He above all that which they associate as partners (with Him)!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
Mankind were but one community, then they differed (later); and had not it been for a Word that went forth before from your Lord, it would have been settled between them regarding what they differed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they say: ``How is it that not a sign is sent down on him from his Lord" Say: ``The Unseen belongs only to Allah, so wait you, verily, I am with you among those who wait."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
And when We let mankind taste mercy after some adversity has afflicted them, behold! They take to plotting against Our Ayat! Say: ``Allah is more swift in planning!" Certainly, Our messengers (angels) record all of that which you plot.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
He it is Who enables you to travel through land and sea, till when you are in the ships, and they sail with them with a favorable wind, and they are glad therein, then comes a stormy wind and the waves come to them from all sides, and they think that they are encircled therein. Then they invoke Allah, making their faith pure for Him (alone), (saying): ``If You (Allah) deliver us from this, we shall truly, be of the grateful."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But when He delivers them, behold! They rebel (disobey Allah) in the earth wrongfully. O mankind! Your rebellion is only against yourselves, -- a brief enjoyment of this worldly life, then (in the end) unto Us is your return, and We shall inform you of that which you used to do.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
Verily, the parable of the life of the world is as the water which We send down from the sky; so by it arises the intermingled produce of the earth of which men and cattle eat: until when the earth is clad in its adornments and is beautified, and its people think that they have all the powers of disposal over it, Our command reaches it by night or by day and We make it like a clean-mown harvest, as if it had not flourished yesterday! Thus do We explain the Ayat in detail for the people who reflect.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
Allah calls to the Abode of Peace (Paradise) and guides whom He wills to the straight path.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For those who have done good is the best, and even more. Neither darkness nor dust nor any humiliating disgrace shall cover their faces. They are the dwellers of Paradise, they will abide therein forever.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
And those who have earned evil deeds, the recompense of an evil deed is the like thereof, and humiliating disgrace will cover them (their faces). No defender will they have from Allah. Their faces will be covered as it were with pieces from the darkness of night. They are the dwellers of the Fire, they will abide therein forever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And the Day whereon We shall gather them all together, then We shall say to those who did set partners in worship with Us: ``Stop at your place! You and your partners." Then We shall separate them, and their partners shall say: ``It was not us that you used to worship."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
``So sufficient is Allah as a witness between us and you that we indeed knew nothing of your worship of us."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There! Every person will know (exactly) what he had earned before and they will be brought back to Allah, their rightful Mawla (Lord), and their invented false deities will vanish from them.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say: ``Who provides for you from the sky and the earth Or who owns hearing and sight And who brings out the living from the dead and brings out the dead from the living And who disposes of the affairs" They will say: ``Allah." Say: ``Will you not then be afraid (of Allah's punishment)"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
Such is Allah, your Lord in truth. So after the truth, what else can there be, save error How then are you turned away\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus is the Word of your Lord justified against those who rebel (disobey Allah), that they will not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say: ``Is there of your partners one that originates the creation and then repeats it" Say: ``Allah originates the creation and then He repeats it. Then how are you deluded away (from the truth)"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say: ``Is there of your partners one that guides to the truth" Say: ``It is Allah Who guides to the truth. Is then He Who guides to the truth more worthy to be followed, or he who finds not guidance (himself) unless he is guided Then, what is the matter with you How judge you"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
And most of them follow nothing but conjecture. Certainly, conjecture can be of no avail against the truth. Surely, Allah is All-Aware of what they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
And this Qur'an is not such as could ever be produced by other than Allah but it is a confirmation of (the revelation) which was before it, and a full explanation of the Book -- wherein there is no doubt -- from the Lord of all that exists.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or do they say: ``He has forged it" Say: ``Bring then a Surah like unto it, and call upon whomsoever you can besides Allah, if you are truthful!"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
Nay, they have belied the knowledge whereof they could not comprehend and what has not yet been fulfilled. Thus those before them did belie. Then see what was the end of the wrongdoers!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And of them there are some who believe therein; and of them there are some who believe not therein, and your Lord is All-Aware of the mischief-makers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they belie you, say: ``For me are my deeds and for you are your deeds! You are innocent of what I do, and I am innocent of what you do!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And among them are some who listen to you, but can you make the deaf to hear -- even though they apprehend not\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And among them are some who look at you, but can you guide the blind -- even though they see not\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Truly, Allah wrongs not mankind in aught; but mankind wrong themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
And on the Day when He shall gather them together, (it will be) as if they had not stayed (in the life of this world and graves) but an hour of a day. They will recognize each other. Ruined indeed will be those who denied the meeting with Allah and were not guided.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
Whether We show you some of what We promise them (the torment), or We cause you to die -- still unto Us is their return, and moreover Allah is Witness over what they used to do.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
And for every Ummah there is a Messenger; when their Messenger comes, the matter will be judged between them with justice, and they will not be wronged.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say: ``When will be this promise (the torment or the Day of Resurrection), if you speak the truth"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say: ``I have no power over any harm or profit for myself except what Allah may will. For every Ummah, there is a term appointed; when their term comes, neither can they delay it nor can they advance it an hour (or a moment)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say: ``Tell me, if His torment should come to you by night or by day, which portion thereof would the criminals hasten on"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
Is it then that when it has actually befallen, you will believe in it What! Now (you believe) And you used (aforetime) to hasten it on!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then it will be said to them who wronged themselves: ``Taste you the everlasting torment! Are you recompensed (aught) save what you used to earn"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they ask you to inform them (saying): ``Is it true" Say: ``Yes! By my Lord! It is the very truth! And you cannot escape it!"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
And if every person who had wronged, possessed all that is on the earth and sought to ransom himself therewith (it will not be accepted), and they would feel in their hearts regret when they see the torment, and they will be judged with justice, and no wrong will be done unto them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
No doubt, surely, all that is in the heavens and the earth belongs to Allah. No doubt, surely, Allah's promise is true. But most of them know not.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
It is He Who gives life, and causes death, and to Him you (all) shall return.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O mankind! There has come to you good advice from your Lord, and a cure for that which is in your breasts, -- a guidance and a mercy for the believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say: ``In the bounty of Allah, and in His mercy; therein let them rejoice." That is better than what (the wealth) they amass.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say: ``Tell me, what provision Allah has sent down to you! And you have made of it lawful and unlawful." Say: ``Has Allah permitted you (to do so), or do you invent a lie against Allah"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what think those who invent a lie against Allah, on the Day of Resurrection Truly, Allah is full of bounty to mankind, but most of them are ungrateful.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
Neither you do any deed nor recite any portion of the Qur'an, nor you do any deed, but We are Witness thereof when you are doing it. And nothing is hidden from your Lord (so much as) the weight of a speck of dust on the earth or in the heaven. Not what is less than that or what is greater than that but is (written) in a Clear Record.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Behold! The Awliya' of Allah, no fear shall come upon them nor shall they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believed, and have Taqwa.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
For them is good news, in the life of the present world, and in the Hereafter. No change can there be in the Words of Allah. This is indeed the supreme success.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
Do not grieve over their speech, for all power and honor belong to Allah. He is the All-Hearer, the All-Knower.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Behold! Verily, to Allah belongs whosoever is in the heavens and whosoever is in the earth. And those who worship and invoke others besides Allah, in fact they follow not the partners, they follow only a conjecture and they do nothing but lie.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
He it is Who has appointed for you the night that you may rest therein, and the day to make things visible (to you). Verily, in this are Ayat for a people who listen (those who think deeply).\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They say: ``Allah has begotten a son." Glory is to Him! He is Rich (free of all needs). His is all that is in the heavens and all that is in the earth. No warrant have you for this. Do you say against Allah what you know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say: ``Verily, those who invent a lie against Allah will never be successful."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
(A brief) enjoyment in this world! and then unto Us will be their return, then We shall make them taste the severest torment because they used to disbelieve.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And recite to them the news of Nuh. When he said to his people: ``O my people, if my stay (with you), and my reminding (you) of the Ayat of Allah is hard on you, then I put my trust in Allah. So devise your plot, you and your partners, and let not your plot be in confusion for you. Then pass your sentence on me and give me no respite.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
``But if you turn away, then no reward have I asked of you, my reward is only from Allah, and I have been commanded to be of the Muslims."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
They denied him, but We delivered him, and those with him in the ship, and We made them generations, replacing one after another, while We drowned those who belied Our Ayat. Then see what was the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then after him We sent Messengers to their people. They brought them clear proofs, but they would not believe what they had already rejected beforehand. Thus We seal the hearts of the transgressors.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then after them We sent Musa and Harun to Fir`awn and his chiefs with Our Ayat. But they behaved arrogantly and were a people who were criminals.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
So when came to them the truth from Us, they said: ``This is indeed clear magic."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Musa said: ``Say you (this) about the truth when it has come to you Is this magic But the magicians will never be successful."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said: ``Have you come to us to turn us away from that we found our fathers following, and that you two may have greatness in the land We are not going to believe you two!"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Fir`awn said: ``Bring me every well-versed sorcerer."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
And when the sorcerers came, Musa said to them: ``Cast down what you want to cast!"\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
Then when they had cast down, Musa said: ``What you have brought is sorcery, Allah will surely make it of no effect. Verily, Allah does not set right the work of the evildoers.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
``And Allah will establish and make apparent the truth by His Words, however much the criminals may hate (it)."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
But none believed in Musa except the offspring of his people, because of the fear of Fir`awn and his chiefs, lest they should persecute them; and verily, Fir`awn was an arrogant tyrant on the earth, he was indeed one of the transgressors.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
And Musa said: ``O my people! If you have believed in Allah, then put your trust in Him if you are Muslims."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
They said: ``In Allah we put our trust. Our Lord! Make us not a trial for the folk who are wrongdoers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
``And save us by Your mercy from the disbelieving folk."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We revealed to Musa and his brother (saying): ``Provide dwellings for your people in Egypt, and make your dwellings as places for your worship, and perform the Salah, and give glad tidings to the believers."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
And Musa said: ``Our Lord! You have indeed bestowed on Fir`awn and his chiefs splendor and wealth in the life of this world, our Lord! That they may lead men astray from Your path. Our Lord! Destroy their wealth, and harden their hearts, so that they will not believe until they see the painful torment."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
Allah said: ``Verily, the invocation of you both is accepted. So you both keep to the straight way, and follow not the path of those who know not."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We took the Children of Israel across the sea, and Fir`awn with his hosts followed them in oppression and enmity, till when drowning overtook him, he (Fira`wn) said: ``I believe that none has the right to be worshipped but He in Whom the Children of Israel believe, and I am one of the Muslims."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
Now (you believe) while you refused to believe before and you were one of the mischief-makers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
So this day We shall deliver your (dead) body (out from the sea) that you may be a sign to those who come after you! And verily, many among mankind are heedless of Our Ayat.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And indeed We settled the Children of Israel in an honorable dwelling place, and provided them with good things, and they differed not until the knowledge came to them. Verily, your Lord will judge between them on the Day of Resurrection in that in which they used to differ.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
So if you are in doubt concerning that which We have revealed unto you, then ask those who are reading the Book before you. Verily, the truth has come to you from your Lord. So be not of those who doubt (it).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And be not one of those who belie the Ayat of Allah, for then you shall be one of the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Truly, those, against whom the Word of your Lord has been justified, will not believe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even if every sign should come to them, until they see the painful torment.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Was there any town (community) that believed (after seeing the punishment), and its faith (at that moment) saved it (from the punishment)-- except the people of Yunus; when they believed, We removed from them the torment of disgrace in the life of the (present) world, and permitted them to enjoy for a while.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And had your Lord willed, those on earth would have believed, all of them together. So, will you then compel mankind, until they become believers.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
It is not for any person to believe, except by the leave of Allah, and He will put the Rijs on those who do not reason.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say: ``Behold all that is in the heavens and the earth." But neither Ayat nor warners benefit those who do not believe.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
Then do they wait save for the likes of the days of men who passed away before them Say: ``Wait then, I am waiting with you among those who wait."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then We save Our Messengers and those who believe! Thus it is incumbent upon Us to save the believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say:"O people! If you are in doubt about my religion - I will never worship those whom you worship besides Allah, rather, I will worship Allah, the One Who cause you to die. And I was commanded to be one of the believers.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
And (I was commanded), ``Direct your face toward the Hanif (monotheism) religion, and not be one of the idolators."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
``And do not invoke besides Allah what will not benefit you nor harm you. For if you did, you would certainly be one of the wrongdoers."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
And if Allah touches you with harm, there is none who can lift it but He. And if He intends good for you, then none can repel His favor which He causes to reach whom He wills among His servants. And He is the Pardoning, the Merciful.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say: ``O people! Now the truth has come to you from your Lord. So whoever receives guidance, he does so for the good of himself. And whoever goes astray, he does so at his own loss. And I am not set over you as a guardian.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And follow what is revealed to you, and be patient until Allah gives judgment. And He is the best of the judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif Lam Ra. (This is) a Book, the Ayat whereof are perfect (in every sphere of knowledge), and then explained in detail from One (Allah), Who is All-Wise Well-Acquainted (with all things).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
(Saying) worship none but Allah. Verily, I (Muhammad) am unto you from Him a warner and a bringer of glad tidings.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
And (commanding you): ``Seek the forgiveness of your Lord, and turn to Him in repentance, that He may grant you good enjoyment, for a term appointed, and bestow His abounding grace to every owner of grace. But if you turn away, then I fear for you the torment of a Great Day.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
To Allah is your return, and He is able to do all things."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
No doubt! They did fold up their breasts, that they may hide from Him. Surely, even when they cover themselves with their garments, He knows what they conceal and what they reveal. Verily, He is the All-Knower of the (innermost secrets) of the breasts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
And no moving creature is there on earth but its provision is due from Allah. And He knows its dwelling place and its deposit. All is in a Clear Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And He it is Who has created the heavens and the earth in six Days and His Throne was over the water, that He might try you, which of you is the best in deeds. But if you were to say to them: ``You shall indeed be raised up after death," those who disbelieve would be sure to say, ``This is nothing but obvious magic."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We delay the torment for them till a determined Ummah (term), they are sure to say, ``What keeps it back" Verily, on the day it reaches them, nothing will turn it away from them, and they will be surrounded by (or fall in) that at which they used to mock!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if We give man a taste of mercy from Us, and then withdraw it from him, verily, he is despairing, ungrateful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
But if We let him taste good (favor) after evil (poverty and harm) has touched him, he is sure to say: ``Ills have departed from me." Surely, he is exultant and boastful (ungrateful to Allah).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Except those who show patience and do righteous good deeds: those, theirs will be forgiveness and a great reward (Paradise).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
So perchance you may give up a part of what is revealed unto you, and that your breast feels straitened for it because they say, ``Why has not a treasure been sent down unto him, or an angel come with him" But you are only a warner. And Allah is a Guardian over all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or they say, ``He forged it." Say: ``Bring you then ten forged Surahs like unto it, and call whomsoever you can, other than Allah, if you speak the truth!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
If then they answer you not, know then that it is sent down with the knowledge of Allah and that there is no god besides Him! Will you then be Muslims\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whosoever desires the life of the world and its glitter, to them We shall pay in full (the wages of) their deeds therein, and they will have no diminution therein.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
They are those for whom there is nothing in the Hereafter but Fire, and vain are the deeds they did therein. And of no effect is that which they used to do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
Can they who rely on a clear proof from their Lord, and whom a witness from Him recites (follows) it; and before it, came the Book of Musa, a guidance and a mercy, they believe therein, but those of the sects that reject it, the Fire will be their promised meeting place. So be not in doubt about it. Verily, it is the truth from your Lord, but most of mankind believe not.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who does more wrong than he who invents a lie against Allah. Such will be brought before their Lord, and the witnesses will say,"These are the ones who lied against their Lord!" No doubt! The curse of Allah is on the wrongdoers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Those who hinder (others) from the path of Allah, and seek a crookedness therein, while they are disbelievers in the Hereafter.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
By no means will they escape on earth, nor have they protectors besides Allah! Their torment will be doubled! They could not bear to listen and they used not to see (the truth).\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
They are those who have lost their own selves, and that which they invented eluded them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Certainly, they are those who will be the greatest losers in the Hereafter.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Verily, those who believe and do righteous good deeds, and humble themselves before their Lord, they will be the dwellers of Paradise to dwell therein forever.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The likeness of the two parties is as the blind and the deaf and the seer and the hearer. Are they equal when compared Will you not then take heed\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And indeed We sent Nuh to his people (and he said): ``I have come to you as a plain warner."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
``That you worship none but Allah; surely, I fear for you the torment of a painful Day."\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
The chiefs who disbelieved among his people said: ``We see you but a man like ourselves, nor do we see any follow you but the meanest among us and they (too) followed you without thinking. And we do not see in you any merit above us, in fact we think you are liars."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said: ``O my people! Tell me, if I have a clear proof from my Lord, and a mercy (prophethood) has come to me from Him, but that (mercy) has been obscured from your sight. Shall we compel you (to accept) it when you have a strong hatred for it\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
And O my people! I ask of you no wealth for it, my reward is from none but Allah. I am not going to drive away those who have believed. Surely, they are going to meet their Lord, but I see that you are a people that are ignorant.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
And O my people! Who will help me against Allah, if I drove them away Will you not then give a thought\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
And I do not say to you that with me are the treasures of Allah, nor that I know the Ghayb; nor do I say I am an angel, and I do not say of those whom your eyes look down upon that Allah will not bestow any good on them. Allah knows what is in their inner selves. In that case, I should, indeed be one of the wrongdoers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said: ``O Nuh! You have disputed with us, and much have you prolonged the dispute with us, now bring upon us what you threaten us with, if you are of the truthful."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said: ``Only Allah will bring it (the punishment) on you, if He wills, and then you will escape not.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
``And my advice will not profit you, even if I wish to give you good counsel, if Allah's will is to keep you astray. He is your Lord! and to Him you shall return."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or they (the pagans of Makkah) say: ``He has fabricated it." Say: ``If I have fabricated it, upon me be my crimes, but I am innocent of (all) those crimes which you commit.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was revealed to Nuh: ``None of your people will believe except those who have believed already. So be not sad because of what they used to do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
``And construct the ship under Our Eyes and with Our revelation, and address Me not on behalf of those who did wrong; they are surely to be drowned."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
And as he was constructing the ship, whenever the chiefs of his people passed by him, they mocked at him. He said: ``If you mock at us, so do we mock at you likewise for your mocking."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
``And you will know who it is on whom will come a torment that will cover him with disgrace and on whom will fall a lasting torment."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
(So it was) till when Our command came and the oven gushed forth (water like fountains from the earth). We said: ``Embark therein, of each kind two (male and female), and your family -- except him against whom the Word has already gone forth -- and those who believe. And none believed with him, except a few."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
And he said: ``Embark therein: in the Name of Allah will be its (moving) course and its (resting) anchorage. Surely, my Lord is Oft-Forgiving, Most Merciful."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
So it (the ship) sailed with them amidst waves like mountains, and Nuh called out to his son, who had separated himself (apart): ``O my son! Embark with us and be not with the disbelievers."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
The son replied: ``I will betake myself to some mountain, it will save me from the water." Nuh said: ``This day there is no savior from the decree of Allah except him on whom He has mercy." And waves came in between them, so he (the son) was among the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said: ``O earth! Swallow up your water, and O sky! Withhold (your rain)." And the water was made to subside and the decree was fulfilled. And it rested on (Mount) Judi, and it was said: ``Away with the people who are wrongdoing!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Nuh called upon his Lord and said, ``O my Lord! Verily, my son is of my family! And certainly, Your promise is true, and You are the Most Just of the judges."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said: ``O Nuh! Surely, he is not of your family; verily, his work is unrighteous, so ask not of Me that of which you have no knowledge! I admonish you, lest you should be one of the ignorant."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
Nuh said: ``O my Lord! I seek refuge with You from asking You that of which I have no knowledge. And unless You forgive me and have mercy on me, I would indeed be one of the losers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said: ``O Nuh! Come down (from the ship) with peace from Us and blessings on you and on the people who are with you (and on some of their offspring), but (there will be other) people to whom We shall grant their pleasures (for a time), but in the end a painful torment will reach them from Us."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
This is of the news of the Unseen which We reveal unto you; neither you nor your people knew it before this. So be patient. Surely, the (good) end is for those who have Taqwa.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And to the `Ad (people We sent) their brother Hud. He said, ``O my people! Worship Allah! You have no other god but Him. Certainly, you do nothing but invent lies!\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
``O my people I ask of you no reward for it (the Message). My reward is only from Him Who created me. Will you not then understand"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
``And O my people! Ask forgiveness of your Lord and then repent to Him, He will send you (from the sky) abundant rain, and add strength to your strength, so do not turn away as criminals."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said: ``O Hud! No evidence have you brought us, and we shall not leave our gods for your (mere) saying! And we are not believers in you.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
All that we say is that some of our gods (false deities) have seized you with evil (madness). He said: ``I call Allah to witness and bear you witness that I am free from that which you ascribe as partners in worship,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
Besides Him (Allah). So plot against me, all of you, and give me no respite."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
I put my trust in Allah, my Lord and your Lord! There is not a moving creature but He has the grasp of its forelock. Verily, my Lord is on the straight path (the truth).\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
So if you turn away, still I have conveyed the Message with which I was sent to you. My Lord will make another people succeed you, and you will not harm Him in the least. Surely, my Lord is Guardian over all things.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our commandment came, We saved Hud and those who believed with him by a mercy from Us, and We saved them from a severe torment.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
Such were [the people of] `Ad. They rejected the Ayat of their Lord and disobeyed His Messengers, and followed the command of every proud, obstinate (oppressor of the truth from their leaders).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And they were pursued by a curse in this world and (so they will be) on the Day of Resurrection. No doubt! Verily, `Ad disbelieved in their Lord. So away with `Ad, the people of Hud.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamud (people We sent) their brother Salih. He said: ``O my people! Worship Allah: you have no other god but Him. He brought you forth from the earth and settled you therein, then ask forgiveness of Him and turn to Him in repentance. Certainly, my Lord is Near (to all by His knowledge), Responsive."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said: ``O Salih! You have been among us as a figure of good hope until this! Do you (now) forbid us the worship of what our fathers have worshipped But we are really in grave doubt as to that to which you invite us."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said: ``O my people! Tell me, if I have a clear proof from my Lord, and there has come to me a mercy from Him, who then can help me against Allah, if I were to disobey Him Then you increase me not but in loss."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
``And O my people! This she-camel of Allah is a sign to you, so leave her to graze in Allah's land, and touch her not with evil, lest a near torment should seize you."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they slaughtered her. So he said: ``Enjoy yourselves in your homes for three days. This is a promise (a threat) that will not be belied."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
So when Our commandment came, We saved Salih and those who believed with him by a mercy from Us, and from the disgrace of that Day. Verily, your Lord -- He is the All-Strong, the All-Mighty.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And As-Sayhah (awful cry) overtook the wrongdoers, so they lay (dead), prostrate in their homes.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As if they had never lived there. No doubt! Verily, Thamud disbelieved in their Lord. So away with Thamud!\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
And verily, there came Our messengers to Ibrahim with the glad tidings. They said: ``Salaman (greetings or peace!)" He answered, ``Salamun (greetings or peace!)," and he hastened to entertain them with a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
But when he saw their hands went not towards it (the meal), he mistrusted them, and conceived a fear of them. They said: ``Fear not, we have been sent against the people of Lut."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his wife was standing (there), and she laughed. But We gave her glad tidings of Ishaq, and after Ishaq, of Ya`qub.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said (in astonishment): ``Woe unto me! Shall I bear a child while I am an old woman, and here is my husband an old man Verily, this is a strange thing!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said: ``Do you wonder at the decree of Allah The mercy of Allah and His blessings be on you, O the family [of Ibrahim]. Surely, He (Allah) is All-Praiseworthy, All-Glorious."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
Then when the fear had gone away from (the mind of) Ibrahim, and the glad tidings had reached him, he began to plead with Us (Our messengers) for the people of Lut.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Verily, Ibrahim was, without doubt, forbearing, used to invoke Allah with humility, and was repentant.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
``O Ibrahim! Forsake this. Indeed, the commandment of your Lord has gone forth. Verily, there will come a torment for them which cannot be turned back."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers came to Lut, he was grieved on account of them and was concerned for them. He said: ``This is a distressful day."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came rushing towards him, and since aforetime they used to commit crimes, he said: ``O my people! Here are my daughters, they are purer for you. So have Taqwa of Allah and disgrace me not with regard to my guests! Is there not among you a single right-minded man"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said: ``Surely, you know that we have no need of your daughters, and indeed you know well what we want!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said: ``Would that I had strength to overpower you, or that I could betake myself to some powerful support."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
They (messengers) said: ``O Lut! Verily, we are the messengers from your Lord! They shall not reach you! So travel with your family in a part of the night, and let not any of you look back; but your wife (will remain behind), verily, the punishment which will afflict them, will afflict her. Indeed, morning is their appointed time. Is not the morning near"\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
So when Our commandment came, We turned them upside down, and rained on them stones of clay, in an array.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked from your Lord; and they are not ever far from the wrongdoers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to the Madyan people (We sent) their brother Shu`ayb. He said: ``O my people! Worship Allah, you have no other god but Him, and give not short measure or weight. I see you in prosperity and verily, I fear for you the torment of a Day encompassing."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
``And O my people! Give full measure and weight in justice and reduce not the things that are due to the people, and do not commit mischief in the land, causing corruption."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
``That which is left by Allah is better for you, if you are believers. And I am not a guardian over you."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said: ``O Shu`ayb! Does your Salah command you that we give up what our fathers used to worship, or that we give up doing what we like with our property Verily, you are the forbearer, right-minded!"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said: ``O my people! Tell me if I have a clear evidence from my Lord and He has given me a good sustenance from Himself (shall I corrupt it by mixing it with the unlawfully earned money). I wish not, in contradiction to you, to do that which I forbid you. I only desire reform to the best of my power. And my guidance cannot come except from Allah, in Him I put my trust and unto Him I repent."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
``And O my people! Let not my Shiqaq cause you to suffer the fate similar to that of the people of Nuh or of Hud or of Salih, and the people of Lut are not far off from you!"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
``And ask forgiveness of your Lord and turn unto Him in repentance. Verily, my Lord is Most Merciful, Most Loving."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said: ``O Shu`ayb! We do not understand much of what you say, and we see you weak among us. Were it not for your family, you would have been stoned, and you are not powerful against us."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said: ``O my people! Is then my family of more weight with you than Allah And you have cast Him away behind your backs. Verily, my Lord is surrounding all that you do."\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
``And O my people! Act according to your ability, and I am acting. You will come to know who it is on whom descends the torment that will cover him with ignominy, and who is a liar! And watch you! Verily, I too am watching with you."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our commandment came, We saved Shu`ayb and those who believed with him by a mercy from Us. And As-Sayhah (awful cry) seized the wrongdoers, and they lay (Jathimin) in their homes.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As if they had never lived there! So away with Madyan just as Thamud went away!\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And indeed We sent Musa with Our Ayat and a manifest authority.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
To Fir`awn and his chiefs, but they followed the command of Fir`awn, and the command of Fir`awn was no right guide.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will go ahead of his people on the Day of Resurrection, and will lead them into the Fire, and evil indeed is the place to which they are led.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
They were pursued by a curse in this (deceiving life of this world) and (so they will be pursued by a curse) on the Day of Resurrection, evil indeed is the gift granted.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That is some of the news of the (population of) towns which We relate unto you; of them, some are (still) standing, and some have been (already) reaped.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
We wronged them not, but they wronged themselves. So their gods whom they call upon besides Allah, profited them naught when there came the command of your Lord, nor did they add aught to them but destruction.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
Such is the punishment of your Lord when He seizes the (population of) towns while they are doing wrong. Verily, His punishment is painful (and) severe.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Indeed in that (there) is a sure lesson for those who fear the torment of the Hereafter. That is a Day whereon mankind will be gathered together, and that is a Day when all will be present.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
And We delay it only for a term (already) fixed.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
On the Day when it comes, no person shall speak except by His (Allah's) leave. Some among them will be wretched and (others) blessed.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for those who are wretched, they will be in the Fire, in it they will experience Zafir and Shahiq.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
They will dwell therein for all the time that the heavens and the earth endure, except as your Lord wills. Verily, your Lord is the doer of whatsoever He intends (or wills).\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And those who are blessed, they will be in Paradise, abiding therein for all the time that the heavens and the earth endure, except as your Lord wills: a gift without an end.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So be not in doubt as to what these people (pagans and polytheists) worship. They worship nothing but what their fathers worshipped before (them). And verily, We shall repay them in full their portion without diminution.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
Indeed, We gave the Book to Musa, but differences arose therein, and had it not been for a Word that had gone forth before from your Lord, the case would have been judged between them, and indeed they are in grave doubt concerning it (this Qur'an).\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And verily, to each of them your Lord will repay their works in full. Surely, He is All-Aware of what they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So stand (ask Allah to make) you firm and straight as you are commanded and those who turn in repentance with you, and transgress not. Verily, He is All-Seer of what you do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And incline not toward those who do wrong, lest the Fire should touch you, and you have no protectors other than Allah, nor would you then be helped.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And perform the Salah, at the two ends of the day and in some hours of the night. Verily, the good deeds remove the evil deeds. That is a reminder for the mindful.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be patient; verily, Allah wastes not the reward of the doers of good.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
If only there had been among the generations before you persons having wisdom, prohibiting (others) from Fasad (corruption) in the earth, except a few of those whom We saved from among them! Those who did wrong pursued the enjoyment of good things of (this worldly) life, and were criminals.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
And your Lord would never destroy the towns wrongfully, while their people were doers of good.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
And if your Lord had so willed, He could surely have made mankind one Ummah, but they will not cease to disagree.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Except him on whom your Lord has bestowed His mercy, and for that did He create them. And the Word of your Lord has been fulfilled (His saying): ``Surely, I shall fill Hell with Jinn and men all together."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And all that We relate to you of the news of the Messengers is in order that We may make strong and firm your heart thereby. And in this has come to you the truth, as well as an admonition and a reminder for the believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say to those who do not believe: ``Act according to your ability and way, We are acting.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And you wait! We (too) are waiting."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
And to Allah belongs the Ghayb of the heavens and the earth, and to Him return all affairs (for decision). So worship Him and put your trust in Him. And your Lord is not unaware of what you (people) do.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif-Lam-Ra. These are the verses of the Book that is clear.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
Verily, We have sent it down as an Arabic Qur'an in order that you may understand.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We relate unto you the best of stories through Our revelations unto you, of this Qur'an. And before this, you were among those who knew nothing about it.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
(Remember) when Yusuf said to his father: ``O my father! Verily, I saw (in a dream) eleven stars and the sun and the moon - I saw them prostrating themselves to me."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He (the father) said: ``O my son! Relate not your vision to your brothers, lest they should arrange a plot against you. Verily, Shaytan is to man an open enemy!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
``Thus will your Lord choose you and teach you the interpretation of dreams (and other things) and perfect His favor on you and on the offspring of Ya`qub, as He perfected it on your fathers, Ibrahim and Ishaq aforetime! Verily, your Lord is All-Knowing, All-Wise."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
Verily, in Yusuf and his brethren there were Ayat for those who ask.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said: ``Truly, Yusuf and his brother are dearer to our father than we, while we are `Usbah (a group). Really, our father is in a plain error."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
``Kill Yusuf or cast him out to some (other) land, so that the favor of your father may be given to you alone, and after that you will be righteous folk."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
One from among them said: ``Kill not Yusuf, but if you must do something, throw him down to the bottom of a well; he will be picked up by some caravan of travelers."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said: ``O our father! Why do you not trust us with Yusuf though we are indeed his well-wishers"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
``Send him with us tomorrow to enjoy himself and play, and verily, we will take care of him."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
He (Ya`qub) said: ``Truly, it saddens me that you should take him away. I fear lest a wolf should devour him, while you are careless of him."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said: ``If a wolf devours him, while we are `Usbah (a group), then surely, we are the losers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So, when they took him away, they all agreed to throw him down to the bottom of the well, and We revealed to him: ``Indeed, you shall (one day) inform them of this their affair, when they know (you) not."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came to their father in the early part of the night weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said: ``O our father! We went racing with one another, and left Yusuf by our belongings and a wolf devoured him; but you will never believe us even when we speak the truth."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought his shirt stained with false blood. He said: ``Nay, but your own selves have made up a tale. So (for me) patience is most fitting. And it is Allah (Alone) Whose help can be sought against that (lie) which you describe."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And there came a caravan of travelers and they sent their water-drawer, and he let down his bucket (into the well). He said: ``What good news! Here is a boy." So they hid him as merchandise (a slave). And Allah was the All-Knower of what they did.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And they sold him for a Bakhs price, - for a few Dirhams. And they were of those who regarded him insignificant.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
And he (the man) from Egypt who bought him, said to his wife: ``Make his stay comfortable, maybe he will profit us or we shall adopt him as a son." Thus did We establish Yusuf in the land, that We might teach him the interpretation of events. And Allah has full power and control over His affairs, but most of men know not.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when he [Yusuf] attained his full manhood, We gave him wisdom and knowledge (the prophethood), thus We reward the doers of good.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And she, in whose house he was, sought to seduce him (to do an evil act), and she closed the doors and said: ``Come on, O you." He said: ``I seek refuge in Allah! Truly, he is my Rabb! He made my living in a great comfort! Verily, the wrongdoers will never be successful."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And indeed she did desire him, and he would have inclined to her desire, had he not seen the evidence of his Lord. Thus it was, that We might turn away from him evil and immoval sins. Surely, he was one of Our Mukhlasin servants.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
So they raced with one another to the door, and she tore his shirt from the back. They both found her master (i.e. her husband) at the door. She said: ``What is the recompense (punishment) for him who intended an evil design against your wife, except that he be put in prison or a painful torment"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
He [Yusuf] said: ``It was she that sought to seduce me;" and a witness of her household bore witness (saying): ``If it be that his shirt is torn from the front, then her tale is true and he is a liar!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
``But if it be that his shirt is torn from the back, then she has told a lie and he is speaking the truth!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when he (her husband) saw his [Yusuf`s] shirt torn at the back, he (her husband) said: ``Surely, it is a plot of you women! Certainly mighty is your plot!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
``O Yusuf! Turn away from this! (O woman!) Ask forgiveness for your sin, verily, you were of the sinful."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And women in the city said: ``The wife of the `Aziz is seeking to seduce her (slave) young man, indeed she loves him violently; verily, we see her in plain error."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
So when she heard of their accusation, she sent for them and prepared a banquet for them; she gave each one of them a knife, and she said [to Yusuf]: ``Come out before them." Then, when they saw him, they exalted him (at his beauty) and (in their astonishment) cut their hands. They said: ``How perfect is Allah! No man is this! This is none other than a noble angel!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said: ``This is he (the young man) about whom you did blame me, and I did seek to seduce him, but he refused. And now if he refuses to obey my order, he shall certainly be cast into prison, and will be one of those who are disgraced."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said: ``O my Lord! Prison is dearer to me than that to which they invite me. Unless You turn away their plot from me, I will feel inclined towards them and be one of the ignorant."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord answered his invocation and turned away from him their plot. Verily, He is the All-Hearer, the All-Knower.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it occurred to them, after they had seen the proofs (of his innocence), to imprison him for a time.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And there entered with him two young men in the prison. One of them said: ``Verily, I saw myself (in a dream) pressing wine." The other said: ``Verily, I saw myself (in a dream) carrying bread on my head and birds were eating thereof." (They said): ``Inform us of the interpretation of this. Verily, we think you are one of the doers of good."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said: ``No food will come to you as your provision, but I will inform its interpretation before it comes. This is of that which my Lord has taught me. Verily, I have abandoned the religion of a people that believe not in Allah and are disbelievers in the Hereafter."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
``And I have followed the religion of my fathers, - Ibrahim, Ishaq and Ya'qub and never could we attribute any partners whatsoever to Allah. This is from the grace of Allah to us and to mankind, but most men thank not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
``O two companions of the prison! Are many different lords (gods) better or Allah, the One, the Irresistible"\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
``You do not worship besides Him but only names which you have named (forged) - you and your fathers - for which Allah has sent down no authority. The command is for none but Allah. He has commanded that you worship none but Him; that is the straight religion, but most men know not."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
``O two companions of the prison! As for one of you, he will pour out wine for his master to drink; and as for the other, he will be crucified and birds will eat from his head. Thus is the case judged concerning which you both did inquire."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said to the one whom he knew to be saved: ``Mention me to your king." But Shaytan made him forget to mention it to his master. So [Yusuf] stayed in prison a few (more) years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And the king (of Egypt) said: ``Verily, I saw (in a dream) seven fat cows, whom seven lean ones were devouring, and seven green ears of corn, and (seven) others dry. O notables! Explain to me my dream, if it be that you can interpret dreams."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said: ``Mixed up false dreams and we are not skilled in the interpretation of dreams."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
Then the man who was released, now at length remembered and said: ``I will tell you its interpretation, so send me forth."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
(He said): ``O Yusuf, the man of truth! Explain to us seven fat cows whom seven lean ones were devouring, and seven green ears of corn, and (seven) others dry, that I may return to the people, and that they may know."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
[Yusuf] said: ``For seven consecutive years, you shall sow as usual and that which you reap you shall leave it in the ears, (all) except a little of it which you may eat."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
``Then will come after that, seven hard (years), which will devour what you have laid by in advance for them, (all) except a little of that which you have guarded (stored)."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
``Then thereafter will come a year in which people will have abundant rain and in which they will press (wine and oil)."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
And the king said: ``Bring him to me." But when the messenger came to him, [Yusuf] said: ``Return to your king and ask him, `What happened to the women who cut their hands Surely, my Lord (Allah) is Well-Aware of their plot."'\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
(The king) said (to the women): ``What was your affair when you did seek to seduce Yusuf" The women said: ``Allah forbid! No evil know we against him!" The wife of the `Aziz said: ``Now the truth is manifest (to all); it was I who sought to seduce him, and he is surely of the truthful. ``\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
[Then Yusuf said: ``I asked for this inquiry] in order that he may know that I betrayed him not in (his) absence." And, verily, Allah guides not the plot of the betrayers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
``And I free not myself (from the blame). Verily, the self is inclined to evil, except when my Lord bestows His mercy (upon whom He wills). Verily, my Lord is Oft-Forgiving, Most Merciful."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
And the king said: ``Bring him to me that I may attach him to my person." Then, when he spoke to him, he said: ``Verily, this day, you are with us high in rank and fully trusted."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
[Yusuf] said: ``Set me over the storehouses of the land; I will indeed guard them with full knowledge."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
Thus did We give full authority to Yusuf in the land, to take possession therein, when or where he likes. We bestow of Our mercy on whom We will, and We make not to be lost the reward of the good doers.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
And verily, the reward of the Hereafter is better for those who believed and had Taqwa.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And Yusuf's brethren came and they entered unto him, and he recognized them, but they recognized him not.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he furnished them with their provisions, he said: ``Bring me a brother of yours from your father. See you not that I give full measure, and that I am the best of the hosts"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
``But if you bring him not to me, there shall be no measure (of corn) for you with me, nor shall you come near me."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said: ``We shall try to get permission (for him) from his father, and verily, we shall do it."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
And [Yusuf] told his servants to put their money into their bags, so that they might know it when they go back to their people; in order that they might come again.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
So, when they returned to their father, they said: ``O our father! No more measure of grain shall we get (unless we take our brother). So send our brother with us, and we shall get our measure and truly, we will guard him."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said: ``Can I entrust him to you except as I entrusted his brother [Yusuf] to you aforetime But Allah is the Best to guard, and He is the Most Merciful of those who show mercy."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their bags, they found their money had been returned to them. They said: ``O our father! What (more) can we desire This, our money has been returned to us; so we shall get (more) food for our family, and we shall guard our brother and add one more measure of a camel's load. This quantity is easy (for the king to give)."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
He [Ya`qub] said: ``I will not send him with you until you swear a solemn oath to me in Allah's Name, that you will bring him back to me unless you are yourselves surrounded (by enemies)," And when they had sworn their solemn oath, he said: ``Allah is the Witness to what we have said."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said: ``O my sons! Do not enter by one gate, but enter by different gates, and I cannot avail you against Allah at all. Verily, the decision rests only with Allah. In Him, I put my trust and let all those that trust, put their trust in Him."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered according to their father's advice, it did not avail them in the least against (the will of) Allah; it was but a need of Ya`qub's inner self which he discharged. And verily, he was endowed with knowledge because We had taught him, but most men know not.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they went in before Yusuf, he took his brother (Binyamin) to himself and said: ``Verily, I am your brother, so grieve not for what they used to do."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
So when he furnished them forth with their provisions, he put the bowl in his brother's bag. Then a crier cried: ``O you (in) the caravan! Surely, you are thieves!"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They, turning towards them, said: ``What is it that you have lost"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said: ``We have lost the bowl of the king and for him who produces it is (the reward of) a camel load; and I will be bound by it."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said: ``By Allah! Indeed you know that we came not to make mischief in the land, and we are no thieves!"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
They said: ``What then shall be the penalty of him, if you are (proved to be) liars."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
They [Yusuf's brothers] said: ``His penalty should be that he, in whose bag it is found, should be held for the punishment (of the crime). Thus we punish the wrongdoers!"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he [Yusuf] began (the search) in their bags before the bag of his brother. Then he brought it out of his brother's bag. Thus did We plan for Yusuf. He could not take his brother by the law of the king (as a slave), except that Allah willed it. We raise to degrees whom We will, but over all those endowed with knowledge is the All-Knowing (Allah).\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They [Yusuf's brothers] said: ``If he steals, there was a brother of his [Yusuf] who did steal before (him). `` But these things did Yusuf keep in himself, revealing not the secrets to them. He said (within himself): ``You are in an evil situation, and Allah is the Best Knower of that which you describe!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said: ``O `Aziz! Verily, he has an old father (who will grieve for him); so take one of us in his place. Indeed we think that you are one of the doers of good."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said: ``Allah forbid, that we should take anyone but him with whom we found our property. Indeed (if we did so), we should be wrongdoers."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
So, when they despaired of him, they consulted in private. The eldest among them said: ``Know you not that your father did take an oath from you in Allah's Name, and before this you did fail in your duty with Yusuf Therefore I will not leave this land until my father permits me, or Allah decides my case and He is the Best of the judges.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
``Return to your father and say, `O our father! Verily, your son has stolen, and we testify not except according to what we know, and we could not know the Unseen!\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
``And ask (the people of) the town where we have been, and the caravan in which we returned; and indeed we are telling the truth."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
He [Ya`qub] said: ``Nay, but your own selves have beguiled you into something. So patience is most fitting (for me). May be Allah will bring them (back) all to me. Truly, He! Only He is All-Knowing, All-Wise."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them and said: ``Alas, my grief for Yusuf!" And he lost his sight because of the sorrow that he was suppressing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said: ``By Allah! You will never cease remembering Yusuf until you become weak with old age, or until you be of the dead."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said: ``I only complain of my grief and sorrow to Allah, and I know from Allah that which you know not."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
``O my sons! Go you and inquire about Yusuf and his brother, and never give up hope of Allah's mercy. Certainly no one despairs of Allah's mercy, except the people who disbelieve."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
Then, when they entered unto him, they said: ``O `Aziz! A hard time has hit us and our family, and we have brought but poor capital, so pay us full measure and be charitable to us. Truly, Allah does reward the charitable."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said: ``Do you know what you did with Yusuf and his brother, when you were ignorant"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said: ``Are you indeed Yusuf" He said: ``I am Yusuf, and this is my brother. Allah has indeed been gracious to us. He who has Taqwa, and is patient, then surely, Allah makes not the reward of the gooddoers to be lost."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said: ``By Allah! Indeed Allah has preferred you above us, and we certainly have been sinners."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said: ``No reproach on you this day; may Allah forgive you, and He is the Most Merciful of those who show mercy!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
``Go with this shirt of mine, and cast it over the face of my father, his vision will return, and bring to me all your family."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
And when the caravan departed, their father said: ``I do indeed sense the smell of Yusuf, if only you think me not senile."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said: ``By Allah! Certainly, you are in your old Dalal (error)."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
Then, when the bearer of the good news arrived, he cast it (the shirt) over his face, and his vision returned. He said: ``Did I not say to you, `I know from Allah that which you know not"'\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said: ``O our father! Ask forgiveness (from Allah) for our sins, indeed we have been sinners."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said: ``I will ask my Lord for forgiveness for you, verily, He! Only He is the Oft-Forgiving, the Most Merciful."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
Then, when they came in before Yusuf, he took his parents to himself and said: ``Enter Egypt, if Allah wills, in security."\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he raised his parents to the `Arsh and they fell down before him prostrate. And he said: ``O my father! This is the interpretation of my dream aforetime! My Lord has made it come true! He was indeed good to me, when He took me out of the prison, and brought you (all here) out of the bedouin life, after Shaytan had sown enmity between me and my brothers. Certainly, my Lord is the Most Courteous and Kind unto whom He wills. Truly, He! Only He is the All-Knowing, the All-Wise.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
``My Lord! You have indeed bestowed on me of the sovereignty, and taught me something of the interpretation of dreams - the (Only) Creator of the heavens and the earth! You are my Wali in this world and in the Hereafter. Cause me to die as a Muslim, and join me with the righteous."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
That is of the news of the Ghayb (Unseen) which We reveal to you. You were not (present) with them when they arranged their plan together, and (while) they were plotting.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And most of mankind will not believe even if you desire it eagerly.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
And no reward you ask of them for it; it (the Qur'an) is no less than a Reminder unto the `Alamin (men and Jinn).\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
And how many a sign in the heavens and the earth they pass by, while they are averse therefrom.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe not in Allah except that they attribute partners unto Him.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Do they then feel secure from the coming against them of the covering veil of the torment of Allah, or of the coming against them of the (Final) Hour, all of a sudden while they perceive not\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say ``This is my way; I invite unto Allah with sure knowledge, I and whosoever follows me. And Glorified and Exalted be Allah. And I am not of the idolators."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
And We sent not before you (as Messengers) any but men unto whom We revealed, from among the people of townships. Have they not traveled in the land and seen what was the end of those who were before them And verily, the home of the Hereafter is the best for those who have Taqwa. Do you not then understand\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
(They were reprieved) until, when the Messengers gave up hope and thought that they were denied, then came to them Our help, and whomsoever We willed were rescued. And Our punishment cannot be warded off from the people who are criminals.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
Indeed in their stories, there is a lesson for men of understanding. It (the Qur'an) is not a forged statement but a confirmation of that which was before it and a detailed explanation of everything and a guide and a mercy for the people who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif Lam-Mim Ra. These are the verses of the Book (the Qur'an), and that which has been revealed unto you from your Lord is the truth, but most men believe not.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
Allah is He Who raised the heavens without any pillars that you can see. Then, He rose above (Istawa) the `Arsh [Throne]. He has subjected the sun and the moon, each running (its course) for a term appointed. He manages and regulates all affairs; He explains the Ayat in detail, that you may believe with certainty in the meeting with your Lord.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And it is He Who spread out the earth, and placed therein firm mountains and rivers and of every kind of fruit He made Zawjayn Ithnayn (two in pairs). He brings the night as a cover over the day. Verily, in these things, there are Ayat (signs) for people who reflect.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And in the earth are neighboring tracts, and gardens of vines, and green crops (fields), and date palms, growing into two or three from a single stem root, or otherwise, watered with the same water; yet some of them We make more excellent than others to eat. Verily, in these things there are Ayat (signs) for the people who understand.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And if you wonder, then wondrous is their saying: ``When we are dust, shall we indeed then be (raised) in a new creation" They are those who disbelieved in their Lord! They are those who will have iron chains linking their hands to their necks. They will be dwellers of the Fire to abide therein forever.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They ask you to hasten the evil before the good, while exemplary punishments have indeed occurred before them. But verily, your Lord is full of forgiveness for mankind, in spite of their wrongdoing. And verily, your Lord is (also) severe in punishment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
And the disbelievers say: ``Why is not a sign sent down to him from his Lord" You are only a warner, and to every people there is a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knows what every female bears, and by how much the wombs fall short (of their time or number) or exceed. Everything with Him is in (due) proportion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
All-Knower of the unseen and the seen, the Most Great, the Most High.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
It is the same (to Him) whether any of you conceals his speech or declares it openly, whether he be hid by night or goes forth freely by day.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For him (each person), there are angels in succession, before and behind him. They guard him by the command of Allah. Verily, Allah will not change the (good) condition of a people as long as they do not change their state (of goodness) themselves. But when Allah wills a people's punishment, there can be no turning it back, and they will find besides Him no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He Who shows you the lightning, as a fear and as a hope. And it is He Who brings up the clouds, heavy (with water).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
And Ar-Ra'd (thunder) glorifies and praises Him, and so do the angels because of His awe. He sends the thunderbolts, and therewith He strikes whom He wills, yet they (disbelievers) dispute about Allah. And He is Mighty in strength and Severe in punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
For Him is the Word of Truth. And those whom they invoke besides Him, answer them no more than one who stretches forth his hand for water to reach his mouth, but it reaches him not; and the invocation of the disbelievers is nothing but misguidance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
And unto Allah falls in prostration whoever is in the heavens and the earth, willingly or unwillingly, and so do their shadows in the mornings and in the afternoons.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say: ``Who is the Lord of the heavens and the earth" Say: ``(It is) Allah." Say: ``Have you then taken (for worship) Awliya' (protectors) other than Him, such as have no power either for benefit or for harm to themselves" Say: ``Is the blind equal to the one who sees Or darkness equal to light Or do they assign to Allah partners who created the like of His creation, so that the creation seemed alike to them" Say: ``Allah is the Creator of all things; and He is the One, the Irresistible."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down water from the sky, and the valleys flow according to their measure, but the flood bears away the foam that mounts up to the surface - and (also) from that (ore) which they heat in the fire in order to make ornaments or utensils, rises a foam like unto it, thus does Allah (by parables) show forth truth and falsehood. Then, as for the foam it passes away as scum upon the banks, while that which is for the good of mankind remains in the earth. Thus Allah sets forth parables.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who answered their Lord's call is Al-Husna. But those who answered not His call, if they had all that is in the earth together with its like, they would offer it in order to save themselves. For them there will be the terrible reckoning. Their dwelling place will be Hell; and worst indeed is that place for rest.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Shall he then who knows that what has been revealed unto you from your Lord is the truth, be like him who is blind But it is only the men of understanding that pay heed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfill, the covenant of Allah and break not the trust.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
And those who join that which Allah has commanded to be joined and fear their Lord, and dread the terrible reckoning.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
And those who remain patient, seeking their Lord's Face, perform the Salah, and spend out of that which We have bestowed on them, secretly and openly, and repel evil with good, for such there is a good end.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
`Adn Gardens, which they shall enter and (also) those who acted righteously from among their fathers, and their wives, and their offspring. And angels shall enter unto them from every gate (saying):\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
``Salamun `Alaykum (peace be upon you) for you persevered in patience! Excellent indeed is the final home!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
And those who break the covenant of Allah, after its ratification, and sever that which Allah has commanded to be joined, and work mischief in the land, on them is the curse, and for them is the unhappy (evil) home (i.e. Hell).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah increases the provision for whom He wills, and straitens (it for whom He wills), and they rejoice in the life of the world, whereas the life of this world compared to the Hereafter is but a brief passing enjoyment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
And those who disbelieved say: ``Why is not a sign sent down to him from his Lord" Say: ``Verily, Allah sends astray whom He wills and guides unto Himself those who turn to Him in repentance."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Those who believed and whose hearts find rest in the remembrance of Allah. Verily, in the remembrance of Allah do hearts find rest.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
Those who believed, and work righteousness, Tuba is for them and a beautiful place of (final) return.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus have We sent you to a community before whom other communities have passed away, in order that you might recite unto them what We have revealed to you, while they disbelieve in the Most Gracious (Allah). Say: ``He is my Lord! None has the right to be worshipped but He! In Him is my trust, and to Him I turn."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
And if there had been a Qur'an with which mountains could be moved (from their places), or the earth could be cloven asunder, or the dead could be made to speak (it would not have been other than this Qur'an). But the decision of all things is certainly with Allah. Have not then those who believed yet known that had Allah willed, He could have guided all mankind And a disaster will not cease to strike those who disbelieved because of their (evil) deeds or it (i.e. the disaster) settles close to their homes, until the promise of Allah comes to pass. Certainly, Allah breaks not His promise.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
And indeed (many) Messengers were mocked at before you but I granted respite to those who disbelieved, and finally I punished them. Then how (terrible) was My punishment!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Is then He (Allah) Who takes charge of every person and knows all that he has earned (like any other deity who knows nothing) Yet, they ascribe partners to Allah. Say: ``Name them! Is it that you will inform Him of something He knows not in the earth or is it (just) a show of false words." Nay! To those who disbelieved, their plotting is made fair-seeming, and they have been hindered from the right path; and whom Allah sends astray, for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them is a torment in the life of this world, and certainly, harder is the torment of the Hereafter. And they have no defender (or protector) against Allah.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The description of the Paradise which those who have Taqwa have been promised: Underneath it rivers flow, its provision is eternal and so is its shade; this is the end (final destination) of those who have Taqwa, and the end (final destination) of the disbelievers is Fire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
Those to whom We have given the Book, rejoice at what has been revealed unto you, but there are among the Ahzab (Confederates) those who reject a part thereof. Say: ``I am commanded only to worship Allah and not to join partners with Him. To Him I call and to Him is my return."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And thus have We sent it (the Qur'an) down to be a judgement of authority in Arabic. Were you to follow their (vain) desires after the knowledge which has come to you, then you will not have any Wali (protector) or defender against Allah.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And indeed We sent Messengers before you, and made for them wives and offspring. And it was not for a Messenger to bring a sign except by Allah's leave. (For) every matter there is a decree (from Allah).\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah blots out what He wills and confirms (what He wills). And with Him is the Mother of the Book.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
Whether We show you part of what We have promised them or cause you to die, your duty is only to convey (the Message) and on Us is the reckoning.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
See they not that We gradually reduce the land from its outlying borders. And Allah judges, there is none to put back His judgement, and He is swift at reckoning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
And verily, those before them did devise plots, but all planning is Allah's. He knows what every person earns, and the disbelievers will know who gets the good end (final destination).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
And those who disbelieved, say: ``You are not a Messenger." Say: ``Sufficient as a witness between me and you is Allah and those too who have knowledge of the Scripture."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif-Lam-Ra. (This is) a Book which We have revealed unto you in order that you might lead mankind out of darkness into light by their Lord's leave to the path of the Almighty, the Praised.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah to Whom belongs all that is in the heavens and all that is in the earth! And woe unto the disbelievers from a severe torment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
Those who prefer the life of this world to the Hereafter, and hinder (men) from the path of Allah and seek crookedness therein - they are far astray.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We sent not a Messenger except with the language of his people, in order that he might make (the Message) clear for them. Then Allah misleads whom He wills and guides whom He wills. And He is the All-Mighty, the All-Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
And indeed We sent Musa with Our Ayat (saying): ``Bring out your people from darkness into light, and remind them of the annals (or days) of Allah. Truly, therein are Ayat for every patient, thankful (person)."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And (remember) when Musa said to his people: ``Call to mind Allah's favor to you, when He delivered you from Fir`awn's people who were afflicting you with horrible torment, and were slaughtering your sons and letting your women live; and in it was a tremendous trial from your Lord."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And (remember) when your Lord proclaimed: ``If you give thanks, I will give you more; but if you are thankless, verily, My punishment is indeed severe."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Musa said: ``If you disbelieve, you and all on earth together, then verily, Allah is Rich (free of all needs), Worthy of all praise."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Has not the news reached you, of those before you, the people of Nuh, `Ad, and Thamud And those after them None knows them but Allah. To them came their Messengers with clear proofs, but they put their hands in their mouths and said: ``Verily, we disbelieve in that with which you have been sent, and we are really in grave doubt as to that to which you invite us."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their Messengers said: ``(What!) Can there be a doubt about Allah, the Creator of the heavens and the earth He calls you that He may forgive you of your sins and give you respite for a term appointed." They said: ``You are no more than human beings like us! You wish to turn us away from what our fathers used to worship. Then bring us a clear authority."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their Messengers said to them: ``We are no more than human beings like you, but Allah bestows His grace to whom He wills of His servants. It is not ours to bring you an authority (proof) except by the permission of Allah. And in Allah (alone) let the believers put their trust."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
``And why should we not put our trust in Allah while He indeed has guided us in our ways And we shall certainly bear with patience all the hurt you may cause us, and in Allah (alone) let those who trust, put their trust."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And those who disbelieved, said to their Messengers: ``Surely, we shall drive you out of our land, or you shall return to our religion." So their Lord revealed to them: ``Truly, We shall destroy the wrongdoers."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
``And indeed, We shall make you dwell in the land after them. This is for him who fears standing before Me and also fears My threat."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
And they sought victory and help; and every obstinate, arrogant dictator (who refuses to believe in the Oneness of Allah) was brought to a complete loss and destruction.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
In front of him is Hell, and he will be made to drink boiling, festering water.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
He will sip it unwillingly, and he will find great difficulty in swallowing it down his throat, and death will come to him from every side, yet he will not die, and in front of him, will be a great torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The parable of those who disbelieved in their Lord is that their works are as ashes, on which the wind blows furiously on a stormy day; they shall not be able to get aught of what they have earned. That is the straying, far away (from the right path).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Do you not see that Allah has created the heavens and the earth with truth If He wills, He can remove you and bring (in your place) a new creation!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And for Allah that is not hard or difficult.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
And they all shall appear before Allah; then the weak will say to those who were arrogant: ``Verily, we were following you; can you avail us anything against Allah's torment" They will say: ``Had Allah guided us, we would have guided you. It makes no difference to us (now) whether we rage, or bear (these torments) with patience; there is no place of refuge for us."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Shaytan will say when the matter has been decided: ``Verily, Allah promised you a promise of truth. And I too promised you, but I betrayed you. I had no authority over you except that I called you, and you responded to me. So blame me not, but blame yourselves. I cannot help you, nor can you help me. I deny your former act in associating me (Shaytan) as a partner with Allah (by obeying me in the life of the world). Verily, there is a painful torment for the wrongdoers."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
And those who believed and did righteous deeds, will be made to enter Gardens under which rivers flow, - to dwell therein for ever (i.e. in Paradise), with the permission of their Lord. Their greeting therein will be: ``Salam (peace!)."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
See you not how Allah sets forth a parable A goodly word as a goodly tree, whose root is firmly fixed, and its branches (reach) to the sky.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
Giving its fruit at all times, by the leave of its Lord, and Allah sets forth parables for mankind in order that they may remember.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the parable of an evil word is that of an evil tree uprooted from the surface of earth, having no stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah will keep firm those who believe, with the word that stands firm in this world, and in the Hereafter. And Allah will cause the wrongdoers to go astray, and Allah does what He wills.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Have you not seen those who have changed the blessings of Allah into disbelief (by denying Prophet Muhammad and his Message of Islam), and caused their people to dwell in the house of destruction\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
Hell, in which they will burn, - and what an evil place to settle in!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they set up rivals to Allah, to mislead (men) from His path! Say: ``Enjoy (your brief life)! But certainly, your destination is the (Hell) Fire!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
Say to My servants who have believed, that they should perform the Salah, and spend (in charity) out of the sustenance We have given them, secretly and openly, before the coming of a Day on which there will be neither mutual bargaining nor befriending.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
Allah is He Who has created the heavens and the earth and sends down water (rain) from the sky, and thereby brought forth fruits as provision for you; and He has made the ships to be of service to you, that they may sail through the sea by His command; and He has made rivers (also) to be of service to you.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And He has made the sun and the moon, both constantly pursuing their courses, to be of service to you; and He has made the night and the day to be of service to you.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He gave you of all that you asked for, and if you [try to] count the blessings of Allah, never will you be able to count them. Verily, man is indeed an extreme wrongdoer, ungrateful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And (remember) when Ibrahim said: ``O my Lord! Make this city (Makkah) one of peace and security, and keep me and my sons away from worshipping idols.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
``O my Lord! They have indeed led astray many among mankind. But whoso follows me, he verily, is of me. And whoso disobeys me, still You are indeed Oft-Forgiving, Most Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
``O our Lord! I have made some of my offspring dwell in an uncultivable valley by Your Sacred House in order, O our Lord, that they may perform Salah. So fill some hearts among men with love towards them, and (O Allah) provide them with fruits so that they may give thanks.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
``O our Lord! Certainly, You know what we conceal and what we reveal. Nothing on the earth or in the heaven is hidden from Allah."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
``All praise is due to Allah, Who has given me in old age Isma'il and Ishaq. Verily, my Lord is indeed the All-Hearer of invocations."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
``O my Lord! Make me one who performs Salah, and (also) from my offspring, our Lord! And accept my invocation."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
``Our Lord! Forgive me and my parents, and (all) the believers on the Day when the reckoning will be established."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
Consider not that Allah is unaware of that which the wrongdoers do, but He gives them respite up to a Day when the eyes will stare in horror.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
(They will be) hastening forward with necks outstretched, their heads raised up (towards the sky), their gaze returning not towards them and their hearts empty.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And warn mankind of the Day when the torment will come unto them; then the wrongdoers will say: ``Our Lord! Respite us for a little while, we will answer Your call and follow the Messengers!" (It will be said:) ``Had you not sworn aforetime that you would not leave (the world for the Hereafter)."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
``And you dwelt in the dwellings of men who wronged themselves, and it was clear to you how We dealt with them. And We put forth (many) parables for you."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
Indeed, they planned their plot, and their plot was with Allah, though their plot was not such as to remove the mountains from their places.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So think not that Allah will fail to keep His promise to His Messengers. Certainly, Allah is All-Mighty, All-Able of Retribution.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
On the Day when the earth will be changed to another earth and so will be the heavens, and they (all creatures) will appear before Allah, the One, the Irresistible.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And you will see the criminals that Day, Muqarranun (bound together) in fetters.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their garments will be of Qatiran (tar), and fire will cover their faces.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
That Allah may requite each person according to what he has earned. Truly, Allah is swift at reckoning.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This (Qur'an) is a Message for mankind (and a clear proof against them), in order that they may be warned thereby, and that they may know that He is the only One God and that men of understanding may take heed.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif-Lam-Ra. These are Ayat of the Book and a plain Qur'an.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
How much would those who disbelieved wish that they had been Muslims.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Leave them to eat and enjoy, and let them be preoccupied with (false) hope. They will come to know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
And never did We destroy a township but there was a known decree for it.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No nation can advance its term, nor delay it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they say: ``O you (Muhammad) to whom the Dhikr (the Qur'an) has been revealed! Verily, you are a madman!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
``Why do you not bring angels to us if you are of the truthful"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We do not send the angels down except with the truth, and in that case, they (the disbelievers) would have no respite!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Verily, We, it is We Who revealed the Dhikr (i.e. the Qur'an) and surely We will guard it (from corruption).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
Indeed, We sent (Messengers) before you (O Muhammad) amongst the earlier communities.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And there never came a Messenger to them but that they mocked him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Thus We allow it to enter the hearts of the guilty.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They would not believe in it (the Qur'an); and already the example of the ancients has gone forth.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
And even if We opened to them a gate to the heavens and they were to continue ascending through it (all day long).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would surely say (in the evening): ``Our eyes have been (as if) dazzled (we have not seen any angel or heaven). Nay, we are a people bewitched."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
And indeed, We have put the big stars in the heaven and We beautified it for the beholders.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We have guarded it (near heaven) from every outcast Shaytan (devil).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Except him (devil) who steals the hearing, then he is pursued by a clear flaming fire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And We have spread out the earth, and have placed firm mountains in it, and caused all kinds of things to grow in it, in due proportion.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And in it We have provided means of living, for you and for those whom you provide not.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing, but the supplies for it are with Us, and We do not send it down but in a known measure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We send the winds fertilizing, then We cause the water to descend from the sky, and We give it to you to drink, and it is not you who are the owners of its supply.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And certainly We! It is We Who give life, and cause death, and We are the Inheritors.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And indeed, We know the first generations of you who have passed away, and indeed, We know the present generations of you (mankind), and also those who will come afterwards.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
And verily, your Lord will gather them together. Truly, He is Most Wise, (and) Knowing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
And indeed, We created man from dried (sounding) clay of altered mud.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the Jinn, We created earlier from the smokeless flame of fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And (remember) when your Lord said to the angels: ``I am going to create a man (Adam) from dried (sounding) clay of altered mud. ``\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
``So, when I have fashioned him completely and breathed into him (Adam) of My spirit (the soul which I created for him,) then fall down, prostrating yourselves before him."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So the angels prostrated themselves, all of them together.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Except Iblis (Shaytan) - he refused to be among the prostrate.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
(Allah) said: ``O Iblis! What is your reason for not being among the prostrate"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
[Iblis] said: ``I am not one to prostrate myself to a human, whom You created from dried (sounding) clay of altered mud."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
(Allah) said: ``Then leave, for verily, you are an outcast. ``\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
``And verily, the curse shall be upon you until the Day of Recompense."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
[Iblis] said: ``O my Lord! Then give me respite until the Day they (the dead) will be resurrected."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
Allah said: ``Then verily, you are of those reprieved,"\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
``Until the Day of the time appointed."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
[Iblis] said: ``O my Lord! Because You misled me, I shall indeed adorn the path of error for them (mankind) on the earth, and I shall mislead them all."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
``Except Your chosen (guided) servants among them."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
(Allah) said: ``This is the way which will lead straight to Me."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
``Certainly, you shall have no authority over My servants, except those of the astray who follow you."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And surely, Hell is the place promised for them all.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
It has seven gates, for each of those gates is a class assigned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
Truly, those who have Taqwa, will dwell in Gardens and water springs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
(It will be said to them): ``Enter it in peace and security."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We shall remove any deep feeling of bitterness from their breasts. (So they will be like) brothers facing each other on thrones.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
No sense of fatigue shall touch them, nor shall they be asked to leave it.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
Declare to My servants that I am truly the Forgiving, the Most Merciful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that My torment is indeed the most painful torment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And tell them about the guests (i.e., the angels) of Ibrahim.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they entered upon him, and said: ``Salaman (peace!)." He said: ``Indeed we are frightened of you."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
They said: ``Do not be afraid! We bring you the good news of a boy possessing much knowledge and wisdom."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said: ``Do you give me this good news while old age has overtaken me Of what then is your news about"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said: ``We give you good news in truth. So do not be of those who despair."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said: ``And who despairs of the mercy of his Lord except those who are astray"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
He said: ``What then is the business for which you have come, O messengers"\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said: ``We have been sent to a guilty people."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
``(All) except the family of Lut, all of whom we are to save (from the destruction)."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
``Except for his wife, of whom We have decreed that she shall be of those who remain behind."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
Then when the messengers (the angels) came to the family of Lut\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He (Lut) said: ``Verily, you are people unknown to me."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said: ``Nay, we have come to you with that (torment) which they have been doubting."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
``And we have brought you the truth and certainly we tell the truth."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
``Then travel for a portion of the night with your family, and you go behind them in the rear, and let no one amongst you look back, but go on to where you are ordered."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We made this decree known to him that those (sinners) would be rooted out in the early morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the inhabitants of the city came rejoicing.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
[Lut] said: ``Verily, these are my guests, so do not shame me."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
``And have Taqwa of Allah, and do not disgrace me."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said: ``Did we not forbid you from entertaining any of the `Alamin"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
[Lut] said: ``These are my daughters, if you must act (so)."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
Verily, by your life, in their wild intoxication, they were wandering blindly.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
So the Sayhah overtook them at the time of sunrise.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We turned them upside down and rained stones of baked clay upon them.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Surely, in this are signs for those who see.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And verily, they were right on the highroad.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Surely, there is indeed a sign in that for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the Dwellers of Al-Aykah, were also wrongdoers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So, We took vengeance on them. They are both on an open route, plain to see.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And verily, the Dwellers of Al-Hijr denied the Messengers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
And We gave them Our signs, but they were averse to them.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
And they used to hew out dwellings from the mountains, (feeling) secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But the Sayhah (torment - awful cry) overtook them in the early morning.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
And all that they used to earn availed them not.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
And We did not create the heavens and the earth and all that is between them except with the truth, and the Hour is surely coming, so overlook their faults with gracious forgiveness.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Verily, your Lord is the Knowing Creator.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
And indeed, We have bestowed upon you seven of the Mathani, and the Grand Qur'an.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Look not with your eyes ambitiously at what We have given to certain classes of them, nor grieve over them. And lower your wings to the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say (O Muhammad): ``I am indeed a plain warner."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
As We have sent down on the Muqtasimin (conspiring confederates),\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Who have made the Qur'an into parts.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
So, by your Lord, We shall certainly call all of them to account.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
For all that they used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Therefore openly proclaim what you have been commanded, and turn away from the idolators.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Truly, We will suffice you against the mockers,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Who make another god along with Allah; but they will come to know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
Indeed, We know that your breast becomes tight because of what they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
So glorify the praises of your Lord and be of those who prostrate themselves (to Him).\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And worship your Lord until the certainty (i.e. death) comes to you.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The Event ordained by Allah has indeed come, so do not seek to hasten it. Glorified and Exalted be He above all that they associate as partners with Him.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels with the Ruh (revelation) of His command to those servants of His whom He wills (saying): ``Warn mankind that none has the right to be worshipped but I, so have Taqwa of Me."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He has created the heavens and the earth with truth. High is He, Exalted above all that they associate as partners with Him.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He has created man from a Nutfah, then behold, this same (man) becomes an open opponent.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the cattle, He has created them for you; in them there is warmth (warm clothing), and numerous benefits, and you eat from them.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And there is beauty in them for you, when you bring them home in the evening, and as you lead them forth to pasture (in the morning).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they carry your loads to a land that you could not reach yourselves except with great trouble. Truly, your Lord is full of kindness, Most Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And (He has created) horses, mules and donkeys for you to ride, and as an adornment. And He creates (other) things of which you have no knowledge.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
And it is up to Allah to show the right way. But there are ways that stray. And had He willed, He would have guided you all.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
He it is Who sends water down from the sky; from it you drink and from it (grows) the vegetation on which you send your cattle to pasture.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
With it He causes crops to grow for you, the olives, the date palms, the grapes, and every kind of fruit. Verily, in this there is indeed an evident proof and a manifest sign for people who give thought.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He has subjected the night and the day for you, and the sun and the moon; and the stars are subjected by His command. Surely, in this are proofs for people who understand.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And all He has created of varying colors on the earth for you. Verily, in this is a sign for people who reflect.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And He it is Who subjected the sea (to you), that you may eat from the fresh tender meat, and that you bring forth out of it ornaments to wear. And you see the ships plowing through it, that you may seek from His bounty and that you may perhaps be grateful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He has driven firm standing mountains into the earth, lest it should shake with you; and rivers and roads, that you may guide yourselves.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And (by the) landmarks; and by the stars, they guide themselves.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Is then He Who creates the same as one who creates, not Will you not then reflect\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if you would try to count the favors of Allah, you would never be able to count them. Truly, Allah is Forgiving, Most Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah knows what you conceal and what you reveal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
Those whom they invoke besides Allah have not created anything, but are themselves created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
(They are) dead, not alive; and they do not know when they will be resurrected.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your god is one God. But for those who believe not in the Hereafter, their hearts are in denial, and they are proud.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Certainly, Allah knows what they conceal and what they reveal. Truly, He does not like the proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said to them: ``What is it that your Lord has revealed" They say: ``Tales of the men of old!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
They will bear their own burdens in full on the Day of Resurrection, and also the burdens of those whom they misled without knowledge. Evil indeed is that which they shall bear!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those before them indeed plotted, but Allah struck at the foundation of their building, the roof fell down upon them from above them, and the torment overtook them from directions they did not perceive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then, on the Day of Resurrection, He will disgrace them and will say: ``Where are My (so-called) partners, those over which you caused so much discord" Those who have been given the knowledge will say: ``Indeed it is a Day of disgrace and misery for the disbelievers."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
Those whose lives the angels take while they are doing wrong to themselves. Then, they will (falsely) submit (saying): ``We did not do any evil." (The angels will reply): ``Yes! Truly, Allah is Most Knowing of what you did."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
``So enter the gates of Hell, to abide therein, and indeed, what an evil abode there is for the arrogant."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And (when) it is said to those who had Taqwa (piety and righteousness), ``What is it that your Lord has revealed" They say: ``That which is good." For those who do good in this world, there is good, and the home of the Hereafter will be better. And excellent indeed will be the home (i.e. Paradise) of those who have Taqwa.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
`Adn (Eden) Paradise (Gardens of Eternity) which they will enter, under which rivers flow, in it they will have all that they wish. Thus Allah rewards those who have Taqwa.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
Those whose lives the angels take while they are in a pious state saying (to them) ``Salamun `Alaikum (peace be on you!). Enter Paradise because of what (good) you used to do (in the world)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Are they but waiting for the angels to come to them, or there comes the command of your Lord Thus did those before them. And Allah did not wrong them, but they were wronging themselves.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
Then, they were afflicted by their evil deeds, and they were surrounded by that which they used to mock.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
And those who worshipped others with Allah said: ``If Allah had so willed, neither we nor our fathers would have worshipped any but Him nor would we have forbidden anything without (a command from) Him." Those before them did the same. Then! Are the Messengers charged with anything but to clearly convey the Message\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
And We have indeed sent a Messenger to every Ummah (community, nation) (saying): ``Worship Allah (Alone), and shun the Taghut (all false deities). `` Then among them were some whom Allah guided, and among them were some who deserved to be left to stray. So travel through the land and see the end of those who denied (the truth).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
[Even] if you desire that they be guided, then verily, Allah does not guide those whom He allowed to stray, and they will have no helpers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swear by Allah with their strongest oaths, that Allah will not raise up one who dies. Yes, (He will raise them up), a promise (binding) upon Him in truth, but most of mankind know not.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
In order that He may make clear to them what they differed over, and so that those who disbelieved may know that they were liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
Verily, Our Word to a thing when We intend it, is only that We say unto it: ``Be!" - and it is.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And as for those who emigrated for the cause of Allah, after they had been wronged, We will certainly give them good residence in this world, but indeed the reward of the Hereafter will be greater; if they but knew!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
(They are) those who remained patient, and put their trust in their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And We sent not (as Our Messengers) before you (O Muhammad) any but men, whom We sent revelation. So ask Ahl Adh-Dhikr, if you know not.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
With clear signs and Books (We sent the Messengers). And We have also revealed the Dhikr to you so that you may clearly explain to men what was revealed to them, and that perhaps they may reflect.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Do then those who devise evil plots feel secure that Allah will not cause them to sink into the earth, or that torment will not seize them from where they do not perceive it\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He may punish them in the midst of their going to and fro (in their livelihood), so that there be no escape for them (from Allah's punishment)\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He may punish them where they fear it most Indeed, Your Lord is full of kindness, Most Merciful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not observed things that Allah has created: (how) their shadows shift from right to left, prostrating to Allah while they are humble\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
And to Allah prostrate all that are in the heavens and all that are in the earth, the moving creatures and the angels, and they are not proud [i.e. they worship their Lord (Allah) with humility].\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They fear their Lord above them, and they do what they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
And Allah said ``Do not worship two gods. Indeed, He (Allah) is only One God. Then fear Me Alone.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
To Him belongs all that is in the heavens and the earth and the religion. Will you then fear any other than Allah\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And whatever of blessings and good things you have, it is from Allah. Then, when harm touches you, unto Him you cry aloud for help.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
Then, when He has removed the harm from you, behold! some of you associate others in worship with their Lord (Allah).\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
So they are ungrateful for that which We have given them! Then enjoy yourselves but you will soon come to know.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they assign a portion of that which We have provided them with, to what they have no knowledge of (false deities). By Allah, you shall certainly be questioned about (all) that you used to fabricate.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they assign daughters to Allah! Glorified (and Exalted) is He (above all that they associate with Him!). And for themselves (they assign) what they desire;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
And when the news of (the birth of) a female (child) is brought to any of them, his face becomes dark, and he is filled with inner grief!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
He hides himself from the people because of the evil of what he has been informed. Shall he keep her with dishonor or bury her in the earth Certainly, evil is their decision.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
For those who do not believe in the Hereafter is an evil description, and for Allah is the highest description. And He is the All-Mighty, the All-Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
And if Allah were to punish (all) mankind for their wrongdoing, He would not leave on it (the earth) a single moving creature, but He defers them to an appointed term; and when their term comes, they can neither delay nor advance it an hour (or a moment).\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
They assign to Allah that which they dislike (for themselves), and their tongues assert the lie that the better things will be theirs. No doubt the Fire is for them, and they will be forsaken.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, We indeed sent (Messengers) to the nations before you, but Shaytan made their deeds seeming fair to them. So today he is their helper, and theirs will be a painful torment.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We have not revealed the Book to you, except that you may clearly explain to them those things in which they differ, and (as) a guidance and a mercy for a people who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And Allah sends water down from the sky, then He revives the earth with it after its death. Surely that is a sign for people who listen.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And there is indeed a lesson for you in the An'am (cattle). We have made a drink for you out of what is in its belly, from between excretions and blood, pure milk; palatable to the drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And from the fruits of date palms and grapes, you derive strong drink and a goodly provision. There is indeed a sign in this for those of reason.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And your Lord inspired the bee, saying: ``Take you habitations in the mountains and in the trees and in what they (humans) erect."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
``Then, eat of all fruits, and follow the routes that your Lord made easy (for you)." There comes forth from their bellies, a drink of varying colors, in which there is a cure for men. There is indeed a sign in that for people who reflect.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
And Allah created you and then He will cause you to die; and among you there are some who are sent back to senility, so that they know nothing after having known (much). Truly, Allah is Knowing, capable of all things.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And Allah honored some of you over others with wealth and properties. Then, those who are so honored will by no means hand over their wealth and properties to those (captives of war) whom their right hands possess, so that they may be equal with them in that. Do they then deny the favor of Allah\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah has made for you mates of your own kind, and has made for you, from your mates, sons and grandsons, and has granted you good provisions. Do they then believe in false deities and deny favor of Allah\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And they worship others besides Allah such as do not have power to grant them any provision from the heavens or the earth nor the ability to do so.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So do not give examples on behalf of Allah. Truly, Allah knows and you know not.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah gives the example of a servant under the possession of another, he has no power of any sort, and a man on whom We have bestowed good provisions from Us, and he spends from that secretly and openly. Can they be equal (By no means). All the praises and thanks are to Allah. Nay! (But) most of them know not.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah gives an example of two men, one of them dumb, who has no power over anything, and he is a burden on his master; whichever way he directs him, he brings no good. Is such a man equal to one who commands justice, and is himself on the straight path\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
And to Allah belongs the Unseen of the heavens and the earth. And the matter of the Hour is not but as a twinkling of the eye, or even nearer. Truly, Allah is able to do all things.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And Allah has brought you out from the wombs of your mothers while you knew nothing. And He gave you hearing, sight, and hearts, that you might give thanks.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Do they not see the birds held (flying) in the midst of the sky None holds them up but Allah. Verily, in this are clear signs for people who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And Allah had made your homes a place of rest for you, and made dwellings for you out of the hides of the cattle which you find so light when you travel and when you camp; and furnishings and articles of convenience out of their wool, fur, and hair - comfort for a while.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah has made shade for you out of that which He has created, and He has made places of refuge in the mountains for you, and He has made garments for you to protect you from the heat, and coats of mail to protect you from your violence. Thus does He perfect His favor for you, that you may submit yourselves to His will.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
Then, if they turn away, your duty (O Muhammad) is only to convey (the Message) in a clear way.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognize the grace of Allah, yet they deny it (by worshipping others besides Allah) and most of them are disbelievers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And on the Day when We resurrect a witness from each nation, then those who disbelieve will not be given leave, nor will they be allowed (to return to the world) to repent and ask for Allah's forgiveness.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And once those who did wrong see the torment, it will not decrease for them, nor will they be given respite.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when those who associated partners with Allah see their partners, they will say: ``Our Lord! These are our partners whom we used to call upon besides you." But they will throw back their statement at them (saying): ``You indeed are liars!"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And they will offer (their full) submission to Allah on that Day, and what they falsely invented will wander away from them.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieved and tried to obstruct the path of Allah, for them We will add torment on top of the torment because of the corruption they spread.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And on the Day when We resurrect a witness from each nation from among themselves, and We bring you (O Muhammad) as a witness against these. And We have revealed the Book (the Qur'an) to you as an explanation of everything, a guidance, a mercy, and good news for the Muslims.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Verily, Allah orders justice and kindness, and giving (help) to the relatives, and He forbids immoral sins, and evil and tyranny. He admonishes you, so that perhaps you may take heed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
And fulfill the covenants (taken in the Name of) Allah when you have taken them, and do not break the oaths after you have confirmed them - and indeed you have appointed Allah as your guarantor. Verily, Allah knows what you do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And do not be like the one who undoes the thread which she has spun, after it has become strong, by taking your oaths as a means of deception among yourselves when one group is more numerous than another group. Allah only tests you by this, and on the Day of Resurrection, He will certainly clarify that which used to differ over.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
And had Allah willed, He would have made you (all) one nation, but He allows whom He wills to stray and He guides whom He wills. But you shall certainly be called to account for what you used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And do not make your oaths a means of deception among yourselves, resulting in the slip of a foot after it was firmly planted, and you taste the evil of having hindered from the path of Allah, and you will suffer a terrible punishment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And do not use an oath by Allah for the purchase of little value, what is with Allah is better for you if you only knew.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
Whatever you have will be exhausted, and what is with Allah will remain. And to those who are patient, We will certainly grant them their rewards in proportion to the best of what they used to do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whoever does righteous deeds - whether male or female - while he (or she) is a believer; then We will certainly give them a good life, and We will certainly grant them their rewards in proportion to the best of what they used to do.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
So when you recite the Qur'an, seek refuge with Allah from Shaytan, the outcast.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
Verily, he has no power over those who believe and put their trust only in their Lord.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His power is only over those who obey and follow him (Shaytan), and those who join partners with Him (Allah).\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
And when We change a verse in place of another - and Allah knows best what He reveals - they (the disbelievers) say: ``You (O Muhammad) are but a forger." Rather, most of them know not.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say (O Muhammad); ``Ruh-ul-Qudus has brought it (the Qur'an) down from your Lord with truth." for the conviction of those who believe, and as a guide and good news for the Muslims.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
And indeed We know that they (polytheists and pagans) say: ``It is only a human being who teaches him." The tongue of the man they refer to is foreign, while this (the Qur'an) is (in) a clear Arabic tongue.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Verily, those who do not believe in Allah's Ayat (signs, or revelation), Allah will not guide them, and theirs will be a painful punishment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
It is only those who do not believe in Allah's Ayat who fabricate the falsehood, and it is they who are liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whoever disbelieves in Allah after his belief - except one who was forced while his heart is at peace with the faith - but whoever opens their breasts to disbelief, on them is wrath from Allah, and theirs will be a terrible torment.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they preferred the life of this world over that of the Hereafter. And Allah does not guide the people who disbelieve.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
They are those upon whose hearts, hearing (ears) and sight (eyes) Allah has set a seal over. And they are the heedless!\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
No doubt, in the Hereafter they will be the losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then, verily, your Lord for those who emigrated after they were put to trials and then performed Jihad, and were patient, - after this, your Lord is indeed Forgiving, Most Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
(Remember) the Day when every person will come pleading for himself, and every one will be paid in full for what he did, and they will not be dealt with unjustly.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
And Allah gives the example of a township (Makkah), it was secure and peaceful: its provision coming to it in abundance from every place, but it (its people) denied the favors of Allah. So Allah made it taste extreme hunger (famine) and fear, because of what they did.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
There has come to them a Messenger from among themselves, but they denied him, so the torment seized them while they were wrongdoers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
So eat of the lawful and good food which Allah has provided for you. And be grateful for Allah's favor, if it is He Whom you worship.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He has only forbidden dead flesh, blood, the flesh of swine, and any animal which is slaughtered as a sacrifice for other than Allah. But if one is forced by necessity, without willful disobedience, nor transgressing, then, Allah is Pardoning, Most Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not describe what your tongues have lied about, saying: ``This is lawful and this is forbidden," to invent lies against Allah. Verily, those who invent lies against Allah, will never succeed.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
A passing brief enjoyment (will be theirs), but they will suffer a painful torment.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
And for those who are Jews, We have forbidden such things as We have mentioned to you before. And We did not wrong them, but they wronged themselves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then, your Lord for those who did evil out of ignorance and afterward repent and do righteous deeds - verily, after that, your Lord is Pardoning, Most Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Verily, Ibrahim was (himself) an Ummah, obedient to Allah, a Hanif (monotheist), and he was not one of the idolators.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
(He was) thankful for His favors. He (Allah) chose him and guided him to a straight path.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him good in this world, and in the Hereafter he shall be of the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then, We have sent the revelation to you: ``Follow the religion of Ibrahim (he was a) Hanif, and he was not one of the idolators."\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The Sabbath was only prescribed for those who differed concerning it, and verily, your Lord will judge between them on the Day of Resurrection about what they differed over.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Invite to the way of your Lord with wisdom and fair preaching, and argue with them with that which is best. Truly, your Lord best knows who has strayed from His path, and He best knows those who are guided.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if you punish them, then punish them with the like of that with which you were afflicted. But if you have patience with them, then it is better for those who are patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And be patient, and your patience will not be, but by the help of Allah. And do not grieve over them, and do not be distressed by their plots.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Truly, Allah is with those who have Taqwa, and the doers of good.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Glorified be He Who took His servant for a Journey by Night from Al-Masjid Al-Haram to Al-Masjid Al-Aqsa, the neighborhood whereof We have blessed, in order that We might show him of Our Ayat. Verily, He is the All-Hearer, the All-Seer.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We gave Musa the Scripture and made it a guidance for the Children of Israel (saying): ``Take none other than Me as (your) Wakil."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
``O offspring of those whom We carried (in the ship) with Nuh! Verily, he was a grateful servant."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We decreed for the Children of Israel in the Scripture: ``Indeed you would do mischief in the land twice and you will become tyrants and extremely arrogant!"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So, when the promise came for the first of the two, We sent against you servants of Ours given to terrible warfare. They entered the very innermost parts of your homes. And it was a promise (completely) fulfilled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then We gave you a return of victory over them. And We helped you with wealth and children and made you more numerous in manpower.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
(And We said): ``If you do good, you do good for your own selves, and if you do evil (you do it) against yourselves." Then, when the second promise came to pass, (We permitted your enemies) to disgrace your faces and to enter the Masjid as they had entered it before, and to destroy with utter destruction all that fell in their hands.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
It may be that your Lord may show mercy unto you, but if you return (to sins), We shall return (to Our punishment). And We have made Hell a prison for the disbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Verily, this Qur'an guides to that which is most just and right and gives good news to those who believe, those who do righteous deeds, that they will have a great reward (Paradise).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And that those who do not believe in the Hereafter, for them We have prepared a painful torment (Hell).\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
And man invokes (Allah) for evil as he invokes (Allah) for good and man is ever hasty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
And We have appointed the night and the day as two Ayat (signs). Then, We have obliterated the sign of the night (with darkness) while We have made the sign of the day illuminating, that you may seek bounty from your Lord, and that you may know the number of the years and to count (periods of time). And We have explained everything (in detail) with full explanation.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And We have fastened every man's Ta'irah (deeds) to his neck, and on the Day of Resurrection, We shall bring out for him a Book which he will find wide open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
(It will be said to him): ``Read your Book. You yourself are sufficient as a reckoner against you this Day."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whoever goes right, then he goes right only for the benefit of himself. And whoever goes astray, then he goes astray at his own loss. No one laden with burdens can bear another's burden. And We never punish until We have sent a Messenger (to give warning).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We decide to destroy a town (population), Amarna those who live luxuriously. Then, they transgress therein, and thus the word (of torment) is justified against it (them). Then We destroy it with complete destruction.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
And how many generations have We destroyed after Nuh! And sufficient is your Lord as All-Knower and Seer of the sins of His servants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whoever desires the quick-passing (transitory enjoyment of this world), We readily grant him what We will for whom We like. Then, afterwards, We have appointed for him Hell; he will burn therein disgraced and rejected.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
And whoever desires the Hereafter and strives for it, with the necessary effort due for it while he is a believer, then such are the ones whose striving shall be appreciated, (rewarded by Allah).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
On each these as well as those We bestow from the bounties of your Lord. And the bounties of your Lord can never be forbidden.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
See how We prefer one above another (in this world), and verily, the Hereafter will be greater in degrees and greater in preferment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Set not up with Allah any other ilah (god), or you will sit down reproved, forsaken (in the Hellfire).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
And your Lord has Qada [decreed] that you worship none but Him. And that you be dutiful to your parents. If one of them or both of them attain old age in your life, say not to them a word of disrespect, nor reprimand them but address them in terms of honor.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower unto them the wing of submission and humility through mercy, and say: ``My Lord! Bestow on them Your mercy as they did bring me up when I was young."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord knows best what is in your souls. If you are righteous, then, verily, He is Ever Most Forgiving to those who turn to Him in repentance.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give to the kinsman his due, and to the Miskin (poor), and to the wayfarer. But spend not wastefully (your wealth) in the manner of a spendthrift.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Verily, the spendthrifts are brothers of the Shayatin (devils), and the Shaytan is ever ungrateful to his Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
And if you turn away from them and you are awaiting a mercy from your Lord for which you hope, then, speak unto them a soft, kind word.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And let not your hand be tied (like a miser) to your neck, nor overextend it (like a spendthrift), so that you become blameworthy and in severe poverty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Truly, your Lord expands the provision for whom He wills and straitens (for whom He wills). Verily, He is Ever All-Knower, All-Seer of His servants.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
And kill not your children for fear of poverty. We shall provide for them as well as for you. Surely, the killing of them is a great sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And come not near to unlawful sex. Verily, it is Fahishah (immoral sin) and an evil way.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And do not kill anyone whose killing Allah has forbidden, except for a just cause. And whoever is killed wrongfully (not by mistake), We have given his heir the authority. But let him not exceed limits in the matter of taking life. Verily, he is helped.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And come not near to the orphan's property except to improve it, until he attains the age of full strength. And fulfill (every) covenant. Verily, the covenant will be questioned about.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And give full measure when you measure, and weigh with a balance that is straight. That is good (advantageous) and better in the end.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And follow not that of which you have no knowledge. Verily, the hearing, and the sight, and the heart of each of those ones will be questioned (by Allah).\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And walk not on the earth with conceit and arrogance. Verily, you can neither rend nor penetrate the earth nor can you attain a stature like the mountains in height.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
All the bad aspects of these (the above mentioned things) are hateful to your Lord.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
This is (part) of Al-Hikmah (wisdom) which your Lord has revealed to you. And set not up with Allah any other god lest you should be thrown into Hell, blameworthy and rejected (from Allah's mercy).\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Has then your Lord preferred for you sons, and taken for Himself from among the angels daughters Verily, you indeed utter an awful saying.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
And surely, We have explained in this Qur'an that they may take heed, but it increases them in naught save aversion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say: ``If there had been other gods along with Him as they assert, then they would certainly have sought out a way to the Lord of the Throne.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Glorified and Exalted is He high above what they say!\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth and all that is therein, glorify Him and there is not a thing but glorifies His praise. But you understand not their glorification. Truly, He is Ever Forbearing, Oft-Forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
And when you recite the Qur'an, We put between you and those who believe not in the Hereafter, an invisible veil.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We have put Akinnah over their hearts, lest they should understand it, and in their ears deafness. And when you make mention of your Lord Alone in the Qur'an, they turn on their backs, fleeing in extreme dislike.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We know best of what they listen to, when they listen to you. And when they take secret counsel, then the wrongdoers say: ``You follow none but a bewitched man."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
See what examples they have put forward for you. So they have gone astray, and never can they find a way.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say: ``When we are bones and fragments (destroyed), should we really be resurrected (to be) a new creation"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say: ``Be you stones or iron,"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
``Or some created thing that is yet greater (or harder) in your breasts." Then, they will say: ``Who shall bring us back (to life)" Say: ``He Who created you first!" Then, they will shake their heads at you and say: ``When will that be" Say: ``Perhaps it is near!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
On the Day when He will call you, and you will answer with (words of) His praise and obedience, and you will think that you have stayed (in this world) but a little while!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
And say to My servants that they should say those words that are best. (Because) Shaytan verily, sows a state of conflict and disagreement among them. Surely, Shaytan is to man a plain enemy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Lord knows you best; if He wills, He will have mercy on you, or if He wills, He will punish you. And We have not sent you as a guardian over them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And your Lord knows best all who are in the heavens and the earth. And indeed, We have preferred some of the Prophets above others, and to Dawud We gave the Zabur.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say: ``Call upon those - besides Him whom you pretend. They have neither the power to remove the adversity from you nor even to shift (it from you to another person)."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those whom they call upon, desire a means of access to their Lord, as to which of them should be the nearest; and they hope for His mercy and fear His torment. Verily, the torment of your Lord is (something) to be afraid of!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
And there is not a town (population) but We shall destroy it before the Day of Resurrection, or punish it with a severe torment. That is written in the Book (of Our decrees)\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
And nothing stops Us from sending the Ayat but that the people of old denied them. And We sent the she-camel to Thamud as a clear sign, but they did her wrong. And We sent not the signs except to make them afraid (of destruction).\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And (remember) when We told you: ``Verily, your Lord has encompassed mankind." And We made not the vision which We showed you but a trial for mankind, and (likewise) the accursed tree in the Qur'an. We warn and make them afraid but it only increases them in naught save great disbelief, oppression and disobedience to Allah.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
And (remember) when We said to the angels: ``Prostrate yourselves unto Adam." They prostrated themselves except Iblis. He said: ``Shall I prostrate myself to one whom You created from clay"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
He said: ``See this one whom You have honored above me, if You give me respite to the Day of Resurrection, I will surely, seize and mislead his offspring, all but a few!"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
(Allah) said: ``Go, and whosoever of them follows you, surely, Hell will be the recompense of you (all) an ample recompense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
``And fool them gradually, those whom you can among them with your voice, Ajlib upon them with your cavalry and your infantry, share with them wealth and children, and make promises to them." But Shaytan promises them nothing but deceit.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
``Verily, My servants, you have no authority over them. And All-Sufficient is your Lord as a Guardian."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
Your Lord is He Who drives the ship for you through the sea, in order that you may seek of His bounty. Truly, He is ever Most Merciful towards you.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when harm touches you upon the sea, those that you call upon vanish from you except Him. But when He brings you safe to land, you turn away. And man is ever ungrateful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Do you then feel secure that He will not cause a side of the land to swallow you up, or that He will not send against you a Hasib Then, you shall find no guardian.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or do you feel secure that He will not send you back a second time to sea and send against you a Qasif and drown you because of your disbelief Then you will not find any avenger therein against Us.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
And indeed We have honored the Children of Adam, and We have carried them on land and sea, and have provided them with At-Tayyibat, and have preferred them above many of those whom We have created with a marked preferment.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
(And remember) the Day when We shall call together all human beings with their (respective) Imam (i.e. the Book of deeds). So whosoever is given his record in his right hand, such will read their records, and they will not be dealt with unjustly in the least.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
And whoever is blind in this [world] then he will be blind in the Hereafter, and most astray from the path.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
Verily, they were about to tempt you away from that which We have revealed to you, to fabricate something other than it against Us, and then they would certainly have taken you as an intimate friend!\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
And had We not made you stand firm, you would nearly have inclined to them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
In that case We would have made you taste a double portion in this life and a double portion after death. And then you would have found none to help you against Us.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
And verily, they were about to frighten you so much as to drive you out from the land. But in that case, they would not have stayed (therein) after you, except for a little while.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
A Sunnah with which We sent Our Messengers before you and you will not find any alteration in Our Sunnah.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Perform the Salah from midday till the darkness of the night, and recite the Qur'an in the early dawn. Verily, the recitation of the Qur'an in the early dawn is ever witnessed.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And in some parts of the night (also) offer the Salah with it as an additional prayer for you. It may be that your Lord will raise you to Maqam Mahmud.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say: ``My Lord! Let my entry be good, and (likewise) my exit be good. And grant me from You a helping authority,"\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say: ``Truth has come and falsehood has vanished. Surely, falsehood is ever bound to vanish."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We send down of the Qur'an that which is a cure and a mercy to the believers, and it increases the wrongdoers in nothing but loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We bestow Our grace on man, he turns away and becomes arrogant. And when evil touches him, he is in great despair.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say: ``Each one does according to Shakilatihi, and your Lord knows best of him whose path is right."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
And they ask you concerning the Ruh (the spirit). Say: ``The Ruh (the spirit) is one of the things, the knowledge of which is only with my Lord. And of knowledge, you (mankind) have been given only a little."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
And if We willed, We could surely take away that which We have revealed to you. Then you would find no protector for you against Us in that respect.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except as a mercy from your Lord. Verily, His grace unto you is ever great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say: ``If mankind and the Jinn were together to produce the like of this Qur'an, they could not produce the like thereof, even if they helped one another."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And indeed We have fully explained to mankind, in this Qur'an, every kind of similitude, but most of mankind refuse (the truth and accept nothing) but disbelief.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they say: ``We shall not believe in you, until you cause a spring to gush forth from the earth for us;"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
``Or you have a garden of date palms and grapes, and cause rivers to gush forth in their midst abundantly;"\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
``Or you cause the heaven to fall upon us in pieces, as you have pretended, or you bring Allah and the angels before (us) face to face;"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
``Or you have a house of Zukhruf, or you ascend up into the sky, and even then we will put no faith in your ascension until you bring down for us a Book that we would read." Say: ``Glorified be my Lord! Am I anything but a man, sent as a Messenger"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And nothing prevented men from believing when the guidance came to them, except that they said: ``Has Allah sent a man as (His) Messenger"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say: ``If there were on the earth, angels walking about in peace and security, We should certainly have sent down for them from the heaven an angel as a Messenger."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say: ``Sufficient is Allah for a witness between me and you. Verily, He is Ever the All-Knower, the All-Seer of His servants."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
And he whom Allah guides, he is led aright; and whomever He leaves astray can never find helpers other than Him, and We shall gather them together on the Day of Resurrection on their faces, blind, dumb and deaf; their abode will be Hell; whenever it abates, We shall increase for them the fierceness of the Fire.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That is their recompense, because they denied Our Ayat and said: ``When we are bones and fragments, shall we really be raised up as a new creation"\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
See they not that Allah, Who created the heavens and the earth, is able to create the like of them. And He has decreed for them an appointed term, whereof there is no doubt. But the wrongdoers refuse but disbelief.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say: ``If you possessed the treasure of the mercy of my Lord, then you would surely hold back for fear of spending, and man is ever miserly!"\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And indeed We gave Musa nine clear signs. Ask then the Children of Israel, when he came to them, then Fir`awn said to him: ``O Musa! I think you are indeed bewitched."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
He said: ``Verily, you know that these signs have been sent down by none but the Lord of the heavens and the earth. And I think you are indeed, O Fir`awn, doomed to destruction!"\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
So he resolved to turn them out of the land. But We drowned him and all who were with him.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said to the Children of Israel after him: ``Dwell in the land, then, when the final and the last promise comes near, We shall bring you altogether as mixed crowd."\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
And with truth We have sent it down, and with truth it has descended. And We have sent you as nothing but a bearer of glad tidings, and a warner.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
And a Qur'an which We have divided (into parts), in order that you might recite it to men at intervals. And We have revealed it by stages.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say: ``Believe in it or do not believe (in it). Verily, those who were given knowledge before it, when it is recited to them, fall down on their chins (faces) in humble prostration."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
And they say: ``Glory be to our Lord! Truly, the promise of our Lord must be fulfilled."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall down on their chins (faces) weeping and it increases their humility.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say: ``Invoke Allah or invoke Ar-Rahman (the Most Gracious), by whatever name you invoke Him (it is the same), for to Him belong the Best Names. And offer your Salah (prayer) neither aloud nor in a low voice, but follow a way between.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say: ``All the praises and thanks be to Allah, Who has not begotten a son, and Who has no partner in (His) dominion, nor is He low to have a supporter. And magnify Him with all magnificence."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen All praise is due to Allah, Who has sent down to His servant the Book, and has not placed therein any crookedness.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
(He has made it) straight to give warning of a severe punishment from Him, and to give good news to the believers, who do righteous deeds, that they shall have a fair reward.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
They shall abide therein forever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And to warn those who say, ``Allah has begotten a child."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
No knowledge have they of such a thing, nor had their fathers. Mighty is the word that comes out of their mouths. They utter nothing but a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Perhaps, you would kill yourself in grief, over their footsteps, because they believe not in this narration.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
Verily, we have made that which is on earth an adornment for it, in order that We may test which of them are best in deeds.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And verily, We shall make all that is on it bare, dry soil.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Do you think that the people of Al-Kahf and Ar-Raqim were a wonder among Our signs\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
When the young men fled for refuge to Al-Kahf. They said: ``Our Lord! Bestow on us mercy from Yourself, and facilitate for us our affair in the right way!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
Therefore, We covered up their hearing in Al-Kahf for a number of years.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Then We raised them up, that We might test which of the two parties was best at calculating the time period they tarried.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
We narrate unto you their story with truth: Truly, they were young men who believed in their Lord (Allah), and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We made their hearts firm and strong when they stood up and said: ``Our Lord is the Lord of the heavens and the earth, never shall we call upon any god other than Him; if we did, we should indeed have uttered an enormity in disbelief.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
These our people have taken for worship gods other than Him. Why do they not bring for them a clear authority And who does more wrong than he who invents a lie against Allah.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
(The young men said to one another:) ``And when you withdraw from them, and that which they worship, except Allah, then seek refuge in the cave; your Lord will open a way for you from His mercy and will make easy for you your affair."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And you might have seen the sun, when it rose, declining to the right from their cave, and when it set, turning away from them to the left, while they lay in the midst of the cave. That is from the Ayat of Allah. He whom Allah guides, he is the rightly-guided; but he whom He sends astray, for him you will find no guardian to lead him.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
And you would have thought them awake, whereas they were asleep. And We turned them on their right and on their left sides, and their dog stretching forth his two forelegs at the Wasid. Had you happened upon them, you would certainly have turned back from them in flight, and would certainly have been filled with awe of them.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
Likewise, We woke them that they might question one another. A speaker among them said: ``How long have you stayed (here)" They said: ``We have stayed a day or part of a day." They said: ``Your Lord knows best how long you have stayed (here). So send one of you with this silver coin of yours to the town, and let him find out which is the Azka food, and bring some of that to you. And let him be careful and let no man know of you."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
``For, if they come to know of you, they will stone you or turn you back to their religion; and in that case you will never be successful."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And thus We made their case known, that they might know that the promise of Allah is true, and that there can be no doubt about the Hour. (Remember) when they (the people) disputed among themselves about their case, they said: ``Construct a building over them; their Lord knows best about them," (then) those who won their point said: ``We verily, shall build a place of worship over them."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
They say they were three, the dog being the fourth among them; and they say they were five, the dog being the sixth, guessing at the unseen; and they say they were seven, and the dog being the eighth. Say: ``My Lord knows best their number; none knows them but a few." So debate not except with the clear proof. And consult not any of them (about the people of the Cave).\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say of anything, ``I shall do such and such thing tomorrow."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Except (with the saying), ``If Allah wills!" And remember your Lord when you forget and say: ``It may be that my Lord guides me to a nearer way of truth than this."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they stayed in their cave three hundred years, adding nine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say: ``Allah knows best how long they stayed. With Him is the unseen of the heavens and the earth." How clearly He sees, and hears (everything)! They have no protector other than Him, and He makes none to share in His decision and His rule.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite what has been revealed to you (O Muhammad) of your Lord's Book. None can change His Words, and none will you find as refuge other than Him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And keep yourself (O Muhammad) patiently with those who call on their Lord morning and afternoon, seeking His Face; and let not your eyes overlook them, desiring the pomp and glitter of the life of the world; and obey not him whose heart We have made heedless of Our remembrance, and who follows his own lusts, and whose affair has been lost.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And say: ``The truth is from your Lord." Then whosoever wills, let him believe; and whosoever wills, let him disbelieve. Verily, We have prepared for the wrongdoers, a Fire whose walls will be surrounding them. And if they ask for drink, they will be granted water like Al-Muhl, that will scald their faces. Terrible is the drink, and an evil Murtafaq!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Verily, as for those who believed and did righteous deeds, certainly We shall not make the reward of anyone to be lost who does his (righteous) deeds in the most perfect manner.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
These! For them will be Jannatu `Adn; wherein rivers flow beneath them; therein they will be adorned with bracelets of gold, and they will wear green garments of Sundus and Istabraq. They will be Muttaki'in therein on Ara'ik. How good is the reward, and what an excellent Murtafaq!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
And put forward to them the example of two men: unto one of them We had given two gardens of grapes, and We had surrounded both with date palms; and had put between them green crops (cultivated fields).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of those two gardens brought forth its produce, and failed not in the least therein, and We caused a river to gush forth in the midst of both.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And he had Thamar, and he said to his companion in the course of discussion: ``I am greater than you in wealth and have a mightier entourage."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he went into his garden while having been unjust to himself. He said: ``I do not think that this will ever perish."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
``And I do not think the Hour will ever come, and if indeed I am brought back to my Lord, I surely, shall find better than this when I return to Him."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His companion said to him during his discussion: ``Do you disbelieve in Him Who created you out of dust, then out of Nutfah, then fashioned you into a man"\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
``But as for my part, (I believe) that He is Allah, my Lord, and none shall I associate as partner with my Lord."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
``It was better for you to say, when you entered your garden: `That which Allah wills! There is no power but with Allah!' If you see me less than you in wealth, and children,"\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
``It may be that my Lord will give me something better than your garden, and will send on it Husban from the sky, then it will be as a barren slippery earth."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
``Or the water thereof becomes Ghawran so that you will never be able to seek it."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
So his fruits were encircled (with ruin). And began Yuqallibu his hands over what he had spent upon it, while it was all destroyed on its trellises, and he could only say: ``Would that I had ascribed no partners to my Lord!"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And he had no group of men to help him against Allah, nor could he defend (or save) himself.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
There (on the Day of Resurrection), Al-Walayah will be for Allah (Alone), the True God. He (Allah) is the best for reward and the best for the final end.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And mention the parable of the worldly life: it is like the water which We send down from the sky, and the vegetation of the earth mingles with it, and becomes fresh and green. But (later) it becomes dry and broken pieces, which the winds scatter. And Allah is able to do everything.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are the adornment of the life of this world. But the good righteous deeds that last, are better with your Lord for reward and better for hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And (remember) the Day We shall cause the mountains to pass away, and you will see the earth as a levelled plain, and We shall gather them so that We will leave not one of them behind.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And they will be set before your Lord, aligned. (He will say:) ``Now indeed, you have come to Us as We created you the first time. Nay, but you thought that We had appointed no meeting for you (with Us)."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the Book will be produced, and you will see the criminals, fearful of that which is therein. They will say: ``Woe to us! What sort of Book is this that leaves neither a small thing nor a large thing, but has recorded it with numbers!" And they will find all that they did, present, and your Lord treats no one with injustice.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And (remember) when We said to the angels: ``Prostrate yourselves unto Adam." So they prostrated themselves, except Iblis. He was one of the Jinn; he disobeyed the command of his Lord. Will you then take him and his offspring as protectors and helpers rather than Me while they are enemies to you What an evil is the exchange for the wrongdoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
They did not witness the creation of the heavens and the earth nor their own creation, nor did I take those who mislead as `Adudan.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And (remember) the Day He will say: ``Call those (so-called) partners of Mine whom you claimed." Then they will cry unto them, but they will not answer them, and We shall put Mawbiq between them.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the criminals shall see the Fire and apprehend that they are to fall therein. And they will find no way of escape from it.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And indeed We have given every kind of example in this Qur'an for mankind. But, man is ever more quarrelsome than anything.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And nothing prevents men from believing, while the guidance has come to them, and from asking forgiveness of their Lord, except that the ways of the ancients be repeated with them, or the torment be brought to them face to face.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
And We send not the Messengers except as bearers of good news and warners. But those who disbelieve, argue with falsehood, in order to refute the truth thereby. And they take My Ayat and that which they are warned for jest!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who does more wrong than he who is reminded of the Ayat (signs) of his Lord, but turns away from them, forgetting what his hands have sent forth. Truly, We have set over their hearts Akinnah, lest they should understand this (the Qur'an), and in their ears, deafness. And if you call them to guidance, even then they will never be guided.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
And your Lord is Most Forgiving, Owner of mercy. Were He to call them to account for what they have earned, then surely, He would have hastened their punishment. But they have their appointed time, beyond which they will find no escape.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And these towns, We destroyed them when they did wrong. And We appointed a fixed time for their destruction.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
And (remember) when Musa said to his boy-servant: ``I will not give up until I reach the junction of the two seas or a Huqub passes."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
But when they reached the junction of the two seas, they forgot their fish, and it took its way through the sea as in a tunnel.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
So when they passed further on, Musa said to his boy-servant: ``Bring us our morning meal; truly, we have suffered Nasaban in this, our journey."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said: ``Do you remember when we betook ourselves to the rock I indeed forgot the fish; none but Shaytan made me forget to remember it. It took its course into the sea in a strange (way)!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
[Musa] said: ``That is what we have been seeking." So they went back retracing their footsteps.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
Then they found one of Our servants, on whom We had bestowed mercy from Us, and whom We had taught knowledge from Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Musa said to him: ``May I follow you so that you teach me something of that knowledge which you have been taught (by Allah)"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He said: ``Verily, you will not be able to have patience with me!"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
``And how can you have patience about a thing which you know not"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
Musa said: ``If Allah wills, you will find me patient, and I will not disobey you in aught."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said: ``Then, if you follow me, ask me not about anything till I myself mention of it to you."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they both proceeded, till, when they boarded the boat, he (Khidr) damaged it. Musa said: ``Have you damaged it wherein its people will drown Verily, you have committed a thing Imr."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
He said: ``Did I not tell you, that you would not be able to have patience with me"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
He said: ``Call me not to account for what I forgot, and be not hard upon me for my affair (with you)."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
Then they both proceeded till they met a boy, and he (Khidr) killed him. Musa said: ``Have you killed an innocent person without Nafs Verily, you have committed a thing Nukr!"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
He said: ``Did I not tell you that you can have no patience with me"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
He said: ``If I ask you anything after this, keep me not in your company, you have received an excuse from me."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
Then they both proceeded till when they came to the people of a town, they asked them for food, but they refused to entertain them. Then they found therein a wall about to collapse and he set it up straight. (Musa) said: ``If you had wished, surely you could have taken wages for it!"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
He said: ``This is the parting between you and I, I will tell you the interpretation of (those) things over which you were not able to be patient."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
``As for the boat, it belonged to poor people working in the sea. So I wished to make a defective damage in it, as there was a king behind them who seized every boat by force."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
``And as for the boy, his parents were believers, and we feared he would oppress them by rebellion and disbelief."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
``So we intended that their Lord should exchange him for them for one better in righteousness and nearer to mercy."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
``And as for the wall, it belonged to two orphan boys in the town; and there was under it a treasure belonging to them; and their father was a righteous man, and your Lord intended that they should attain their age of full strength and take out their treasure as a mercy from your Lord. And I did them not of my own accord. That is the interpretation of those (things) over which you could not be patient.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
And they ask you about Dhul-Qarnayn. Say: ``I shall recite to you something of his story."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Verily, We established him in the earth, and We gave him the means of everything.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
So he followed a way.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Until, when he reached the setting place of the sun, he found it setting in a spring of Hami'ah. And he found near it a people. We said: ``O Dhul-Qarnayn! Either you punish them or treat them with kindness."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said: ``As for him who does wrong, we shall punish him, and then he will be brought back unto his Lord, Who will punish him with a terrible torment (Hell)."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
``But as for him who believes and works righteousness, he shall have the best reward, and we shall speak unto him mild words."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he followed (another) way,\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Until, when he came to the rising place of the sun, he found it rising on a people for whom We (Allah) had provided no shelter against the sun.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
So (it was)! And We knew all about him (Dhul-Qarnayn).\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he followed (another) way,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until, when he reached between two mountains, he found before them a people who scarcely understood a word.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said: ``O Dhul-Qarnayn! Verily, Ya'juj and Ma'juj are doing great mischief in the land. Shall we then pay you a tribute in order that you might erect a barrier between us and them"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said: ``That in which my Lord had established me is better. So help me with strength, I will erect between you and them a barrier."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
``Give me Zubar of iron;" then, when he had filled up the gap between the two mountain-cliffs, he said: ``Blow;" then when he had made them (red as) fire, he said: ``Bring me Qitran to pour over them."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
So they could not scale it or dig through it.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
He said: ``This is a mercy from my Lord, but when the promise of my Lord comes, He shall Dakka' it down to the ground. And the promise of my Lord is ever true.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And on that Day, We shall leave some of them to surge like waves on one another; and the Trumpet will be blown, and We shall collect them (the creatures) all together.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
And on that Day We shall present Hell to the disbelievers, plain to view.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
(To) those whose eyes had been under a covering from My Reminder, and they could not bear to hear (it).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Do then those who disbelieved think that they can take My servants as Awliya' [protectors] besides Me Verily, We have prepared Hell as an entertainment for the disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say: ``Shall We tell you the greatest losers in respect of (their) deeds"\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
``Those whose efforts have been wasted in this life while they thought that they were acquiring good by their deeds."\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
``They are those who deny the Ayat of their Lord and the meeting with Him. So their works are in vain, and on the Day of Resurrection, We shall assign no weight for them."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
``That shall be their recompense, Hell; because they disbelieved and took My Ayat and My Messengers for jest."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
``Verily, those who believe and do righteous deeds, shall have the Gardens of Al-Firdaws for their entertainment."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
``Wherein they shall dwell (forever). No desire will they have for removal therefrom."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say: ``If the sea were ink for the Words of my Lord, surely, the sea would be exhausted before the Words of my Lord would be finished, even if We brought like it for its aid."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say: ``I am only a man like you. It has been revealed to me that your God is One God. So whoever hopes for the meeting with his Lord, let him work righteousness and associate none as a partner in the worship of his Lord."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf Ha Ya `Ain Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
A reminder of the mercy of your Lord to His servant Zakariyya.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
When he called his Lord [with] a call in secret.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
He said: ``My Lord! Indeed my bones have grown feeble, and gray hair has Ashta`al on my head, and I have never been unblessed in my invocation to You, O my Lord!"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
``And verily, I fear Mawali after me, and my wife is barren. So give me from Yourself an heir."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
``Who shall inherit me, and inherit (also) the posterity of Ya`qub. And make him, my Lord, one with whom You are well-pleased!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
(Allah said:) ``O Zakariyya! Verily, We give you the good news of a son, whose name will be Yahya. We have given that name to none before (him)."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said: ``My Lord! How can I have a son, when my wife is barren, and I have reached the extreme old age."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
He said: ``Thus your Lord says: `It is easy for Me. Certainly I have created you before, when you had been nothing!"') [19:8-9]\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
He [Zakariyya] said: ``My Lord! Appoint for me a sign." He said: ``Your sign is that you shall not speak unto mankind for three nights, though having no bodily defect."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
Then he came out to his people from the Mihrab and he indicated to them by signs to glorify [Allah] in the morning and in the afternoon.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
(It was said to his son): ``O Yahya! Hold fast to the Scripture." And We gave him wisdom while yet a child.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And Hananan from Us, and Zakatan, and he was pious,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And dutiful to his parents, and he was not arrogant or disobedient.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
And Salam (peace) be on him the day he was born, and the day he dies, and the day he will be raised up to life (again)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention in the Book, Maryam, when she withdrew in seclusion from her family to place facing east.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
She placed a screen before them; then We sent to her Our Ruh, and he appeared before her in the form of a man in all respects.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said: ``Verily, I seek refuge with the Most Gracious (Allah) from you, if you do fear Allah."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
(The angel) said: ``I am only a messenger from your Lord, (to announce) to you the gift of a righteous son."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said: ``How can I have a son when no man has touched me, nor am I Baghiyya"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said: ``Thus says your Lord: `That is easy for Me (Allah). And (We wish) to appoint him as a sign to mankind and a mercy from Us (Allah), and it is a matter (already) decreed (by Allah)."'\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she conceived him, and she withdrew with him to a remote place.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And the pains of childbirth drove her to the trunk of a date palm. She said: ``Would that I had died before this, and had been forgotten and out of sight!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
Then he cried unto her from below her, saying: ``Grieve not: your Lord has provided a Sariy under you."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
``And shake the trunk of date palm towards you, it will let fall fresh ripe dates upon you."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
``So eat and drink and rejoice. And if you see any human being, say: `Verily, I have vowed a fast for the Most Gracious so I shall not speak to any human being today.,"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she brought him to her people, carrying him. They said: ``O Mary! Indeed you have brought a thing Fariy."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
``O sister of Harun! Your father was not a man who used to commit adultery, nor your mother was an unchaste woman."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
Then she pointed to him. They said: ``How can we talk to one who is a child in the cradle"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
He said: ``Verily, I am a servant of Allah, He has given me the Scripture and made me a Prophet;"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
``And He has made me blessed wherever I be, and has enjoined on me [Awsani] Salah and Zakah, as long as I live."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
``And to be dutiful to my mother, and made me not arrogant, unblessed."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
``And Salam (peace) be upon me the day I was born, and the day I die, and the day I shall be raised alive!"\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
Such is `Isa, son of Maryam. Qawlal-Haqq [it is a statement of truth] about which they doubt (or dispute).\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It befits not (the majesty of) Allah that He should beget a son. Glorified be He. When He decrees a thing, He only says to it: ``Be!" -- and it is.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
[`Isa said]: ``And verily, Allah is my Lord and your Lord. So worship Him. That is the straight path."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
Then the sects differed, so woe unto the disbelievers from the meeting of a great Day.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How clearly will they see and hear, the Day when they will appear before Us! But the wrongdoers today are in plain error.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn them of the Day of grief and regrets, when the case has been decided, while (now) they are in a state of carelessness, and they believe not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Verily, We will inherit the earth and whatsoever is thereon. And to Us they all shall be returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And mention in the Book, Ibrahim. Verily, he was a man of truth, a Prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
When he said to his father: ``O my father! Why do you worship that which hears not, sees not and cannot avail you in anything"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
``O my father! Verily, there has come to me the knowledge of that which came not unto you. So follow me, I will guide you to the straight path."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
``O my father! Worship not Shaytan. Verily, Shaytan has been a rebel against the Most Gracious."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
``O my father! Verily, I fear lest a torment from the Most Gracious should overtake you, so that you become a companion of Shaytan."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
He (the father) said: ``Do you revile my gods, O Ibrahim If you stop not (this), I will La'arjumannak. So get away from me Maliyan."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
Ibrahim said: ``Peace be on you! I will ask forgiveness of my Lord for you. Verily, He is unto me Hafiyyan.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
And I shall turn away from you and from those whom you invoke besides Allah. And I shall call upon my Lord, and I certainly hope that I shall not be unblessed in my invocation to my Lord."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So when he had turned away from them and from those whom they worshipped besides Allah, We gave him Ishaq and Ya`qub, and each one of them We made a Prophet.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We gave them of Our mercy, and We granted them Sidqin `Aliyyan on the tongues.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And mention in the Book, Musa. Verily, he was Mukhlasan and he was a Messenger, (and) a Prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
And We called him from the right side of the Mount (Tur), and made him draw near to Us for a talk with him.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We granted him his brother Harun, (also) a Prophet, out of Our mercy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention in the Book, Isma`il. Verily, he was true to what he promised, and he was a Messenger, (and) a Prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
And he would enjoin on his family and his people the Salah and the Zakah, and his Lord was pleased with him.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention in the Book, Idris. Verily, he was a man of truth, (and) a Prophet.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We raised him to a high station.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
Those were they unto whom Allah bestowed His grace from among the Prophets, of the offspring of Adam, and of those whom We carried (in the ship) with Nuh, and of the offspring of Ibrahim and Israel, and from among those whom We guided and chose. When the Ayat of the Most Gracious were recited unto them, they fell down prostrate and weeping.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
Then, there has succeeded them a posterity who have lost the Salah and have followed lusts. So they will meet Ghaiy.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Except those who repent and believe, and work righteousness. Such will enter Paradise and they will not be wronged in aught.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
(They will enter) `Adn Gardens which the Most Gracious has promised to His servants in the unseen. Verily, His promise must come to pass.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They shall not hear therein any Laghw, but only Salam. And they will have therein their sustenance, morning and afternoon.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
Such is the Paradise which We shall give as an inheritance to those of Our servants who had Taqwa.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
And we descend not except by the command of your Lord. To Him belongs what is before us and what is behind us, and what is between those two; and your Lord is never forgetful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth, and all that is between them, so worship Him and abide patiently in His worship. Do you know of any who is similar to Him\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And man says: ``When I am dead, shall I then be raised up alive"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Does not man remember that We created him before, while he was nothing\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
So by your Lord, surely We shall gather them together, and (also) the Shayatin, then We shall bring them round Hell, Jithyya.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then indeed We shall drag out from every sect all those who were worst in obstinate rebellion against the Most Gracious.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
Then, verily, We know best those who are most worthy of being burnt therein.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
There is not one of you but will pass over it (Hell); this is with your Lord, a decree which must be accomplished.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We shall save those who had Taqwa. And We shall leave the wrongdoers in it, Jithiyya.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
And when Our clear Ayat are recited to them, those who disbelieve say to those who believe: ``Which of the two groups has the best dwellings and the finest Nadiyyan"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
And how many a generation have We destroyed before them, who were better in wealth, goods and outward appearance\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say: whoever is in error, the Most Gracious will extend [circumstances] for him, until, when they see that which they were promised, either the torment or the Hour, they will come to know who is worst in position, and who is weaker in forces.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
And Allah increases in guidance those who walk aright. And the righteous good deeds that last are better with your Lord for reward and better for resort.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Have you seen him who disbelieved in Our Ayat and said: ``I shall certainly be given wealth and children [if I live again]."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he known the Unseen or has he taken a covenant from the Most Gracious\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
Nay, We shall record what he says, and We shall increase his torment;\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
And We shall inherit from him all that he speaks of, and he shall come to Us alone.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken gods besides Allah, that they might give them honor, power and glory.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
Nay, but they will deny their worship of them, and will become their adversaries.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
See you not that We have sent the Shayatin against the disbelievers to push them to do evil.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So make no haste against them; We only count out to them a (limited) number.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
The Day We shall gather those with Taqwa unto the Most Gracious (Allah), like a delegation.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And We shall drive the criminals to Hell, in a thirsty state.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
None shall have the power of intercession, but such a one as has received permission (or promise) from the Most Gracious (Allah).\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say: ``The Most Gracious (Allah) has begotten a son."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
Indeed you have brought forth (said) a thing Idda.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
Whereby the heavens are almost torn, and the earth is split asunder, and the mountains Hadda.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
That they ascribe a son to the Most Gracious.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
But it is not suitable for the Most Gracious that He should beget a son.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is none in the heavens and the earth but comes unto the Most Gracious as a slave.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
Verily, He knows each one of them, and has counted them a full counting.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And everyone of them will come to Him alone on the Day of Resurrection.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Verily, those who believe and work deeds of righteousness, the Most Gracious will bestow love for them.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
So, We have made this easy in your own tongue, only that you may give glad tidings to those who have Taqwa, and warn with it the people that are Ludda.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And how many a generation before them have We destroyed! Can you find a single one of them or hear even a whisper of them\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta Ha.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down the Qur'an unto you to cause you distress,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But only as a Reminder to those who fear (Allah).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A revelation from Him Who created the earth and high heavens.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Most Gracious Istawa the Throne.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs all that is in the heavens and all that is on the earth, and all that is between them, and all that is under the soil.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
And if you speak aloud, then verily, He knows the secret and that which is yet more hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah! There is no God but Him! To Him belong the Best Names.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
And has there come to you the story of Musa\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire, he said to his family: ``Wait! Verily, I have seen a fire; perhaps I can bring you some burning brand therefrom, or find some guidance at the fire."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
And when he came to it (the fire), he was called by name: ``O Musa!"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
``Verily, I am your Lord! So take off your shoes; you are in the sacred valley, Tuwa."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
``And I have chosen you. So listen to that which will be revealed (to you)"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
``Verily, I am Allah! There is no God but Me, so worship Me, and perform Salah for My remembrance."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
``Verily, the Hour is coming -- and I am almost hiding it -- that every person may be rewarded for that which he strives."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
``Therefore, let not the one who believes not therein, but follows his own lusts, divert you therefrom, lest you perish."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
``And what is that in your right hand, O Musa"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said: ``This is my stick, whereon I lean, and wherewith I beat down branches for my sheep, and wherein I find other uses."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
(Allah) said: ``Cast it down, O Musa!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
He cast it down, and behold! It was a snake, moving quickly.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
Allah said: ``Grasp it and fear not; We shall return it to its former state."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
``And press your (right) hand to your (left) side: it will come forth white (and shining), without any disease as another sign,"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
``That We may show you (some) of Our greater signs."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
``Go to Fir`awn! Verily, he has transgressed."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
He said: ``O my Lord! Open for me my chest."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
``And ease my task for me;"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
``And loosen the knot from my tongue,"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
``That they understand my speech."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
``And appoint for me a helper from my family,"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
``Harun, my brother."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
``Increase my strength with him,"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
``And let him share my task,"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
``That we may glorify You much,"\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
``And remember You much,"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
``Verily, You are ever seeing us."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
(Allah) said: ``You are granted your request, O Musa!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
``And indeed We conferred a favor on you another time (before)."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
``When We inspired your mother with that which We inspired."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
``Saying: `Put him (the child) into the Tabut and put it into the river; then the river shall cast it up on the bank, and there, an enemy of Mine and an enemy of his shall take him.' And I endued you with love from Me, in order that you may be brought up under My Eye."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
``When your sister went and said: `Shall I show you one who will nurse him' So We restored you to your mother, that she might cool her eyes and she should not grieve. Then you did kill a man, but We saved you from great distress and tried you with a heavy trial." Then you stayed a number of years with the people of Madyan. Then you came here according to the fixed term which I ordained (for you), O Musa!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
And I have chosen you for Myself.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
Go you and your brother with My Ayat, and do not, you both, slacken and become weak in My remembrance.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go both of you to Fir`awn, verily, he has transgressed.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
And speak to him mildly, perhaps he may accept admonition or fear (Allah).\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
Both of them said: ``Our Lord! Verily, we fear lest he should hasten to punish us or lest he should transgress."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
He (Allah) said: ``Fear not, verily, I am with you both, hearing and seeing."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
``So go you both to him, and say: 'Verily, we are both Messengers of your Lord, so let the Children of Israel go with us, and torment them not; indeed, we have come with a sign from your Lord! And peace will be upon him who follows the guidance!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
`Truly, it has been revealed to us that the torment will be for him who denies, and turns away.`"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
Fir`awn said: ``Who then, O Musa, is the Lord of you two"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
[Musa] said: ``Our Lord is He Who gave to each thing its form and nature, then guided it aright."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
[Fir`awn] said: ``What about the generations of old"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
[Musa] said: ``The knowledge thereof is with my Lord, in a Record. My Lord neither errs nor forgets."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
Who has made earth for you like a bed; and has opened ways for you therein, and has sent down water (rain) from the sky. And We have brought forth with it various kinds of vegetation.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat and pasture your cattle; verily, in this are Ayat for men of understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
Thereof We created you, and into it We shall return you, and from it We shall bring you out once again.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And indeed We showed him (Fir`awn) all Our Ayat, but he denied and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He (Fir`awn) said: ``Have you come to drive us out of our land with your magic, O Musa"\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
``Then verily, we can produce magic the like thereof; so appoint a meeting between us and you, which neither we nor you shall fail to keep, in an open place where both shall have a just and equal chance."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
(Musa) said: ``Your appointed meeting is the day of the festival, and let the people assemble when the sun has risen (forenoon)."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
So Fir`awn withdrew, devised his plot and then came back.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Musa said to them: ``Woe unto you! Invent not a lie against Allah, lest He should destroy you completely by a torment. And surely, he who invents a lie (against Allah) will fail miserably."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
Then they debated one with another what they must do, and they kept their talk secret.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said: ``Verily, these are two magicians. Their object is to drive you out from your land with magic, and to take you away from your exemplary way."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
``So devise your plot, and then assemble in line. And whoever overcomes this day will be indeed successful."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said: ``O Musa! Either you throw first or we be the first to throw"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
[Musa] said: ``Nay, throw you (first)!" Then behold! their ropes and their sticks, by their magic, appeared to him as though they moved fast.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
So Musa conceived fear in himself.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
We (Allah) said: ``Fear not! Surely, you will have the upper hand."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
``And throw that which is in your right hand! It will swallow up that which they have made. That which they have made is only a magician's trick, and the magician will never be successful, to whatever amount (of skill) he may attain."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
So the magicians fell down prostrate. They said: ``We believe in the Lord of Harun and Musa."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
(Fir`awn) said: ``Believe you in him before I give you permission Verily, he is your chief who has taught you magic. So I will surely cut off your hands and feet on opposite sides, and I will surely crucify you on the trunks of date palms, and you shall surely know which of us can give the severe and more lasting torment. ``\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said: ``We prefer you not over what have come to us of the clear signs and to Him (Allah) Who created us. So, decree whatever you desire to decree, for you can only' decree (regarding) this life of the world."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
``Verily, we have believed in our Lord, that He may forgive us our faults, and the magic to which you did compel us. And Allah is better as regards reward in comparison to your reward, and more lasting."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Verily, whoever comes to his Lord as a criminal, then surely, for him is Hell, wherein he will neither die nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But whoever comes to Him as a believer, and has done righteous good deeds, for such are the high ranks,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
`Adn Gardens, under which rivers flow, wherein they will abide forever, and such is the reward of those who purify themselves.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And indeed We revealed to Musa: ``Travel by night with My servants and strike a dry path for them in the sea, fearing neither to be overtaken nor being afraid."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
Then Fir`awn pursued them with his hosts, but the sea [Al-Yamm] completely overwhelmed them and covered them up.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
And Fir`awn led his people astray, and he did not guide them.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Children of Israel! We delivered you from your enemy, and We made a covenant with you on the right side of the Mount, and We sent down to you manna and quail,\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
(Saying) eat of the Tayyibat wherewith We have provided you, and commit no transgression or oppression therein, lest My anger should justly descend on you. And he on whom My anger descends, he is indeed perished.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
And verily, I am indeed forgiving to him who repents, believes and does righteous deeds, and then Ihtada.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
``And what made you hasten from your people, O Musa\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said: ``They are close on my footsteps, and I hastened to You, O my Lord, that You might be pleased."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
(Allah) said: ``Verily, We have tried your people in your absence, and As-Samiri has led them astray."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
Then Musa returned to his people in a state of anger and sorrow [Asif]. He said: ``O my people! Did not your Lord promise you a fair promise Did then the promise seem to you long in coming Or did you desire that wrath should descend from your Lord on you, that you broke your promise to me"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said: ``We broke not the promise to you, of our own will, but we were made to carry the weight of the ornaments of the people, then we cast them, and that was what As-Samiri suggested."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
Then he took out for them a calf which was mooing. They said: ``This is your god, and the god of Musa," but he had forgotten.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Did they not see that it could not return them a word (for answer), and that it had no power either to harm them or to do them good\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
And Harun indeed had said to them beforehand: ``O my people! You are being tried in this, and verily, your Lord is (Allah) the Most Gracious, so follow me and obey my order."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said: ``We will not stop worshipping it, until Musa returns to us."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
(Musa) said: ``O Harun! What prevented you when you saw them going astray;"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
``That you followed me not (according to my advice to you) Have you then disobeyed my order"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
He (Harun) said: ``O son of my mother! Seize (me) not by my beard, nor by my head! Verily, I feared lest you should say: `You have caused a division among the Children of Israel, and you have not respected my word!"'\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
(Musa) said: ``And what is the matter with you. O Samiri"\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
(Samiri) said: ``I saw what they saw not, so I took a (Qabdah) handful (of dust) from the (hoof) print of the messenger and threw it. Thus my inner self suggested to me."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
Musa said: ``Then go away! And verily, your (punishment) in this life will be that you will say: `Touch me not;' and verily, you have a promise that will not fail. And look at your god to which you have been devoted. We will certainly burn it, and scatter its particles in the sea."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your God is only Allah, there is no God but Him. He has full knowledge of all things.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus We relate to you some information of what happened before. And indeed We have given you from Us a Reminder.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whoever turns away from it, verily, they will bear a heavy burden on the Day of Resurrection.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
They will abide in that -- and evil indeed will it be that load for them on the Day of Resurrection.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The Day when the Sur will be blown: that Day, We shall gather the criminals blue-eyed.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
They will speak in a very low voice to each other (saying): ``You stayed not longer than ten."\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We know very well what they will say, when the best among them in knowledge and wisdom will say: ``You stayed no longer than a day!"\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
And they ask you concerning the mountains. Say: ``My Lord will blast them and scatter them as particles of dust."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
``Then He shall leave it as a level smooth plain."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
``You will see therein no crookedness nor curve."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
On that Day mankind will follow strictly (the voice of) Allah's caller, no crookedness (that is without going to the right or left of that voice) will they show him (Allah's caller). And all voices will be humbled for the Most Gracious (Allah), and nothing shall you hear except Hamsa.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
On that day no intercession shall avail, except the one for whom the Most Gracious has given permission and whose word is acceptable to Him.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
He knows what happens to them, and what will happen to them, but they will never encompass anything of His knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And (all) faces shall be humbled before the Ever Living, the Sustainer. And he who carried wrongdoing, will be indeed a complete failure.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
And he who works deeds of righteousness, while he is a believer, then he will have no fear of injustice, nor of any curtailment.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
And thus We have sent it down as a Qur'an in Arabic, and have explained therein in detail the warnings, in order that they may have Taqwa, or that it may cause them to have a lesson from it.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
Then High above all be Allah, the True King. And be not in haste with the Qur'an before its revelation is completed to you, and say: ``My Lord! Increase me in knowledge."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And indeed We made a covenant with Adam before, but he forgot, and We found on his part no firm willpower.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And (remember) when We said to the angels: ``Prostrate yourselves to Adam." They prostrated themselves (all) except Iblis; he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
Then We said: ``O Adam! Verily, this is an enemy to you and to your wife. So let him not get you both out of Paradise, so that you will be distressed."\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
``You will never be hungry therein nor naked."\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
``And you (will) suffer not from thirst therein nor from the sun's heat."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
Then Shaytan whispered to him, saying: ``O Adam! Shall I lead you to the Tree of Eternity and to a kingdom that will never waste away"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
Then they both ate of the Tree, and so their private parts became manifest to them, and they began to cover themselves with the leaves of the Paradise for their covering. Thus Adam disobeyd his Lord, so he went astray.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Then his Lord chose him, and turned to him with forgiveness, and gave him guidance.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
He (Allah) said: ``Get you down, both of you, together, some of you are an enemy to some others. Then if there comes to you guidance from Me, then whoever follows My guidance he shall neither go astray nor shall be distressed.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
But whosoever turns away from My Reminder, verily, for him is a life of hardship, and We shall raise him up blind on the Day of Resurrection."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say: ``O my Lord! Why have you raised me up blind, while I had sight (before)."\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
(Allah) will say: ``Like this Our Ayat came unto you, but you disregarded them, and so this Day, you will be neglected."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
And thus do We requite him who transgresses beyond bounds and believes not in the Ayat of his Lord; and the torment of the Hereafter is far more severe and more lasting.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Is it not a guidance for them (to know) how many generations We have destroyed before them, in whose dwellings they walk Verily, in this are signs indeed for men of understanding.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And had it not been for a Word that went forth before from your Lord, and a term determined, (their punishment) must necessarily have come (in this world).\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So bear patiently what they say, and glorify the praises of your Lord before the rising of the sun, and before its setting, and during some hours of the night, and at the ends of the day, that you may become pleased with the reward which Allah shall give you.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And strain not your eyes in longing for the things We have given for enjoyment to various groups of them, the splendor of the life of this world, that We may test them thereby. But the provision of your Lord is better and more lasting.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And enjoin Salah on your family, and be patient in offering them. We ask not of you a provision: We provide for you. And the good end is for those who have Taqwa.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
And they say, ``Why does he not bring us a sign from his Lord?" Has there not come to them evidence of what was in the former scriptures?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And if We had destroyed them with a torment before this, they would surely have said: ``Our Lord! If only You had sent us a Messenger we should certainly have followed Your Ayat, before we were humiliated and disgraced."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
(Say) ``Say, O Muhammad, to those who deny you, oppose you and continue in their disbelief and obstinance."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen Draws near for mankind their reckoning, while they turn away in heedlessness.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
Comes not unto them an admonition from their Lord as a recent revelation but they listen to it while they play.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
With their hearts occupied. Those who do wrong, conceal their private counsels, (saying): ``Is this more than a human being like you Will you submit to magic while you see it"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
He said: ``My Lord knows what is said in the heavens and on earth. And He is the All-Hearer, the All-Knower."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
Nay, they say: ``These are mixed up false dreams! Nay, he has invented it! -- Nay, he is a poet! Let him then bring us an Ayah like the ones that were sent before!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not one of the towns of those which We destroyed, believed before them; will they then believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We sent not before you but men to whom We revealed. So ask the people of the Reminder if you do not know.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
And We did not place them in bodies that did not eat food, nor were they immortals.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We fulfilled to them the promise. So We saved them and those whom We willed, but We destroyed Al-Musrifin.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
Indeed, We have sent down for you a Book in which there is Dhikrukum. Will you not then understand\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
How many a town given to wrongdoing, have We destroyed, and raised up after them another people!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
Then, when they sensed Our torment, behold, they (tried to) flee from it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
Flee not, but return to that wherein you lived a luxurious life, and to your homes, in order that you may be questioned.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They cried: ``Woe to us! Certainly we have been wrongdoers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And that cry of theirs ceased not, till We made them as a field that is reaped, extinct.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
We created not the heavens and the earth and all that is between them for play.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
Had We intended to take a pastime, We could surely have taken it from Us, if We were going to do (that).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Nay, We fling the truth against the falsehood, so it destroys it, and behold, it disappears. And woe to you for that which you ascribe.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs whosoever is in the heavens and on earth. And those who are near Him are not too proud to worship Him, nor are they weary.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They glorify His praises night and day, they never slacken.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have they taken (for worship) gods from the earth who raise the dead\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
Had there been therein (in the heavens and the earth) gods besides Allah, then verily, both would have been ruined. Glorified be Allah, the Lord of the Throne, (High is He) above all that (evil) they associate with Him!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He cannot be questioned as to what He does, while they will be questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they taken for worship gods besides Him Say: ``Bring your proof. This is the Reminder for those with me and the Reminder for those before me." But most of them know not the Truth, so they are averse.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We did not send any Messenger before you but We revealed to him (saying): ``There is no God but I, so worship Me."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say: ``The Most Gracious has begotten children." Glory to Him! They are but honored servants.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They speak not until He has spoken, and they act on His command.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is before them, and what is behind them, and they cannot intercede except for him with whom He is pleased. And they stand in awe for fear of Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And if any of them should say: ``Verily, I am a god besides Him," such We should recompense with Hell. Thus We recompense the wrongdoers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have not those who disbelieve known that the heavens and the earth were joined together as one united piece, then We parted them And We have made from water every living thing. Will they not then believe\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We have placed on the earth firm mountains, lest it should shake with them, and We placed therein broad highways for them to pass through, that they may be guided.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We have made the heaven a roof, safe and well-guarded. Yet they turn away from its signs.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
And He it is Who has created the night and the day, and the sun and the moon, each in an orbit floating.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
And We granted not to any human being immortality before you; then if you die, would they live forever\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Everyone is going to taste death, and We shall test you with evil and with good by way of trial. And to Us you will be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
And when those who disbelieved see you, they take you not except for mockery (saying): ``Is this the one who talks about your gods" While they disbelieve at the mention of the Most Gracious.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man is created of haste. I will show you My Ayat. So ask Me not to hasten (them).\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say: ``When will this promise (come to pass), if you are truthful."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If only those who disbelieved knew (the time) when they will not be able to ward off the Fire from their faces, nor from their backs, and they will not be helped.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Nay, it will come upon them all of a sudden and will perplex them, and they will have no power to avert it nor will they get respite.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
Indeed (many) Messengers were mocked before you, but the scoffers were surrounded by what they used to mock.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say: ``Who can guard and protect you in the night or in the day from the Most Gracious" Nay, but they turn away from the remembrance of their Lord.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or have they gods who can guard them from Us They have no power to help themselves, nor can they be protected from Us.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
Nay, We gave the luxuries of this life to these men and their fathers until the period grew long for them. See they not that We gradually reduce the land from its outlying borders Is it then they who will overcome\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say: ``I warn you only by the revelation. ``But the deaf will not hear the call, (even) when they are warned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And if a breath of the torment of your Lord touches them, they will surely cry: ``Woe unto us! Indeed we have been wrongdoers."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We shall set up Balances of justice on the Day of Resurrection, then none will be dealt with unjustly in anything. And if there be the weight of a mustard seed, We will bring it. And sufficient are We to take account.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
And indeed We granted to Musa and Harun the criterion, and a shining light and a Reminder for those who have Taqwa.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Those who fear their Lord in the unseen, and they are afraid of the Hour.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
And this is a blessed Reminder which We have sent down; will you then deny it\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
And indeed We bestowed aforetime on Ibrahim his guidance, and We were Well-Acquainted with him.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
When he said to his father and his people: ``What are these images to which you are devoted"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said: ``We found our fathers worshipping them."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said: ``Indeed you and your fathers have been in manifest error."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said: ``Have you brought us the Truth, or are you one of those who play about"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said: ``Nay, your Lord is the Lord of the heavens and the earth, Who created them and to that I am one of the witnesses."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
``And by Allah, I shall plot a plan for your idols after you have gone away and turned your backs."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
So he broke them to pieces, except the biggest of them, that they might turn to it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said: ``Who has done this to our gods He must indeed be one of the wrongdoers."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said: ``We heard a young man talking against them, who is called Ibrahim."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said: ``Then bring him before the eyes of the people, that they may testify."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said: ``Are you the one who has done this to our gods, O Ibrahim"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said: ``Nay, this one, the biggest of them did it. Ask them, if they can speak!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they turned to themselves and said: ``Verily, you are the wrongdoers."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Then they turned to themselves: ``Indeed you know well that these speak not!"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said: ``Do you then worship besides Allah, things that can neither profit you nor harm you"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
``Fie upon you, and upon that which you worship besides Allah! Have you then no sense"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said: ``Burn him and help your gods, if you will be doing."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
We said: ``O fire! Be you cool and safety for Ibrahim!"\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
And they wanted to harm him, but We made them the worst losers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We rescued him and Lut to the land which We have blessed for the nations.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We bestowed upon him Ishaq, and Ya`qub Nafilatan. Each one We made righteous.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders, guiding by Our command, and We revealed to them the doing of good deeds, performing Salah, and the giving of Zakah, and of Us (Alone) they were the worshippers.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And (remember) Lut, We gave him wisdom and knowledge, and We saved him from the town who practised Al-Khaba'ith. Verily, they were a people given to evil, and were rebellious.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him to Our mercy; truly, he was of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And (remember) Nuh, when he cried (to Us) aforetime. We answered to his invocation and saved him and his family from the great distress.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
We helped him against the people who denied Our Ayat. Verily, they were a people given to evil. So We drowned them all.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And (remember) Dawud and Sulayman, when they gave judgement in the case of the field in which the sheep of certain people had Nafashat; and We were witness to their judgement.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
And We made Sulayman to understand (the case); and to each of them We gave wisdom (Hukm) and knowledge. And We subjected the mountains and the birds to glorify Our praises along with Dawud. And it was We Who were the doer (of all these things).\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the making of metal coats of mail (for battles), to protect you in your fighting. Are you then grateful\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And to Sulayman (We subjected) the wind strongly raging, running by his command towards the land which We had blessed. And of everything We are the All-Knower.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the Shayatin were some who dived for him, and did other work besides that; and it was We Who guarded them.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And (remember) Ayyub, when he cried to his Lord: ``Verily, distress has seized me, and You are the Most Merciful of all those who show mercy."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We answered his call, and We removed the distress that was on him, and We restored his family to him, and the like thereof along with them as a mercy from Ourselves and a Reminder for all those who worship Us.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And (remember) Isma`il, Idris and Dhul-Kifl: All were from among the patient.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We admitted them to Our mercy. Verily, they were of the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And (remember) Dhun-Nun, when he went off in anger, and imagined that We shall not punish him! But he cried through the darknesses (Zulumat) (saying): ``There is no God but You, Glorified be You! Truly, I have been of the Zalimin wrongdoers."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We answered his call, and delivered him from the distress. And thus We do deliver the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And (remember) Zakariyya, when he cried to his Lord: ``O My Lord! Leave me not single (childless), though You are the Best of the inheritors."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We answered his call, and We bestowed upon him Yahya, and cured his wife for him. Verily, they used to hasten on to do good deeds, and they used to call on Us with hope and fear, and they were Khashi`in before Us.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And she who guarded her chastity, We breathed into her through Our Ruh, and We made her and her son a sign for nations.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Truly, this, your Ummah is one, and I am your Lord, therefore worship Me.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
But they have broken up and differed in their religion among themselves. (And) they all shall return to Us.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
So whoever does righteous good deeds while he is a believer, his efforts will not be rejected. Verily, We record it for him (in his Book of deeds).\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
And a ban is laid on every town which We have destroyed that they shall not return.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until, when Ya'juj and Ma'juj (Gog and Magog people) are let loose, and they swoop down from every Hadab.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
And the true promise shall draw near. Then, you shall see the eyes of the disbelievers fixedly staring in horror. (They will say:) ``Woe to us! We were indeed heedless of this -- nay, but we were wrongdoers."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
Certainly you and that which you are worshipping now besides Allah, are (but) fuel (Hasab) for Hell! (Surely) you will enter it.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
Had these been gods, they would not have entered there (Hell), and all of them will abide therein forever.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
Therein they will be breathing out with deep sighs and roaring and therein they will hear not.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Verily, those for whom the good has preceded from Us, they will be removed far therefrom (Hell).\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They shall not hear the slightest sound of it (Hell), while they abide in that which their own selves desire.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
The greatest terror will not grieve them, and the angels will meet them, (with the greeting:) ``This is your Day which you were promised."\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
And (remember) the Day when We shall roll up the heaven like a Sijill for books. As We began the first creation, We shall repeat it. (It is) a promise binding upon Us. Truly, We shall do it.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
And indeed We have written in Az-Zabur after Adh-Dhikr that My righteous servants shall inherit the land.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Verily, in this there is a plain Message for people who worship Allah.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
And We have sent you (O Muhammad) not but as a mercy for the `Alamin.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say: ``It is revealed to me that your God is only one God. Will you then be Muslims"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
But if they turn away say: ``I give you a notice to be known to us all alike. And I know not whether that which you are promised is near or far."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
``Verily, He knows that which is spoken aloud and He knows that which you conceal."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
``And I know not, perhaps it may be a trial for you, and an enjoyment for a while."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
He said:"My Lord! Judge You in truth! Our Lord is the Most Gracious, Whose help is to be sought against that which you attribute!"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O mankind! Have Taqwa of your Lord! Verily, the earthquake of the Hour is a terrible thing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
The Day you shall see it, every nursing mother will forget her nursling, and every pregnant one will drop her load, and you shall see mankind as in a drunken state, yet they will not be drunk, but Allah's torment is severe.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And among mankind is he who disputes about Allah, without knowledge, and follows every rebellious Shaytan.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
For him (the devil) it is decreed that whosoever follows him, he will mislead him, and will drive him to the torment of the Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O mankind! If you are in doubt about the Resurrection, then verily, We have created you from dust, then from a Nutfah, then from a clot then from a little lump of flesh -- some formed and some unformed -- that We may make (it) clear to you. And We cause whom We will to remain in the wombs for an appointed term, then We bring you out as infants, then (give you growth) that you may reach your age of full strength. And among you there is he who dies (young), and among you there is he who is brought back to the miserable old age, so that he knows nothing after having known. And you see the earth Hamidatan, but when We send down water on it, it is stirred (to life), and it swells and puts forth every lovely kind (of growth).\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because Allah: He is the Truth, and it is He Who gives life to the dead, and it is He Who is able to do all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And surely, the Hour is coming, there is no doubt about it; and certainly, Allah will resurrect those who are in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And among men is he who disputes about Allah, without knowledge or guidance, or a Book giving light (from Allah).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
Bending his neck in pride, and leading (others) too (far) astray from the path of Allah. For him there is disgrace in this worldly life, and on the Day of Resurrection We shall make him taste the torment of burning.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
That is because of what your hands have sent forth, and verily, Allah is not unjust to servants.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And among mankind is he who worships Allah as it were upon the edge: if good befalls him, he is content therewith; but if a Fitnah strikes him, he turns back on his face. He loses both this world and the Hereafter. That is the evident loss.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He calls besides Allah unto that which can neither harm him nor profit him. That is a straying far away.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He calls unto him whose harm is nearer than his profit; certainly an evil Mawla and certainly an evil `Ashir!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Truly, Allah will admit those who believe and do righteous good deeds to Gardens underneath which rivers flow. Verily, Allah does what He wills.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whoever thinks that Allah will not help him in this world and in the Hereafter, let him stretch out a rope to the ceiling and let him strangle himself. Then let him see whether his plan will remove that whereat he rages!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
Thus have We sent it down as clear Ayat, and surely, Allah guides whom He wills.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Verily, those who believe, and those who are Jews, and the Sabians, and the Christians, and the Majus, and those who worship others besides Allah; truly, Allah will judge between them on the Day of Resurrection. Verily, Allah is over all things a Witness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
See you not that whoever is in the heavens and whoever is on the earth, and the sun, and the moon, and the stars, and the mountains, and the trees, and Ad-Dawabb, and many of mankind prostrate themselves to Allah. But there are many (men) on whom the punishment is justified. And whomsoever Allah disgraces, none can honor him. Verily, Allah does what He wills.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These two opponents dispute with each other about their Lord; then as for those who disbelieved, garments of fire will be cut out for them, boiling water will be poured down over their heads.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
With it will melt (or vanish away) what is within their bellies, as well as (their) skins.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And for them are hooked rods of iron.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Every time they seek to get away therefrom, from anguish, they will be driven back therein, and (it will be) said to them: ``Taste the torment of burning!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Truly, Allah will admit those who believe and do righteous good deeds, to Gardens underneath which rivers flow (in Paradise), wherein they will be adorned with bracelets of gold and pearls and their garments therein will be of silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
And they are guided unto goodly speech and they are guided to the path of Him, Who is Worthy of all praises.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Verily, those who disbelieved and hinder (men) from the path of Allah, and from Al-Masjid Al-Haram which We have made (open) to (all) men, the dweller in it and the visitor from the country are equal there, and whoever inclines to evil actions therein or to do wrong, him We shall cause to taste from a painful torment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And (remember) when We showed Ibrahim the site of the House (saying): ``Associate not anything with Me, and sanctify My House for those who circumambulate it, and those who stand up (for prayer), and those who bow and make prostration (in prayer);"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
And proclaim to mankind the Hajj (pilgrimage). They will come to you on foot and on every lean camel, they will come from every Fajj `Amiq.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
That they may witness things that are of benefit to them, and mention the Name of Allah on appointed days, over the beast of cattle that He has provided for them. Then eat thereof and feed therewith the poor having a hard time.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Then let them complete their prescribed duties and perform their vows, and circumambulate the `Atiq House.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
That and whoever honors the sacred things of Allah, then that is better for him with his Lord. The cattle are lawful to you, except those (that will be) mentioned to you. So shun the Rijs of the idols, and shun false speech.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Hunafa' Lillah, not associating partners unto Him; and whoever assigns partners to Allah, it is as if he had fallen from the sky, the birds caught him in midair, or the wind had thrown him to a far off place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
Thus it is, and whosoever honors the Sha`a'ir of Allah, then it is truly from the Taqwa of the hearts.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
In them are benefits for you for an appointed term, and afterwards they are brought for sacrifice to the `Atiq House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
And for every nation We have appointed religious ceremonies, that they may mention the Name of Allah over the beast of cattle that He has given them for food. And your God is One God, so you must submit to Him Alone. And give glad tidings to the Mukhbitin.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Whose hearts are filled with fear when Allah is mentioned, and the patient who bear whatever may befall them, and who perform the Salah, and who spend out of what We have provided for them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the Budn, We have made them for you as among the symbols of Allah, wherein you have much good. So mention the Name of Allah over them when they are drawn up in lines (for sacrifice). Then, when they are down on their sides (after slaughter), eat thereof, and feed the Qani` and the Mu`tarr. Thus have We made them subject to you that you may be grateful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
It is neither their meat nor their blood that reaches Allah, but it is Taqwa from you that reaches Him. Thus have We made them subject to you that you may proclaim Allah's greatness for His guidance to you. And give glad tidings to the doers of good.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Truly, Allah defends those who believe. Verily, Allah likes not any treacherous ingrate.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission (to fight) is given to those (believers) who are fought against, because they have been wronged; and surely, Allah is able to give them victory.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
Those who have been expelled from their homes unjustly only because they said: ``Our Lord is Allah." For had it not been that Allah checks one set of people by means of another, Sawami`, Biya`, Salawat, and Masjids, wherein the Name of Allah is mentioned much, would surely have been pulled down. Verily, Allah will help those who help His (cause). Truly, Allah is All-Strong, All-Mighty.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
Those who, if We give them power in the land, establish the Salah, enforce the Zakah, and they enjoin the good and forbid the evil. And with Allah rests the end of (all) matters.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
And if they deny you, so did deny before them the people of Nuh, `Ad and Thamud.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And the people of Ibrahim and the people of Lut,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the dwellers of Madyan; and denied was Musa. But I granted respite to the disbelievers for a while, then I seized them, and how (terrible) was My punishment!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
And many a township did We destroy while they were given to wrongdoing, so that it lie in ruins, and a deserted well and castle Mashid!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
Have they not traveled through the land, and have they hearts wherewith to understand and ears wherewith to hear Verily, it is not the eyes that grow blind, but it is the hearts which are in the breasts that grow blind.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they ask you to hasten on the torment! And Allah fails not His promise. And verily a day with your Lord is as a thousand years of what you reckon.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And many a township did I give respite while it was given to wrongdoing. Then I seized it (with punishment). And to Me is the (final) return (of all).\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say: ``O mankind! I am (sent) to you only as a plain warner."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
So those who believe and do righteous good deeds, for them is forgiveness and Rizq Karim.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
But those who strive against Our Ayat to frustrate them, they will be dwellers of the Hellfire.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
Never did We send a Messenger or a Prophet before you but when he did recite (the revelation or narrated or spoke), Shaytan threw (some falsehood) in his recitation (of the revelation). But Yansakh Allah that which Shaytan throws in. Then Allah establishes His revelations. And Allah is All-Knower, All-Wise:\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
That He (Allah) may make what is thrown in by Shaytan a trial for those in whose hearts is a disease and whose hearts are hardened. And certainly, the wrongdoers are in an opposition far-off (from the truth).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And that those who have been given knowledge may know that it (this Qur'an) is the truth from your Lord, so that they may believe therein, and their hearts may submit to it with humility. And verily, Allah is the Guide of those who believe, to the straight path.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
And those who disbelieved, will not cease to be in doubt about it until the Hour comes suddenly upon them, or there comes to them the torment of Yawm `Aqim.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
The sovereignty on that Day will be that of Allah. He will judge between them. So those who believed and did righteous good deeds will be in Gardens of Delight.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
And those who disbelieved and denied Our Ayat, for them will be a humiliating torment (in Hell).\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
Those who emigrated in the cause of Allah and after that were killed or died, surely, Allah will provide a good provision for them. And verily, it is Allah Who indeed is the Best of those who make provision.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
Truly, He will make them enter an entrance with which they shall be well-pleased, and verily, Allah indeed is All-Knowing, Most Forbearing.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That is so. And whoever has retaliated with the like of that which he was made to suffer, and then has again been wronged, Allah will surely help him. Verily, Allah indeed is Oft-Pardoning, Oft-Forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because Allah merges the night into the day, and He merges the day into the night. And verily, Allah is All-Hearer, All-Seer.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah -- He is the Truth, and what they invoke besides Him, it is false. And verily, Allah -- He is the Most High, the Most Great.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
See you not that Allah sends down water from the sky, and then the earth becomes green Verily, Allah is the Most Kind and Courteous, Well-Acquainted with all things.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs all that is in the heavens and all that is on the earth. And verily, Allah -- He is Rich, Worthy of all praise.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
See you not that Allah has subjected to you all that is on the earth, and the ships that sail through the sea by His command He withholds the heaven from falling on the earth except by His leave. Verily, Allah is for mankind, full of kindness, Most Merciful.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
It is He, Who gave you life, and then will cause you to die, and will again give you life. Verily, man is indeed Kafurun.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For every nation We have made Mansak which they must follow; so let them not dispute with you on the matter, but invite them to your Lord. Verily, you indeed are on the straight guidance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they argue with you, say: ``Allah knows best of what you do."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
``Allah will judge between you on the Day of Resurrection about that wherein you used to differ."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Know you not that Allah knows all that is in the heaven and on the earth Verily, it is (all) in the Book. Verily, that is easy for Allah.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
And they worship besides Allah others for which He has sent down no authority, and of which they have no knowledge; and for the wrongdoers there is no helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our clear Ayat are recited to them, you will notice a denial on the faces of the disbelievers! They are nearly ready to attack with violence those who recite Our Ayat to them. Say: ``Shall I tell you of something worse than that The Fire which Allah has promised to those who disbelieved, and worst indeed is that destination!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O mankind! A parable has been made, so listen to it: Verily, those on whom you call besides Allah, cannot create a fly, even though they combine together for the purpose. And if the fly snatches away a thing from them, they will have no power to release it from the fly. So weak are the seeker and the sought.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They have not regarded Allah with His rightful esteem. Verily, Allah is All-Strong, All-Mighty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses Messengers from angels and from men. Verily, Allah is All-Hearer, All-Seer.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows what is before them, and what is behind them. And to Allah return all matters.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O you who believe! Bow down, and prostrate yourselves, and worship your Lord and do good that you may be successful.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive hard in Allah's cause as you ought to strive. He has chosen you, and has not laid upon you in religion any hardship: it is the religion of your father Ibrahim. He has named you Muslims both before and in this (Qur'an), that the Messenger may be a witness over you and you be witnesses over mankind! So, perform the Salah, give the Zakah and hold fast to Allah. He is your Mawla, what an Excellent Mawla and what an Excellent Helper!\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Successful indeed are the believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
Those who with their Salah are Khashi`un.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
And those who turn away from Al-Laghw.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
And those who pay the Zakah.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
And those who guard their private parts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Except from their wives or their right hand possessions, for then, they are free from blame.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
But whoever seeks beyond that, then those are the transgressors.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
Those who are faithfully true to their Amanat and to their covenants are Ra`un.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And those who strictly guard their Salawat.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
These are indeed the heirs.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who shall inherit Firdaws. They shall dwell therein forever.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
And indeed We created man out of an extract of Tin.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Thereafter We made him a Nutfah in a safe lodging.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then We made the Nutfah into a clot, then We made the clot into a little lump of flesh, then We made out of that little lump of flesh bones, then We clothed the bones with flesh, and then We brought it forth as another creation. So Blessed is Allah, the Best of creators.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
After that, surely you will die.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then (again), surely you will be resurrected on the Day of Resurrection.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And indeed We have created above you seven Tara'iq, and We are never unaware of the creation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We sent down from the sky water in measure, and We gave it lodging in the earth, and verily, We are able to take it away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
Then We brought forth for you therewith gardens of date palms and grapes, wherein is much fruit for you, and whereof you eat.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And a tree that springs forth from Tur Sinai, that grows oil, and relish for the eaters.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And verily, in the cattle there is indeed a lesson for you. We give you to drink of that which is in their bellies. And there are, in them, numerous benefits for you, and of them you eat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And on them, and on ships you are carried.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And indeed We sent Nuh to his people, and he said: ``O my people! Worship Allah! You have no other God but Him. Will you not then have Taqwa"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
But the chiefs of his people who disbelieved said: ``He is no more than a human being like you, he seeks to make himself superior to you. Had Allah willed, He surely could have sent down angels. Never did we hear such a thing among our fathers of old."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
``He is only a man in whom is madness, so wait for him a while."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
He said: ``O my Lord! Help me because they deny me."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
So, We revealed to him: ``Construct the ship under Our Eyes and under Our revelation. Then, when Our command comes, and (water) gushes forth from the oven, take on board of each kind two, and your family, except those thereof against whom the Word has already gone forth. And address Me not in favor of those who have done wrong. Verily, they are to be drowned."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
``And when you have embarked on the ship, you and whoever is with you, then say: `All the praise be to Allah, Who has saved us from the people who are wrongdoers."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
``And say: `My Lord! Cause me to land at a blessed landing place, for You are the Best of those who bring to land."'\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Verily, in this, there are indeed Ayat, for sure We are ever putting (men) to the test.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then, after them, We created another generation.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
And We sent to them a Messenger from among themselves (saying): ``Worship Allah! You have no other God but Him. Will you not then have Taqwa"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And the chiefs of his people who disbelieved and denied the meeting in the Hereafter, and whom We had given the luxuries and comforts of worldly life, said: ``He is no more than a human being like you, he eats of that which you eat, and drinks of what you drink."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
``If you were to obey a human being like yourselves, then verily, you indeed would be losers."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
``Does he promise you that when you have died and have become dust and bones, you shall come out alive"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
``Far, very far is that which you are promised!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
``There is nothing but our life of this world! We die and we live! And we are not going to be resurrected!"\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
``He is only a man who has invented a lie against Allah, and we are not going to believe in him."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said: ``O my Lord! Help me because they deny me."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
(Allah) said: ``In a little while, they are sure to be regretful."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
So, the Sayhah overtook them in truth, and We made them as rubbish of dead plants. So, away with the people who are wrongdoers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then, after them, We created other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation can advance their term, nor can they delay it.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent Our Messengers in succession. Every time there came to a nation their Messenger, they denied him; so, We made them follow one another, and We made them as Ahadith. So, away with a people who believe not!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Musa and his brother Harun, with Our Ayat and manifest authority,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
To Fir`awn and his chiefs, but they behaved insolently and they were people self-exalting (by disobeying their Lord).\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They said: ``Shall we believe in two men like ourselves, and their people are obedient to us with humility!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So, they denied them both and became of those who were destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And indeed We gave Musa the Scripture, that they may be guided.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Maryam and his mother as a sign, and We gave them refuge on a Rabwah, Dhat Qarar, and Ma`in.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
O Messengers! Eat of the Tayyibat and do righteous deeds. Verily, I am Well-Acquainted with what you do.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
And verily, this your religion is one religion, and I am your Lord, so have Taqwa."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But they have broken their religion among them into sects, each group rejoicing in what is with it.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So, leave them in their error for a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they think that in wealth and children with which We prolong them\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
We hasten unto them with good things. Nay, but they perceive not.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Verily, those who live in awe for fear of their Lord;\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And those who believe in the Ayat of their Lord;\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And those who join not anyone as partners with their Lord;\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And those who give that which they give with their hearts full of fear, because they are sure to return to their Lord.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
It is these who hasten in the good deeds, and they are foremost in them.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
And We task not any person except according to his capacity, and with Us is a Record which speaks the truth, and they will not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
Nay, but their hearts are covered from this, and they have other deeds, besides which they are doing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Until when We seize those of them who lead a luxurious life with punishment; behold, they make humble invocation with a loud voice.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
Invoke not loudly this day! Certainly you shall not be helped by Us.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
Indeed My Ayat used to be recited to you, but you used to turn back on your heels.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
In pride, talking evil about it by night.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Have they not pondered over the Word, or has there come to them what had not come to their fathers of old\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or is it that they did not recognize their Messenger so they deny him\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or they say: There is madness in him Nay, but he brought them the truth, but most of them are averse to the truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
And if Al-Haqq had followed their desires, verily, the heavens and the earth, and whosoever is therein would have been corrupted! Nay, We have brought them their reminder, but they turn away from their reminder.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or is it that you ask them for some Kharj But the recompense of your Lord is better, and He is the Best of those who give sustenance.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
And certainly, you call them to the straight path.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
And verily, those who believe not in the Hereafter are indeed deviating far astray from the path.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
And though We had mercy on them and removed the distress which is on them, still they would obstinately persist in their transgression, wandering blindly.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
And indeed We seized them with punishment, but they humbled not themselves to their Lord, nor did they invoke with submission to Him.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until, when We open for them the gate of severe punishment, then lo! they will be plunged in despair.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
It is He Who has created for you hearing, eyes, and hearts. Little thanks you give.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And it is He Who has created you on the earth, and to Him you shall be gathered back.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And it is He Who gives life and causes death, and His is the alternation of night and day. Will you not then understand\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Nay, but they say the like of what the men of old said.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They said: ``When we are dead and have become dust and bones, shall we be resurrected indeed"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
``Verily, this we have been promised -- we and our fathers before! This is only (from) tales of the ancients!") Allah's saying:\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say: ``Whose is the earth and whosoever is therein If you know!"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say: ``It is Allah's!" Say: ``Will you not then remember"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say: ``Who is (the) Lord of the seven heavens, and (the) Lord of the Great Throne"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say: ``Allah." Say: ``Will you not then have Taqwa"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say: ``In Whose Hand is the sovereignty of everything And He protects, while against Whom there is no protector, if you know"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say: ``(All that belongs) to Allah." Say: ``How then are you deceived and turn away from the truth"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
Nay, but We have brought them the truth, and verily, they are liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
No son (or offspring) did Allah beget, nor is there any god along with Him. (If there had been many gods), then each god would have taken away what he had created, and some would have tried to overcome others! Glorified be Allah above all that they attribute to Him!\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
All-Knower of the unseen and the seen! Exalted be He over all that they associate as partners to Him!\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say: ``My Lord! If You would show me that with which they are threatened, ``\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
``My Lord! Then, put me not amongst the people who are the wrongdoers."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And indeed We are able to show you that with which We have threatened them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel evil with that which is better. We are best-acquainted with the things they utter.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say: ``My Lord! I seek refuge with You from the whisperings of the Shayatin."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
``And I seek refuge with You, My Lord! lest they should come near me."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
Until, when death comes to one of them, he says: ``My Lord! Send me back,"\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
``So that I may do good in that which I have left behind!" No! (Kalla) It is but a word that he speaks; and in front of them is Barzakh until the Day when they will be resurrected.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
Then, when the Trumpet is blown, there will be no kinship among them that Day, nor will they ask of one another.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
Then, those whose Scales (of good deeds) are heavy, these! they are the successful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
And those whose Scales (of good deeds) are light, they are those who lose themselves, in Hell will they abide.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire will burn their faces, and therein they will grin, with displaced lips (disfigured).\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
``Were not My Ayat recited to you, and then you used to deny them"\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say: ``Our Lord! Our wretchedness overcame us, and we were (an) erring people."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
``Our Lord! Bring us out of this. If ever we return (to evil), then indeed we shall be wrongdoers."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He (Allah) will say: ``Remain you in it with ignominy! And speak you not to Me!"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
Verily, there was a party of My servants who used to say: ``Our Lord! We believe, so forgive us and have mercy on us, for You are the Best of all who show mercy!"\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But you took them for a laughing stock, so much so that they made you forget My remembrance while you used to laugh at them!\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Verily, I have rewarded them this Day for their patience; they are indeed the ones that are successful.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
He will say: ``What number of years did you stay on earth"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say: ``We stayed a day or part of a day. Ask of those who keep account."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say: ``You stayed not but a little, if you had only known!"\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
``Did you think that We had created you in play, and that you would not be brought back to Us"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So Exalted be Allah, the True King: None has the right to be worshipped but He, the Lord of Al-`Arsh Al-Karim!\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
And whoever invokes besides Allah, any other god, of whom he has no proof; then his reckoning is only with his Lord. Surely, disbelievers will not be successful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And say: ``My Lord! Forgive and have mercy, for You are the Best of those who show mercy!"\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen A Surah which We have sent down and which We have enjoined (Faradnaha), and in it We have revealed manifest Ayat, that you may remember.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The Zaniyah and the Zani, flog each of them with a hundred stripes. Let not pity withhold you in their case, in a punishment prescribed by Allah, if you believe in Allah and the Last Day. And let a party of the believers witness their punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The Zani marries not but a Zaniyah or a Mushrikah; and the Zaniyah, none marries her except a Zani or a Mushrik. Such a thing is forbidden to the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who accuse chaste women, and produce not four witnesses, flog them with eighty stripes, and reject their testimony forever. They indeed are the rebellious.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Except those who repent thereafter and do righteous deeds; (for such) verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And for those who accuse their wives, but have no witnesses except themselves, let the testimony of one of them be four testimonies by Allah that he is one of those who speak the truth.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth (testimony); invoking of the curse of Allah on him if he be of those who tell a lie.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
But she shall avert the punishment from her, if she bears witness four times by Allah, that he is telling a lie.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth; should be that the wrath of Allah be upon her if he speaks the truth.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
And had it not been for the grace of Allah and His mercy on you! And that Allah is the One Who forgives and accepts repentance, the All-Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Verily, those who brought forth the slander are a group among you. Consider it not a bad thing for you. Nay, it is good for you. Unto every man among them will be paid that which he had earned of the sin, and as for him among them who had the greater share therein, his will be a great torment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why then, did not the believers, men and women, when you heard it, think good of their own people and say: ``This is an obvious lie"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they not produce four witnesses against him Since they have not produced witnesses! Then with Allah, they are the liars.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
Had it not been for the grace of Allah and His mercy unto you in this world and in the Hereafter, a great torment would have touched you for that whereof you had spoken.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When you were propagating it with your tongues, and uttering with your mouths that whereof you had no knowledge, you counted it a little thing, while with Allah it was very great.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And why did you not, when you heard it, say: ``It is not right for us to speak of this. Glory be to You (O Allah)! This is a great lie."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah forbids you from it and warns you not to repeat the like of it forever, if you are believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And Allah makes the Ayat plain to you, and Allah is All-Knowing, All-Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Verily, those who like that Fahishah should be circulated among those who believe, they will have a painful torment in this world and in the Hereafter. And Allah knows and you know not.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
And had it not been for the grace of Allah and His mercy on you, and that Allah is full of kindness, Most Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O you who believe! Follow not the Khutuwat of Shaytan. And whosoever follows the footsteps of Shaytan, then, verily, he commands Al-Fahsha' and the evil deeds. And had it not been for the grace of Allah and His mercy on you, not one of you would ever have been pure from sins. But Allah purifies whom He wills, and Allah is All-Hearer, All-Knower.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
And let not those among you who are blessed with graces and wealth swear not to give to their kinsmen, the poor, and those who left their homes for Allah's cause. Let them pardon and forgive. Do you not love that Allah should forgive you And Allah is Oft-Forgiving, Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Verily, those who accuse chaste believing women, who never even think of anything touching their chastity and are good believers -- are cursed in this life and in the Hereafter, and for them will be a great torment.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On the Day when their tongues, their hands, and their legs will bear witness against them as to what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
On that Day Allah will pay them the recompense of their deeds in full, and they will know that Allah, He is the Manifest Truth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Bad statements are for bad people and bad people for bad statements. Good statements are for good people and good people for good statements: such are innocent of (every) bad statement which they say; for them is forgiveness, and honored provision.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O you who believe! Enter not houses other than your own, until you have asked permission and greeted those in them; that is better for you, in order that you may remember.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you find no one therein, still enter not until permission has been given. And if you are asked to go back, go back, for it is purer for you. And Allah is All-Knower of what you do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no sin on you that you enter houses uninhabited, you have any interest in them. And Allah has knowledge of what you reveal and what you conceal.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Tell the believing men to lower their gaze, and protect their private parts. That is purer for them. Verily, Allah is All-Aware of what they do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And tell the believing women to lower their gaze, and protect their private parts and not to show off their adornment except that which is apparent, and to draw their veils all over their Juyub and not to reveal their adornment except to their husbands, or their fathers, or their husband's fathers, or their sons, or their husband's sons, or their brothers or their brother's sons, or their sister's sons, or their women, or their right hand possessions, or the Tabi`in among men who do not have desire, or children who are not aware of the nakedness of women. And let them not stamp their feet so as to reveal what they hide of their adornment. And all of you beg Allah to forgive you all, O believers, that you may be successful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And marry those among you who are single (Al-Ayama) and the pious of your servants and maidservants. If they be poor, Allah will enrich them out of His bounty. And Allah is All-Sufficent, All-Knowing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
And let those who find not the financial means for marriage keep themselves chaste, until Allah enriches them of His bounty. And such of your servants as seek a writing (of emancipation), give them such writing, if you find that there is good and honesty in them. And give them something (yourselves) out of the wealth of Allah which He has bestowed upon you. And force not your slave-girls to prostitution, if they desire chastity, in order that you may make a gain in the goods of this worldly life. But if anyone compels them, then after such compulsion, Allah is Oft-Forgiving, Most Merciful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
And indeed We have sent down for you Ayat that make things plain, and the example of those who passed away before you, and an admonition for those who have Taqwa.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Light of the heavens and the earth. The parable of His Light is as a niche and within it a lamp: the lamp is in a glass, the glass as it were a star Durriyyun, lit from a blessed tree, an olive, neither of the east nor of the west, whose oil would almost glow forth, though no fire touched it. Light upon Light! Allah guides to His Light whom He wills. And Allah sets forth parables for mankind, and Allah is All-Knower of everything.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
In houses which Allah has ordered to be raised, in them His Name is remembered. Therein glorify Him in the mornings and in the evenings,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
Men whom neither trade nor business diverts from the remembrance of Allah nor from performing the Salah nor from giving the Zakah. They fear a Day when hearts and eyes will be overturned.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
That Allah may reward them according to the best of their deeds, and add even more for them out of His grace. And Allah provides without measure to whom He wills.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
As for those who disbelieved, their deeds are like a mirage in a Qi`ah. The thirsty one thinks it to be water until he comes up to it, he finds it to be nothing; but he finds Allah with him, Who will pay him his due. And Allah is swift in taking account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or like the darkness in a vast deep sea, overwhelmed with waves topped by waves, topped by dark clouds, (layers of) darkness upon darkness: if a man stretches out his hand, he can hardly see it! And he for whom Allah has not appointed light, for him there is no light.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
See you not that Allah, He it is Whom glorify whosoever is in the heavens and the earth, and the birds with wings outspread Of each one He knows indeed his Salah and his glorification; and Allah is All-Aware of what they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
And to Allah belongs the sovereignty of the heavens and the earth, and to Allah is the return.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
See you not that Allah drives the clouds gently, then joins them together, then makes them into a heap of layers, and you see the rain come forth from between them; and He sends down from the sky, from mountains in it of ice, and strikes therewith whom He wills, and averts it from whom He wills. The vivid flash of its (clouds) lightning nearly blinds the sight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah causes the night and the day to succeed each other. Truly, in this is indeed a lesson for those who have insight.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
Allah has created every moving creature from water. Of them there are some that creep on their bellies, and some that walk on two legs, and some that walk on four. Allah creates what He wills. Verily, Allah is able to do all things.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We have indeed sent down manifest Ayat. And Allah guides whom He wills to the straight path.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
They say: ``We have believed in Allah and in the Messenger, and we obey," then a party of them turn away thereafter, such are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they are called to Allah and His Messenger, to judge between them, lo! a party of them refuses and turns away.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
But if the truth is on their side, they come to him willingly with submission.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is there a disease in their hearts Or do they doubt or fear lest Allah and His Messenger should wrong them in judgement. Nay, it is they themselves who are the wrongdoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The only saying of the faithful believers, when they are called to Allah and His Messenger, to judge between them, is that they say: ``We hear and we obey." And such are the successful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
And whosoever obeys Allah and His Messenger, fears Allah, and has Taqwa of Him, such are the successful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
They swear by Allah their strongest oaths that if only you would order them, they would leave. Say: ``Swear you not; obedience is known. Verily, Allah knows well what you do."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say: ``Obey Allah and obey the Messenger, but if you turn away, he is only responsible for the duty placed on him and you for that placed on you. If you obey him, you shall be on the right guidance. The Messenger's duty is only to convey (the Message) in a clear way.") Allah says about the hypocrites who had promised the Messenger and sworn that if he were to command them to go out for battle, they would go:\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised those among you who believe and do righteous good deeds, that He will certainly grant them succession in the land, as He granted it to those before them, and that He will grant them the authority to practise their religion which He has chosen for them. And He will surely give them in exchange a safe security after their fear if they worship Me and do not associate anything with Me. But whoever disbelieved after this, they are the rebellious.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
And perform the Salah, and give the Zakah and obey the Messenger that you may receive mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Consider not that the disbelievers can escape in the land. Their abode shall be the Fire -- and worst indeed is that destination.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O you who believe! Let your slaves and slave-girls, and those among you who have not come to the age of puberty ask your permission on three occasions: before the Fajr prayer, and while you put off your clothes during the afternoon, and after the `Isha' prayer. (These) three (times) are of privacy for you; other than these times there is no sin on you or on them to move about, attending to each other. Thus Allah makes clear the Ayat to you. And Allah is All-Knowing, All-Wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when the children among you come to puberty, then let them (also) ask for permission, as those senior to them (in age) ask permission. Thus Allah makes clear His Ayat for you. And Allah is All-Knowing, All-Wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
And the Qawa`id among women who do not hope for marriage, it is no sin on them if they discard their (outer) clothing in such a way as not to show their adornment. But to refrain is better for them. And Allah is All-Hearer, All-Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is no restriction on the blind, nor any restriction on the lame, nor any restriction on the sick, nor on yourselves, if you eat from your houses, or the houses of your fathers, or the houses of your mothers, or the houses of your brothers, or the houses of your sisters, or the houses of your father's brothers, or the houses of your father's sisters, or the houses of your mother's brothers, or the houses of your mother's sisters, or (from that) whereof you hold keys, or (from the house) of a friend. No sin on you whether you eat together or apart. But when you enter the houses, greet one another with a greeting from Allah, blessed and good. Thus Allah makes clear the Ayat to you that you may understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The believers are only those who believe in Allah and His Messenger; and when they are with him on some common matter, they go not away until they have asked his permission. Verily, those who ask your permission, those are they who (really) believe in Allah and His Messenger. So if they ask your permission for some affairs of theirs, give permission to whom you will of them, and ask Allah for their forgiveness. Truly, Allah is Oft-Forgiving, Most Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Make not the calling of the Messenger among you as your calling one of another. Allah knows those of you who slip away under shelter. And let those beware who oppose the Messenger's commandment, lest some Fitnah should befall them or a painful torment be inflicted on them.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Certainly, to Allah belongs all that is in the heavens and the earth. Indeed, He knows your condition and the Day when they will be brought back to Him, then He will inform them of what they did. And Allah is All-Knower of everything.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed be He Who sent down (Nazzala) the criterion to His servant that he may be a warner to all nations.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He to Whom belongs the dominion of the heavens and the earth, and Who has begotten no son and for Whom there is no partner in the dominion. He has created everything, and has measured it exactly according to its due measurements.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
Yet they have taken besides Him other gods who created nothing but are themselves created, and possess neither harm nor benefit for themselves, and possess no power (of causing) death, nor (of giving) life, nor of raising the dead.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
Those who disbelieve say: ``This is nothing but a lie that he has invented, and others have helped him in it." In fact, they have produced an unjust wrong and a lie.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say: ``Tales of the ancients which he has written down, and they are dictated to him morning and afternoon. ``\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say: ``It has been sent down by Him Who knows the secret of the heavens and the earth. Truly, He is Oft-Forgiving, Most Merciful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say: ``Why does this Messenger eat food, and walk about in the markets. Why is not an angel sent down to him to be a warner with him"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
``Or (why) has not a treasure been granted to him, or why has he not a garden whereof he may eat" And the wrongdoers say: ``You follow none but a man bewitched."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
See how they coin similitudes for you, so they have gone astray, and they cannot find a path.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed be He Who, if He wills, will assign you better than (all) that -- Gardens under which rivers flow and will assign you palaces.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
Nay, they deny the Hour, and for those who deny the Hour, We have prepared a flaming Fire.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When it sees them from a far place, they will hear its raging and its roaring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they shall be thrown into a narrow place thereof, chained together, they will exclaim therein for destruction.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
Exclaim not today for one destruction, but exclaim for many destructions.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say: ``Is that better or the Paradise of Eternity which is promised to those who have Taqwa" It will be theirs as a reward and final destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
For them there will be therein all that they desire, and they will abide (therein forever). It is upon your Lord a Wa`dan Mas'ula.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And on the Day when He will gather them together and that which they worship besides Allah. He will say: ``Was it you who misled these My servants or did they stray from the path"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say: ``Glorified be You! It was not for us to take any Awliya' besides You, but You gave them and their fathers comfort till they forgot the warning, and became a lost people."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
Thus they will deny you in what you say; then you can neither avert nor find help. And whoever among you does wrong, We shall make him taste a great torment.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And We never sent before you any of the Messengers but verily, they ate food and walked in the markets. And We have made some of you as a trial for others; will you have patience And your Lord is Ever All-Seer.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
And those who expect not a meeting with Us said: ``Why are not the angels sent down to us, or why do we not see our Lord" Indeed they think too highly of themselves, and are scornful with great pride.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
On the Day they will see the angels -- no good news will there be for the criminals that day. And they will say: ``Hijran Mahjura."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We shall turn to whatever deeds they did, and We shall make such deeds as scattered floating particles of dust.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
The dwellers of Paradise will, on that Day, have the best abode, and have the fairest of places for repose.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
And (remember) the Day when the heaven shall be rent asunder with clouds, and the angels will be sent down, with a grand descending.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
The sovereignty on that Day will be the true (sovereignty) of the Most Gracious, and it will be a hard Day for the disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
And (remember) the Day when the wrongdoer will bite at his hands, he will say: ``Oh! Would that I had taken a path with the Messenger."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
``Ah! Woe to me! Would that I had never taken so-and-so as an intimate friend!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
``He indeed led me astray from the Reminder after it had come to me. And Shaytan is to man ever a deserter."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Messenger will say: ``O my Lord! Verily, my people deserted this Qur'an."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
Thus have We made for every Prophet an enemy among the criminals. But sufficient is your Lord as a Guide and Helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
And those who disbelieve say: ``Why is not the Qur'an revealed to him all at once" Thus, that We may strengthen your heart thereby. And We have revealed it to you gradually, in stages.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And no example or parable do they bring, but We reveal to you the truth, and the better explanation thereof.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
Those who will be gathered to Hell on their faces, such will be in an evil state, and most astray from the path.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
And indeed We gave Musa the Scripture, and placed his brother Harun with him as a helper;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
And We said: ``Go you both to the people who have denied Our Ayat." Then We destroyed them with utter destruction.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And Nuh's people, when they denied the Messengers, We drowned them, and We made them as a sign for mankind. And We have prepared a painful torment for the wrongdoers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And (also) `Ad and Thamud, and the Dwellers of Ar-Rass, and many generations in between.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
And for each We put forward examples, and each We brought to utter ruin.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And indeed they have passed by the town on which was rained the evil rain. Did they not then see it Nay! But they used not to expect any resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see you, they treat you only in mockery (saying): ``Is this the one whom Allah has sent as a Messenger"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
``He would have nearly misled us from our gods, had it not been that we were patient and constant in their worship!" And they will know, when they see the torment, who it is that is most astray from the path!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Have you seen him who has taken as his god his own vain desire Would you then be a guardian over him\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or do you think that most of them hear or understand They are only like cattle -- nay, they are even farther astray from the path.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Have you not seen how your Lord spread the shadow. If He willed, He could have made it still -- but We have made the sun its guide.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We withdraw it towards Ourselves -- a gradual withdrawal.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is He Who makes the night a covering for you, and the sleep (as) a repose, and makes the day Nushur.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He Who sends the winds as heralds of glad tidings, going before His mercy; and We send down pure water from the sky,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
That We may give life thereby to a dead land, and We give to drink thereof many of the cattle and men that We have created.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And indeed We have distributed it among them in order that they may remember the grace of Allah, but most men refuse (out of) gratitude.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
And had We willed, We would have raised a warner in every town.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So obey not the disbelievers, but strive against them with the utmost endeavor with it.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He Who has let free the two seas, this is palatable and sweet, and that is salty and bitter; and He has set a barrier and a complete partition between them.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He Who has created man from water, and has appointed for him kindred by blood, and kindred by marriage. And your Lord is Ever All-Powerful to do what He wills.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
And they worship besides Allah, that which can neither profit them nor harm them; and the disbeliever is ever a helper against his Lord.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
And We have sent you only as a bearer of good news and a warner.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say: ``No reward do I ask of you for this, save that whosoever wills may take a path to his Lord."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And put your trust in the Ever Living One Who dies not, and glorify His praises, and sufficient is He as the All-Knower of the sins of His servants,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
Who created the heavens and the earth and all that is between them in six Days. Then He rose over (Istawa) the Throne. The Most Gracious! Ask Him, as He is the All-Knower.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said to them: ``Prostrate yourselves to Ar-Rahman!" They say: ``And what is Ar-Rahman Shall we fall down in prostration to that which you command us" And it increases in them only aversion.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed be He Who has placed in the heaven Al-Buruj, and has placed therein a great lamp, and a moon giving light.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And He it is Who has put the night and the day in succession (Khilfatan), for such who desires to remember or desires to show his gratitude.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
And the servants of the Most Gracious are those who walk on the earth Hawna, and when the foolish address them they say; ``Salama."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And those who spend the night in worship of their Lord, prostrate and standing.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And those who say: ``Our Lord! Avert from us the torment of Hell. Verily, its torment is ever an inseparable, permanent punishment."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
Evil indeed it is as an abode and as a place to rest in.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And those who, when they spend, are neither extravagant nor stingy, but are in a just balance between them.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who invoke not any other god along with Allah, nor kill such person as Allah has forbidden, except for just cause, nor commit illegal sexual intercourse -- and whoever does this shall receive Athama.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
The torment will be doubled for him on the Day of Resurrection, and he will abide therein in disgrace;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Except those who repent and believe, and do righteous deeds; for those, Allah will change their sins into good deeds, and Allah is Oft-Forgiving, Most Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And whosoever repents and does righteous good deeds; then indeed he has repented to Allah Mataba.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And those who do not bear witness to falsehood, and if they pass by some evil play or evil talk, they pass by it with dignity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when they are reminded of the Ayat of their Lord, fall not deaf and blind thereat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And those who say: ``Our Lord! Bestow on us from our wives and our offspring the comfort of our eyes, and make us leaders of those who have Taqwa."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those will be rewarded with the highest place because of their patience. Therein they shall be met with greetings and the word of peace and respect.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Abiding therein -- excellent it is as an abode, and as a place to rest in.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say: ``My Lord pays attention to you only because of your invocation to Him. But now you have indeed denied. So the torment will be yours forever."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta Sin Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are Ayat of the Book Mubin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
It may be that you are going Bakhi` yourself, that they do not become believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We will, We could send down to them from the heaven a sign, to which they would bend their necks in humility.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
And never comes there unto them a Reminder as a recent revelation from the Most Gracious, but they turn away therefrom.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
So, they have indeed denied, then the news of what they mocked at will come to them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Do they not observe the earth -- how much of every good kind We cause to grow therein\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Verily, in this is an Ayah, yet most of them are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And verily your Lord, He is truly the All-Mighty, the Most Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And (remember) when your Lord called Musa (saying): ``Go to the people who are wrongdoers."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
``The people of Fira`wn. Will they not have Taqwa"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said: ``My Lord! Verily, I fear that they will deny me,"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
``And my breast straitens, and my tongue expresses not well. So send for Harun."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
``And they have a charge of crime against me, and I fear they will kill me. ``\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
(Allah) said: ``Nay! Go you both with Our signs. Verily, We shall be with you, listening."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
``And go both of you to Fira`wn, and say: `We are the Messengers of the Lord of Al-`Alamin,'\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
`So allow the Children of Israel to go with us."'\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
(Fir`awn) said (to Musa): ``Did we not bring you up among us as a child And you did dwell many years of your life with us."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
``And you did your deed, which you did. While you were one of the ingrates."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
Musa said: ``I did it then, when I was in error."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
``So, I fled from you when I feared you. But my Lord has granted me Hukm, and made me one of the Messengers."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
``And this is the past favor with which you reproach me, -- that you have enslaved the Children of Israel."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Fir`awn said: ``And what is the Lord of Al-`Alamin"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
(Musa) said: ``The Lord of the heavens and the earth, and all that is between them, if you seek to be convinced with certainty."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
(Fir`awn) said to those around: ``Do you not hear (what he says)"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
(Musa) said: ``Your Lord and the Lord of your ancient fathers!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
(Fir`awn) said: ``Verily, your Messenger who has been sent to you is a madman!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
(Musa) said: ``Lord of the east and the west, and all that is between them, if you did but understand!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
He said: ``If you choose a god other than me, I will certainly put you among the prisoners."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
He said: ``Even if I bring you something manifest"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
He said: ``Bring it forth then, if you are of the truthful!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So he threw his stick, and behold, it was a serpent, manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew out his hand, and behold, it was white to all beholders!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
He said to the chiefs around him: ``Verily, this is indeed a well-versed sorcerer."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
``He wants to drive you out of your land by his sorcery: what is it then that you command"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said: ``Put him off and his brother (for a while), and send callers to the cities;"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
``To bring up to you every well-versed sorcerer."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So, the sorcerers were assembled at a fixed time on a day appointed.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said to the people: ``Are you (too) going to assemble"\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
``That we may follow the sorcerers if they are the winners."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
So, when the sorcerers arrived, they said to Fir`awn: ``Will there surely be a reward for us if we are the winners"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said: ``Yes, and you shall then verily be of those brought near (to myself)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Musa said to them: ``Throw what you are going to throw!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So, they threw their ropes and their sticks, and said: ``By the might of Fir`awn, it is we who will certainly win!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Musa threw his stick, and behold, it swallowed up all that they falsely showed!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
And the sorcerers fell down prostrate.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
Saying: ``We believe in the Lord of Al-`Alamin."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
``The Lord of Musa and Harun."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
He said: ``You have believed in him before I give you leave. Surely, he indeed is your chief, who has taught you magic! So verily, you shall come to know. Verily, I will cut off your hands and your feet on opposite sides, and I will crucify you all."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said: ``No harm! Surely, to our Lord we are to return."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
``Verily, we really hope that our Lord will forgive us our sins, as we are the first of the believers."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We revealed to Musa, saying: ``Depart by night with My servants, verily, you will be pursued."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Fir`awn sent callers to (all) the cities.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
(Saying): ``Verily, these indeed are but a small band."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
``And verily, they have done what has enraged us."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
``But we are a host all assembled, amply forewarned."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
So, We expelled them from gardens and springs,\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
Treasures, and every kind of honorable place.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
Thus and We caused the Children of Israel to inherit them.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
So, they pursued them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two hosts saw each other, the companions of Musa said: ``We are sure to be overtaken."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
(Musa) said: ``Nay, verily with me is my Lord. He will guide me."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We revealed to Musa (saying): ``Strike the sea with your stick." And it parted, and each separate part became like huge mountain.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
Then We brought near the others to that place.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We saved Musa and all those with him.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
Then We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
And verily your Lord, He is truly the All-Mighty, the Most Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite to them the story of Ibrahim.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said to his father and his people: ``What do you worship"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said: ``We worship idols, and to them we are ever devoted."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said: ``Do they hear you when you call"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
``Or do they benefit you or do they cause harm"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said: ``(Nay) but we found our fathers doing so."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said: ``Do you observe that which you have been worshipping --"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
``You and your ancient fathers"\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
``Verily, they are enemies to me, save the Lord of Al-`Alamin,"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
Who has created me, and it is He Who guides me.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
And it is He Who feeds me and gives me to drink.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
And when I am ill, it is He Who cures me.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
And Who will cause me to die, and then will bring me to life.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
And Who, I hope, will forgive me my faults on the Day of Recompense.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
My Lord! Bestow Hukm on me, and join me with the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And grant me an honorable mention in later generations.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
And make me one of the inheritors of the Paradise of Delight.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
And forgive my father, verily, he is of the erring.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
And disgrace me not on the Day when they will be resurrected.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The Day whereon neither wealth nor sons will avail,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
Except him who brings to Allah a clean heart.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And Paradise will be brought near to those who had Taqwa.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And the (Hell) Fire will be placed in full view of the astray.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it will be said to them: ``Where are those that you used to worship."\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
``Instead of Allah Can they help you or help themselves"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
Then they will be thrown on their faces into it (the Fire), they and the astray.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And all of the hosts of Iblis together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
They will say while contending therein,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
``By Allah, we were truly in a manifest error,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
``When we held you as equals with the Lord of all that exists;"\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
``And none has brought us into error except the criminals."\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
``Now we have no intercessors,"\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
``Nor a close friend."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
``(Alas!) If we only had a chance to return, we shall truly be among the believers!"\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And verily your Lord, He is truly the All-Mighty, the Most Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Nuh denied the Messengers.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
When their brother Nuh said to them: ``Will you not have Taqwa"\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
``I am a trustworthy Messenger to you."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
``So have Taqwa of Allah, and obey me."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
``No reward do I ask of you for it; my reward is only from the Lord of all that exists."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
``So have Taqwa of Allah, and obey me."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said: ``Shall we believe in you, when the inferior follow you"\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said: ``And what knowledge have I of what they used to do"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
``Their account is only with my Lord, if you could (but) know."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
``And I am not going to drive away the believers."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
``I am only a plain warner."\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said: ``If you cease not, O Nuh you will surely be among those stoned."\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said: ``My Lord! Verily, my people have denied me."\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
``Therefore judge You between me and them, and save me and those of the believers who are with me."\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
And We saved him and those with him in the laden ship.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then We drowned the rest thereafter.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And verily your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
`Ad denied the Messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hud said to them: ``Will you not have Taqwa"\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
``Verily, I am a trustworthy Messenger to you."\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
``So, have Taqwa of Allah, and obey me."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
``No reward do I ask of you for it; my reward is only from the Lord of all that exists."\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
``Do you build on every Ri` an Ayah for your amusement"\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
``And do you get for yourselves Masani` as if you will live therein forever"\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
``And when you seize (somebody), seize you (him) as tyrants"\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
``So have Taqwa of Allah, and obey me."\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
``And have Taqwa of Him, fear Him Who has aided you with all (good things) that you know."\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
``He has aided you with cattle and children."\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
``And gardens and springs."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
``Verily, I fear for you the torment of a Great Day."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said: ``It is the same to us whether you preach or be not of those who preach."\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
``This is no other than Khuluq of the ancients,"\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
``And we are not going to be punished."\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
So they denied him, and We destroyed them. Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And verily your Lord, He is indeed the Almighty, the Most Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
Thamud denied the Messengers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their brother Salih said to them: ``Will you not have Taqwa"\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
``I am a trustworthy Messenger to you."\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
``So, have Taqwa of Allah, and obey me."\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
``No reward do I ask of you for it; my reward is only from the Lord of Al-`Alamin."\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
``Will you be left secure in that which you have here"\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
``In gardens and springs."\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
``And crops and date palms with soft clusters."\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
``And you hew out in the mountains, houses with great skill."\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
``So, have Taqwa of Allah, and obey me."\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
``And follow not the command of the extravagant,"\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
Who make mischief in the land, and reform not."\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said: ``You are only of those bewitched!"\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
``You are but a human being like us. Then bring us a sign if you are of the truthful."\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said: ``Here is a she-camel: it has a right to drink (water), and you have a right to drink (water) (each) on a day, known."\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
``And touch her not with harm, lest the torment of a Great Day should seize you."\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they killed her, and then they became regretful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
So, the torment overtook them. Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And verily, your Lord He is indeed the All-Mighty, the Most Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lut denied the Messengers.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lut said to them: ``Will you not have Taqwa"\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
``Verily, I am a trustworthy Messenger to you."\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
``So, have Taqwa of Allah, and obey me."\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
``No reward do I ask of you for it; my reward is only from the Lord of all that exits."\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
``Go you in unto the males of Al-`Alamin (people),"\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
``And leave those whom Allah has created for you to be your wives Nay, you are a trespassing people!"\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said: ``If you cease not, O Lut, verily, you will be one of those who are driven out!"\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said: ``I am indeed of those who disapprove with severe anger and fury your behavior."\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
``My Lord! Save me and my family from what they do."\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So, We saved him and his family, all,\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Except an old woman among those who remained behind.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Then afterward We destroyed the others.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We rained on them a rain, and how evil was the rain of those who had been warned!\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And verily your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The companions of Al-Aykah denied the Messengers.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
When Shu`ayb said to them: ``Will you not have Taqwa"\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
``I am a trustworthy Messenger to you."\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
``So, have Taqwa of Allah, and obey me."\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
``No reward do I ask of you for it; my reward is only from the Lord of Al-`Alamin."\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
``Give full measure, and cause no loss (to others)."\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
``And weigh with the true and straight balance."\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
``And defraud not people by reducing their things, nor do evil, making corruption and mischief in the land."\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
``And have Taqwa of Him Who created you and the generations of the men of old."\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said: ``You are only one of those bewitched!"\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
``You are but a human being like us and verily, we think that you are one of the liars!"\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
``So, cause a piece of the heaven to fall on us, if you are of the truthful!"\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said: ``My Lord is the Best Knower of what you do."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
But they denied him, so the torment of the Day of Shadow (a gloomy cloud) seized them. Indeed that was the torment of a Great Day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Verily, in this is indeed a sign, yet most of them are not believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And verily your Lord, He is indeed the All-Mighty, the Most Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
And truly, this is a revelation from the Lord of all that exists,\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
Which the trustworthy Ruh (Jibril) has brought down.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon your heart that you may be (one) of the warners,\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In the plain Arabic language.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And verily, it is in the Zubur of the former people.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
Is it not a sign to them that the learned scholars of the Children of Israel knew it\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
And if We had revealed it unto any of the non-Arabs,\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And he had recited it unto them, they would not have believed in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus have We caused it to enter the hearts of the criminals.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it until they see the painful torment.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
It shall come to them of a sudden, while they perceive it not.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
Then they will say: ``Can we be respited"\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
Would they then wish for Our torment to be hastened on\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Think, if We do let them enjoy for years,\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
And afterwards comes to them that which they had been promised.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
All that with which they used to enjoy shall not avail them.\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
And never did We destroy a township but it had its warners\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
By way of reminder, and We have never been unjust.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
And it is not the Shayatin (devils) who have brought it down.\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
Neither would it suit them nor are they able.\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Verily, they have been removed far from hearing it.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So, invoke not with Allah another god lest you should be among those who receive punishment.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn your tribe of near kindred.\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And be kind and humble to the believers who follow you.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
Then if they disobey you, say: ``I am innocent of what you do."\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And put your trust in the All-Mighty, the Most Merciful,\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who sees you when you stand up.\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And your movements among those who fall prostrate.\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Verily, He, only He, is the All-Hearer, the All-Knower.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you upon whom the Shayatin descend\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend on every lying, sinful person (Athim).\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
Who gives ear, and most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
As for the poets, the astray follow them,\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
See you not that they speak about every subject in their poetry\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And that they say what they do not do.\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except those who believe and do righteous deeds, and remember Allah much and vindicate themselves after they have been wronged. And those who do wrong will come to know by what overturning they will be overturned.\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta Sin. These are the Ayat of the Qur'an, and (it is) a Book (that is) clear.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
A guide and glad tidings for the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Those who perform the Salah and give the Zakah and they believe with certainty in the Hereafter.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Verily, those who believe not in the Hereafter, We have made their deeds fair seeming to them, so that they wander about blindly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
They are those for whom there will be an evil torment. And in the Hereafter they will be the greatest losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
And verily, you are being taught the Qur'an from One, All-Wise, All-Knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
(Remember) when Musa said to his household: ``Verily, I have seen a fire; I will bring you from there some information, or I will bring you a burning ember, that you may warm yourselves."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
But when he came to it, he was called: ``Blessed is whosoever is in the fire, and whosoever is round about it! And glorified be Allah, the Lord of all that exists."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
``O Musa! Verily, it is I, Allah, the All-Mighty, the All-Wise."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
``And throw down your stick!" But when he saw it moving as if it were a snake, he turned in flight, and did not look back. (It was said:) ``O Musa! Fear not: verily, the Messengers fear not in front of Me."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
``Except him who has done wrong and afterwards has changed evil for good; then surely, I am Oft-Forgiving, Most Merciful."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
``And put your hand into opening of your garment, it will come forth white without hurt. (These are) among the nine signs (you will take) to Fir`awn and his people. Verily, they are a people who are rebellious."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when Our Ayat came to them, clear to see, they said: ``This is a manifest magic."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they belied them wrongfully and arrogantly, though they themselves were convinced thereof. So, see what was the end of the mischief-makers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And indeed We gave knowledge to Dawud and Sulayman, and they both said: ``All praise be to Allah, Who has preferred us above many of His believing servants!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Sulayman inherited from Dawud. He said: ``O mankind! We have been taught the language of birds, and we have been given from everything. This, verily, is an evident grace."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And there were gathered before Sulayman his hosts of Jinn and men, and birds, and they all were set in battle order (marching forward).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Till, when they came to the valley of the ants, one of the ants said: ``O ants! Enter your dwellings, lest Sulayman and his armies should crush you, while they perceive not."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
So he (Sulayman) smiled, amused at her speech and said: ``My Lord! Grant me the power and ability that I may be grateful for Your favors which You have bestowed on me and on my parents, and that I may do righteous good deeds that will please You, and admit me by Your mercy among Your righteous servants."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
He inspected the birds, and said: ``What is the matter that I see not the hoopoe Or is he among the absentees"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
``I will surely punish him with a severe torment or slaughter him, unless he brings me a clear reason."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But (the hoopoe) stayed not long, he said: ``I have grasped which you have not grasped and I have come to you from Saba' with true news."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
``I found a woman ruling over them, she has been given all things, and she has a great throne."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
``I found her and her people worshipping the sun instead of Allah, and Shaytan has made their deeds fair seeming to them to prevent them from the way, so they have no guidance."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
So they do not prostrate themselves before Allah, Who brings to light what is hidden in the heavens and the earth, and knows what you conceal and what you reveal.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah, La ilaha illa Huwa, the Lord of the Supreme Throne!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
(Sulayman) said: ``We shall see whether you speak the truth or you are (one) of the liars."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
``Go you with this letter of mine and deliver it to them, then draw back from them and see what they return."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She said: ``O chiefs! Verily, here is delivered to me a noble letter, ``\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
``Verily, it is from Sulayman, and it (reads): `In the Name of Allah, the Most Gracious, the Most Merciful;'\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
`Be you not exalted against me, but come to me submitting (as Muslims).' ``\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said: ``O chiefs! Advise me in case of mine. I decide no case till you are present with me."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said: ``We have great strength, and great ability for war, but it is for you to command; so think over what you will command."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said: ``Verily, kings, when they enter a town, they destroy it and make the most honorable among its people the lowest. And thus they do."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
``But verily, I am going to send him a present, and see with what (answer) the messengers return."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
So, when (the messengers with the gift) came to Sulayman, he said: ``Will you help me in wealth What Allah has given me is better than that which He has given you! Nay, you rejoice in your gift!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
``Go back to them. We verily, shall come to them with armies that they cannot resist, and we shall drive them out from there in disgrace, and they will be abased."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
He said: ``O chiefs! Which of you can bring me her throne before they come to me surrendering themselves in obedience (as Muslims)"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
An `Ifrit from the Jinn said: ``I will bring it to you before you rise from your place. And verily, I am indeed strong and trustworthy for such work."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
One with whom was knowledge of the Scripture, said: ``I will bring it to you within the twinkling of an eye!" Then when he saw it placed before him, he said: ``This is by the grace of my Lord -- to test me whether I am grateful or ungrateful! And whoever is grateful, truly, his gratitude is for himself; and whoever is ungrateful, certainly my Lord is Rich, Bountiful."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said: ``Disguise her throne for her that we may see whether she will be guided, or she will be one of those not guided."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
So when she came, it was said, ``Is your throne like this" She said: ``As though it were the very same." And he said, ``Knowledge was bestowed on us before her, and we had submitted to Allah (as Muslims)."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And Saddaha that which she used to worship besides Allah has prevented her (from Islam), for she was of a disbelieving people.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
It was said to her: ``Enter As-Sarh," but when she saw it, she thought it was a pool, and she (tucked up her clothes) uncovering her legs. Sulayman said: ``Verily, it is a Sarh Mumarrad of Qawarir." She said: ``My Lord! Verily, I have wronged myself, and I submit, together with Sulayman to Allah, the Lord of all that exits."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And indeed We sent to Thamud their brother Salih, (saying): ``Worship Allah." Then look! They became two parties quarreling with each other.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said: ``O my people! Why do you seek to hasten the evil before the good Why seek you not the forgiveness of Allah, that you may receive mercy"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said: ``We augur an omen from you and those with you." He said: ``Your omen is of Allah; nay, but you are a people that are being tested."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
And there were in the city nine Rahtin, who made mischief in the land, and would not reform.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said: ``Swear one to another by Allah that we shall make a secret night attack on him and his household, and thereafter we will surely say to his near relatives: `We witnessed not the destruction of his household, and verily, we are telling the truth."'\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
So, they plotted a plot, and We planned a plan, while they perceived not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
Then see how was the end of their plot! Verily, We destroyed them and their nation all together.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
These are their houses in utter ruin, for they did wrong. Verily, in this is indeed an Ayah for people who know.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We saved those who believed, and had Taqwa of Allah.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And (remember) Lut! When he said to his people: ``Do you commit immoral sins while you see"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
``Do you practice your lusts on men instead of women Nay, but you are a people who behave senselessly."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
There was no other answer given by his people except that they said: ``Drive out the family of Lut from your city. Verily, these are men who want to be clean and pure!"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
So, We saved him and his family, except his wife. We destined her to be of those who remained behind.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained down on them a rain. So, evil was the rain of those who were warned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say: ``Praise and thanks be to Allah, and peace be on His servants whom He has chosen! Is Allah better, or what they ascribe as partners"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
Is not He Who created the heavens and the earth, and sends down for you water from the sky, whereby We cause to grow wonderful gardens full of beauty and delight It is not in your ability to cause the growth of their trees. Is there any god with Allah Nay, but they are a people who ascribe equals!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Is not He Who has made the earth as a fixed abode, and has placed rivers in its midst, and has placed firm mountains therein, and has set a barrier between the two seas (of salt and sweet water) Is there any ilah (god) with Allah Nay, but most of them know not!\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Is not He Who responds to the distressed one, when he calls on Him, and Who removes the evil, and makes you inheritors of the earth, generations after generations Is there any god with Allah Little is that you remember!\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Is not He Who guides you in the darkness of the land and the sea, and Who sends the winds as heralds of glad tidings, going before His mercy Is there any god with Allah Exalted be Allah above all that they associate as partners!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Is not He Who originates creation, and shall thereafter repeat it, and Who provides for you from heaven and earth Is there any god with Allah Say: ``Bring forth your proofs, if you are truthful."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say: ``None in the heavens and the earth knows the Unseen except Allah, nor can they perceive when they shall be resurrected."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Nay, their knowledge will perceive that in the Hereafter. Nay, they are in doubt about it. Nay, they are in complete blindness about it.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
And those who disbelieve say: ``When we have become dust -- we and our fathers -- shall we really be brought forth"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
``Indeed we were promised this -- we and our forefathers before, verily, these are nothing but tales of ancients."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say to them: ``Travel in the land and see how has been the end of the criminals."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
And grieve you not over them, nor be straitened (in distress) because of what they plot.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they say: ``When this promise, if you are truthful"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say: ``Perhaps that which you wish to hasten on, may be close behind you."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
Verily, your Lord is full of grace for mankind, yet most of them do not give thanks.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And verily, your Lord knows what their breasts conceal and what they reveal.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And there is nothing hidden in the heaven and the earth but it is in a Clear Book.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Verily, this Qur'an narrates to the Children of Israel most of that in which they differ.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And truly, it is a guide and a mercy for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Verily, your Lord will decide between them by His judgement. And He is the All-Mighty, the All-Knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So, put your trust in Allah; surely, you are on manifest truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Verily, you cannot make the dead to hear nor can you make the deaf to hear the call, when they flee, turning their backs.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
Nor can you lead the blind out of their error. You can only make to hear those who believe in Our Ayat, so they submit (became Muslims).\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the Word is fulfilled against them, We shall bring out from the earth a beast for them, to speak to them because mankind believed not with certainty in Our Ayat.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
And (remember) the Day when We shall gather out of every nation a Fawj of those who denied Our Ayat, and they shall be driven,\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Till, when they come, He will say: ``Did you deny My Ayat whereas you comprehended them not by knowledge, or what was it that you used to do"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the Word will be fulfilled against them, because they have done wrong, and they will be unable to speak.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
See they not that We have made the night for them to rest therein, and the day sight-giving Verily, in this are Ayat for the people who believe.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And (remember) the Day on which the Trumpet (Sur) will be blown -- and all who are in the heavens and all who are on the earth, will be terrified except him whom Allah wills. And all shall come to Him, humbled.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And you will see the mountains and think them solid, but they shall pass away as the passing away of the clouds. The work of Allah, Who perfected all things, verily, He is well-acquainted with what you do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whoever brings a good deed, will have better than its worth; and they will be safe from the terror on that Day.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whoever brings an evil deed, they will be cast down on their faces in the Fire. (And it will be said to them) ``Are you being recompensed anything except what you used to do"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
I have been commanded only to worship the Lord of this city, Who has sanctified it and to Whom belongs everything. And I am commanded to be from among the Muslims.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And that I should recite the Qur'an, then whosoever receives guidance, receives it for the good of himself; and whosoever goes astray, say (to him): ``I am only one of the warners."\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say: ``All the praises and thanks be to Allah. He will show you His Ayat, and you shall recognize them. And your Lord is not unaware of what you do."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta Sin Mim\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are the Ayat of the manifest Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We recite to you some of the news of Musa and Fir`awn in truth, for a people who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Verily, Fir`awn exalted himself in the land and made its people Shiya`a, weakening a group among them: killing their sons, and letting their females live. Verily, he was of the mischief-makers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We wished to do a favor to those who were weak in the land, and to make them rulers and to make them the inheritors,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And to establish them in the land, and We let Fir`awn and Haman and their armies receive from them that which they feared.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
And We inspired the mother of Musa: ``Suckle him (Musa), but when you fear for him, then cast him into the river and fear not, nor grieve. Verily, We shall bring him back to you, and shall make him one of the Messengers."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
Then the household of Fir`awn picked him up, that he might become for them an enemy and a (cause of) grief. Verily, Fir`awn, Haman and their armies were sinners.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
And the wife of Fir`awn said: ``A comfort of the eye for me and for you. Kill him not, perhaps he may be of benefit to us, or we may adopt him as a son." And they perceived not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
And the heart of the mother of Musa became empty. She was very near to disclose his (case), had We not strengthened her heart, so that she might remain as one of the believers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said to his sister: ``Follow him." So she watched him from a far place (secretly), while they perceived not.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had already forbidden foster suckling mothers for him, until she said: ``Shall I direct you to a household who will rear him for you, and look after him in a good manner"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So We restored him to his mother, that her eye might be comforted, and that she might not grieve, and that she might know that the promise of Allah is true. But most of them know not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he reached maturity, and was complete, We bestowed on him Hukm and knowledge. And thus do We reward the doers of good.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city when its people were unaware: and he found there two men fighting, -- one of his party, and the other of his foes. The man of his (own) party asked him for help against his foe, so Musa struck him with his fist and he died. He said: ``This is of Shaytan's doing, verily, he is a plain misleading enemy."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said: ``My Lord! Verily, I have wronged myself, so forgive me." Then He forgave him. Verily, He is the Oft-Forgiving, the Most Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said: ``My Lord! For that with which You have favored me, I will nevermore be a helper of the criminals!"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
So he became afraid, looking about in the city, when behold, the man who had sought his help the day before, called for his help (again). Musa said to him: ``Verily, you are a plain misleader!"\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
Then when he decided to seize the man who was an enemy to both of them, the man said: ``O Musa! Is it your intention to kill me as you killed a man yesterday Your aim is nothing but to become a tyrant in the land, and not to be one of those who do right."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And there came a man running, from the farthest end of the city. He said: ``O Musa! Verily, the chiefs are taking counsel together about you, to kill you, so escape. Truly, I am one of the good advisers to you."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he escaped from there, looking about in a state of fear. He said: ``My Lord! Save me from the people who are wrongdoers!"\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he went towards Madyan, he said: ``It may be that my Lord guides me to the right way."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he arrived at the water of Madyan, he found there a group of men watering, and besides them he found two women who were keeping back (their flocks). He said: ``What is the matter with you" They said: ``We cannot water (our flocks) until the shepherds take (their flocks). And our father is a very old man."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he watered (their flocks) for them, then he turned back to shade, and said: ``My Lord! Truly, I am in need of whatever good that You bestow on me!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then there came to him one of them, walking shyly. She said: ``Verily, my father calls you that he may reward you for having watered (our flocks) for us." So when he came to him and narrated the story, he said: ``Fear you not. You have escaped from the people who are wrongdoers."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
And said one of them (the two women): ``O my father! Hire him! Verily, the best of men for you to hire is the strong, the trustworthy."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said: ``I intend to wed one of these two daughters of mine to you, on condition that you serve me for eight years; but if you complete ten years, it will be (a favor) from you. But I intend not to place you under a difficulty. If Allah wills, you will find me one of the righteous."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
He (Musa) said: ``That (is settled) between me and you: whichever of the two terms I fulfill, there will be no injustice to me, and Allah is Surety over what we say."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
Then, when Musa had fulfilled the term, and was traveling with his family, he saw a fire in the direction of At-Tur. He said to his family: ``Wait, I have seen a fire; perhaps I may bring to you from there some information, or a burning firebrand that you may warm yourselves."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
So when he reached it, he was called from the right side of the valley, in the blessed place, from the tree: ``O Musa! Verily, I am Allah, the Lord of all that exists!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
``And throw your stick!" But when he saw it moving as if it were a snake, he turned in flight, and looked not back. (It was said:) ``O Musa! Draw near, and fear not. Verily, you are of those who are secure."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
``Put your hand into the opening of your garment, it will come forth white without a disease; and draw your hand close to your side to be free from the fear. These are two proofs from your Lord to Fir`awn and his chiefs. Verily, they are the people who are rebellious."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said: ``My Lord! I have killed a man among them, and I fear that they will kill me."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
``And my brother Harun -- he is more eloquent in speech than me, so send him with me as a helper to confirm me. Verily, I fear that they will deny me."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
Allah said: ``We will strengthen your arm through your brother, and give you both power, so they shall not be able to harm you, with Our Ayat; you two as well as those who follow you, will be the victors."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
Then when Musa came to them with Our Clear Ayat, they said: ``This is nothing but invented magic. Never did we hear of this among our fathers of old."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
Musa said: ``My Lord knows best him who came with guidance from Him, and whose will be the happy end in the Hereafter. Verily, the wrongdoers will not be successful."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
Fir`awn said: ``O chiefs! I know not that you have a god other than me. So kindle for me (a fire), O Haman, to bake clay, and set up for me a Sarh in order that I may look at the God of Musa; and verily, I think that he (Musa) is one of the liars."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he and his armies were arrogant in the land, without right, and they thought that they would never return to Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
So, We seized him and his armies, and We threw them all into the sea. So, behold what was the end of the wrongdoers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders inviting to the Fire: and on the Day of Resurrection, they will not be helped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We made a curse to follow them in this world, and on the Day of Resurrection, they will be among disgraced.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And indeed We gave Musa -- after We had destroyed the generations of old -- the Scripture as an enlightenment for mankind, and a guidance and a mercy, that they might remember.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
And you were not on the western side (of the Mount), when We made clear to Musa the commandment, and you were not among the witnesses.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We created generations, and long were the ages that passed over them. And you were not a dweller among the people of Madyan, reciting Our Ayat to them. But it is We Who kept sending (Messengers).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
And you were not at the side of At-Tur when We called. But (you are sent) as a mercy from your Lord, to give warning to a people to whom no warner had come before you, in order that they may remember or receive admonition.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
And if (We had) not (sent you to the people of Makkah) in case a calamity should seize them for what their hands have sent forth, they would have said: ``Our Lord! Why did You not send us a Messenger We would then have followed Your Ayat and would have been among the believers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But when the truth has come to them from Us, they say: ``Why is he not given the like of what was given to Musa Did they not disbelieve in that which was given to Musa of old" They say: ``Two kinds of magic, each helping the other!" And they say: ``Verily, in both we are disbelievers."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say: ``Then bring a Book from Allah, which is a better guide than these two, that I may follow it, if you are truthful."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
But if they answer you not, then know that they only follow their own lusts. And who is more astray than one who follows his own lusts, without guidance from Allah Verily, Allah guides not the people who are wrongdoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
And indeed now We have conveyed the Word to them, in order that they may remember.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Scripture before it, they believe in it.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when it is recited to them, they say: ``We believe in it. Verily, it is the truth from our Lord. Indeed even before it we have been from Muslims."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
These will be given their reward twice over, because they are patient, and repel evil with good, and spend out of what We have provided for them.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear evil vain talk, they withdraw from it and say: ``To us our deeds, and to you your deeds. Peace be to you. We seek not (the way of) the ignorant."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Verily, you guide not whom you like, but Allah guides whom He wills. And He knows best those who are the guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say: ``If we follow the guidance with you, we would be snatched away from our land." Have We not established for them a secure sanctuary, to which are brought fruits of all kinds, a provision from Ourselves, but most of them know not.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a town have We destroyed, which was thankless for its means of livelihood! And those are their dwellings, which have not been inhabited after them except a little. And verily, We have been the heirs.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
And never will your Lord destroy the towns until He sends to their mother town a Messenger reciting to them Our Ayat. And never would We destroy the towns unless the people thereof are wrongdoers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
And whatever you have been given is an enjoyment of the life of the world and its adornment, and that which is with Allah is better and will remain forever. Have you then no sense\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Is he whom We have promised an excellent promise -- which he will find true -- like him whom We have made to enjoy the luxuries of the life of the world, then on the Day of Resurrection, he will be among those brought up\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
And (remember) the Day when He will call to them and say: ``Where are My (so-called) partners whom you used to assert"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those about whom the Word will have been fulfilled will say: ``Our Lord! These are they whom we led astray. We led them astray, as we were astray ourselves. We declare our innocence before You. It was not us they worshipped."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it will be said: ``Call upon your partners," and they will call upon them, but they will give no answer to them, and they will see the torment. If only they had been guided!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
And the Day He will call to them, and say: ``What answer gave you to the Messengers"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
Then the news of a good answer will be obscured to them on that Day, and they will not be able to ask one another.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But as for him who repented, believed, and did righteous deeds, then perhaps he will be among those who are successful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
And your Lord creates whatsoever He wills and chooses, no choice have they. Glorified is Allah, and exalted above all that they associate.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And your Lord knows what their breasts conceal, and what they reveal.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah; La ilaha illa Huwa, His is the praise in the first and in the last, and His is the decision, and to Him shall you be returned.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say: ``Tell me! If Allah made the night continuous for you till the Day of Resurrection, which god besides Allah could bring you light Will you not then hear"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say: ``Tell me! If Allah made the day continuous for you till the Day of Resurrection, which god besides Allah could bring you night wherein you rest Will you not then see"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
It is out of His mercy that He has made for you the night and the day that you may rest therein and that you may seek of His bounty -- and in order that you may be grateful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
And the Day when He will call to them, and will say: ``Where are My (so-called) partners, whom you used to assert"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We shall take out from every nation a witness, and We shall say: ``Bring your proof." Then they shall know that the truth is with Allah, and the lies which they invented will disappear from them.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Verily, Qarun was of Musa's people, but he behaved arrogantly towards them. And We gave him of the treasures, that of which the keys would have been a burden to a body of strong men. Remember when his people said to him: ``Do not exult. Verily, Allah likes not those who exult."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
``But seek, with that which Allah has bestowed on you, the home of the Hereafter, and forget not your portion of lawful enjoyment in this world; and be generous as Allah has been generous to you, and seek not mischief in the land. Verily, Allah likes not the mischief-makers."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said: ``This has been given to me only because of the knowledge I possess." Did he not know that Allah had destroyed before him generations, men who were stronger than him in might and greater in the amount they had collected But the criminals will not be questioned of their sins.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
So, he went forth before his people in his finery. Those who were desirous of the life of the world, said: ``Ah, would that we had the like of what Qarun has been given! Verily, he is the owner of a great fortune."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those who had been given knowledge said: ``Woe to you! The reward of Allah is better for those who believe and do righteous deeds, and this none shall attain except the patient."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
So, We caused the earth to swallow him and his dwelling place. Then he had no group to help him against Allah, nor was he one of those who could save themselves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who desired his position the day before, began to say: ``Know you not that it is Allah Who expands the provision or restricts it to whomsoever He pleases of His servants. Had it not been that Allah was Gracious to us, He could have caused the earth to swallow us up! Know you not that the disbelievers will never be successful."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That is the home of the Hereafter, We shall assign to those who do not want to exalt themselves in the land nor cause corruption. And the good end is for those who have Taqwa.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whosoever brings good, he shall have the better thereof; and whosoever brings evil, then those who do evil deeds will only be requited for what they used to do.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Verily, He Who has given you the Qur'an, will surely bring you back to the return. Say: ``My Lord is Aware of him who brings guidance, and of him who is in manifest error."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
And you were not expecting that the Book would be sent down to you, but it is a mercy from your Lord. So never be a supporter of the disbelievers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And let them not turn you away from the Ayat of Allah after they have been sent down to you, and invite to your Lord and be not of idolators.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And invoke not any other god along with Allah, La ilaha illa Huwa. Everything will perish save His Face. His is the decision, and to Him you shall be returned.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do people think that they will be left alone because they say: ``We believe," and will not be tested.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
And We indeed tested those who were before them so that Allah will indeed know those who are true, and He will know those who are liars.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or think those who do evil deeds that they can outstrip Us Evil is that which they judge!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoever hopes in meeting with Allah, then Allah's term is surely coming, and He is the All-Hearer, the All-Knower.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And whosoever strives, he strives only for himself. Verily, Allah stands not in need of any of the creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
Those who believe, and do righteous good deeds, surely, We shall expiate from them their evil deeds and We shall indeed reward them according to the best of that which they used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
And We have enjoined on man to be dutiful to his parents; but if they strive to make you associate with Me, which you have no knowledge of, then obey them not. Unto Me is your return and I shall tell you what you used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And for those who believe and do righteous deeds, surely, We shall admit them among the righteous.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
Of mankind are some who say: ``We believe in Allah." But if they are made to suffer for Allah, they consider the trial of mankind as Allah's punishment; and if victory comes from your Lord, they will say: ``Verily, we were with you." Is not Allah Best Aware of what is in the breasts of the creatures\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
And indeed Allah knows those who believe, and verily, He knows the hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
And those who disbelieve say to those who believe: ``Follow our way and let us bear your sins." Never will they bear anything of their sins. Surely, they are liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
And verily, they shall bear their own loads, and other loads besides their own; and verily, they shall be questioned on the Day of Resurrection about that which they used to fabricate.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
And indeed We sent Nuh to his people, and he stayed among them a thousand years less fifty years; so the Deluge overtook them while they were wrongdoers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
Then We saved him and the Companions of the Boat, and made it an Ayah for all people.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And (remember) Ibrahim when he said to his people: ``Worship Allah, and have Taqwa of Him, that is better for you if you know."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
You worship besides Allah only idols, and you only invent falsehood. Verily, those whom you worship besides Allah have no power to give you provision, so seek from Allah your provision, and worship Him, and be grateful to Him. To Him you will be brought back.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
And if you deny, then nations before you have denied. And the duty of the Messenger is only to convey plainly."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
See they not how Allah originates the creation, then repeats it. Verily, that is easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say: ``Travel in the land and see how He originated the creation, and then Allah will bring forth the creation of the Hereafter. Verily, Allah is able to do all things."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punishes whom He wills, and shows mercy to whom He wills; and to Him you will be returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
And you cannot escape in the earth or in the heaven. And besides Allah you have neither any protector nor any helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
And those who disbelieve in the Ayat of Allah and meeting with Him, such have no hope of My mercy: and for such there is a painful torment.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
So nothing was the answer of people except that they said: ``Kill him or burn him." Then Allah saved him from the fire. Verily, in this are indeed signs for a people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And (Ibrahim) said: ``You have taken idols instead of Allah. The love between you is only in the life of this world, but on the Day of Resurrection, you shall deny each other, and curse each other, and your abode will be the Fire, and you shall have no helper."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
So, Lut believed in him. He said: ``I will emigrate for the sake of my Lord. Verily, He is the All-Mighty, the All-Wise."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We bestowed on him, Ishaq and Ya`qub, and We ordained among his offspring prophethood and the Book, and We granted him his reward in this world; and verily, in the Hereafter he is indeed among the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And (remember) Lut, when he said to his people: ``You commit immoral sins which none has preceded you in (committing) it in all creatures."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
``Verily, you practice sodomy with men, and rob the wayfarer! And practice Al-Munkar in your meetings." But his people gave no answer except that they said: ``Bring Allah's torment upon us if you are one of the truthful."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said: ``My Lord! Give me victory over the people who are corrupt."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our messengers came to Ibrahim with the glad tidings they said: ``Verily, we are going to destroy the people of this town; truly, its people have been wrongdoers."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
Ibrahim said: ``But there is Lut in it." They said: ``We know better who is there. We will verily, save him and his family - except his wife, she will be of those who remain behind."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our messengers came to Lut, he was grieved because of them, and felt straitened on their account. They said: ``Have no fear, and do not grieve! Truly, we shall save you and your family except your wife: she will be of those who remain behind."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
``Verily, we are about to bring down on the people of this town a great torment from the sky, because they have been rebellious."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And indeed We have left thereof an evident Ayah for a folk who understand.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And to Madyan, We sent their brother Shu`ayb. He said: ``O my people! Worship Allah and hope for the last Day, and commit no mischief on the earth as mischief-makers."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
And they denied him; so the earthquake seized them, and they lay, prostrate in their dwellings.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And `Ad and Thamud! And indeed (their destruction) is clearly apparent to you from their (ruined) dwellings. Shaytan made their deeds fair seeming to them, and turned them away from the path, though they were intelligent.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And Qarun, Fir`awn, and Haman. And indeed Musa came to them with clear Ayat, but they were arrogant in the land, yet they could not outstrip Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
So, We punished each for his sins, of them were some on whom We sent a Hasib, and of them were some who were overtaken by As-Sayhah, and of them were some whom We caused the earth to swallow, and of them were some whom We drowned. It was not Allah Who wronged them, but they wronged themselves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The parable of those who seek protectors from other than Allah is that of a spider who builds a house; but indeed, the weakest of houses is the spider's house -- if they but knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Verily, Allah knows what things they invoke instead of Him. He is the All-Mighty, the All-Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And these are the examples We give for mankind; but none will understand them except those who have knowledge (of Allah).\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah created the heavens and the earth with truth. Verily, therein is surely a sign for those who believe.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite what has been revealed to you of the Book, and perform the Salah. Verily, the Salah prevents from Al-Fahsha' (immoral sins) and Al-Munkar (evil deeds) and the remembering (praising) of Allah is greater indeed. And Allah knows what you do.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And argue not with the People of the Scripture, except with that which is better -- except with such of them as do wrong; and say (to them): ``We believe in that which has been revealed to us and revealed to you; our God and your God is One, and to Him we have submitted."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
And thus We have sent down the Book to you, and those whom We gave the Scripture believe therein as also do some of these and none but the disbelievers reject Our Ayat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
Neither did you read any book before it nor did you write any book with your right hand. In that case, indeed, the followers of falsehood might have doubted.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
Nay, but it is clear Ayat, (preserved) in the breasts of those who have been given knowledge. And none but the wrongdoers deny Our Ayat.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
And they say: ``Why are not signs sent down to him from his Lord" Say: ``The signs are only with Allah, and I am only a plain warner."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
Is it not sufficient for them that We have sent down to you the Book which is recited to them Verily, herein is mercy and a reminder for a people who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say: ``Sufficient is Allah for a witness between me and you. He knows what is in the heavens and on the earth." And those who believe in falsehood, and disbelieve in Allah, it is they who are the losers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they ask you to hasten on the torment, and had it not been for a term appointed, the torment would certainly have come to them. And surely, it will come upon them suddenly while they perceive not!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They ask you to hasten on the torment. And verily, Hell, of a surety, will encompass the disbelievers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day when the torment shall cover them from above them and from beneath their feet, and it will be said: ``Taste what you used to do."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My servants who believe! Certainly, spacious is My earth. Therefore worship Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Everyone shall taste death. Then unto Us you shall be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
And those who believe and do righteous good deeds, to them We shall surely give lofty dwellings in Paradise, beneath which rivers flow, to live therein forever. Excellent is the reward for the workers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Those who are patient, and put their trust in their Lord.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
And so many a moving creature carries not its own provision! Allah provides for it and for you. And He is the All-Hearer, the All-Knower.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
And if you were to ask them: ``Who has created the heavens and the earth and subjected the sun and the moon" They will surely reply: ``Allah." How then are they deviating\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah expands the provision for whom He wills of His servants, and straitens it for whom (He wills). Verily, Allah is the All-Knower of everything.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And if you were to ask them: ``Who sends down water from the sky, and gives life therewith to the earth after its death" They will surely reply: ``Allah." Say: ``All the praises and thanks be to Allah!" Nay, most of them have no sense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
And this life of the world is only an amusement and a play! Verily, the home of the Hereafter -- that is the life indeed, if they but knew.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
And when they embark on a ship, they invoke Allah, making their faith pure for Him only, but when He brings them safely to land, behold, they give a share of their worship to others.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
So that they become ingrate for that which We have given them, and that they take their enjoyment, but they will come to know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Have they not seen that We have made a secure sanctuary, while men are being snatched away from all around them Then do they believe in falsehood, and deny the graces of Allah\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who does more wrong than he who invents a lie against Allah or denies the truth, when it comes to him Is there not a dwelling in Hell for the disbelievers\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
As for those who strive hard for Us, We will surely guide them to Our paths. And verily, Allah is with the doers of good.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Romans have been defeated.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In the nearest land, and they, after their defeat, will be victorious.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
In Bid`i years. The decision of the matter, before and after is only with Allah. And on that day, the believers will rejoice\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
With the help of Allah. He helps whom He wills, and He is the All-Mighty, the Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
A promise from Allah, and Allah fails not in His promise, but most men know not.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know only the outer appearance of the life of the world, and they are heedless of the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
(Do they not reflect upon themselves) Thinking and pondering how Allah created various things in the upper and lower realms and in the space between, realizing that this was not created in jest or in vain, but in truth, and that it will continue until an appointed time, the Day of Resurrection\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Have they not traveled through the earth and observed how was the end of those before them? They were greater than them in power, and they plowed the earth and built it up more than they have built it up, and their messengers came to them with clear evidences. And Allah would not ever have wronged them, but they were wronging themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then evil was the end of those who did evil, because they denied the Ayat of Allah and made a mockery of them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah originates the creation, then He will repeat it, then to Him you will be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
And on the Day when the Hour will be established, the criminals will be plunged into destruction with despair.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
No intercessors will they have from those whom they made equal with Allah, and they will reject and deny their partners.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
And on the Day when the Hour will be established -- that Day shall they be separated.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
Then as for those who believed and did righteous good deeds, such shall be honored and made to enjoy a luxurious life in a Garden of Delight.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
And as for those who disbelieved and denied Our Ayat, and the meeting of the Hereafter, such shall be brought forth to the torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So glorify Allah, when you enter the evening, and when you enter the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
And His is all the praise in the heavens and the earth; and in `Ashiyya and when Tuzhirun.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings out the living from the dead, and brings out the dead from the living. And He revives the earth after its death. And thus shall you be brought out.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And among His signs is this that He created you from dust, and then -- behold you are human beings scattered!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And among His signs is this that He created for you wives from among yourselves, that you may find repose in them, and He has put between you affection and mercy. Verily, in that are indeed signs for a people who reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And among His signs is the creation of the heavens and the earth, and the difference of your languages and colors. Verily, in that are indeed signs for men of sound knowledge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And among His signs is your sleep by night and by day, and your seeking His bounty. Verily, in that are indeed signs for a people who listen.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And among His signs is that He shows you the lightning, for fear and for hope, and He sends down water from the sky, and therewith revives the earth after its death. Verily, in that are indeed signs for a people who understand.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And among His signs is that the heaven and the earth stand by His command. Then afterwards when He will call you by a single call, behold, you will come out from the earth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
To Him belongs whatever is in the heavens and the earth. All are obedient to Him.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
And He it is Who originates the creation, then He will repeat it; and this is easier for Him. His is the highest description in the heavens and in the earth. And He is the All-Mighty, the All-Wise.) Allah says:\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He sets forth for you a parable from yourselves: Do you have partners among those whom your right hands possess to share as equals in the wealth We have bestowed on you, whom you fear as you fear each other Thus do We explain the signs in detail to a people who have sense.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
Nay, but those who do wrong follow their own lusts without knowledge. Then who will guide him whom Allah has sent astray And for such there will be no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So, set you your face towards the religion as a Hanif. Allah's Fitrah with which He has created mankind. No change let there be in Allah's Khalq, that is the straight religion, but most men know not.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
(And remain always) turning in repentance to Him and have Taqwa of Him; and perform the Salah and be not of idolators.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
Of those who split up their religion, and became sects, each sect rejoicing in that which is with it.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
And when harm touches men, they cry sincerely only to their Lord, turning to Him in repentance; but when He gives them a taste of His mercy, behold, a party of them associates partners in worship with their Lord.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
So as to be ungrateful for the graces which We have bestowed on them. Then enjoy; but you will come to know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We revealed to them an authority, which speaks of that which they have been associating with Him\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We cause mankind to taste of mercy, they rejoice therein; but when some evil afflicts them because of what their hands have sent forth, behold, they are in despair!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Do they not see that Allah expands the provision for whom He wills and straitens (it for whom He wills). Verily, in that are indeed signs for a people who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So, give to the kindred his due, and to Al-Miskin and to the wayfarer. That is best for those who seek Allah's Face; and it is they who will be successful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
And that which you give in Riba in order that it may increase from other people's property, has no increase with Allah; but that which you give in Zakah seeking Allah's Face, then those they shall have manifold increase.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
Allah is He Who created you, then provided food for you, then will cause you to die, then He will give you life. Is there any of your partners that do anything of that Glory be to Him! And Exalted be He above all that they associate.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Evil has appeared in Al-Barr and Al-Bahr because of what the hands of men have earned, that He may make them taste a part of that which they have done, in order that they may return.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say: ``Travel in the land and see what was the end of those before (you)! Most of them were idolators."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So, set you your face to the straight and right religion, before there comes from Allah a Day which none can avert. On that Day men shall be divided.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whosoever disbelieves will suffer from his disbelief, and whosoever does righteous good deeds, then such will prepare a good place for themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
That He may reward those who believe and do righteous good deeds, out of His bounty. Verily, He likes not the disbelievers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And among His signs is this that He sends the winds as glad tidings, giving you a taste of His mercy, and that the ships may sail at His command, and that you may seek of His bounty, in order that you may be thankful.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
And indeed We did send Messengers before you to their own peoples. They came to them with clear proofs, then, We took vengeance on those who committed crimes; and it was incumbent upon Us to help the believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
Allah is He Who sends the winds, so that they raise clouds and spread them along the sky as He wills, and then break them into fragments until you see rain drops come forth from their midst! Then when He has made them fall on whom of His servants as He wills, lo, they rejoice!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
And verily, before that -- just before it was sent down upon them -- they were in despair!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
Look then at the effects of Allah's mercy, how He revives the earth after its death. Verily, that shall indeed raise the dead, and He is able to do all things.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
And if We send a wind, and they see it turn yellow -- behold, they then would become unthankful (disbelievers).\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
So verily, you cannot make the dead to hear, nor can you make the deaf to hear the call, when they show their backs and turn away.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
And you cannot guide the blind from their straying; you can make to hear only those who believe in Our Ayat, and have submitted (to Allah in Islam).\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
Allah is He Who created you in weakness, then gave you strength after weakness, then after strength gave (you) weakness and grey hair. He creates what He wills. And He is the All-Knowing, the All-Powerful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
And on the Day that the Hour will be established, the criminals will swear that they stayed not but an hour -- thus were they ever deluded.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
And those who have been bestowed with knowledge and Faith will say: ``Indeed you have stayed according to the decree of Allah, until the Day of Resurrection; so this is the Day of Resurrection, but you knew not."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So, on that Day no excuse of theirs will avail those who did wrong, nor will they be allowed to return to seek (Allah's) pleasure.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
And indeed We have set forth for mankind, in this Qur'an every kind of parable. But if you bring to them any sign or proof, the disbelievers are sure to say (to the believers): ``You follow nothing but falsehood and magic."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Thus does Allah seal up the hearts of those who know not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So be patient. Verily, the promise of Allah is true; and let not those who have no certainty of faith discourage you (from conveying Allah's Message).\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are Ayat of the Wise Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
A guide and a mercy for the Muhsinin.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Those who perform the Salah and give Zakah and they have faith in the Hereafter with certainty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
Such are on guidance from their Lord, and such are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
And of mankind is he who purchases idle talk (Lahw Al-Hadith) to mislead from the path of Allah without knowledge, and takes it by way of mockery. For such there will be a humiliating torment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when Our Ayat are recited to such a one, he turns away in pride, as if he heard them not -- as if there were deafness in his ear. So announce to him a painful torment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Verily, those who believe and do righteous good deeds, for them are Gardens of Delight.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
To abide therein. It is a promise of Allah in truth. And He is the All-Mighty, the All-Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He has created the heavens without any pillars that you see, and has set on the earth firm mountains lest it should shake with you. And He has scattered therein moving creatures of all kinds. And We send down water from the sky, and We cause (plants) of every goodly kind to grow therein in pairs,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
This is the creation of Allah. So, show Me that which those besides Him have created. Nay, the wrongdoers are in plain error.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
And indeed We bestowed upon Luqman Al-Hikmah saying: ``Give thanks to Allah." And whoever gives thanks, he gives thanks for (the good of) himself. And whoever is unthankful, then verily, Allah is All-Rich, Worthy of all praise.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And when Luqman said to his son when he was advising him: ``O my son! Join not in worship others with Allah. Verily, joining others in worship with Allah is a great Zulm (wrong) indeed."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We have enjoined on man (to be dutiful and good) to his parents. His mother bore him in weakness and hardship upon weakness and hardship, and his weaning is in two years -- give thanks to Me and to your parents. Unto Me is the final destination.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they strive with you to make you join in worship with Me others that of which you have no knowledge, then obey them not; but behave with them in the world kindly, and follow the path of him who turns to Me in repentance and in obedience. Then to Me will be your return, and I shall tell you what you used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
``O my son! If it be (anything) equal to the weight of a grain of mustard seed, and though it be in a rock, or in the heavens or on the earth, Allah will bring it forth. Verily, Allah is Subtle, Well-Aware."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
``O my son! Perform the Salah, enjoin the good, and forbid the evil, and bear with patience whatever befalls you. Verily, these are some of the important commandments."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
``And turn not your face away from men with pride, nor walk in insolence through the earth. Verily, Allah likes not any arrogant boaster."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
``And be moderate in your walking, and lower your voice. Verily, the harshest of all voices is the braying of the asses."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
See you not that Allah has subjected for you whatsoever is in the heavens and whatsoever is on the earth, and has completed and perfected His graces upon you, apparent and hidden Yet of mankind is he who disputes about Allah without knowledge or guidance or a Book giving light!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And when it is said to them: ``Follow that which Allah has sent down," they say: ``Nay, we shall follow that which we found our fathers (following)." Even if Shaytan invites them to the torment of the Fire\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
And whosoever submits his face (himself) to Allah, while he is a Muhsin, then he has grasped the most trustworthy handhold. And to Allah return all matters for decision.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whoever disbelieves, let not his disbelief grieve you. To Us is their return, and We shall inform them what they have done. Verily, Allah is the All-Knower of what is in the breasts.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We let them enjoy for a little while, then in the end We shall oblige them to (enter) a great torment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
And if you ask them: ``Who has created the heavens and the earth," they will certainly say: ``Allah." Say: ``All the praises and thanks be to Allah!" But most of them know not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To Allah belongs whatsoever is in the heavens and the earth. Verily, Allah, He is Al-Ghani, Worthy of all praise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if all the trees on the earth were pens and the sea, with seven seas behind it to add to it, yet the Words of Allah would not be exhausted. Verily, Allah is All-Mighty, All-Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
The creation of you all and the resurrection of you all are only as a single person. Verily, Allah is All-Hearer, All-Seer.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
See you not that Allah merges the night into the day, and merges the day into the night, and has subjected the sun and the moon, each running its course for a term appointed; and that Allah is All-Aware of what you do.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because Allah, He is the Truth, and that which they invoke besides Him is falsehood; and that Allah, He is the Most High, the Most Great.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
See you not that the ships sail through the sea by Allah's grace that He may show you of His signs Verily, in this are signs for every patient, grateful (person).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And when waves cover them like shades, they invoke Allah, making their invocations for Him only. But when He brings them safe to land, there are among them those that stop in between. And Our Ayat are not denied except by every Khattar Kafur.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O mankind! Have Taqwa of your Lord, and fear a Day when no father can avail aught for his son, nor a son avail aught for his father. Verily, the promise of Allah is true, let not then this present life deceive you, nor let the chief deceiver deceive you about Allah.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Verily, Allah, with Him is the knowledge of the Hour, He sends down the rain, and knows that which is in the wombs. No person knows what he will earn tomorrow, and no person knows in what land he will die. Verily, Allah is All-Knower, All-Aware.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif Lam Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
The revelation of the Book in which there is no doubt, is from the Lord of all that exists.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or say they: ``He has fabricated it" Nay, it is the truth from your Lord, so that you may warn a people to whom no warner has come before you, in order that they may be guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
Allah it is He Who has created the heavens and the earth, and all that is between them in six Days. Then He Istawa over the Throne. You have none, besides Him, as a protector or an intercessor. Will you not then remember\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He directs the command from the heavens to the earth; then it will go up to Him, in one Day, the space whereof is a thousand years of your reckoning.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
That is He, the All-Knower of the unseen and the seen, the All-Mighty, the Most Merciful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
Who made everything He has created good and He began the creation of man from clay.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then He made his offspring from semen of despised water.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He fashioned him in due proportion, and breathed into him the soul; and He gave you hearing, sight and the sense of deduction. Little is the thanks you give!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say: ``When we are lost in the earth, shall we indeed be created anew" Nay, but they deny the meeting with their Lord!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say: ``The angel of death, who is set over you, will take your souls. Then you shall be brought to your Lord."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
And if you only could see when the criminals shall hang their heads before their Lord (saying): ``Our Lord! We have now seen and heard, so send us back that we will do righteous good deeds. Verily, we now believe with certainty."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
And if We had willed, surely We would have given every person his guidance, but the Word from Me took effect, that I will fill Hell with Jinn and mankind together.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
Then taste because of your forgetting the meeting of this Day of yours. Surely, We too will forget you, so taste you the abiding torment for what you used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our Ayat, who, when they are reminded of them, fall down prostrate, and glorify the praises of their Lord, and they are not proud.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
Their sides forsake their beds, to invoke their Lord in fear and hope, and they spend out of what We have bestowed on them.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
No person knows what is kept hidden for them of delights of eyes as a reward for what they used to do.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Is then he who is a believer like him who is rebellious Not equal are they.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believe and do righteous good deeds, for them are Gardens of Abode as an entertainment for what they used to do.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
And as for those who rebel, their abode will be the Fire, every time they wish to get away therefrom, they will be put back thereto, and it will be said to them: ``Taste you the torment of the Fire which you used to deny."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And verily, We will make them taste of the near lighter torment prior to the greater torment, in order that they may return.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who does more wrong than he who is reminded of the Ayat of his Lord, then turns aside therefrom Verily, We shall exact retribution from the criminals.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
And indeed We gave Musa the Scripture. So, be not you in doubt of meeting him. And We made it a guide to the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We made from among them, leaders, giving guidance under Our command, when they were patient and used to believe with certainty in Our Ayat.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Verily, your Lord will judge between them on the Day of Resurrection, concerning that wherein they used to differ.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Is it not a guidance for them: how many generations We have destroyed before them in whose dwellings they do walk about Verily, therein indeed are signs. Would they not then listen\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Have they not seen how We drive water to the dry land that has no vegetation, and therewith bring forth crops providing food for their cattle and themselves Will they not then see\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
They say: ``When will this Fath be, if you are telling the truth"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say: ``On the Day of Al-Fath, no profit will it be to those who disbelieve if they (then) believe! Nor will they be granted a respite."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So turn aside from them and await, verily, they (too) are awaiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet! Have Taqwa of Allah, and obey not the disbelievers and the hypocrites. Verily, Allah is Ever All-Knower, All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow that which is revealed to you from your Lord. Verily, Allah is Well-Acquainted with what you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And put your trust in Allah, and sufficient is Allah as a Trustee.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has not made for any man two hearts inside his body. Neither has He made your wives whom you declare to be like your mothers' backs, your real mothers nor has He made your adopted sons your real sons. That is but your saying with your mouths. But Allah says the truth, and He guides to the way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them by their fathers, that is more just with Allah. But if you know not their father's, your brothers in faith and Mawalikum (your freed servants). And there is no sin on you concerning that in which you made a mistake, except in regard to what your hearts deliberately intend. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is closer to the believers than themselves, and his wives are their mothers. And blood relations among each other have closer personal ties in the decree of Allah than the believers and the Muhajirin, except that you do kindness to those brothers. This has been written in the Book.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And when We took from the Prophets their covenant, and from you, and from Nuh, Ibrahim, Musa, and `Isa son of Maryam. We took from them a strong covenant.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That He may ask the truthful about their truth. And He has prepared for the disbelievers a painful torment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O you who believe! Remember Allah's favor to you, when there came against you hosts, and We sent against them a wind and forces that you saw not. And Allah is Ever All-Seer of what you do.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
When they came upon you from above you and from below you, and when the eyes grew wild and the hearts reached to the throats, and you were harboring doubts about Allah.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
There, the believers were tried and shaken with a mighty shaking.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And when the hypocrites and those in whose hearts is a disease said: ``Allah and His Messenger promised us nothing but delusion!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a party of them said: ``O people of Yathrib! There is no postition for you. Therefore go back!" And a band of them ask for permission of the Prophet saying: ``Truly, our homes lie open." And they lay not open. They but wished to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if the enemy had entered from all sides, and they had been exhorted to Al-Fitnah, they would surely have committed it and would have hesitated thereupon but little.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And indeed they had already made a covenant with Allah not to turn their backs, and a covenant with Allah must be answered for.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say: ``Flight will not avail you if you flee from death or killing and then you will enjoy no more than a little while!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say: ``Who is he who can protect you from Allah if He intends to harm you, or intends mercy on you" And they will not find, besides Allah, for themselves any protector or any helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Allah already knows those among you who keep back (men) from fighting (in Allah's cause), and those who say to their brethren, ``Come here towards us," while they come not to the battle except a little,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Being miserly towards you. Then when fear comes, you will see them looking to you, their eyes revolving like one over whom hovers death; but when the fear departs, they will smite you with sharp tongues, miserly towards good. Such have not believed. Therefore, Allah makes their deeds fruitless and that is ever easy for Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think that the Confederates have not yet withdrawn; and if the Confederates should come, they would wish they were in the deserts among the bedouins, seeking news about you; and if they were to be among you, they would not fight but little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
Indeed in the Messenger of Allah you have a good example to follow for him who hopes in Allah and the Last Day, and remembers Allah much.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the believers saw the Confederates, they said: ``This is what Allah and His Messenger had promised us; and Allah and His Messenger had spoken the truth." And it only added to their faith and to their submissiveness.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the believers are men who have been true to their covenant with Allah; of them some have fulfilled their Nahbah; and some of them are still waiting, but they have never changed in the least.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
That Allah may reward the men of truth for their truth, and punish the hypocrites, if He wills, or accept their repentance by turning to them. Verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah drove back those who disbelieved in their rage: they gained no advantage. Allah sufficed for the believers in the fighting. And Allah is Ever All-Strong, All-Mighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And those of the People of the Scripture who backed them, Allah brought them down from their forts and cast terror into their hearts; a group you killed, and a group you made captives.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He caused you to inherit their lands, and their houses, and their riches, and a land which you had not trodden. And Allah is able to do all things.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet! Say to your wives: ``If you desire the life of this world, and its glitter, then come! I will make a provision for you and set you free in a handsome manner."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
``But if you desire Allah and His Messenger, and the Home of the Hereafter, then verily, Allah has prepared for the doers of good among you an enormous reward."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O wives of the Prophet! Whoever of you commits an open Fahishah, the torment for her will be doubled, and that is ever easy for Allah.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
And whosoever of you is obedient to Allah and His Messenger, and does righteous good deeds, We shall give her, her reward twice over, and We have prepared for her a noble provision.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O wives of the Prophet! You are not like any other women. If you keep you have Taqwa, then be not soft in speech, lest he in whose heart is a disease should be moved with desire, but speak in an honorable manner.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And stay in your houses, and do not Tabarruj yourselves like the Tabarruj of the times of ignorance, and perform the Salah, and give Zakah and obey Allah and His Messenger. Allah wishes only to remove the Ar-Rijs from you, O members of the family, and to purify you with a thorough purification.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember, that which is recited in your houses of the Ayat of Allah and Al-Hikmah. Verily, Allah is Ever Most Courteous, Well-Acquainted with all things.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Verily, the Muslims: men and women, the believers: men and women, the Qanit: men and the women, the men and women who are truthful, the men and the women who are patient, the Khashi`: men and the women, the men and the women who give Sadaqat, the men and the women who fast, the men and the women who guard their chastity and the men and the women who remember Allah much with their hearts and tongues, Allah has prepared for them forgiveness and a great reward.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not for a believer, man or woman, when Allah and His Messenger have decreed a matter that they should have any option in their decision. And whoever disobeys Allah and His Messenger, he has indeed strayed into a plain error.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And (remember) when you said to him on whom Allah has bestowed grace and you have done a favor: ``Keep your wife to yourself, and have Taqwa of Allah." But you did hide in yourself that which Allah will make manifest, you did fear the people whereas Allah had a better right that you should fear Him. So, when Zayd had completed his aim with her, We gave her to you in marriage, so that there may be no difficulty to the believers in respect of the wives of their adopted sons when the latter have no desire to keep them. And Allah's command must be fulfilled.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is no blame on the Prophet in that which Allah has made legal for him. That has been Allah's way with those who have passed away of old. And the command of Allah is a decree determined.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
Those who convey the Message of Allah and fear Him, and fear none save Allah. And sufficient is Allah as a Reckoner.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of any of your men, but he is the Messenger of Allah and the last of the Prophets. And Allah is Ever All-Aware of everything.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O you who believe! Remember Allah with much remembrance.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And glorify His praises morning and Asila.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
He it is Who sends Salah on you, and His angels too, that He may bring you out from darkness into light. And He is Ever Most Merciful to the believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their greeting on the Day they shall meet Him will be ``Salam (Peace!)" And He has prepared for them a generous reward.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet! Verily, We have sent you as witness, and a bearer of glad tidings, and a warner,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And as one who invites to Allah by His leave, and as a lamp spreading light.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And announce to the believers the glad tidings, that they will have from Allah a great bounty.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And obey not the disbelievers and the hypocrites, and harm them not. And put your trust in Allah, and sufficient is Allah as a Trustee.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O you who believe! When you marry believing women, and then divorce them before you have sexual intercourse with them, no `Iddah have you to count in respect of them. So, give them a present, and set them free in a handsome manner.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet! Verily, We have made lawful to you your wives, to whom you have paid their due (dowery), and those (slaves) whom your right hand possesses -- whom Allah has given to you, and the daughters of your paternal uncles and the daughters of your paternal aunts and the daughters of your maternal uncles and the daughters of your maternal aunts who migrated with you, and a believing woman if she offers herself to the Prophet, and the Prophet wishes to marry her -- a privilege for you only, not for the (rest of) the believers. Indeed We know what We have enjoined upon them about their wives and those (slaves) whom their right hands possess, in order that there should be no difficulty on you. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
You can postpone whom you will of them, and you may receive whom you will. And whomsoever you desire of those whom you have set aside, it is no sin on you: that is better that they may be comforted and not grieved, and may all be pleased with what you give them. Allah knows what is in your hearts. And Allah is Ever All-Knowing, Most Forbearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
It is not lawful for you (to marry other) women after this, nor to change them for other wives even though their beauty attracts you, except those whom your right hand possesses. And Allah is Ever a Watcher over all things.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O you who believe! Enter not the Prophet's houses, unless permission is given to you for a meal, (and then) not (so early as) to wait for its preparation. But when you are invited, enter, and when you have taken your meal, disperse without sitting for a talk. Verily, such (behavior) annoys the Prophet, and he is shy of (asking) you (to go); but Allah is not shy of (telling you) the truth. And when you ask (his wives) for anything you want, ask them from behind a screen, that is purer for your hearts and for their hearts. And it is not (right) for you that you should annoy Allah's Messenger, nor that you should ever marry his wives after him (his death). Verily, with Allah that shall be an enormity.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you reveal anything or conceal it, verily, Allah is Ever All-Knower of everything.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
It is no sin on them before their fathers, or their sons, or their brothers, or their brother's sons, or the sons of their sisters, or their own (believing) women, or their (female) slaves. And (O ladies) have Taqwa of Allah. Verily, Allah is Ever All-Witness over everything.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Allah sends His Salah on the Prophet, and also His angels (do so). O you who believe! Send your Salah on him, and greet him with Taslim.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Verily, those who annoy Allah and His Messenger, Allah has cursed them in this world and in the Hereafter, and has prepared for them a humiliating torment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who annoy believing men and women undeservedly, they bear the crime of slander and plain sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet! Tell your wives and your daughters and the women of the believers to draw their Jalabib over their bodies. That will be better that they should be known so as not to be annoyed. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites and those in whose hearts is a disease, and those who spread false news among the people in Al-Madinah stop not, We shall certainly let you overpower them, then they will not be able to stay in it as your neighbors but a little while.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
Accursed, they shall be seized wherever found, and killed with a (terrible) slaughter.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
That was the way of Allah in the case of those who passed away of old, and you will not find any change in the way of Allah.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
People ask you concerning the Hour, say: ``The knowledge of it is with Allah only. What do you know It may be that the Hour is near!"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Verily, Allah has cursed the disbelievers, and has prepared for them a flaming Fire.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Wherein they will abide forever, and they will find neither a a protector nor a helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
On the Day when their faces will be turned over in the Fire, they will say: ``Oh, would that we had obeyed Allah and obeyed the Messenger."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they will say: ``Our Lord! Verily, we obeyed our chiefs and our great ones, and they misled us from the way."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
``Our Lord! Give them double torment and curse them with a mighty curse!"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O you who believe! Be not like those who annoyed Musa, but Allah cleared him of that which they alleged, and he was honorable before Allah.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O you who believe! Have Taqwa of Allah and speak (always) the truth.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He will direct you to do righteous good deeds and will forgive you your sins. And whosoever obeys Allah and His Messenger, he has indeed achieved a great victory.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
Truly, We did offer the Amanah to the heavens and the earth, and the mountains, but they declined to bear it and were afraid of it. But man bore it. Verily, he was unjust and ignorant.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
So that Allah will punish the hypocrites, men and women, and the men and women who are idolators. And Allah will pardon the believers, men and women. And Allah is Ever Oft-Forgiving, Most Merciful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen All praise is due to Allah, to Whom belongs all that is in the heavens and all that is on the earth. His is all praise in the Hereafter, and He is the All-Wise, the All-Aware.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows that which goes into the earth and that which comes forth from it, and that which descends from the heaven and that which ascends to it. And He is the Most Merciful, the Oft-Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
Those who disbelieve say: ``The Hour will not come to us." Say: ``Yes, by my Lord, the All-Knower of the Unseen, it will come to you; not even the weight of a speck of dust or less than that or greater escapes His knowledge in the heavens or in the earth but it is in a Clear Book."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may recompense those who believe and do righteous good deeds. Those, theirs is forgiveness and generous provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
But those who strive against Our Ayat to frustrate them -- those, for them will be a severe painful torment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
And those who have been given knowledge see that what is revealed to you from your Lord is the truth, and that it guides to the path of the Exalted in might, Owner of all praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
Those who disbelieve say: ``Shall we direct you to a man who will tell you (that) when you have become fully disintegrated into dust with full dispersion, then you will be created (again) anew"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Has he invented a lie against Allah, or is there a madness in him Nay, but those who disbelieve in the Hereafter are (themselves) in a torment, and in far error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
See they not what is before them and what is behind them, of the heaven and the earth If We will, We shall sink the earth with them, or cause a piece of the heaven to fall upon them. Verily, in this is a sign for every servant who turns (to Allah) in repentance.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And indeed We bestowed grace on Dawud from Us (saying): ``O you mountains! Glorify with him! And you birds (also)! And We made the iron soft for him."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
Saying: ``Make you perfect coats of mail, and balance well the rings of chain armor [Sard], and work you (men) righteousness. Truly, I am All-Seer of what you do."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And to Sulayman (We subjected) the wind, its morning was a month's (journey), and its afternoon was a month's (journey). And We caused a fount of Qitr to flow for him, and there were Jinn that worked in front of him, by the leave of his Lord. And whosoever of them turned aside from Our command, We shall cause him to taste of the torment of the blazing Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They worked for him as he desired on Maharib, Tamathil, large basins like Jawab and Qudur Rasiyat. ``Work you, O family of Dawud, with thanks!" But few of My servants are grateful.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
Then when We decreed death for him, nothing informed them (Jinn) of his death except a little worm of the earth which kept (slowly) gnawing away at his stick. So when he fell down, the Jinn saw clearly that if they had known the Unseen, they would not have stayed in the humiliating torment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
Indeed there was for Saba' a sign in their dwelling place -- two gardens on the right and on the left; (and it was said to them:) ``Eat of the provision of your Lord, and be grateful to Him." A fair land and an Oft-Forgiving Lord!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away, so We sent against them flood released from the dam, and We converted their two gardens into gardens producing bitter bad fruit, and Athl, and some few lote trees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
Like this We requited them because they were ungrateful disbelievers. And never do We requite in such a way except those who are ungrateful (disbelievers).\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We placed, between them and the towns which We had blessed, towns easy to be seen, and We made the stages (of journey) between them easy (saying): ``Travel in them safely both by night and day."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But they said: ``Our Lord! Make the stages between our journey longer," and they wronged themselves; so We made them as tales (in the land), and We dispersed them all totally. Verily, in this are indeed signs for every steadfast, grateful (person).\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And indeed Iblis did prove true his thought about them, and they followed him, all except a group of true believers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
And he had no authority over them, -- except that We might test him who believes in the Hereafter, from him who is in doubt about it. And your Lord is Watchful over everything.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say: ``Call upon those whom you assert besides Allah, they possess not even the weight of a speck of dust, either in the heavens or on the earth, nor have they any share in either, nor there is for Him any supporter from among them. ``\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
Intercession with Him profits not except for him whom He permits. So much so that when fear is banished from their hearts, they say: ``What is it that your Lord has said" They say the truth. And He is the Most High, the Most Great.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say: ``Who gives you provision from the heavens and the earth" Say: ``Allah. And verily, (either) we or you are rightly guided or in plain error."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say: ``You will not be asked about our sins, nor shall we be asked of what you do."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say: ``Our Lord will assemble us all together, then He will judge between us with truth. And He is the Just Judge, the All-Knower of the true state of affairs."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say: ``Show me those whom you have joined with Him as partners. Nay! But He is Allah, the Almighty, the All-Wise."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
And We have not sent you except as a giver of glad tidings and a warner to all mankind, and most of men know not.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say: ``When is this promise if you are truthful"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say: ``The appointment to you is for a Day, which you cannot put back for an hour nor put forward."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
And those who disbelieve say: ``We believe not in this Qur'an nor in that which was before it." But if you could see when the wrongdoers are made to stand before their Lord, how they will cast the (blaming) word one to another! Those who were deemed weak will say to those who were arrogant: ``Had it not been for you, we should certainly have been believers!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
And those who were arrogant will say to those who were deemed weak: ``Did we keep you back from guidance after it had come to you Nay, but you were criminals."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who were deemed weak will say to those who were arrogant: ``Nay, but it was your plotting by night and day, when you ordered us to disbelieve in Allah and set up rivals to Him!" And each of them (parties) will conceal their own regrets, when they behold the torment. And We shall put iron collars round the necks of those who disbelieved. Are they requited aught except what they used to do\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
And We did not send a warner to a township but those who were given the worldly wealth and luxuries among them said: ``We believe not in what you have been sent with."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they say: ``We are more in wealth and in children, and we are not going to be punished."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say: ``Verily, my Lord expands the provision to whom He wills and restricts, but most men know not."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
And it is not your wealth, nor your children that bring you nearer to Us, but only he who believes, and does righteous deeds; as for such, there will be multiple rewards for what they did, and they will reside in the high dwellings (Paradise) in peace and security.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And those who strive against Our Ayat, to frustrate them, they will be brought to the torment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say: ``Truly, my Lord expands the provision for whom He wills of His servants, and (also) restricts (it) for him, and whatsoever you spend of anything, He will replace it." And He is the Best of those who make provision.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And (remember) the Day when He will gather them all together, then He will say to the angels: ``Was it you that these people used to worship"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They (the angels) will say: ``Glorified be You! You are our Protector instead of them. Nay, but they used to worship the Jinn; most of them were believers in them."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
So Today, none of you can profit or harm one another. And We shall say to those who did wrong: ``Taste the torment of the Fire which you used to deny."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And when Our Clear Verses are recited to them, they say: ``This is naught but a man who wishes to hinder you from that which your fathers used to worship." And they say: ``This is nothing but an invented lie." And those who disbelieve say of the truth when it has come to them: ``This is nothing but evident magic!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
And We had not given them Scriptures that they could study, nor sent to them before you any warner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
And those before them denied; these have not received even a tenth of what We had granted to those (of old); yet they denied My Messengers. Then how (terrible) was My denial!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say: ``I exhort you to one (thing) only, that you stand up for Allah's sake in pairs and singly, and reflect, there is no madness in your companion. He is only a warner to you in face of a severe torment."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say: ``Whatever wage I might have asked of you is yours. My wage is from Allah only, and He is a Witness over all things."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say: ``Verily, my Lord sends down the truth, the All-Knower of the Unseen."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say: ``The truth has come, and the falsehood can neither create anything nor resurrect."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say: ``If (even) I go astray, I shall stray only to my own loss. But if I remain guided, it is because of the Revelation of my Lord to me. Truly, He is All-Hearer, Ever Near."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
And if you could but see, when they will be terrified with no escape, and they will be seized from a near place.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And they will say: ``We do believe (now);" but how could they receive (Tanawush) from a place so far off.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
Indeed they did disbelieve before (in this world), and they (used to) conjecture about the Unseen, from a far place.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And a barrier will be set between them and that which they desire, as was done in the past with the people of their kind. Verily, they have been in grave doubt.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen All praise is due to Allah, Fatir of the heavens and the earth, Who made the angels messengers with wings, two or three or four. He increases in creation what He wills. Verily, Allah is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatever of mercy, Allah may grant to mankind, none can withhold it; and whatever He may withhold, none can grant it thereafter. And He is the Almighty, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O mankind! Remember the grace of Allah upon you! Is there any creator other than Allah who provides for you from the sky (rain) and the earth La ilaha illa Huwa. How then are you turning away (from Him)\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they deny you, so were Messengers denied before you. And to Allah return all matters.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O mankind! Verily, the promise of Allah is true. So, let not this present life deceive you, and let not the chief deceiver deceive you about Allah.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Surely, Shaytan is an enemy to you, so take (treat) him as an enemy. He only invites his followers that they may become the dwellers of the blazing Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve, theirs will be a severe torment; and those who believe and do righteous good deeds, theirs will be forgiveness and a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
Is he, then, to whom the evil of his deeds is made fairseeming, so that he considers it as good Verily, Allah sends astray whom He wills, and guides whom He wills. So destroy not yourself in sorrow for them. Truly, Allah is the All-Knower of what they do!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
And it is Allah Who sends the winds, so that they raise up the clouds, and We drive them to a dead land, and revive therewith the earth after its death. As such (will be) the Resurrection!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whosoever desires Al-`Izzah then to Allah belongs Al-`Izzah. To Him ascend the good words, and the righteous deeds exalt it, but those who plot evils, theirs will be a severe torment. And the plotting of such will perish.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
And Allah did create you from dust, then from Nutfah, then He made you pairs. And no female conceives or gives birth but with His knowledge. And no aged man is granted a length of life nor is a part cut off from his life, but is in a Book. Surely, that is easy for Allah.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
And the two seas (kinds of water) are not alike: this is palatable, sweet and pleasant to drink, and that is salty and bitter. And from them both you eat fresh tender meat (fish), and derive the ornaments that you wear. And you see the ships cleaving, that you may seek of His bounty, and that you may give thanks.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He merges the night into the day, and He merges the day into the night. And He has subjected the sun and the moon, each runs its course for a term appointed. Such is Allah, your Lord; His is the kingdom. And those, whom you invoke or call upon instead of Him, own not even a Qitmir.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you invoke them, they hear your call; and if (in case) they were to hear, they could not grant it to you. And on the Day of Resurrection, they will disown your worshipping them. And none can inform you like Him Who is the All-Knower.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O mankind! it is you who stand in need of Allah. But Allah is the Rich, Worthy of all praise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He willed, He could destroy you and bring about a new creation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
And that is not hard for Allah.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
And no bearer of burdens shall bear another's burden; and if one heavily laden calls another to (bear) his load, nothing of it will be lifted even though he be near of kin. You can warn only those who fear their Lord unseen and perform the Salah. And he who purifies himself (from all kinds of sins), then he purifies only for the benefit of himself. And to Allah is the Return (of all).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
Not alike are the blind and the seeing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Nor are (depths of) darkness and light.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
Nor are the shade and the sun's heat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
Nor are the living and the dead. Verily, Allah makes whom He wills to hear, but you cannot make hear those who are in graves.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You are only a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Verily, We have sent you with the truth, a bearer of glad tidings and a warner. And there never was a nation but a warner had passed among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if they deny you, those before them also denied. Their Messengers came to them with clear signs, and with the Scriptures, and with the Book giving light.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I took hold of those who disbelieved, and how terrible was My denial!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
See you not that Allah sends down water from the sky, and We produce therewith fruits of various colors, and among the mountains are Judad, white and red, of varying colors and (others) Gharabib black.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And likewise, men and moving creature and cattle are of various colors. It is only those among His servants who have knowledge that fear Allah. Verily, Allah is Almighty, Oft-Forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Verily, those who recite the Book of Allah, and perform the Salah, and spend out of what We have provided for them, secretly and openly, they hope for a (sure) trade-gain that will never perish.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
That He may pay them their wages in full, and give them (even) more, out of His grace. Verily, He is Oft-Forgiving, Most Ready to appreciate.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
And what We have revealed to you of the Book, it is the (very) truth confirming that which was (revealed) before it. Verily, Allah is indeed All-Aware and All-Seer of His servants.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then We gave the Book as inheritance to such of Our servants whom We chose. Then of them are some who wrong themselves, and of them are some who follow a middle course, and of them are some who are, by Allah's leave, foremost in good deeds. That -- that is indeed a great grace.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
`Adn (Gardens) will they enter, therein will they be adorned with bracelets of gold and pearls, and their garments therein will be of silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will say: ``All praise and thanks be to Allah, Who has removed from us (all) grief. Verily, our Lord is indeed Oft-Forgiving, Most Ready to appreciate."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
``Who, out of His grace, has lodged us in a home that will last forever, where toil will touch us not nor weariness will touch us."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
But those who disbelieve, for them will be the fire of Hell. Neither will it have a complete killing effect on them so that they die nor shall its torment be lightened for them. Thus do We requite every disbeliever!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
Therein they will cry: ``Our Lord! Bring us out, we shall do righteous good deeds, not that we used to do." (Allah will reply:) ``Did We not give you lives long enough, so that whosoever would receive admonition could receive it And the warner came to you. So taste you. For the wrongdoers there is no helper."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Verily, Allah is the All-Knower of the Unseen of the heavens and the earth. Verily, He is the All-Knower of that is in the breasts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
He it is Who has made you successors generations after generations in the earth, so whosoever disbelieves, on him will be his disbelief. And the disbelief of the disbelievers adds nothing but hatred of their Lord. And the disbelief of the disbelievers adds nothing but loss.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say: ``Have you considered your partners whom you call upon besides Allah Show Me, what they have created of the earth. Or have they any share in the heavens Or have We given them a Book, so that they act on clear proof therefrom Nay, the wrongdoers promise one another nothing but delusions."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Verily, Allah grasps the heavens and the earth lest they should move away from their places, and if they were to move away from their places, there is not one that could grasp them after Him. Truly, He is Ever Most Forbearing, Oft-Forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And they swore by Allah their most binding oath that if a warner came to them, they would be more guided than any of the nations; yet when a warner came to them, it increased in them nothing but flight (from the truth).\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
(They took to flight because of their) arrogance in the land and their plotting of evil. But the evil plot encompasses only him who makes it. Then, can they expect anything (else) but the Sunnah (way of dealing) of the peoples of old So, no change will you find in Allah's Sunnah, and no turning off will you find in Allah's Sunnah.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not traveled in the land, and seen what was the end of those before them -- though they were superior to them in power Allah is not such that anything in the heavens or in the earth escapes Him. Verily, He is All-Knowing, All-Able.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
And if Allah were to punish men for that which they earned, He would not leave a moving creature on the surface of the earth; but He gives them respite to an appointed term, and when their term comes, then verily, Allah is Ever All-Seer of His servants.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya Sin.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the Qur'an, full of wisdom,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
Truly, you are one of the Messengers,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On the straight path.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
Sent down by the Almighty, the Most Merciful,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
In order that you may warn a people whose forefathers were not warned, so they are heedless.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Indeed the Word has proved true against most of them, so they will not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
Verily, We have put on their necks iron collars reaching to the chins, so that their heads are raised up.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have put a barrier before them, and a barrier behind them, and We have covered them up, so that they cannot see.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
It is the same to them whether you warn them or you warn them not, they will not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You can only warn him who follows the Reminder, and fears the Most Gracious unseen. Bear you to such one the glad tidings of forgiveness, and a generous reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Verily, We give life to the dead, and We record that which they send before (them), and their traces and all things We have recorded with numbers in Imam Mubin (a Clear Book).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
And put forward to them a similitude; the Dwellers of the Town, when there came Messengers to them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
When We sent to them two Messengers, they denied them both; so We reinforced them with a third, and they said: ``Verily, we have been sent to you as Messengers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said: ``You are only human beings like ourselves, and the Most Gracious has revealed nothing. You are only telling lies."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
The Messengers said: ``Our Lord knows that we have been sent as Messengers to you,"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
``And our duty is only to convey plainly."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They (people) said: ``For us, we see an evil omen from you; if you cease not, we will surely stone you, and a painful torment will touch you from us."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They (Messengers) said: ``Your evil omens be with you! Because you are admonished Nay, but you are a people mischievous."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
And there came a man running from the farthest part of the town. He said, ``O my people! Obey the Messengers."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
``Obey those who ask no wages of you, and who are rightly guided."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
``And why should I not worship Him Who has created me and to Whom you shall be returned."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
``Shall I take besides Him gods If the Most Gracious intends me any harm, their intercession will be of no use for me whatsoever, nor can they save me."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
``Then verily, I should be in plain error."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
``Verily, I have believed in your Lord, so listen to me!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said: ``Enter Paradise." He said: ``Would that my people knew."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
``That my Lord (Allah) has forgiven me, and made me of the honored ones!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We sent not against his people after him an army from the heaven, nor was it needful for Us to send (such a thing).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was but one Sayhah and lo! they (all) were still.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
Alas for mankind! There never came a Messenger to them but they used to mock at him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Do they not see how many of the generations We have destroyed before them Verily, they will not return to them.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
And surely, all -- everyone of them will be brought before Us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And a sign for them is the dead land. We give it life, and We bring forth from it grains, so that they eat thereof.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We have made therein gardens of date palms and grapes, and We have caused springs of water to gush forth therein.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
So that they may eat of the fruit thereof -- and their hands made it not. Will they not then give thanks\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Glory be to Him Who has created all the pairs of that which the earth produces, as well as of their own kind, and of that which they know not.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a sign for them is the night. We withdraw therefrom the day, and behold, they are in darkness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runs on its fixed course for a term (appointed). That is the decree of the Almighty, the All-Knowing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon, We have decreed for it stages, till it returns like the old dried curved date stalk.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not for the sun to overtake the moon, nor does the night outstrip the day. They all float, each in an orbit.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And an Ayah for them is that We bore their offspring in the laden ship.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We have created for them of the like thereunto, on which they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
And if We will, We shall drown them, and there will be no shout for them, nor will they be saved.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Unless it be a mercy from Us, and as an enjoyment for a while.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
And when it is said to them: ``Beware of that which is before you, and that which is behind you, in order that you may receive mercy."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
And never came an Ayah from among the Ayat of their Lord to them, but they did turn away from it.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them: ``Spend of that with which Allah has provided you," those who disbelieve say to those who believe: ``Shall we feed those whom, if Allah willed, He would have fed You are only in a plain error."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say: ``When will this promise be fulfilled, if you are truthful"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They await only but a single Sayhah which will seize them while they are disputing!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
Then they will not be able to make bequest, nor they will return to their family.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the Trumpet will be blown and behold from the graves they will come out quickly to their Lord.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They will say: ``Woe to us! Who has raised us up from our place of sleep." (It will be said to them): ``This is what the Most Gracious had promised, and the Messengers spoke truth!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It will be but a single Sayhah, so behold they will all be brought up before Us!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
This Day, none will be wronged in anything, nor will you be requited anything except that which you used to do.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Verily, the dwellers of the Paradise, that Day, will be busy with joyful things.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their wives will be in pleasant shade, reclining on thrones.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
They will have therein fruits and all that they ask for.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
(It will be said to them): ``Salam (Peace!)" -- a Word from the Lord, Most Merciful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
(It will be said): ``And O you the criminals! Get you apart this Day."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
``Did I not command you, O Children of Adam, that you should not worship Shaytan Verily, he is a plain enemy to you."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
``And that you should worship Me. That is the straight path."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
``And indeed he did lead astray a great multitude of you. Did you not then understand"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This is Hell which you were promised!\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
Burn (enter) therein this Day, for that you used to disbelieve.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
This Day, We shall seal up their mouths, and their hands will speak to Us, and their legs will bear witness to what they used to earn.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
And if it had been Our will, We would surely have wiped out their eyes, so that they would struggle for the path, how then would they see\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And if it had been Our will, We could have transformed them in their places. Then they would have been unable to go forward (move about) nor they could have turned back.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
And he whom We grant long life -- We reverse him in creation. Will they not then understand\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
And We have not taught him poetry, nor is it suitable for him. This is only a Reminder and a plain Qur'an.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
That he or it may give warning to him who is living, and that Word may be justified against the disbelievers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Do they not see that We have created for them of what Our Hands have fashioned, the cattle, so that they are their owners.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And We have subdued them unto them so that some of them they have for riding and some they eat.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And they have (other) benefits from them, and (they get to) drink. Will they not then be grateful\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
And they have taken besides Allah, gods, hoping that they might be helped.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They cannot help them, but they will be brought forward as a troop (against those who worshipped them).\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So, let not their speech then grieve you. Verily, We know what they conceal and what they reveal.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Does not man see that We have created him from Nutfah. Yet behold he (stands forth) as an open opponent.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he puts forth for Us a parable, and forgets his own creation. He says: ``Who will give life to these bones after they are rotten and have become dust"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say: ``He will give life to them Who created them for the first time! And He is the All-Knower of every creation!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
He Who produces for you fire out of the green tree, when behold you kindle therewith.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He Who created the heavens and the earth, able to create the like of them Yes, indeed! He is the All-Knowing Supreme Creator.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
Verily, His command, when He intends a thing, is only that He says to it, ``Be!" -- and it is!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
So glorified be He and exalted (above all that they associate with Him), and in Whose Hand is the dominion of all things, and to Him you shall be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By those ranged in ranks.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
By those who drive the clouds in a good way.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
By those who bring the Dhikr.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Verily, your God is indeed One;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and of the earth, and all that is between them, and Lord of every point of the sun's risings.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
Verily, We have adorned the near heaven with the stars.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
And to guard against every rebellious Shaytan.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
They cannot listen to the higher group for they are pelted from every side.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
Outcast, and theirs is a constant torment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except such as snatch away something by stealing, and they are pursued by a flaming fire of piercing brightness.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Then ask them: ``Are they harder to create, or those whom We have created" Verily, We created them of a sticky clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
Nay, you wondered while they mock.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And when they are reminded, they pay no attention.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And when they see an Ayah (a sign) from Allah, they mock at it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And they say: ``This is nothing but evident magic!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
``When we are dead and have become dust and bones, shall we verily be resurrected"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
``And also our fathers of old"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say: ``Yes, and you shall then be humiliated."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
It will be a single Zajrah, and behold, they will be staring!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
They will say: ``Woe to us! This is the Day of Recompense!"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
(It will be said:) ``This is the Day of Judgement which you used to deny."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
(It will be said to the angels:) Assemble those who did wrong, together with their companions and what they used to worship,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
Instead of Allah, and lead them on to the way of flaming Fire (Hell);\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
But stop them, verily, they are to be questioned.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
``What is the matter with you Why do you not help one another"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
Nay, but that Day they shall surrender.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And they will turn to one another and question one another.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They will say: ``It was you who used to come to us from the right side."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
They will reply: ``Nay, you yourselves were not believers."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
``And we had no authority over you. Nay! But you were a transgressing people."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
``So now the Word of our Lord has been justified against us, that we shall certainly taste (the torment)."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
``So we led you astray because we were ourselves astray."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
Then verily, that Day, they will (all) share in the torment.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Certainly, that is how We deal with the criminals.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
Truly, when it was said to them: ``La ilaha illallah," they puffed themselves up with pride.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And (they) said: ``Are we going to abandon our gods for the sake of a mad poet"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
Nay! he has come with the truth and he confirms the Messengers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Verily, you are going to taste the painful torment;\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
And you will be requited nothing except for what you used to do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
Save the chosen servants of Allah.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
For them there will be a known provision,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits; and they shall be honored,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In the Gardens of Delight,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
Facing one another on thrones.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
Round them will be passed a cup of pure wine\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White, delicious to the drinkers.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
Neither will they have Ghawl from that nor will they suffer intoxication therefrom.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And beside them will be Qasirat-At-Tarf with (wide and beautiful) eyes.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
as if they were Bayd Maknun.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
Then they will turn to one another, mutually questioning.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
A speaker of them will say: ``Verily, I had a companion (in the world),"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
``Who used to say: `Are you among those who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
(That) when we die and become dust and bones, shall we indeed be indebted (Madinun)"'\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
(The speaker) said: ``Will you look down"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
So he looked down and saw him in the midst of the Fire.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He said: ``By Allah! You have nearly ruined me."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
``Had it not been for the grace of my Lord, I would certainly have been among those brought forth (to Hell)."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
``Are we then not to die (any more)"\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
``Except our first death, and we shall not be punished"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Truly, this is the supreme success!\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this let the workers work.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is that (Paradise) better entertainment or the tree of Zaqqum\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
Truly, We have made it (as) a trial for the wrongdoers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
Verily, it is a tree that springs out of the bottom of Hell-fire,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
The shoots of its fruit stalks are like the heads of Shayatin.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
Truly, they will eat thereof and fill their bellies therewith.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then on the top of that they will be given boiling Hamim.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then thereafter, verily, their return is to the flaming fire of Hell.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
Verily, they found their fathers on the wrong path;\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
So they (too) hastened in their footsteps!\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And indeed most of the earlier ones went astray before them;\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
And indeed We sent among them warners;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Then see what was the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
Except the chosen servants of Allah.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And indeed Nuh invoked Us, and We are the best of those who answer.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We rescued him and his family from the great distress,\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And, his progeny, them We made the survivors.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And left for him (a goodly remembrance) among the later generations\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
``Salam (peace!) be upon Nuh among the all creatures!"\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Verily, thus We reward the gooddoers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
Verily, he [Nuh] was one of Our believing servants.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then We drowned the others.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
And verily, among those who followed his way was Ibrahim.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came to his Lord with a Salim heart.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
When he said to his father and to his people: ``What is it that which you worship"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
``Is it a falsehood -- gods other than Allah -- that you desire"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
``Then what think you about the Lord of the all that exists"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
Then he cast a glance at the stars,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
And he said: ``Verily, I am sick."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
So they turned away from him and departed.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he turned to their gods and said: ``Will you not eat"\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
``What is the matter with you that you speak not"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
Then he turned upon them, striking (them) with (his) right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Then they came hastily towards him.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said: ``Worship you that which you (yourselves) carve"\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
``While Allah has created you and what you make!"\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said: ``Build for him a building and throw him into the blazing fire!"\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
So, they plotted a plot against him, but We made them the lowest.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
And he said: ``Verily, I am going to my Lord. He will guide me!"\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
``My Lord! Grant me (offspring) from the righteous."\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
So, We gave him the glad tidings of a forbearing boy.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And, when he (his son) was old enough to walk with him, he said: ``O my son! I have seen in a dream that I am slaughtering you. So look what you think!" He said: ``O my father! Do that which you are commanded, if Allah wills, you shall find me of the patient."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
Then, when they had both submitted themselves, and he had laid him prostrate on his forehead;\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called out to him: ``O Ibrahim!"\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
``You have fulfilled the dream!" Verily, thus do We reward the doers of good.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
Verily, that indeed was a manifest trial.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a great sacrifice;\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left for him among the later generations.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
``Salam (peace!) be upon Ibrahim!"\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Thus indeed do We reward the doers of good.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
Verily, he was one of Our believing servants.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him the glad tidings of Ishaq -- a Prophet from the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
We blessed him and Ishaq. And of their progeny are (some) that do right, and some that plainly wrong themselves.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And, indeed We gave Our grace to Musa and Harun.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And We saved them and their people from the great distress,\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And helped them, so that they became the victors;\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We gave them the clear Scripture;\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And guided them to the right path.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left for them among the later generations.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
``Salam (peace!) be upon Musa and Harun!"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Verily, thus do We reward the doers of good.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Verily, they were two of Our believing servants.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And verily, Ilyas was one of the Messengers.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
When he said to his people: ``Will you not have Taqwa"\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
``Will you call upon `Ba`l and forsake the Best of creators,\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
Allah, your Lord and the Lord of your forefathers"\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
But they denied him, so they will certainly be brought forth,\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Save the chosen servants of Allah.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We left for him among the later generations.\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
``Salam (peace!) be upon Ilyasin!"\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Verily, thus do We reward the doers of good.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
Verily, he was one of Our believing servants.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And verily, Lut was one of the Messengers.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
When We saved him and his family, all,\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Except an old woman (his wife) who was among those who remained behind.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We destroyed the rest.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
Verily, you pass by them in the morning.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And at night; will you not then reflect\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And verily, Yunus was one of the Messengers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
When he ran to the laden ship:\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
Then he (agreed to) cast lots, and he was among the losers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
Then a (big) fish swallowed him as he had done an act worthy of blame.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
Had he not been of them who glorify Allah,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have indeed remained inside its belly (the fish) till the Day of Resurrection.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
But We cast him forth on the naked shore while he was sick,\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We caused a plant of gourd to grow over him.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We sent him to a hundred thousand (people) or even more.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed; so We gave them enjoyment for a while.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
Now ask them: ``Are there (only) daughters for your Lord and sons for them"\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or did We create the angels female while they were witnesses\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Verily, it is of their falsehood that they say:\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
``Allah has begotten." And, verily, they are liars!\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Has He (then) chosen daughters rather than sons\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is the matter with you How do you decide\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Will you not then remember\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or is there for you a plain authority\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then bring your Book if you are truthful!\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they have invented a kinship between Him and the Jinn, but the Jinn know well that they have indeed to appear (before Him).\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Glorified be Allah! (He is free) from what they attribute unto Him!\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Except the servants of Allah, whom He chooses.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
So, verily you and those whom you worship\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
Cannot lead astray,\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Except those who are predestined to burn in Hell!\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
And there is not one of us (angels) but has his known place;\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
And verily, we (angels), we stand in rows;\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
And verily, we (angels) indeed are those who glorify.\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And indeed they used to say:\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
``If we had a reminder as had the men of old,"\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
``We would have indeed been the chosen servants of Allah!"\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But (now) they disbelieve therein, so they will come to know!\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
And, verily, Our Word has gone forth of old for Our servants, the Messengers,\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
That they verily would be made triumphant,\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And that Our hosts! they verily would be the victors.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So, turn away from them for a while,\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And watch them and they shall see!\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Do they seek to hasten on Our torment\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
Then, when it descends in their courtyard, evil will be the morning for those who had warned!\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
So, turn away from them for a while,\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And watch and they shall see!\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Glorified be your Lord, the Lord of Al-`Izzah! (He is free) from what they attribute unto Him!\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And Salam (peace!) be on the Messengers!\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And all the praises and thanks be to Allah, Lord of all that exists.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad. By the Qur'an full of reminding.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
Those who disbelieve are in false pride and opposition.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a generation have We destroyed before them! And they cried out when there was no longer time for escape.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they wonder that a warner has come to them from among themselves. And the disbelievers say: ``This is a sorcerer, a liar."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
``Has he made the gods into One God. Verily, this is a curious thing!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And the leaders among them went about (saying): ``Go on, and remain constant to your gods! Verily, this is a thing designed!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
``We have not heard (the like) of this in the religion of these later days. This is nothing but an invention!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
``Has the Reminder been sent down to him (alone) from among us" Nay, but they are in doubt about My Reminder! Nay, but they have not tasted (My) torment!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or have they the treasures of the mercy of your Lord, the Almighty, the Real Bestower\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or is it that the dominion of the heavens and the earth and all that is between them is theirs If so, let them ascend up with means!\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
They will be a defeated host like the Confederates of the old times.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
Before them denied -- the people of Nuh; and `Ad; and Fir`awn the man of stakes,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And Thamud, and the people of Lut, and the Dwellers of Al-Aykah; such were the Confederates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
Not one of them but denied the Messengers; therefore My torment was justified.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
And these only wait for a single Sayhah there will be no pause or ending thereto.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
They say: ``Our Lord! Hasten to us Qittana before the Day of Reckoning!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Be patient of what they say and remember Our slave Dawud, endued with Al-Ayd. Verily, he was ever oft-returning in all matters and in repentance.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
Verily, We made the mountains to glorify Our praises with him in the `Ashi and Ishraq.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And (so did) the birds assembled, all obedient to him.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
We made his kingdom strong and gave him Al-Hikmah and sound judgement in speech and decision.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
And has the news of the litigants reached you When they climbed over the wall into (his) Mihrab (private chamber of worship);\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they entered in upon Dawud, he was terrified of them. They said: ``Fear not! (We are) two litigants, one of us has wronged the other, therefore judge between us with truth, and treat us not with injustice, and guide us to the right way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
Verily, this my brother (in religion) has ninety-nine ewes, while I have (only) one ewe, and he says: ``Hand it over to me, and he overpowered me in speech."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
[Dawud] said: ``He has wronged you in demanding your ewe in addition to his ewes. And, verily, many partners oppress one another, except those who believe and do righteous good deeds, and they are few." And Dawud guessed that We have tried him and he sought forgiveness of his Lord, and he fell down prostrate and turned (to Allah) in repentance.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So, We forgave him that, and verily, for him is a near access to Us, and a good place of return.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
O Dawud! Verily, We have placed you as a successor on the earth; so judge you between men in truth (and justice) and follow not your desire -- for it will mislead you from the path of Allah. Verily, those who wander astray from the path of Allah (shall) have a severe torment, because they forgot the Day of Reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
And We created not the heaven and the earth and all that is between them without purpose! That is the consideration of those who disbelieve! Then woe to those who disbelieve from the Fire!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Shall We treat those who believe and do righteous good deeds as those who cause mischief on the earth Or shall We treat those who have Taqwa as the evildoers\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
(This is) a Book which We have sent down to you, full of blessings, that they may ponder over its Verses, and that men of understanding may remember.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And to Dawud We gave Sulayman. How excellent a servant! Verily, he was ever turning in repentance (to Us)!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
When there were displayed before him, in the afternoon, well trained horses of the highest breed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
He said: ``I did love the good instead of remembering my Lord," till the time was over, and (the sun) had hidden in the veil (of night).\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
Then he said: ``Bring them back to me." Then he began to pass his hand over their legs and their necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And indeed, We tried Sulayman and We placed on his throne Jasad (a body), and he returned.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said: ``My Lord! Forgive me, and bestow upon me a kingdom such as shall not belong to any other after me. Verily, You are the Bestower."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So, We subjected to him the wind; it blew gently by his order wherever he willed,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And the Shayatin, from every kind of builder and diver,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And also others bound in fetters.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
[Allah said to Sulayman]: ``This is Our gift, so spend you or withhold, no account will be asked of you."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And verily, for him is a near access to Us, and a good (final) return.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And remember Our servant Ayyub, when he invoked his Lord (saying): ``Verily, Shaytan has afflicted me with distress and torment!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
(Allah said to him): ``Strike the ground with your foot. This is (a spring of) water to wash in, cool and a drink."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We gave him (back) his family, and along with them the like thereof, as a mercy from Us, and a reminder for those who understand.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
``And take in your hand a bundle of thin grass and strike therewith (your wife), and break not your oath." Truly, We found him patient. How excellent a servant! Verily, he was ever oft-returning in repentance (to Us)!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And remember Our servants, Ibrahim, Ishaq, and Ya`qub, Ulil-Aydi wal-Absar.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Verily, We did choose them by granting them the remembrance of the Abode.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
And they are with Us, verily, of the chosen and the best!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And remember Isma`il, Al-Yasa`, and Dhul-Kifl, all are among the best.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a Reminder. And verily, for those who have Taqwa is a good final return.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
`Adn Paradise, whose doors will be opened for them.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Therein they will recline; therein they will call for fruits in abundance and drinks;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And beside them will be Qasirat-at-Tarf, (and) of equal ages.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This it is what you are promised for the Day of Reckoning!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
(It will be said to them)! Verily, this is Our provision which will never finish.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
This is so! And for the Taghin will be an evil final return.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell! Where they will enter it, and worst (indeed) is that place to rest!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
This is so! Then let them taste it - Hamim and Ghassaq.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And other of similar kind - all together!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
This is a troop entering with you (in Hell), no welcome for them! Verily, they shall enter in the Fire!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
(The followers will say to those who misled): ``Nay, you (too)! No welcome for you! It is you who brought this upon us, so evil is this place to stay in!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say: ``Our Lord! Whoever brought this upon us, add to him a double torment in the Fire!"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will say: ``What is the matter with us that we see not men whom we used to count among the bad ones"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
``Did we take them as an object of mockery, or have (our) eyes failed to perceive them"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Verily, that is the very truth -- the mutual dispute of the people of the Fire!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say: ``I am only a warner and there is no God (worthy of worship) except Allah the One, the Irresistible,"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
``The Lord of the heavens and the earth and all that is between them, the Almighty, the Oft-Forgiving."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say: ``That is a great news,"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
``From which you turn away!"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
``I had no knowledge of the chiefs (angels) on high when they were disputing and discussing."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
``Only this has been revealed to me, that I am a plain warner."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
(Remember) when your Lord said to the angels: ``Truly, I am going to create man from clay."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
``So, when I have fashioned him and breathed into him (his) soul created by Me, then you fall down prostrate to him."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So, the angels prostrated themselves, all of them,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Except Iblis, he was proud and was one of the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
(Allah) said: ``O Iblis! What prevents you from prostrating yourself to one whom I have created with Both My Hands. Are you too proud or are you one of the high exalted"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
[Iblis] said: ``I am better than he. You created me from fire, and You created him from clay."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
(Allah) said: ``Then get out from here; for verily, you are outcast."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
``And verily, My curse is on you till the Day of Recompense."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
[Iblis] said: ``My Lord! Give me then respite till the Day the (dead) are resurrected."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
(Allah) said: ``Verily, you are of those allowed respite,"\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
``Till the Day of the time appointed."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
[Iblis] said: ``By Your might, then I will surely mislead them all,"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
``Except Your true servants amongst them."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
(Allah) said: ``The truth is -- the truth I say - ``\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
``That I will fill Hell with you and those of them (mankind) that follow you, together."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say: ``No wage do I ask of you for this, nor am I one of the Mutakallifin."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
``It is only a Reminder for all the creatures."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
``And you shall certainly know the truth of it after a while."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of this Book is from Allah, the Almighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
Verily, We have sent down the Book to you in truth. So, worship Allah by doing religious deeds sincerely for Him only.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Surely, the religion is for Allah only. And those who take protectors besides Him (say): ``We worship them only that they may bring us near to Allah." Verily, Allah will judge between them concerning that wherein they differ. Truly, Allah guides not him who is a liar, and a disbeliever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
Had Allah willed to take a son, He could have chosen whom He willed out of those whom He created. But glory be to Him! He is Allah, the One, the Irresistible.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He has created the heavens and the earth with truth. He makes the night to go in the day and makes the day to go in the night. And He has subjected the sun and the moon. Each running for an appointed term. Verily, He is the Almighty, the Oft-Forgiving.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you (all) from a single person; then made from him his wife. And He has sent down for you of An`am eight pairs. He creates you in the wombs of your mothers, creation after creation in three veils of darkness. Such is Allah your Lord. His is the kingdom. La ilaha illa Huwa. How then are you turned away\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you disbelieve, then verily, Allah is not in need of you; He likes not disbelief for His servants. And if you are grateful, He is pleased therewith for you. No bearer of burdens shall bear the burden of another. Then to your Lord is your return, and He will inform you what you used to do. Verily, He is the All-Knower of that which is in breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
And when some hurt touches man, he cries to his Lord, turning to Him in repentance. But when He bestows a favor upon him from Himself, he forgets that for which he cried for before, and he sets up rivals to Allah, in order to mislead others from His path. Say: ``Take pleasure in your disbelief for a while, surely, you are (one) of the dwellers of the Fire!"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is one who is obedient to Allah, Ana'a Al-Layl prostrating and standing fearing the Hereafter and hoping for the mercy of his Lord Say: ``Are those who know equal to those who know not" It is only men of understanding who will remember.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say: ``O My servants who believe, have Taqwa of your Lord. Good is for those who do good in this world, and Allah's earth is spacious! Only those who are patient shall receive their reward in full, without reckoning."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say: ``Verily, I am commanded to worship Allah, making religion sincerely for Him."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
``And I am commanded (this) in order that I may be the first of the Muslims."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say: ``Verily, if I disobey my Lord, I am afraid of the torment of a great Day."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say: ``Allah Alone I worship by doing religious deeds sincerely for His sake only."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
``So, worship what you like besides Him." Say: ``The losers are those who will lose themselves and their families on the Day of Resurrection. Verily, that will be a manifest loss!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
They shall have coverings of Fire, above them and covering (of Fire) beneath them. With this Allah frightens His servants: ``O My servants, therefore have Taqwa of Me!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
Those who avoid At-Taghut by not worshipping them and turn to Allah, for them are glad tidings; so announce the good news to My servants.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Those who listen to the Word and follow the best thereof, those are (the ones) whom Allah has guided and those are men of understanding.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Is, then one against whom the Word of punishment is justified (equal to the one who avoids evil) Will you rescue him who is in the Fire\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who have Taqwa of their Lord, for them are built lofty rooms, one above another under which rivers flow. (This is) the promise of Allah, and Allah does not fail in (His) promise.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
See you not that Allah sends down water from the sky, and causes it to penetrate the earth, as water springs, and afterward thereby produces crops of different colors, and afterward they wither and you see them turn yellow; then He makes them dry and broken pieces. Verily, in this is a reminder for men of understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
Is he whose breast Allah has opened to Islam, so that he is in light from his Lord So, woe to those whose hearts are hardened against remembrance of Allah! They are in plain error!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has sent down the Best Statement, a Book, its parts resembling each other, (and) oft-repeated. The skins of those who fear their Lord shiver from it. Then their skin and their heart soften to the remembrance of Allah. That is the guidance of Allah. He guides therewith whom He wills; and whomever Allah sends astray, for him there is no guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Is he then, who will confront with his face the awful torment on the Day of Resurrection And it will be said to the wrongdoers: ``Taste what you used to earn!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them denied, and so the torment came on them from directions they perceived not.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So, Allah made them to taste the disgrace in the present life, but greater is the torment of the Hereafter if they only knew!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
And indeed We have put forth for men, in this Qur'an every kind of parable in order that they may remember.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
An Arabic Qur'an, without any crookedness (therein) in order that they may have Taqwa of Him.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah puts forth a parable: a man belonging to many partners disputing with one another, and a man belonging entirely to one master. Are those two equal in comparison All the praises and thanks be to Allah! But most of them know not.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Verily, you will die, and verily, they (too) will die.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then, on the Day of Resurrection, you will be disputing before your Lord.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
Then, who does more wrong than one who utters a lie against Allah, and denies the truth when it comes to him! Is there not in Hell an abode for the disbelievers\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And he who has brought the truth and (those who) believed therein, they are those who have Taqwa.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They shall have all that they will desire with their Lord. That is the reward of the doers of good.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
So that Allah may expiate from them the evil of what they did and give them the reward, according to the best of what they used to do.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is not Allah Sufficient for His servant Yet they try to frighten you with those besides Him! And whom Allah sends astray, for him there will be no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And whomsoever Allah guides, for him there will be no misleader. Is not Allah Almighty, Possessor of Retribution\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And verily, if you ask them: ``Who created the heavens and the earth" Surely, they will say: ``Allah." Say: ``Tell me then, the things that you invoke besides Allah -- if Allah intended some harm for me, could they remove His harm Or if He intended some mercy for me, could they withhold His mercy" Say: ``Sufficient for me is Allah; in Him those who trust must put their trust."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say: ``O My people! Work according to your way, I am working. Then you will come to know"\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
``To whom comes a disgracing torment, and on whom descends an everlasting torment."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Verily, We have sent down to you the Book for mankind in truth. So, whosoever accepts the guidance, it is only for himself; and whosoever goes astray, he goes astray only to his (own) loss. And you are not a trustee over them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
It is Allah Who takes away the souls at the time of their death, and those that die not during their sleep. He keeps those (souls) for which He has ordained death and sends the rest for a term appointed. Verily, in this are signs for a people who think deeply.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Have they taken as intercessors besides Allah Say: ``Even if they have power over nothing whatever and have no intelligence"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say: ``To Allah belongs all intercession. His is the sovereignty of the heavens and the earth. Then to Him you shall be brought back."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
And when Allah Alone is mentioned, the hearts of those who believe not in the Hereafter are filled with disgust and when those besides Him are mentioned, behold, they rejoice!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say: ``O Allah! Creator of the heavens and the earth! All-Knower of the unseen and the seen! You will judge between your servants about that wherein they used to differ."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
And those who did wrong, if they had all that is on the earth and therewith as much again, they verily, would offer it to ransom themselves therewith on the Day of Resurrection from the evil torment; and there will become apparent to them from Allah what they had not been reckoning.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
And the evils of that which they earned will become apparent to them, and that which they used to mock at will encircle them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
When harm touches man, he calls to Us (for help); then when We have changed it into a favor from Us, he says: ``Only because of knowledge I obtained it." Nay, it is only a trial, but most of them know not!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Verily, those before them said it, yet (all) that they had earned availed them not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
So, the evil results of that which they earned overtook them. And those who did wrong of these will also be overtaken by the evil results for that which they earned; and they will never be able to escape.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that Allah expands the provision for whom He wills, and straitens it. Verily, in this are signs for the folk who believe!\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say: ``O My servants who have transgressed against themselves! Despair not of the mercy of Allah, verily, Allah forgives all sins. Truly, He is Oft-Forgiving, Most Merciful."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
``And turn in repentance (and in obedience with true faith) to your Lord and submit to Him before the torment comes upon you, (and) then you will not be helped."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
``And follow the best of that which is sent down to you from your Lord, before the torment comes on you suddenly while you perceive not!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest a person should say: ``Alas, my grief that I was undutiful to Allah, and I was indeed among those who mocked."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or (lest) he should say: ``If only Allah had guided me, I should indeed have been among those who have Taqwa."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or (lest) he should say when he sees the torment: ``If only I had another chance, then I should indeed be among the doers of good."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
Yes! Verily, there came to you My Ayat and you denied them, and were proud and were among the disbelievers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And on the Day of Resurrection you will see those who lied against Allah - their faces will be black. Is there not in Hell an abode for the arrogant\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And Allah will deliver those who have Taqwa to their places of success. Evil shall touch them not, nor shall they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator of all things, and He is the Trustee over all things.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the Maqalid of the heavens and the earth. And those who disbelieve in the Ayat of Allah, such are they who will be the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say: ``Do you order me to worship other than Allah O you fools!"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
And indeed it has been revealed to you, as it was to those before you: ``If you join others in worship with Allah, surely your deeds will be in vain, and you will certainly be among the losers."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Nay! But worship Allah, and be among the grateful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They made not a just estimate of Allah such as is due to Him. And on the Day of Resurrection the whole of the earth will be grasped by His Hand and the heavens will be rolled up in His Right Hand. Glorified be He, and High be He above all that they associate as partners with Him!\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the Trumpet will be blown, and all who are in the heavens and all who are on the earth will swoon away, except him whom Allah wills. Then it will be blown another time, and behold they will be standing, looking on.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth will shine with the light of its Lord, and the Book will be presented, and the Prophets and the witnesses will be brought forward, and it will be judged between them with truth, and they will not be wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And each person will be paid in full of what he did; and He is Best Aware of what they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
And those who disbelieved will be driven to Hell in groups till when they reach it, the gates thereof will be opened. And its keepers will say: ``Did not the Messengers come to you from yourselves, reciting to you the Ayat of your Lord, and warning you of the meeting of this Day of yours" They will say: ``Yes," but the Word of torment has been justified against the disbelievers!\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
It will be said: ``Enter you the gates of Hell, to abide therein. And what an evil abode of the arrogant!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
And those who had Taqwa will be led to Paradise in groups till when they reach it, and its gates will be opened and its keepers will say: ``Salam `Alaykum (peace be upon you)! You have done well, so enter here to abide therein forever."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they will say: ``All the praises and thanks be to Allah Who has fulfilled His promise to us and has made us inherit the land. We can dwell in Paradise where we will; how excellent a reward for the workers!"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And you will see the angels surrounding the Throne from all round, glorifying the praises of their Lord. And they will be judged with truth. And it will be said, ``All the praises and thanks be to Allah, the Lord of all that exits."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of the Book is from Allah, the Almighty, the All-Knower.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
The Forgiver of sin, the Acceptor of repentance, the Severe in punishment, the Bestower. La ilaha illa Huwa, to Him is the final return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
None disputes in the Ayat of Allah but those who disbelieve. So let not their ability of going about here and there through the land (for their purposes) deceive you!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The people of Nuh and the groups after them denied before these; and every nation plotted against their Messenger to seize him, and disputed by means of falsehood to refute therewith the truth. So I seized them, and how was My punishment!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
Thus has the Word of your Lord been justified against those who disbelieved, that they will be the dwellers of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those (angels) who bear the Throne (of Allah) and those around it glorify the praises of their Lord, and believe in Him, and ask forgiveness for those who believe (saying): ``Our Lord! You comprehend all things in mercy and knowledge, so forgive those who repent and follow Your way, and save them from the torment of the blazing Fire!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Our Lord! And make them enter the `Adn (Eternal) Gardens which you have promised them -- and to the righteous among their fathers, their wives, and their offspring! Verily, You are the Almighty, the All-Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
And save them from the sins, and whomsoever You save from the sins that Day, him verily, You have taken into mercy." And that is the supreme success.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
Those who disbelieve will be addressed: ``Indeed, Allah's aversion was greater towards you than your aversion toward yourselves, when you were called to the Faith but you used to refuse."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say: ``Our Lord! You have made us to die twice, and You have given us life twice! Now we confess our sins, then is there any way to get out"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
(It will be said): ``This is because, when Allah Alone was invoked, you disbelieved; but when partners were joined to Him, you believed! So the judgement is only with Allah, the Most High, the Most Great!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He Who shows you His Ayat and sends down provision for you from the sky. And none remembers but those who turn in repentance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
So, call you upon Allah making religion sincerely for Him, however much the disbelievers may hate.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
(He is Allah) Owner of high ranks and degrees, the Owner of the Throne. He sends the revelation by His command to any of His servants He wills, that he may warn of the Day of Mutual Meeting.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The Day when they will come out, nothing of them will be hidden from Allah. Whose is the kingdom this Day It is Allah's, the One, the Irresistible!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
This Day shall every person be recompensed for what he earned. This Day no injustice. Truly, Allah is swift in reckoning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
And warn them of the Day that is drawing near, when the hearts will be at the throats Kazimin. There will be no friend, nor an intercessor for the wrongdoers, who could be given heed to.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
Allah knows the fraud of the eyes, and all that the breasts conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
And Allah judges with truth, while those to whom they invoke besides Him, cannot judge anything. Certainly, Allah! He is the All-Hearer, the All-Seer.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not traveled in the land and seen what was the end of those who were before them They were superior to them in strength, and in the traces in the land. But Allah seized them with punishment for their sins. And none had they to protect them from Allah.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because there came to them their Messengers with clear evidences but they disbelieved (in them). So Allah seized them. Verily, He is All-Strong, Severe in punishment.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
And indeed We sent Musa with Our Ayat, and a manifest authority,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
To Fir`awn, Haman and Qarun, but they called (him): ``A sorcerer, a liar!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
Then, when he brought them the Truth from Us, they said: ``Kill with him the sons of those who believe and let their women live;" but the plots of disbelievers are nothing but in vain!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
Fir`awn said: ``Leave me to kill Musa, and let him call his Lord! I fear that he may change your religion, or that he may cause mischief to appear in the land!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
Musa said: ``Verily, I seek refuge in my Lord and your Lord from every arrogant who believes not in the Day of Reckoning!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
And a believing man of Fir`awn's family, who hid his Faith said: ``Would you kill a man because he says: `My Lord is Allah,' and he has come to you with clear signs from your Lord And if he is a liar, upon him will be (the sin of) his lie; but if he is telling the truth, then some of that (calamity) wherewith he threatens you will befall on you." Verily, Allah guides not one who is a transgressor, a liar!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
``O my people! Yours is the kingdom today, you being dominant in the land. But who will save us from the torment of Allah, should it befall us" Fir`awn said: ``I show you only that which I see, and I guide you only to the path of right policy!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
And he who believed said: ``O my people! Verily, I fear for you an end like that day (of disaster) of the groups (of old)!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
``Like the end of the people of Nuh, and `Ad, and Thamud and those who came after them. And Allah wills no injustice for (His) servants."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
``And, O my people! Verily, I fear for you the Day when there will be mutual calling."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
A Day when you will turn your backs and flee having no protector from Allah. And whomsoever Allah sends astray, for him there is no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
And indeed Yusuf did come to you, in times gone by, with clear signs, but you ceased not to doubt in that which he did bring to you, till when he died, you said: ``No Messenger will Allah send after him." Thus Allah leaves astray him who is a transgressor and a skeptic.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who dispute about the Ayat of Allah, without any authority that has come to them, it is greatly hateful and disgusting to Allah and to those who believe. Thus does Allah seal up the heart of every arrogant, tyrant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And Fir`awn said: ``O Haman! Build me a lofty tower that I may arrive at the ways --\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
The ways of the heavens, and I may look upon the God of Musa, but verily, I think him to be a liar." Thus it was made fair seeming, in Fir`awn's eyes, the evil of his deeds, and he was hindered from the path; and the plot of Fir`awn led to nothing but loss and destruction.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
And the man who believed said: ``O my people! Follow me, I will guide you to the way of right conduct."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
``O my people! Truly, this life of the world is nothing but an enjoyment, and verily, the Hereafter that is the home that will remain forever."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
``Whoever does an evil deed, will not be requited except the like thereof; and whosoever does a righteous deed, whether male or female and is a true believer, such will enter Paradise, where they will be provided therein without limit."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
``And O my people! How is it that I call you to salvation while you call me to the Fire!"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
``You invite me to disbelieve in Allah, and to join partners in worship with Him of which I have no knowledge; and I invite you to the Almighty, the Oft-Forgiving!"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
``La Jarama, you call me to one that does not have a claim in this world or in the Hereafter. And our return will be to Allah, and the transgressors, they shall be the dwellers of the Fire!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
``And you will remember what I am telling you, and my affair I leave it to Allah. Verily, Allah is the All-Seer of (His) servants."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
So, Allah saved him from the evils that they plotted (against him), while an evil torment encompassed Fir`awn's people.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The Fire, they are exposed to it, morning and afternoon. And on the Day when the Hour will be established (it will be said to the angels): ``Admit Fir`awn's people into the severest torment!"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And, when they will dispute in the Fire, the weak will say to those who were arrogant: ``Verily, we followed you, can you then take from us some portion of the Fire"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who were arrogant will say: ``We are all (together) in this (Fire)! Verily, Allah has judged between (His) servants!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire will say to the keepers (angels) of Hell: ``Call upon your Lord to lighten for us the torment for a day!"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They will say: ``Did there not come to you, your Messengers with (clear) evidences" They will say: ``Yes." They will reply: ``Then call (as you like)! And the invocation of the disbelievers is nothing but in vain!"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Verily, We will indeed make victorious Our Messengers and those who believe in this world's life and on the Day when the witnesses will stand forth, --\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The Day when their excuses will be of no profit to wrongdoers. Theirs will be the curse, and theirs will be the evil abode.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
And, indeed We gave Musa the guidance, and We caused the Children of Israel to inherit the Scripture --\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
A guide and a reminder for men of understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
So be patient. Verily, the promise of Allah is true, and ask forgiveness for your fault, and glorify the praises of your Lord in the `Ashi and in the Ibkar.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Verily, those who dispute about the Ayat of Allah, without any authority having come to them, there is nothing else in their breasts except pride. They will never have it. So seek refuge in Allah. Verily, it is He Who is the All-Hearer, the All-Seer.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
The creation of the heavens and the earth is indeed greater than the creation of mankind; yet, most of the people do not know.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
And not equal are the blind and those who see; nor those who believe, and do righteous good deeds, and those who do evil. Little do you remember!\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Verily, the Hour is surely coming, there is no doubt about it, yet most men believe not.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord said: ``Call upon Me, I will answer you. Verily, those who scorn My worship they will surely enter Hell in humiliation!"\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
Allah, it is He Who has made the night for you that you may rest therein and the day for you to see. Truly, Allah is full of bounty to mankind; yet, most of mankind give no thanks.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
That is Allah, your Lord, the Creator of all things, La ilaha ila Huwa. How then are you turning away\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus were turned away those who used to deny the Ayat of Allah.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
Allah, it is He Who has made for you the earth as a dwelling place and the sky as a canopy, and has given you shape and made your shapes good and pure (looking) and has provided you with good things. That is Allah, your Lord, so Blessed be Allah, the Lord of all that exists.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Ever Living, La ilaha illa Huwa; so invoke Him making the religion for Him Alone. All the praises and thanks be to Allah, the Lord of all that exits.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say: ``I have been forbidden to worship those whom you worship besides Allah, since there have come to me evidences from my Lord; and I am commanded to submit to the Lord of all that exists.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He, Who has created you from dust, then from a Nutfah then from a clot (a piece of coagulated blood), then brings you forth as an infant, then (makes you grow) to reach the age of full strength, and afterwards to be old -- though some among you die before -- and that you reach an appointed term in order that you may understand.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
It is He Who gives life and causes death. And when He decides upon a thing He says to it only: ``Be!" - and it is.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
See you not those who dispute about the Ayat of Allah How are they turning away\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who deny the Book, and that with which We sent Our Messengers they will come to know.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When iron collars will be rounded over their necks, and the chains, they shall be dragged along,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
In the boiling water, then they will be burned in the Fire.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then it will be said to them: ``Where are (all) those whom you used to consider partners"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
``Besides Allah" They will say: ``They have vanished from us. Nay, we did not call upon anything before." Thus Allah leads astray the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
That was because you had been exulting in the earth without any right, and that you used to rejoice extremely.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter the gates of Hell to abide therein, and (indeed) what an evil abode of the arrogant!\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So be patient, verily, the promise of Allah is true and whether We show you some part of what We have promised them, or We cause you to die, then still it is to Us they all shall be returned.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
And, indeed We have sent Messengers before you, of some of them We have related to you their story. And of some We have not related to you their story, and it was not given to any Messenger that he should bring a sign except by the leave of Allah. But, when comes the commandment of Allah, the matter will be decided with truth, and the followers of falsehood will then be lost.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
Allah, it is He Who has made cattle for you, that you may ride on some of them, and of some you eat.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And you have (many other) benefits from them, and that you may reach by their means a desire that is in your breasts, and on them and on ships you are carried.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you His Ayat. Which, then of the Ayat of Allah do you deny\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they not traveled through the earth and seen what was the end of those before them They were more in number than them and mightier in strength, and in the traces in the land; yet all that they used to earn availed them not.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
Then when their Messengers came to them with clear proofs, they were glad (and proud) with that which they had of the knowledge (of worldly things). And that at which they used to mock, surrounded them.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
So when they saw Our punishment, they said: ``We believe in Allah Alone and reject (all) that we used to associate with Him as (His) partners."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
Then their Faith could not avail them when they saw Our punishment. (Like) this has been the way of Allah in dealing with His servants. And there the disbelievers lost utterly.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
A revelation from the Most Gracious, the Most Merciful.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book whereof the Ayat are explained in detail -- a Qur'an in Arabic for people who know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
Giving glad tidings and warning, but most of them turn away, so they hear not.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say: ``Our hearts are under coverings from that to which you invite us; and in our ears is deafness, and between us and you is a screen, so work you (on your way); verily, we are working (on our way)."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say: ``I am only a human being like you. It is revealed to me that your God is One God, therefore take straight path to Him and obedience to Him, and seek forgiveness of Him. And woe to the polytheists.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Those who give not the Zakah and they are disbelievers in the Hereafter.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Truly, those who believe and do righteous good deeds, for them will be an endless reward that will never stop.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say: ``Do you verily disbelieve in Him Who created the earth in two Days And you set up rivals with Him That is the Lord of all that exists."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
He placed therein firm mountains from above it, and He blessed it, and measured therein its sustenance in four Days equal for all those who ask.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He rose over (Istawa ila) the heaven when it was smoke, and said to it and to the earth: ``Come both of you willingly or unwillingly." They both said: ``We come willingly."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
Then He completed and finished their creation (as) seven heavens in two Days and He made in each heaven its affair. And We adorned the nearest (lowest) heaven with lamps (stars) to be an adornment as well as to guard. Such is the decree of Him, the Almighty, the All-Knower.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, then say: ``I have warned you of a Sa`iqah like the Sa`iqah which overtook `Ad and Thamud."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
When the Messengers came to them, from before them and behind them (saying): ``Worship none but Allah," they said: ``If our Lord had so willed, He would surely have sent down the angels. So, indeed we disbelieve in that with which you have been sent."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for `Ad, they were arrogant in the land without right, and they said: ``Who is mightier than us in strength" See they not that Allah Who created them was mightier in strength than them. And they used to deny Our Ayat!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
So, We sent upon them a Sarsar wind in days of calamity that We might give them a taste of disgracing torment in this present worldly life. But surely the torment of the Hereafter will be more disgracing, and they will never be helped.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And as for Thamud, We showed them the path of truth but they preferred blindness to guidance; so the Sa`iqah of disgracing torment seized them because of what they used to earn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We saved those who believed and had Taqwa.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
And (remember) the Day that the enemies of Allah will be gathered to the Fire, then they will be driven.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
Till, when they reach it, their hearing (ears) and their eyes and their skins will testify against them as to what they used to do.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they will say to their skins, ``Why do you testify against us" They will say: ``Allah has caused us to speak - as He causes all things to speak, and He created you the first time, and to Him you are made to return."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
And you have not been hiding yourselves (in the world), lest your ears and your eyes and your skins should testify against you; but you thought that Allah knew not much of what you were doing.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
And that thought of yours which you thought about your Lord, has brought you to destruction; and you have become of those utterly lost!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
Then, if they bear the torment patiently, then the Fire is the home for them, and if they seek to please Allah, yet they are not of those who will ever be allowed to please Allah.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We have assigned for them intimate companions (in this world), who have made fair seeming to them, what was before them and what was behind them. And the Word is justified against them as it was justified against those who were among the previous generations of Jinn and men that had passed away before them. Indeed they (all) were the losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
And those who disbelieve say: ``Listen not to this Qur'an, and make noise in the midst of its (recitation) that you may overcome."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
But surely, We shall cause those who disbelieve to taste a severe torment, and certainly, We shall requite them the worst of what they used to do.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the recompense of the enemies of Allah: the Fire. Therein will be for them the eternal home, a recompense for that they used to deny Our Ayat.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And those who disbelieve will say: ``Our Lord! Show us those among Jinn and men who led us astray, that we may crush them under our feet so that they become the lowest."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Verily, those who say: ``Our Lord is Allah," and then they stand firm, on them the angels will descend (saying): ``Fear not, nor grieve! But receive the glad tidings of Paradise which you have been promised!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
``We have been your friends in the life of this world and are (so) in the Hereafter. Therein you shall have (all) that your souls desire, and therein you shall have (all) for which you ask."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
``An entertainment from the Oft-Forgiving, Most Merciful."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is better in speech than he who invites to Allah, and does righteous deeds, and says: ``I am one of the Muslims."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
The good deed and the evil deed cannot be equal. Repel (the evil) with one which is better, then verily he, between whom and you there was enmity, (will become) as though he was a close friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none is granted it except those who are patient -- and none is granted it except the owner of the great portion in this world.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if an evil whisper from Shaytan tries to turn you away, then seek refuge in Allah. Verily, He is the All-Hearer, the All-Knower.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And from among His signs are the night and the day, and the sun and the moon. Do not prostrate yourselves to the sun nor to the moon, but prostrate yourselves to Allah Who created them, if you worship Him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they are too proud, then there are those who are with your Lord glorify Him night and day, and never are they tired.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And among His signs; that you see the earth barren, but when We send down water to it, it is stirred to life and growth. Verily, He Who gives it life, surely is able to give life to the dead. Indeed He is Able to do all things.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Verily, those who Yulhiduna Fi Our Ayat are not hidden from Us. Is he who is cast into the Fire better or he who comes secure on the Day of Resurrection Do what you will. Verily, He is All-Seer of what you do.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Verily, those who disbelieved in the Reminder when it came to them. And verily, it is an honorable well-fortified respected Book.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot come to it from before it or behind it, (it is) sent down by the All-Wise, Worthy of all praise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Nothing is said to you except what was said to the Messengers before you. Verily, your Lord is the Possessor of forgiveness, and (also) the Possessor of painful punishment.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
And if We had sent this as a Qur'an in a foreign language, they would have said: ``Why are not its verses explained in detail What! Not in Arabic nor an Arab" Say: ``It is for those who believe, a guide and a cure. And as for those who disbelieve, there is heaviness in their ears, and it is blindness for them. They are called from a place far away."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And indeed We gave Musa the Scripture, but dispute arose therein. And had it not been for a Word that went forth before from your Lord, and the matter would have been settled between them. But truly, they are in grave doubt thereto.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whosoever does righteous good deed, it is for himself; and whosoever does evil, it is against himself. And your Lord is not at all unjust to (His) servants.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
To Him is referred the knowledge of the Hour. No fruit comes out of its sheath, nor does a female conceive nor brings forth (young), except by His knowledge. And on the Day when He will call unto them (saying): ``Where are My (so-called) partners" They will say: ``We inform You that none of us bears witness to it!"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
And those whom they used to invoke before (in this world) shall disappear from them, and they will perceive that they have no place of refuge.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man does not get tired of asking for good; but if an evil touches him, then he gives up all hope and is lost in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And truly, if We give him a taste of mercy from Us, after some adversity has touched him, he is sure to say: ``This is due to my (merit); I think not that the Hour will be established. But if I am brought back to my Lord, surely there will be for me the best with Him. ``Then, We verily will show to the disbelievers what they have done, and We shall make them taste a severe torment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
And when We show favor to man, he turns away and becomes arrogant; but when evil touches him, then he has recourse to long supplications.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say: ``Tell me, if it is from Allah, and you disbelieve in it Who is more astray than one who is in opposition far away."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We will show them Our signs in the universes, and within themselves, until it becomes manifest to them that this is the truth. Is it not sufficient in regard to your Lord that He is a Witness over all things\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Lo, Verily, they are in doubt concerning the meeting with their Lord. Verily, He is surrounding all things!\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
`Ain Sin Qaf.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Likewise Allah, the Almighty, the All-Wise sends revelation to you as to those before you.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him belongs all that is in the heavens and all that is on the earth, and He is the Most High, the Most Great.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
Nearly the heavens might be rent asunder from above them, and the angels glorify the praises of their Lord, and ask for forgiveness for those on the earth. Lo, Verily, Allah is the Oft-Forgiving, the Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And as for those who take as protecting friends others besides Him -- Allah is Hafiz over them, and you are not a trustee over them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And thus We have revealed to you a Qur'an in Arabic that you may warn the Mother of the Towns and all around it, and warn (them) of the Day of Assembling of which there is no doubt, a party will be in Paradise and a party in the blazing Fire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
And if Allah had willed, He could have made them one nation, but He admits whom He wills to His mercy. And the wrongdoers will have neither a protector nor a helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they taken protecting friends besides Him But Allah --- He Alone is the protector. And He Who gives life to the dead, and He is Able to do all things.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
And in whatsoever you differ, the decision thereof is with Allah. Such is Allah, my Lord in Whom I put my trust, and to Him I turn in repentance.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
The Creator of the heavens and the earth. He has made for you mates from yourselves, and for the cattle (also) mates. By this means He creates you. There is nothing like Him, and He is the All-Hearer, the All-Seer.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belong the keys of the heavens and the earth. He enlarges provision for whom He wills, and straitens. Verily, He is the All-Knower of everything.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He (Allah) has ordained for you the same religion which He ordained for Nuh, and that which We have revealed to you, and that which We ordained for Ibrahim, Musa and `Isa saying you should establish religion and make no divisions in it. Intolerable for the idolators is that to which you call them. Allah chooses for Himself whom He wills, and guides unto Himself who turns to Him in repentance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they divided not till after knowledge had come to them, through transgression between themselves. And had it not been for a Word that went forth before from your Lord for an appointed term, the matter would have been settled between them. And verily, those who were made to inherit the Scripture after them, are in grave doubt concerning it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
So unto this then invite (people), and stand firm as you are commanded, and follow not their desires but say: ``I believe in whatsoever Allah has sent down of the Book and I am commanded to do justice among you. Allah is our Lord and your Lord. For us our deeds and for you your deeds. There is no dispute between us and you. Allah will assemble us (all), and to Him is the final return."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who dispute concerning Allah, after it has been accepted, of no use is their dispute before their Lord and on them is wrath, and for them will be a severe torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is Allah Who has sent down the Book in truth, and the Balance. And what can make you know that perhaps the Hour is close at hand\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who believe not therein seek to hasten it, while those who believe are fearful of it, and know that it is the very truth. Verily, those who dispute concerning the Hour are certainly in error far away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is very Gracious and Kind to His servants. He gives provisions to whom He wills. And He is the All-Strong, the Almighty.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whosoever desires the reward of the Hereafter, We give him increase in his reward, and whosoever desires the reward of this world, We give him thereof, and he has no portion in the Hereafter.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or have they partners with Allah who have instituted for them a religion which Allah has not ordained And had it not been for a decisive Word, the matter would have been judged between them. And verily, for the wrongdoers there is a painful torment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You will see the wrongdoers fearful of that which they have earned, and it will surely befall them. But those who believe and do righteous deeds (will be) in the flowering meadows of the Gardens. They shall have whatsoever they desire with their Lord. That is the supreme grace.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
That is whereof Allah gives glad tidings to His servants who believe and do righteous good deeds. Say: ``No reward do I ask of you for this except to be kind to me for my kinship with you." And whoever earns a good righteous deed, We shall give him an increase of good in respect thereof. Verily, Allah is Oft-Forgiving, Most Ready to appreciate.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or say they: ``He has invented a lie against Allah" If Allah willed, He could have sealed up your heart. And Allah wipes out falsehood, and establishes the truth by His Word. Verily, He knows well what are in the breasts.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
And He it is Who accepts repentance from His servants, and forgives sins, and He knows what you do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He answers those who believe and do righteous good deeds, and gives them increase of His bounty. And as for the disbelievers, theirs will be a severe torment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
And if Allah were to extend the provision for His servants, they would surely rebel in the earth, but He sends down by measure as He wills. Verily, He is, in respect of His servants, the Well-Aware, the All-Seer.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And He it is Who sends down the rain after they have despaired, and spreads His mercy. And He is the Wali, Worthy of all praise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And among His Ayat is the creation of the heavens and the earth, and whatever moving creatures He has dispersed in them both. And He is Able to assemble them whenever He wills.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
And whatever of misfortune befalls you, it is because of what your hands have earned. And He pardons much.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
And you cannot escape from Allah in the earth, and besides Allah you have neither any protector nor any helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And among His signs are the ships in the sea like mountains.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He wills, He causes the wind to cease, then they would become motionless on the surface (of the sea). Verily, in this are signs for everyone patient and grateful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He may destroy them because of that which their (people) have earned. And He pardons much.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
And those who dispute as regards Our Ayat may know that there is no place of refuge for them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
So whatever you have been given is but (a passing) enjoyment for this worldly life, but that which is with Allah is better and more lasting for those who believe and put their trust in their Lord.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who shun the greater sins, and Al-Fawahish, and when they are angry, they forgive.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who answer the Call of their Lord, and perform the Salah, and who (conduct) their affairs by mutual consultation, and who spend of what We have bestowed on them.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when an oppressive wrong is done to them, take revenge.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
The recompense for an evil is an evil like thereof; but whoever forgives and makes reconciliation, his reward is with Allah. Verily, He likes not the wrongdoers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And indeed whosoever takes revenge after he has suffered wrong, for such there is no way (of blame) against them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The way is only against those who oppress men and rebel in the earth without justification; for such there will be a painful torment.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
And verily, whosoever shows patience and forgives, that would truly be from the things recommended by Allah.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
And whomsoever Allah sends astray, for him there is no protector after Him. And you will see the wrongdoers, when they behold the torment, they will say: ``Is there any way of return"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And you will see them brought forward to it (Hell) made humble by disgrace, (and) looking with stealthy glance. And those who believe will say: ``Verily, the losers are they who lose themselves and their families on the Day of Resurrection." Verily, the wrongdoers will be in a lasting torment.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And they will have no protectors to help them other than Allah. And he whom Allah sends astray, for him there is no way.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Answer the Call of your Lord before there comes from Allah a Day which cannot be averted. You will have no refuge on that Day nor there will be for you any denying.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they turn away, We have not sent you as a Hafiz over them. Your duty is to convey. And verily, when We cause man to taste of mercy from Us, he rejoices there at; but when some evil befalls them because of the deeds which their hands have sent forth, then verily, man (becomes) ingrate!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To Allah belongs the kingdom of the heavens and the earth. He creates what He wills. He bestows female upon whom He wills, and bestows male upon whom He wills.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He bestows both males and females, and He renders barren whom He wills. Verily, He is the All-Knower and is Able (to do all things).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
It is not given to any human being that Allah should speak to him unless (it be) by revelation, or from behind a veil, or (that) He sends a Messenger to reveal what He wills by His leave. Verily, He is Most High, Most Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
And thus We have sent to you Ruh of Our command. You knew not what is the Book, nor what is Faith. But We have made it a light wherewith We guide whosoever of Our servants We will. And verily, you are indeed guiding to a straight path.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The path of Allah to Whom belongs all that is in the heavens and all that is on the earth. Verily, all matters at the end go to Allah.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the manifest Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
Verily, We have made it a Qur'an in Arabic that you may be able to understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And verily, it is in the Mother of the Book with Us, indeed exalted, full of wisdom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Shall We then take away the Reminder from you, because you are a people excessive.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
And how many a Prophet have We sent amongst the men of old.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
And never came there a Prophet to them but they used to mock at him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
Then We destroyed men stronger (in power) than these and the example of the ancients has passed away.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And indeed if you ask them: ``Who has created the heavens and the earth" They will surely say: ``The All-Mighty, the All-Knower created them."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
Who has made for you the earth like a bed, and has made for you roads therein, in order that you may find your way.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And Who sends down water from the sky in due measure, then We revive a dead land therewith, and even so you will be brought forth.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
And Who has created all the pairs and has appointed for you ships and cattle on which you ride,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
In order that you may mount on their backs, and then may remember the favor of your Lord when you mount thereon, and say: ``Glory to Him Who has subjected this to us, and we could have never had it."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
And verily, to Our Lord we indeed are to return!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
Yet, they assign to some of His servants a share with Him. Verily, man is indeed a manifest ingrate!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or has He taken daughters out of what He has created, and He has selected for you sons\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And if one of them is informed of the news of that which he sets forth as a parable to the Most Gracious, his face becomes dark, and he is filled with grief!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
A creature who is brought up in adornments, and who in dispute cannot make itself clear\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they make females the angels who themselves are servants of the Most Gracious. Did they witness their creation Their testimony will be recorded, and they will be questioned!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they said: ``If it had been the will of the Most Gracious, we should not have worshipped them." They have no knowledge whatsoever of that. They do nothing but lie!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them any Book before this (the Qur'an) to which they are holding fast\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Nay! They say: ``We found our fathers following a certain way and religion, and we guide ourselves by their footsteps."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And similarly, We sent not a warner before you to any town (people) but the luxurious ones among them said: ``We found our fathers following a certain way and religion, and we will indeed follow their footsteps."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
He said: ``Even if I bring you better guidance than that which you found your fathers following" They said: ``Verily, we disbelieve in that with which you have been sent."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So We took revenge on them, then see what was the end of those who denied.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And (remember) when Ibrahim said to his father and his people: ``Verily, I am innocent of what you worship,"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
``Except Him Who created me; and verily, He will guide me."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it a word lasting among his offspring, that they may turn back.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
Nay, but I gave to these and their fathers to enjoy, till there came to them the truth, and a Messenger making things clear.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
And when the truth came to them, they said: ``This is magic, and we disbelieve therein."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
And they say: ``Why is not this Qur'an sent down to some great man of the two towns"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Is it they who would portion out the mercy of your Lord It is We Who portion out between them their livelihood in this world, and We raised some of them above others in ranks, so that some may employ others in their work. But the mercy of your Lord is better than what they amass.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And were it not that mankind would have become of one community, We would have provided for those who disbelieve in the Most Gracious, silver roofs for their houses, and elevators whereby they ascend,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And for their houses, doors, and thrones on which they could recline,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And adornments of gold. Yet all this would have been nothing but an enjoyment of this world. And the Hereafter with your Lord is for those who have Taqwa.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
And whosoever Ya`shu (turns away blindly) from the remembrance of the Most Gracious, We appoint for him Shaytan to be a Qarin (a companion) to him.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
And verily, they hinder them from the path, but they think that they are guided aright!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
Till, when (such a one) comes to Us, he says, ``Would that between me and you were the distance of the two easts (or the east and west) a worst companion (indeed)!"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
It will profit you not this Day as you did wrong, (and) that you will be sharers in the punishment.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Can you make the deaf to hear, or can you guide the blind or him who is in manifest error\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
And even if We take you away, We shall indeed take vengeance on them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or (if) We show you that wherewith We threaten them, then verily, We have perfect command over them.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So hold you fast to that which is revealed to you. Verily, you are on the straight path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
And verily, this is indeed a Dhikr for you and your people, and you will be questioned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And ask whom We sent before you of Our Messengers: ``Did We ever appoint gods to be worshipped besides the Most Gracious"\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
And indeed We did send Musa with Our Ayat to Fir`awn and his chiefs. He said: ``Verily, I am a Messenger of the Lord of all that exists."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he came to them with Our Ayat, behold, they laughed at them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And not an Ayah We showed them but it was greater than its fellow preceding it, and We seized them with torment, in order that they might turn.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said (to Musa): ``O you sorcerer! Invoke your Lord for us according to what He has made a pact with you. Verily, We shall guide ourselves."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We removed the torment from them, behold, they broke their covenant.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Fir`awn proclaimed among his people (saying): ``O my people! Is not mine the dominion of Egypt, and these rivers flowing underneath me. See you not then"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
``Am I not better than this one (Musa) who is despicable and can scarcely express himself clearly"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Why then are not golden bracelets bestowed on him, or angels sent along with him"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
Thus he fooled his people, and they obeyed him. Verily, they were ever a people who were rebellious.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
So when they angered Us, We punished them, and drowned them all.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
And We made them a precedent, and an example to later generations.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Maryam is quoted as an example, behold, your people cry aloud thereat.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And say: ``Are our gods better or is he" They quoted not the above example except for argument. Nay! But they are a quarrelsome people.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
He was not more than a servant. We granted Our favor to him, and We made him an example for the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And if it were Our will, We would have made angels to replace you on the earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And he shall be a known sign for (the coming of) the Hour. Therefore have no doubt concerning it. And follow Me! This is the straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And let not Shaytan hinder you. Verily, he (Shaytan) to you is a plain enemy.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when `Isa came with clear proofs, he said: ``I have come to you with Al-Hikmah, and in order to make clear to you some of that in which you differ. Therefore have Taqwa of Allah and obey me."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
``Verily, Allah! He is my Lord and your Lord. So worship Him. This is the straight path."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But the sects from among themselves differed. So woe to those who do wrong from the torment of a painful Day!\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Do they only wait for the Hour that it shall come upon them suddenly while they perceive not\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Friends on that Day will be foes one to another except those who have Taqwa.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
My servants! No fear shall be on you this Day, nor shall you grieve,\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
(You) who believed in Our Ayat and were Muslims.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter Paradise, you and your wives, in happiness.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
Trays of gold and cups will be passed round them; (there will be) therein all that their souls desire, and all that eyes could delight in and you will abide therein forever.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
This is the Paradise, which you have been made to inherit because of your deeds that you used to do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
Therein for you will be fruits in plenty, of which you will eat (as you desire).\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
Verily, the criminals will be in the torment of Hell to abide therein forever.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
(The torment) will not be lightened for them, and they will be plunged into destruction with deep regrets, sorrows and in despair therein.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
We wronged them not, but they were the wrongdoers.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they will cry: ``O Malik (keeper of Hell)! Let your Lord make an end of us." He will say: ``Verily, you shall abide forever."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
Indeed We have brought the truth to you, but most of you have a hatred for the truth.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Or have they plotted some plan Then We too are planning.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think that We hear not their secrets and their private counsel Yes (We do) and Our messengers are by them, to record.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say: ``If the Most Gracious had a son, then I am the first of the worshippers."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Glorified is the Lord of the heavens and the earth, the Lord of the Throne! Exalted be He from all that they ascribe (to Him).\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So leave them (alone) to speak nonsense and play until they meet the Day of theirs which they have been promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
It is He Who is the only God in the heaven and the only God on the earth. And He is the All-Wise, the All-Knower.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And Blessed be He to Whom belongs the kingdom of the heavens and the earth, and all that is between them, and with Whom is the knowledge of the Hour, and to Whom you (all) will be returned.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those whom they invoke instead of Him have no power of intercession -- except for those who bear witness to the truth knowingly, and they know.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And if you ask them who created them, they will surely say: ``Allah." How then are they turned away\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And his saying: ``O my Lord! Verily, these are a people who believe not!"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
So turn away from them, and say: Salam (peace!) But they will come to know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the manifest Book that makes things clear.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
We sent it down on a blessed night. Verily, We are ever warning.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
Therein (that night) is decreed every matter, Hakim.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
As a command from Us. Verily, We are ever sending,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
(As) a mercy from your Lord. Verily, He is the All-Hearer, the All-Knower.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
The Lord of the heavens and the earth and all that is between them, if you (but) have a faith with certainty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
La ilaha illa Huwa. He gives life and causes death -- your Lord and the Lord of your forefathers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
Nay! They play about in doubt.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
Then wait you for the Day when the sky will bring forth a visible smoke,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Covering mankind, this is a painful torment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
(They will say): ``Our Lord! Remove the torment from us, really we shall become believers!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How can there be for them an admonition, when a Messenger explaining things clearly has already come to them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
Then they had turned away from him and said: ``(He is) one taught, a madman!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
Verily, We shall remove the torment for a while. Verily, you will revert.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
On the Day when We shall strike you with the great Batshah. Verily, We will exact retribution.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
And indeed We tried before them Fir`awn's people, when there came to them a noble Messenger.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
Saying: ``Deliver to me the servants of Allah. Verily, I am to you a Messenger worthy of all trust."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
``And exalt not yourselves against Allah. Truly, I have come to you with a manifest authority."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
``And truly, I seek refuge with my Lord and your Lord, lest you should stone me."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
``But if you believe me not, then keep away from me and leave me alone."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
So he (Musa) called upon his Lord (saying): ``These are indeed the people who are criminals."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
(Allah said): ``Depart you with My servants by night. Surely, you will be pursued."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
``And leave the sea as it is (quiet and divided). Verily, they are a host to be drowned."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How many of gardens and springs that they (Fir`awn's people) left behind,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And green crops (fields) and goodly places,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And comforts of life wherein they used to take delight!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Thus (it was)! And We made other people inherit them.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
And the heavens and the earth wept not for them, nor were they given respite.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And indeed We saved the Children of Israel from the humiliating torment,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
From Fir`awn; verily, he was arrogant and was of the excessive.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We chose them above the nations (Al-`Alamin) with knowledge,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And granted them signs in which there was a plain trial.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Verily, these people are saying:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
``There is nothing but our first death, and we shall not be resurrected."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
``Then bring back our forefathers, if you speak the truth!"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better or the people of Tubba` and those before them We destroyed them because they were indeed criminals.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
And We created not the heavens and the earth, and all that is between them, for mere play.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We created them not except with truth, but most of them know not.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Verily, the Day of Judgement is the time appointed for all of them --\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
The Day when a near relative cannot avail a near relative in aught, and no help can they receive,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Except him on whom Allah has mercy. Verily, He is the All-Mighty, the Most Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Verily, the tree of Zaqqum\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
Will be the food of the sinners.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like boiling oil, it will boil in the bellies,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
Like the boiling of scalding water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
(It will be said:) ``Seize him and drag him into the midst of blazing Fire,"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
``Then pour over his head the torment of boiling water."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
``Taste you (this)! Verily, you were (pretending to be) the mighty, the generous."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
``Verily, this is that whereof you used to doubt!"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Verily, those who have Taqwa, will be in place of security.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Among Gardens and Springs,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Dressed in Sundus and Istabraq, facing each other,\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
So (it will be). And We shall marry them to Hur (fair females) with wide lovely eyes,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
They will call therein for every kind of fruit in peace and security;\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They will never taste death therein except the first death, and He will save them from the torment of the blazing Fire,\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
As a bounty from your Lord! That will be the supreme success!\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
Certainly, We have made this easy in your tongue, in order that they may remember.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
Wait then; verily, they (too) are waiting.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Book is from Allah, the Almighty, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Verily, in the heavens and the earth are signs for the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in your creation, and what He spread (through the earth) of moving creatures are signs for people who have faith with certainty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And in the alternation of night and day, and the provision that Allah sends down from the sky, and revives therewith the earth after its death, and in the turning about of the winds, are signs for a people who understand.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are the Ayat of Allah, which We recite to you with truth. Then in which speech after Allah and His Ayat will they believe\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to every sinful liar.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who hears the Ayat of Allah Tutla (recited) to him, yet persists with pride as if he heard them not. So announce to him a painful torment!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he learns something of Our Ayat, he makes them a jest. For such there will be a humiliating torment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
In front of them there is Hell. And that which they have earned will be of no profit to them, nor those whom they have taken as protective friends besides Allah. And theirs will be a great torment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This is guidance. And those who disbelieve in the Ayat of their Lord, for them there is a painful torment of Rijz.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
Allah, it is He Who has subjected to you the sea, that ships may sail through it by His command, and that you may seek of His bounty, and that you may be thankful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And has subjected to you all that is in the heavens and all that is on the earth; it is all (as a favor and kindness) from Him. Verily, in it are signs for a people who think deeply.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Say to the believers to forgive those who hope not for the Days of Allah, that He may recompense people, according to what they have earned.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whosoever does a good deed, it is for himself, and whosoever does evil, it is against (himself). Then to your Lord you will be made to return.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
And indeed We gave the Children of Israel the Scripture, and the understanding of the Scripture and its laws, and the prophethood; and provided them with good things, and preferred them above the nations.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And gave them clear proofs in matters. And they differed not until after the knowledge came to them, through envy among themselves. Verily, your Lord will judge between them on the Day of Resurrection about that wherein they used to differ.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
Then We have put you on a (legal) way of commandment. So follow you that, and follow not the desires of those who know not.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Verily, they can avail you nothing against Allah. Verily, the wrongdoers are protecting friends of one another, but Allah is the Protector of those who have Taqwa.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This is a clear insight and evidence for mankind, and a guidance and a mercy for people who have faith with certainty.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Or do those who earn evil deeds think that We shall hold them equal with those who believe and do righteous good deeds, in their present life and after their death Worst is the judgement that they make.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
And Allah has created the heavens and the earth with truth, in order that each person may be recompensed what he has earned, and they will not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Have you seen him who takes his own lust as his god And Allah, left him astray with knowledge, and sealed his hearing and his heart, and put a cover on his sight. Who then will guide him after Allah Will you not then remember\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say: ``There is nothing but our life of this world, we die and we live and nothing destroys us except Ad-Dahr (time). And they have no knowledge of it, they only presume.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our Clear Ayat are recited to them, their argument is no other than that they say: ``Bring back our (dead) fathers, if you are truthful!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say (to them): ``Allah gives you life, then causes you to die, then He will assemble you on the Day of Resurrection about which there is no doubt. But most of mankind know not."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
And to Allah belongs the kingdom of the heavens and the earth. And on the Day that the Hour will be established -- on that Day the followers of falsehood shall lose.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And you will see each nation humbled to their knees (Jathiyah), each nation will be called to its Record (of deeds). This Day you shall be recompensed for what you used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This Our Record speaks about you with truth. Verily, We were recording what you used to do.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
Then, as for those who believed and did good deeds, their Lord will admit them to His mercy. That will be the evident success.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But as for those who disbelieved (it will be said to them): ``Were not Our Ayat recited to you But you were proud, and you were a people who were criminals."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said: ``Verily, Allah's promise is the truth, and there is no doubt about the coming of the Hour," you said: ``We know not what is the Hour: we do not think it but conjecture, and we have no firm convincing belief (therein)."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And the evil of what they did will appear to them, and that which they used to mock at will completely encircle them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said: ``This Day We will forget you as you forgot the meeting of this Day of yours. And your abode is the Fire, and there is none to help you."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
This, because you took the revelations of Allah in mockery, and the life of the world deceived you. So this Day, they shall not be taken out from there (Hell), nor shall they be returned to the worldly life.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
So all praise is due to Allah, the Lord of the heavens and the Lord of the earth, and the Lord of all that exists.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
And His is the majesty in the heavens and the earth, and He is Al-`Aziz, Al-Hakim.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha Mim.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The revelation of the Book is from Allah, the Almighty, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We created not the heavens and the earth and all that is between them except with truth, and for a specified term. But those who disbelieve, turn away from that whereof they are warned.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say: ``Think you about all that you invoke besides Allah Show me what have they created of the earth Or have they a share in (the creation of) the heavens Bring me a scripture prior to this or some trace of knowledge, if you are truthful!"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is more astray than those who invoke besides Allah others who will not answer them until the Day of Resurrection, and who are unaware of their invocations to them\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when mankind are gathered, they (false deities) will become their enemies and will deny their worship.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our Clear Ayat are recited to them, the disbelievers say of the truth when it reaches them: ``This is plain magic!"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or say they: ``He has fabricated it." Say: ``If I have fabricated it, still you have no power to support me against Allah. He knows best of what you say among yourselves concerning it! Sufficient is He as a witness between me and you! And He is the Oft--Forgiving, the Most Merciful."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say: ``I am not a new thing among the Messengers, nor do I know what will be done with me or you. I only follow that which is revealed to me, and I am but a plain warner."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say: ``Tell me! If it was from Allah and you disbelieved it, (at the same time), a witness from among the Children of Israel has testified to something similar and believed while you rejected (the truth)!" Verily, Allah does not guide the wrongdoing people.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
And those who disbelieve say of those who believe: ``Had it been a good thing, they (the poor believers) would not have preceded us to it!" And when they have not been guided by it, they say: ``This is ancient falsehood!"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And before this was the Scripture of Musa as a guide and a mercy. And this is a Book confirming in the Arabic tongue, to warn those who do wrong, and as glad tidings for the doers of good.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Verily, those who say: ``Our Lord is (only) Allah," and thereafter stand firm, on them shall be no fear, nor shall they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Such shall be the dwellers of Paradise, abiding therein (forever) -- a reward for what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
And We have enjoined on man to be dutiful and kind to his parents. His mother bears him with hardship. And she delivers him with hardship. And (the period of) his gestation and the weaning of him is thirty months, till when he attains full strength and reaches forty years, he says: ``My Lord! Grant me the power and ability that I may be grateful for Your favor which You have bestowed upon me and upon my parents, and that I may do righteous good deeds, such as please You, and make my offspring good. Truly, I have turned to You in repentance, and truly, I am one of the Muslims."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
They are those from whom We shall accept the best of their deeds and overlook their evil deeds. (They shall be) among the dwellers of Paradise. That is a promise of truth that they had been promised.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But he who says to his parents: ``Uff to you! Do you promise me that I will be raised up when generations before me have passed" While they invoke Allah for help: ``Woe to you! Believe! Verily, the promise of Allah is true." But he says: ``This is nothing but the legends of the ancient."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
They are those against whom the Word (of torment) has justified among the previous generations of Jinn and mankind that have passed away. Verily, they are ever the losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And for all, there will be degrees according to that which they did, so that He might fully recompense for their deeds. And they will not be wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
On the Day when those who disbelieve will be exposed to the Fire (it will be said): ``You received your good things in the life of the world, and you took your pleasure therein. Today, you will be recompensed with the torment of extreme humiliation, because you were arrogant upon the earth without a right, and because you used to rebel against Allah's command.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And remember the brother of `Ad, when he warned his people in Al-Ahqaf. And surely, warners had already passed on before him and after him (saying): ``Worship none but Allah; truly, I fear for you the torment of a mighty Day."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said: ``Have you come to delude us from our gods Then bring us that with which you threaten us, if you are one of the truthful!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said: ``The knowledge (of that) is only with Allah. And I convey to you that wherewith I have been sent, but I see that you are a people given to ignorance!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
Then, when they saw it as a dense cloud approaching their valleys, they said: ``This is a cloud bringing us rain!" Nay, but it is that which you were asking to be hastened - a wind wherein is a painful torment!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
Destroying everything by the command of its Lord! So they became such that nothing could be seen except their dwellings! Thus do We recompense the criminal people!\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And indeed We had firmly established them with that wherewith We have not established you! We also gave them hearing, vision, and hearts. But their hearing, vision, and hearts availed them nothing since they used to deny the Ayat of Allah, and they were completely encircled by that which they used to ridicule!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And indeed We have destroyed towns round about you, and We have shown (them) the signs in various ways so that they might return.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
As for those whom they had taken for gods besides Allah, as the means of approach to Him, why then did they not aid them Nay, but they vanished completely from them. And that was their falsehood, and what they were fabricating.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And (remember) when We sent toward you a group of the Jinn, to listen to the Qur'an. When they attended it, they said: ``Listen quietly!" And when it was concluded, they returned to their people, as warners.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said: ``O our people! Verily, we have heard a Book sent down after Musa, confirming what came before it, it guides to the truth and to the straight path."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
``O our people! Respond to Allah's Caller, and believe in him. He (Allah) will forgive you some of your sins, and protect you from a painful torment."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
``And whosoever does not respond to Allah's Caller, he cannot escape on earth, and he will not have besides Allah any protectors. Those are in manifest error."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Do they not see that Allah, Who created the heavens and the earth, and was not wearied by their creation, is Able to give life to the dead Yes, He surely is Able to do all things.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And on the Day when those who disbelieve will be exposed to the Fire (it will be said to them): ``Is this not the truth" They will say: ``Yes, by our Lord!" He will say: ``Then taste the torment, because you used to disbelieve!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
Therefore be patient as did those of determination among the Messengers and be in no hurry for them. On the Day when they will see what they are promised, it will be as though they had not remained (in the world) except an hour in a day. (This is) a clear Message. But will any be destroyed except the defiantly rebellious people\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and hinder (men) from the path of Allah, He will render their deeds vain.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
But those who believe and do righteous good deeds, and believe in that which is sent down to Muhammad -- for it is the truth from their Lord -- He expiates from them their sins and amends their Bal.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow falsehood, while those who believe follow the truth from their Lord. Thus does Allah set forth for mankind their parables.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
So, when you meet those who disbelieve (in battle), smite (their) necks until you have fully defeated them, then tighten their bonds. Thereafter (is the time) either for generosity or ransom, until the war lays down its burden. Thus, and had Allah so willed, He could have taken vengeance against them;--but (He lets you struggle) so as to test with one another. But those who are killed in the way of Allah, He will never let their deeds be lost.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them and amend their condition.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And admit them to Paradise, which He has made known to them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O you who believe! If you support (in the cause of) Allah, He will support you, and make your foothold firm.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But as for those who disbelieve, misery awaits them, and (Allah) will make their deeds vain.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they hate that which Allah has sent down; so He has made their deeds fruitless.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not traveled through the earth and seen what happened in the end to those before them Allah destroyed them completely, and a similar (awaits) the disbelievers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is the Protector of those who believe, whereas the disbelievers have no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Certainly Allah will admit those who believe and do righteous good deeds, into Gardens under which rivers flow (Paradise); while those who disbelieve enjoy their life and eat as cattle eat; but the Fire will be their abode.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And how many a town mightier than your town that has driven you out We have destroyed, with none to help them!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
Can then he, who stands on clear evidence from his Lord, be like those for whom their evil deeds are beautified for them, while they follow their own lusts\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
The description of Paradise which is promised to those who have Taqwa, (is that) in it are rivers of water that are not Asin, rivers of milk the taste of which never changes, rivers of wine delicious to those who drink it, and rivers of refined honey; and therein for them are all kinds of fruits, and forgiveness from their Lord. Can this be likened to those who abide eternally in the Fire and are given to drink boiling water that severs their intestines\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
And among them are some who listen to you till when they go out from you, they say to those who have received knowledge: ``What is it that he has said just now ``Such are men whose hearts Allah has sealed because they followed their lusts.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
And as for those who accept guidance, He increases them in guidance and bestows on them their Taqwa.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Do they then await except that the Hour should come upon them suddenly But already there have come (some of) its portents; and when it (actually) is on them, how can they benefit then by their reminder\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
So know that La ilaha illallah and ask forgiveness for your sin, and also for (the sin of) believing men and women. And Allah knows well your moving about, and your place of rest.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
Those who believe say: ``Why is not a Surah sent down (for us)" But now that a decisive Surah is sent down mentioning fighting, you can see those in whose hearts is disease (of hypocrisy) looking at you with the look of one who is about to faint for fear of death. But it was better for them.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Obedience and good words. And when the matter is resolved, then if they had been true to Allah, it would have been better for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
So would you perhaps, if you turned away, spread corruption on earth, and sever your ties of kinship\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Such are the ones whom Allah has cursed, so that He has made them deaf and blinded their vision.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Will they not then reflect upon the Qur'an, or are there locks upon their hearts\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Verily, those who have turned back as disbelievers after guidance had become clear to them -- Shaytan has enticed them and filled them with false hopes.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they said to those who hate what Allah has sent down: ``We will obey you in part of the matter." And Allah knows their secrets.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
Then how (will it be) when the angels will take their souls at death, striking their faces and their backs\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they followed that which angered Allah and hated what earns His pleasure, so He rendered their deeds worthless.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or do those in whose hearts is a disease, think that Allah will not expose their ill--wills\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
Had We so willed, We could have shown them clearly to you, so that you would know them by their marks; but you will know them by the tone of their speech! And Allah knows (all) your deeds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And We will surely, try you until We know those who strive among you and the patient, and We will put to a test all your affairs.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Verily, those who disbelieve, and hinder from the path of Allah, and oppose the Messenger, after the guidance has been clearly shown to them, they will not harm Allah in the least, but He will make their deeds fruitless,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O you who believe! Obey Allah, and obey the Messenger and invalidate not your deeds.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Verily, those who disbelieved and obstructed others from the path of Allah and then died as disbelievers -- never will Allah not forgive them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So do not lose heart and beg for peace while you are superior. Allah is with you and He will never deprive you of (the reward of) your deeds.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
This worldly life is only amusement and diversion. And if you believe and have Taqwa of Allah, He will grant you your rewards, and will not ask from you (to sacrifice all of) your possessions.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He would demand of you all of it and urge you, you would withhold. And He will expose your (secret) ill--wills.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Here you are now invited to spend in Allah's cause; but among you are those who withhold (stingily). And whoever acts stingily is but stingy toward himself. For Allah is indeed free of needs, while you are the needy. And if you turn away, He will replace you with other people; then they will not be like you.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Verily, We have given you a manifest victory.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That Allah may forgive you your sins of the past and the future, and complete His favor on you, and guide you on the straight path,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And that Allah may help you with strong help.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
He it is Who sent down As-Sakinah into the hearts of the believers, that they may grow more in faith along with their faith. And to Allah belong the armies of the heavens and the earth, and Allah is Ever All-Knower, All-Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
That He may admit the believing men and the believing women to Gardens under which rivers flow to abide therein forever, and He may expiate from them their sins; and that is with Allah supreme success,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And that He may punish the hypocrites men and women, and also the idolators men and women, who think evil thoughts about Allah, for them is a disgraceful torment. And the anger of Allah is upon them, and He has cursed them and prepared Hell for them and worst indeed is that destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
And to Allah belong the armies of the heavens and the earth. And Allah is Ever All-Powerful, All-Wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
Verily, We have sent you as a witness, as a bearer of glad tidings, and as a warner.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
In order that you (O mankind) may believe in Allah and His Messenger and that you Tu`azziruh and Tuwaqqiruh, and Tusabbihuh Bukrah and Asila.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Verily, those who give pledge to you, they are giving pledge to Allah. The Hand of Allah is over their hands. Then whosoever breaks his pledge, breaks it only to his own harm; and whosoever fulfills what he has the covenants he makes with Allah, He will bestow on him a great reward.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
Those of the bedouins who lagged behind will say to you: ``Our possessions and our families occupied us, so ask forgiveness for us." They say with their tongues what is not in their hearts. Say: ``Who then has any power at all (to intervene) on your behalf with Allah, if He intends you hurt or intends you benefit Nay, but Allah is Aware of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
Nay, but you thought that the Messenger and the believers would never return to their families, and that was made fair seeming in your hearts, and you did think an evil thought and you became a Bura."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And whosoever does not believe in Allah and His Messenger, then verily, We have prepared for the disbelievers a blazing Fire.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
And to Allah belongs the sovereignty of the heavens and the earth. He forgives whom He wills, and punishes whom He wills. And Allah is Forgiving, Most Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who lagged behind will say, when you set forth to take the spoils, ``Allow us to follow you." They want to change Allah's Words. Say: ``You shall not follow us; thus Allah has said beforehand." Then they will say: ``Nay, you envy us." Nay, but they understand not except a little.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to the bedouins who lagged behind: ``You shall be called to fight against a people given to great warfare, then you shall fight them, or they shall surrender. Then if you obey, Allah will give you a fair reward; but if you turn away as you did turn away before, He will punish you with a painful torment."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
No blame or sin is there upon the blind, nor is there sin upon the lame, nor is there sin upon the sick. And whosoever obeys Allah and His Messenger, He will admit him to Gardens beneath which rivers flow; and whosoever turns back, He will punish him with a painful torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Indeed, Allah was pleased with the believers when they gave the pledge to you under the tree, He knew what was in their hearts, and He sent down As-Sakinah upon them, and He rewarded them with a near victory.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And abundant spoils that they will capture. And Allah is Ever All-Mighty, All-Wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised you abundant spoils that you will capture, and He has hastened for you this, and He has restrained the hands of men from you, that it may be a sign for the believers, and that He may guide you to the straight path.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And other (victories) which are not yet within your power; indeed Allah encompasses them. And Allah is Ever Able to do all things.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
And if those who disbelieve fight against you, they certainly would have turned their backs; then they would have found neither a protector nor a helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
That has been the way of Allah already with those who passed away before. And you will not find any change in the way of Allah.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And He it is Who has withheld their hands from you and your hands from them in the midst of Makkah, after He had made you victors over them. And Allah sees what you do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are those who disbelieved and hindered you from Al-Masjid Al-Haram and detained the sacrificial animals, from reaching their place of sacrifice. Had there not been believing men and believing women whom you did not know, that you may kill and on whose account a sin would have been committed by you without (your) knowledge, that Allah might bring into His mercy whom He wills -- if they had been apart, We verily, would have punished with painful torment those of them who disbelieved.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
When those who disbelieve had put in their hearts pride and haughtiness -- the pride and haughtiness of the time of ignorance, -- then Allah sent down His calmness and tranquillity upon His Messenger and upon the believers, and made them stick to the word of Taqwa; and they were well entitled to it and worthy of it. And Allah is the All-Knower of everything.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Indeed Allah shall fulfill the true vision which He showed to His Messenger in very truth. Certainly, you shall enter Al-Masjid Al-Haram, if Allah wills, secure, (some) having your heads shaved, and (some) having your hair cut short, having no fear. He knew what you knew not, and He granted besides that a near victory.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
He it is Who has sent His Messenger with guidance and the religion of truth, that He may make it superior to all religions. And All-Sufficient is Allah as a Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the Messenger of Allah. And those who are with him are severe against disbelievers, and merciful among themselves. You see them bowing falling down prostrate, seeking reward from Allah and acceptance. The mark of them is on their faces from the traces of prostration. This is their description in the Tawrah. But their description in the Injil is like a seed which sends forth its shoot, then makes it strong, and becomes thick and it stands straight on its stem, delighting the sowers, that He may enrage the disbelievers with them. Allah has promised those among them who believe and do righteous good deeds, forgiveness and a mighty reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O you who believe! Make not (a decision) in advance before Allah and His Messenger, and have Taqwa of Allah. Verily, Allah is Hearing, Knowing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O you who believe! Raise not your voices above the voice of the Prophet, nor speak aloud to him in talk as you speak aloud to one another, lest your deeds should be thwarted while you perceive not.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Verily, those who lower their voices in the presence of Allah's Messenger, they are the ones whose hearts Allah has tested for Taqwa. For them is forgiveness and a great reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Verily, those who call you from behind the dwellings, most of them have no sense.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And if they had patience till you could come out to them, it would have been better for them. And Allah is Forgiving, Most Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O you who believe! If a rebellious evil person comes to you with a news, verify it, lest you harm people in ignorance, and afterwards you become regretful to what you have done.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that among you there is the Messenger of Allah. If he were to obey you in much of the matter, you would surely be in trouble, but Allah has endeared the faith to you and has beautified it in your hearts, and has made disbelief, Fusuq and `Isyan hateful to you. Such are they who are the rightly guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
This is a grace from Allah and His favor. And Allah is All-Knowing, All-Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
And if two parties among the believers fall to fighting, then make peace between them both. But if one of them outrages against the other, then fight you (all) against the one that which outrages till it complies with the command of Allah. Then if it complies, then make reconciliation between them justly, and be equitable. Verily, Allah loves those who are the equitable.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers are but a brotherhood. So make reconciliation between your brothers, and have Taqwa of Allah that you may receive mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O you who believe! Let not a group scoff at another group, it may be that the latter are better than the former. Nor let (some) women scoff at other women, it may be that the latter are better than the former. Nor defame yourselves, nor insult one another by nicknames. Evil is the name of wickedness after faith. And whosoever does not repent, then such are indeed wrongdoers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O you who believe! Avoid much suspicion; indeed some suspicion is sin. And spy not, neither backbite one another. Would one of you like to eat the flesh of his dead brother You would hate it. And have Taqwa of Allah. Verily, Allah is the One Who forgives and accepts repentance, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind! We have created you from a male and a female, and made you into nations and tribes that you may know one another. Verily, the most honorable of you with Allah is that (believer) who has At-Taqwa. Verily, Allah is All-Knowing, All-Aware.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The bedouins say: ``We believe." Say: ``You do not believe. But say, `We have submitted,' for Faith has not yet entered your hearts. But if you obey Allah and His Messenger, He will not decrease anything in reward for your deeds. Verily, Allah is Forgiving, Most Merciful."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
Only those are the believers who have believed in Allah and His Messenger, and afterward doubt not but strive with their wealth and their lives for the cause of Allah. Those! They are the truthful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say: ``Will you inform Allah of your religion while Allah knows all that is in the heavens and all that is on the earth, and Allah is All-Aware of everything."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They regard as a favor to you that they have embraced Islam. Say: ``Do not count your Islam as a favor to me. Nay, but Allah has conferred a favor upon you that He has guided you to the Faith if you indeed are true. ``\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
``Verily, Allah knows the Unseen of the heavens and the earth. And Allah is the All-Seer of what you do."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the Glorious Qur'an.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
Nay, they wonder that there has come to them a warner from among themselves. So the disbelievers say: ``This is a strange thing!"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
``When we are dead and have become dust. (Shall we be resurrected) That is a far return."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know that which the earth takes of them, and with Us is a Book preserved.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
Nay, but they have denied the truth when it has come to them, so they are in a Marij state.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Have they not looked at the heaven above them, how We have made it and adorned it, and there are no Furuj in it\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth! We have spread it out, and set thereon Rawasi standing firm, and We planted in it every lovely (Bahij) pair.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
An insight and a Reminder for every servant who turns to Allah in repentance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We send down blessed water (rain) from the sky, then We produce therewith Jannat and grain that are reaped.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And date palms Basiqat, with arranged clusters.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
A provision for the servants. And We give life therewith to a dead land. Thus will be the Resurrection.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
Denied before them the people of Nuh, and the Dwellers of Rass, and Thamud,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And `Ad, and Fir`awn, and the brethren of Lut,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the Dwellers of Al-Aykah, and the people of Tubba`. Everyone of them denied (their) Messengers, so My threat took effect.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Were We then tired with the first creation Nay, they are in confused doubt about a new creation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
And indeed We have created man, and We know what his self whispers to him. And We are nearer to him than his jugular vein.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
(Remember) that the two receivers (recording angels) receive (each human being), one sitting on the right and one on the left.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
Not a word does he (or she) utter but there is a watcher by him ready (to record it).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the stupor of death will come in truth: ``This is what you have been avoiding!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Trumpet will be blown -- that will be the Day of the threat.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every person will come forth along with a Sa'iq and a Shahid.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
(It will be said to the sinners): ``Indeed you were heedless of this. Now We have removed from you, your covering, and sharp is your sight this Day!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his companion (angel) will say: ``Here is (his record) ready with me!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
(Allah will say to the angels:) ``Both of you throw into Hell every stubborn disbeliever"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
``Hinderer of good, transgressor, doubter,"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
``Who set up another god with Allah. Then both of you cast him in the severe torment."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His companion (devil) will say: ``Our Lord! I did not push him to transgression, but he was himself in error far astray."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
(Allah) will say: ``Dispute not in front of Me, I had already in advance sent you the threat."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
``The sentence that comes from Me cannot be changed, and I am not unjust to the servants."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On the Day when We will say to Hell: ``Are you filled" It will say: ``Are there any more"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise will be Uzlifat to those who had Taqwa, not far off.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
(It will be said): ``This is what you were promised -- (it is) for those returning in sincere repentance, and Hafiz."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
``Who feared Ar-Rahman unseen and brought a heart turned in repentance."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
``Enter you therein in peace and security -- this is a Day of eternal life!"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
There they will have all that they desire -- and We have more.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
And how many a generation We have destroyed before them who were stronger in power than they. And they went about the land! Could they find any place of refuge\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Verily, therein is indeed a reminder for him who has a heart or gives ear while he is heedful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
And indeed We created the heavens and the earth and all between them in six Days and nothing of fatigue touched Us.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
So bear with patience all that they say, and glorify the praises of your Lord, before the rising of the sun and before (its) setting.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And during a part of the night (also) glorify His praises and (so likewise) after the prostrations.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen on the Day when the caller will call from a near place.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The Day when they will hear As-Sayhah in truth, that will be the Day of coming out.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Verily, it is We Who give life and cause death; and to Us is the final return.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
On the Day when the earth shall be cleft, from off them (they will come out) hastening forth. That will be a gathering, quite easy for Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We know best what they say. And you are not the one to force them. But warn by the Qur'an; him who fears My threat.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By the scattering Dhariyat;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And the laden Hamilat;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And the steady Jariyat;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And the distributors of command,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Verily, that which you are promised is surely true.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And verily, Ad-Din is sure to occur.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven full of Hubuk,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
Certainly, you have different ideas.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Turned aside therefrom is he who is turned aside.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Cursed be Al-Kharrasun\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Who are under a cover of Sahun,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask: ``When will be the Day of Ad-Din"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
(It will be) a Day when they will be Yuftanun in the Fire!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
``Taste you your trial! This is what you used to ask to be hastened!"\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Verily, those who have Taqwa will be in the midst of Gardens and Springs,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Taking joy in the things which their Lord has given them. Verily, they were before this doers of good.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They used to sleep but little by night.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And in the hours before dawn, they were asking for forgiveness.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And in their wealth there was the right of the Sa'il and the Mahrum.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And on the earth are signs for those who have faith with certainty.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And also in yourselves. Will you not then see\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven is your provision, and that which you are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
Then by the Lord of the heaven and the earth, it is the truth, just as you can speak.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Has the story reached you, of the honored guests of Ibrahim\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they came in to him and said: ``Salaman!" He answered: ``Salamun" and said: ``You are a people unknown to me."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he turned to his household, and brought out a roasted calf.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
And placed it before them (saying): ``Will you not eat"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
Then he conceived fear of them (when they ate not). They said: ``Fear not." And they gave him glad tidings of a son having knowledge.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
Then his wife came forward with a loud voice; she smote her face, and said: ``A barren old woman!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said: ``Even so says your Lord. Verily, He is the All-Wise, the All-Knower."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
(Ibrahim) said: ``Then for what purpose you have come, O messengers"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said: ``We have been sent to a people who are criminals."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
``To send down upon them stones of clay."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
``Marked by your Lord for transgressors."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
So We brought out from therein the believers.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
But We found not there any household of the Muslims except one.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We have left there a sign for those who fear the painful torment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Musa, when We sent him to Fir`awn with a manifest authority.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But (he) turned away along with his hosts, and said: ``A sorcerer or a madman."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We took him and his armies, and dumped them into the sea (Yamm), for he was blameworthy.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in `Ad when We sent against them the barren wind;\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It spared nothing that it reached, but blew it into broken spreads of rotten ruins.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in Thamud, when they were told: ``Enjoy yourselves for a while!"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they insolently defied the command of their Lord, so the Sa`iqah overtook them while they were looking.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
Then they were unable to rise up, nor could they help themselves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
(So were) the people of Nuh before them. Verily, they were a people who were rebellious.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
With Hands We constructed the heaven. Verily, We are able to expand the vastness of space thereof.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And We have made the earth a Firash; how excellent spreader (thereof) are We!\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of everything We have created pairs, that you may remember.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
So, flee to Allah. Verily, I am a plain warner to you from Him.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And set not up any other god along with Allah. Verily, I am a plain warner to you from Him.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Likewise, no Messenger came to those before them but they said: ``A sorcerer or a madman!"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Have they transmitted this saying to these Nay, they are themselves a people transgressing beyond bounds!\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So turn away from them, you are not blameworthy.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And remind, for verily, the reminding profits the believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
And I created not the Jinn and mankind except that they should worship Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I seek not any provision from them nor do I ask that they should feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Verily, Allah is the All-Provider, Owner of power, the Most Strong.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
And verily, for those who do wrong, there is a portion of torment like to the evil portion of torment (which came for) their likes (of old); so let them not ask Me to hasten on!\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
Then woe to those who disbelieve from their Day which they have been promised.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the Tur\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
And the Book inscribed\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
In parchment unrolled.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
And by Al-Bayt Al-Ma`mur.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
And the roof raised high.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And by the sea that is Masjur.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Verily, the torment of your Lord will surely come to pass.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
There is none that can avert it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the Day when Tamur the heaven Mawr,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And Tasir the mountains Sayr.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Then woe that Day to those who denied.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Those who were, in their falsehood, playing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
The Day when they will be pushed down by force to the fire of Hell, with a horrible, forceful pushing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
This is the Fire which you used to deny.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Is this magic or do you not see\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
Enter therein and whether you are patient of it or impatient of it, it is all the same. You are only being requited for what you used to do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Verily, those who have Taqwa will be in Gardens and Delight.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Enjoying in that which their Lord has bestowed on them, and (the fact that) their Lord saved them from the torment of the blazing Fire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
``Eat and drink with happiness because of what you used to do."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
They will recline on thrones Masfufah. And We shall marry them to Hur (fair females) with wide lovely eyes.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who believe and whose offspring follow them in faith, -- to them shall We join their offspring, and We shall not decrease the reward of their deeds in anything. Every person is a pledge for that which he has earned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We shall provide them with fruit and meat such as they desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
There they shall pass from hand to hand a cup, free from any idle talk, and free from sin.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
And there will go round boy-servants of theirs, to serve them as if they were preserved pearls.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And some of them draw near to others, questioning.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
Saying: ``Aforetime, we were afraid in the midst of our families."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
``So Allah has been gracious to us, and has saved us from the torment of the Fire."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
``Verily, We used to invoke Him before. Verily, He is the Most Subtle, the Most Merciful."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
Therefore, remind. By the grace of Allah, you are neither a Kahin nor a madman.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say: ``A poet! We await for him some calamity by time!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say: ``Wait! I am with you among those who wait!"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Or do their minds command them this or are they people transgressing all bounds\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or do they say: ``He has forged it" Nay! They believe not!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Let them then produce a recitation like unto it if they are truthful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Or were they created by nothing Or were they themselves the creators\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth Nay, but they have no firm belief.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or are with them the treasures of your Lord Or are they the tyrants with the authority to do as they like\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or have they a stairway (to heaven), by means of which they listen Then let their listener produce some manifest proof.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or has He only daughters and you have sons\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or is it that you ask a wage from them so that they are burdened with a load of debt\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or that the Unseen is with them, and they write it down\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or do they intend a plot But those who disbelieve are themselves plotted against!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or have they a god other than Allah Glorified be Allah from all that they ascribe as partners.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
And if they were to see a piece of the heaven falling down, they would say: ``Clouds gathered in heaps!"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them alone till they meet their Day, in which they will sink into a fainting (with horror).\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
The Day when their plotting shall not avail them at all, nor will they be helped.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And verily, for those who do wrong, there is another punishment before this; but most of them know not.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
So wait patiently for the decision of your Lord, for verily, you are under Our Eyes; and glorify the praises of your Lord when you get up.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And in the nighttime also glorify His praises and at the setting of the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star when it goes down.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your companion has neither gone astray nor has he erred.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
Nor does he speak of desire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is only a revelation revealed.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
He has been taught by one mighty in power.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
Dhu Mirrah then he Istawa.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
While he was in the highest part of the horizon,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he approached and came closer,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
And was at a distance of two bows' length or less.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
So (Allah) revealed to His servant whatever He revealed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The heart lied not in what he saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
Will you then dispute with him about what he saw\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
And indeed he saw him at a second descent.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
Near Sidrat Al-Muntaha.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Near it is the Paradise of Abode.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When that covered the lote tree which did cover it!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The sight turned not aside, nor it transgressed beyond the limit.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
Indeed he saw of the greatest Ssgns of his Lord.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
Have you then considered Al-Lat, and Al-`Uzza.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And Manat, the other third\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
Is it for you the males and for Him the females\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That indeed is a division most unfair!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are but names which you have named - you and your fathers - for which Allah has sent down no authority. They follow but a guess and that which they themselves desire, whereas there has surely come to them the guidance from their Lord!\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Or shall man have what he wishes\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
But to Allah belongs the last (Hereafter) and the first (the world).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
And there are many angels in the heavens, whose intercession will avail nothing, except after Allah has given leave for whom He wills and is pleased with.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Verily, those who believe not in the Hereafter, name the angels with female names.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
But they have no knowledge thereof. They follow but conjecture, and verily, conjecture is no substitute for the truth.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
Therefore withdraw from him who turns away from Our Reminder and desires nothing but the life of this world.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is what they could reach of knowledge. Verily, your Lord is He, Who knows best him who goes astray from His path, and He knows best him who receives guidance.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
And to Allah belongs all that is in the heavens and all that is on the earth, that He may requite those who do evil with that which they have done, and reward those who do good, with what is best.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid great sins and Al-Fawahish (immoral sins) except Al-Lamam -- verily, your Lord is of vast forgiveness. He knows you well when He created you from the earth (Adam), and when you were fetuses in your mothers' wombs. So, ascribe not purity to yourselves. He knows best him who has Taqwa.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Did you observe him who turned away (from Islam).\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And gave a little, then stopped\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Is with him the knowledge of the Unseen so that he sees\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or is he not informed with what is in the Suhuf of Musa,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And of Ibrahim who fulfilled all that:\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no burdened person (with sins) shall bear the burden (sins) of another.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that man can have nothing but what he does.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his deeds will be seen.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Then he will be recompensed with a full and the best recompense.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that to your Lord is the End.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that it is He Who makes laugh, and makes weep.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that it is He Who causes death and gives life.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that He creates the pairs, male and female,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From Nutfah when it is emitted.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that upon Him is another bringing forth (Resurrection).\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that it is He Who Aghna and Aqna.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that He is the Lord of Ash-Shi`ra.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that it is He Who destroyed the former `Ad,\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And Thamud. He spared none of them.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And the people of Nuh aforetime. Verily, they were more unjust and more rebellious and transgressing.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And He destroyed the overthrown cities.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
So, there covered them that which did cover.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Then which of the graces of your Lord will you doubt\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This is a warner from the warners of old.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The Azifah draws near.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
None besides Allah can avert it.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Do you then wonder at this reci- tation\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And you laugh at it and weep not,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
While you are Samidun.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
So fall you down in prostration to Allah and worship Him.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour has drawn near, and the moon has been cleft asunder.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
And if they see an Ayah, they turn away and say: ``This is magic, Mustamir."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
They denied and followed their own lusts. And every matter will be settled.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And indeed there has come to them news wherein there is Muzdajar.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Perfect wisdom, but warners benefit them not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So withdraw from them. The Day that the caller will call (them) to a terrible thing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
They will come forth, with humbled eyes from (their) graves as if they were locusts spread abroad,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Hastening towards the caller. The disbelievers will say: ``This is a hard Day."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
The people of Nuh denied (their Messenger) before them. They rejected Our servant and said: ``A madman!" Wazdujir.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
Then he invoked his Lord (saying): ``I have been overcome, so help (me)!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
So, We opened the gates of the heaven with water Munhamir.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And We caused springs to gush forth from the earth. So, the waters met for a matter predestined.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We carried him on a (ship) made of planks and nails (Dusur)\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
Floating under Our Eyes, a reward for him who had been rejected!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And indeed, We have left this as a sign. Then is there any that will remember\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
Then how (terrible) was My torment and My warnings\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And We have indeed made the Qur'an easy to understand and remember; then is there anyone who will remember\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
`Ad denied; then how was My torment and My warnings\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
Verily, We sent against them a violently cold (Sarsar) wind on a day of calamity, continuous.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Plucking out men as if they were uprooted stems of date palms.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
Then, how was My torment and My warnings\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
And We have indeed made the Qur'an easy to understand and remember; then is there any that will remember\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamud denied the warnings.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
And they said: ``A man, alone among us -- shall we follow him Truly, then we should be in error and distress!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
``Is it that the Reminder is sent to him alone from among us Nay, he is an insolent liar!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
Tomorrow they will come to know who is the liar, the insolent one!\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
Verily, We are sending the she-camel as a test for them. So watch them, and be patient!\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And inform them that the water is to be shared between (her and) them, each one's right to drink being established (by turns).\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they called their comrade and he took (a sword) and killed (her).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
Then, how was My torment and My warnings\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Verily, We sent against them a single Sayhah, and they became like straw Al-Muhtazir.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And indeed, We have made the Qur'an easy to understand and remember; then is there any that will remember\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lut denied the warnings.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
Verily, We sent against them Hasib (a violent storm of stones), except the family of Lut, them We saved in the last hour of the night,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As a favor from Us. Thus do We reward him who gives thanks.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And he indeed had warned them of Our punishment, but they doubted the warnings!\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
And they indeed sought to shame his guests. So, We blinded their eyes (saying), ``Then taste you My torment and My warnings."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And verily, an abiding torment seized them early in the morning.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
Then taste you My torment and My warnings.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And indeed, We have made the Qur'an easy to understand and remember; then is there any that will remember\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
And indeed, warnings came to the people of Fir`awn.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
(They) denied all Our signs, so We seized them with a punishment of the Almighty, All-Capable.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your disbelievers better than these Or have you immunity in the Divine Scriptures\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or say they: ``We are a great multitude, victorious"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
Their multitude will be put to flight, and they will show their backs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
Nay, but the Hour is their appointed time, and the Hour will be more grievous and more bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Verily, the criminals are in error and will burn.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
The Day they will be dragged on their faces into the Fire (it will be said to them): ``Taste you the touch of Hell!"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Verily, We have created all things with Qadar.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our commandment is but one as the twinkling of an eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And indeed, We have destroyed your likes; then is there any that will remember\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
And everything they have done is noted in Az-Zubur.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
And everything, small and large, is written down.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Verily, those who have Taqwa, will be in the midst of Gardens and Rivers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
In a seat of truth, near the Muqtadir King.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen Ar-Rahman!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
He has taught the Qur'an.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
He created man.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
He taught him Al-Bayan.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon (run) on fixed courses.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the Najm and the trees prostrating.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the heaven He has raised high, and He has set up the balance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
In order that you may not transgress the balance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
And observe the weight with equity and do not make the balance deficient.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And the earth He has put down (laid) for Al-An'am.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein are fruits, date palms producing Akmam.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
And also corn, with (its) `Asf, and Rayhan.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
Then which of the blessings of your Lord will you both deny\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man from sounding clay like the clay of pottery.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And the Jinn He created from a smokeless flame of fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
Then which of the blessings of your Lord will you both deny\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
The Lord of the two easts and the Lord of the two wests.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
Then which of the blessings of your Lord will you both deny\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He has Maraja the two seas meeting together.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
Between them is a barrier which none of them can transgress.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
Then which of the blessings of your Lord will you both deny\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
Out of them both come out pearls and Al-Marjan.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
Then which of the blessings of your Lord will you both deny\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
And His are Al-Jawar Al-Munsha'at, in the seas like A`lam.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
Then which of the blessings of your Lord will you both deny\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
Whatsoever is on it (the earth) will perish.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
And the Face of your Lord Dhul-Jalal wal-Ikram will remain forever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
Then which of the blessings of your Lord will you both deny\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Whosoever is in the heavens and on the earth begs of Him. Every day He is (engaged) in some affair!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
Then which of the blessings of your Lord will you both deny\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We shall attend to you, O Thaqalan!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
Then which of the blessings of your Lord will you both deny\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O assembly of Jinn and men! If you are able to pass beyond the zones of the heavens and the earth, then pass beyond (them)! But you will never be able to pass them, except with authority (from Allah)!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
Then which of the blessings of your Lord will you both deny\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
There will be sent against you both, Shuwaz of fire and Nuhas, and you will not be able to defend yourselves.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
Then which of the blessings of your Lord will you both deny\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
Then when the heaven is rent asunder, and it becomes Wardah like Dihan.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
Then which of the blessings of your Lord will you both deny\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
So, on that Day he will not be questioned about his sin, (neither) human nor Jinn.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
Then which of the blessings of your Lord will you both deny\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The criminals will be known by their marks, and they will be seized by their foreheads and feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
Then which of the blessings of your Lord will you both deny\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is the Hell which the criminals denied.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They will go between it and Hamim An!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
Then which of the blessings of your Lord will you both deny\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But for him who fears the standing before his Lord, there will be two Gardens.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
Then which of the blessings of your Lord will you both deny\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
With Afnan.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
Then which of the blessings of your Lord will you both deny\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In them (both) will be two springs flowing (free).\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
Then which of the blessings of your Lord will you both deny\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In them (both) will be every kind of fruit in pairs.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
Then which of the blessings of your Lord will you both deny\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
Reclining upon the couches lined with Istabraq, and the fruits of the two Gardens will be near at hand.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
Then which of the blessings of your Lord will you both deny\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
Wherein both will be Qasirat At-Tarf, whom never deflowered a human before nor Jinn.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
Then which of the blessings of your Lord will you both deny\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
They are like Yaqut and Marjan.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
Then which of the blessings of your Lord will you both deny\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Is there any reward for good other than good\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
Then which of the blessings of your Lord will you both deny\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And below these two, there are two other Gardens.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
Then which of the blessings of your Lord will you both deny\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Mudhammatan.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
Then which of the blessings of your Lord will you both deny\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In them (both) will be two springs Naddakhatan.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
Then which of the blessings of your Lord will you both deny\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In them (both) will be fruits, and date palms and pomegranates.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
Then which of the blessings of your Lord will you both deny\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
Therein (Gardens) will be Khayrat Hisan;\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
Then which of the blessings of your Lord will you both deny\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Hur (beautiful, fair females) guarded in pavilions;\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
Then which of the blessings of your Lord will you both deny\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Whom never deflowered a human before nor Jinn.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
Then which of the blessings of your Lord will you both deny\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green Rafraf and rich beautiful `Abqariy.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
Then which of the blessings of your Lord will you both deny\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed be the Name of your Lord, Dhil-Jalali wal-Ikram.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Waqi`ah occurs\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
There is not, for its occurrence, Kadhibah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
Bringing low (some), exalting (others).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth will be shaken with a terrible shake.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains will be powdered to dust,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
So that they will become floating dust particles.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And you (all) will be in three groups.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
So those on the right -- how (fortunate) will be those on the right!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And those on the left -- how (unfortunate) will be those on the left!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And those foremost will be foremost.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
These will be the nearest (to Allah).\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In the Gardens of Delight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A multitude of those will be from the first ones.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few of those will be from the later ones.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
(They will be) on thrones, Mawdunah.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining thereon, face to face.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
Immortal boys will go around them (serving),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With cups, and jugs, and a glass of flowing wine,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
Wherefrom neither Yusadda`un nor Yunzifun.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And with fruit that they may choose.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And with the flesh of fowls that they desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And (there will be) Hur with wide lovely eyes.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
Like preserved pearls.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
A reward for what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
No Laghw (evil vain talk) will they hear therein, nor any sinful speech.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
But only the saying of: ``Salaman! Salaman!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
And those on the right -- how (fortunate) will be those on the right\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
(They will be) among Sidri Makhdud,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
And among Talh Mandud.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
And in shade Mamdud,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
And by water flowing constantly,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And fruit in plenty,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Whose supply is not cut off nor are they out of reach.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And on couches, raised high.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Verily, We have created them a special creation.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And made them virgins.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
`Urub, Atrab.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For those on the right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A multitude of those will be from the first generation.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a multitude of those will be from the later generations.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And those on the left How will be those on the left\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
In Samum, and Hamim.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And a shadow from Yahmum,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Neither Barid nor Karim,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Verily, before that, they indulged in luxury,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And were persisting in great sin.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say: ``When we die and become dust and bones, shall we then indeed be resurrected"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
``And also our forefathers"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say: ``(Yes) verily, those of old, and those of later times."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
``All will surely be gathered together for appointed meeting of a known Day."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
``Then verily, --- you the erring -- ones, the deniers!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
``You verily, will eat of the trees of Zaqqum."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
``Then you will fill your bellies therewith,"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
``And drink the Hamim on top of it."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
``And you will drink (that) like Al-Him!"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
That will be their entertainment on the Day of Recompense!\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We created you, then why do you believe not\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Do you not see the semen you emit.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Is it you who create it, or are We the Creator\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We have decreed death to you all, and We are not outstripped,\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
To transfigure you and create you in (forms) that you know not.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And indeed, you have already known the first form of creation, why then do you not remember\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
Do you not see what you sow.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it you that make it grow, or are We the Grower\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
Were it Our will, We could crumble it to dry pieces, and you would be Tafakkahun.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
(Saying:) ``We are indeed Mughramun!"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
``Nay, but we are deprived!"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
Do you not see the water that you drink.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you who cause it to come down from Al-Muzn, or are We the Cause of it coming down\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We willed, We verily could make it salty; why then do you not give thanks\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
Do you not see the fire which you kindle.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it you who made the tree thereof to grow, or are We the Grower\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it a Reminder, and an article of use for the Muqwin.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
Then glorify with praises the Name of your Lord, the Most Great.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
Fala! I swear by the Mawaqi` of the stars.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And verily that is indeed a great oath, if you but know.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
That (this) is indeed an honorable recitation.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In a Book Maknun.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
Which none touches but the pure ones.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
A revelation from the Lord of all that exists.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Is it such a talk that you are Mudhinun\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And you make your provision your denial!\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Then why do you not (intervene) when it reaches Al-Hulqum\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
And you at the moment are looking,\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
But We are nearer to him than you, but you see not,\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
Then why do you not -- if you are not Madinin\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Return the soul, if you are truthful\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
Then, if he be of the Muqarrabin,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
Then Rawh, Rayhan and a Garden of Delights.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he be of those on the right,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then Salam (peace) to you from those on the right.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But if he be of the denying, the erring,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then for him is an entertainment with Hamim.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And entry in Hellfire.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Verily, this! This is an absolute truth with certainty.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So, glorify with praises the Name of your Lord, the Most Great.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen Whatever is in the heavens and the earth glorifies Allah -- and He is the Almighty, All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
His is the kingdom of the heavens and the earth. It is He Who gives life and causes death; and He is Able to do all things.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is Al-Awwal and Al-Akhir, Az-Zahir and Al-Batin. And He is the All-Knower of everything.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
He it is Who created the heavens and the earth in six Days and then rose (Istawa) over the Throne. He knows what goes into the earth and what comes forth from it, and what descends from the heaven and what ascends thereto. And He is with you wheresoever you may be. And Allah is the All-Seer of what you do.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
His is the kingdom of the heavens and the earth. And to Allah return all the matters.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He merges night into day, and merges day into night, and He has full knowledge of whatsoever is in the breasts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His Messenger, and spend of that whereof He has made you trustees. And such of you as believe and spend, theirs will be a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
And what is the matter with you that you believe not in Allah! While the Messenger invites you to believe in your Lord; and He has indeed taken your covenant, if you are real believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He Who sends down manifest Ayat to His servant that He may bring you out from darkness into light. And verily, Allah is to you full of kindness, Most Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And what is the matter with you that you spend not in the cause of Allah And to Allah belongs the heritage of the heavens and the earth. Not equal among you are those who spent and fought before the conquering. Such are higher in degree than those who spent and fought afterwards. But to all Allah has promised the best. And Allah is All-Aware of what you do.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is he that will lend Allah a handsome loan: then He will increase it manifold to his credit, and he will have a honorable reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
On the Day you shall see the believing men and the believing women -- their light running forward before them and in their right hands. Glad tidings for you this Day! Gardens under which rivers flow (Paradise), to dwell therein forever! Truly, this is the great success!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On the Day when the hypocrites men and women will say to the believers: ``Wait for us! Let us get something from your light!" It will be said: ``Go back to your rear! Then seek a light!" So, a wall will be put up between them, with a gate therein. Inside it will be mercy, and outside it will be torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
(The hypocrites) will call the believers: ``Were we not with you" The believers will reply: ``Yes! But you led yourselves into temptations, you looked forward to our destruction; and you doubted, and you were deceived by false hopes, till the command of Allah came to pass. And the deceiver deceived you in regard to Allah."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
So, this Day no ransom shall be taken from you, nor of those who disbelieved. Your abode is the Fire. That is your protector, and worst indeed is that destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Has not the time yet come for the believers that their hearts should be humble for the remembrance of Allah And that which has been revealed of the truth, lest they become as those who received the Scripture before, and the term was prolonged for them and so their hearts were hardened And many of them were rebellious.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that Allah gives life to the earth after its death! Indeed We have made clear the Ayat to you, if you but understand.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Verily, those who give Sadaqat, men and women, and lend Allah handsome loan, it shall be increased manifold (to their credit), and theirs shall be an honorable good reward.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who believe in Allah and His Messengers. they are the Siddiqun (true believers) and the martyrs with their Lord. They shall have their reward and their light. But those who disbelieve and deny Our Ayat -- they shall be the dwellers of the blazing Fire.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of this world is only play and amusement, pomp and mutual boasting among you, and rivalry in respect of wealth and children. (It is) like a rain (Ghayth), thereof the growth is pleasing to the tiller; afterwards it dries up and you see it turning yellow; then it becomes straw. But in the Hereafter (there is) a severe torment, and (there is) forgiveness from Allah and (His) pleasure. And the life of this world is only a deceiving enjoyment.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Race with one another in hastening towards forgiveness from your Lord, and Paradise the width whereof is as the width of the heaven and the earth, prepared for those who believe in Allah and His Messengers. That is the grace of Allah which He bestows on whom He is pleased with. And Allah is the Owner of great bounty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No calamity occurs in the earth nor in yourselves but it is inscribed in the Book of Decrees before We bring it into existence. Verily, that is easy for Allah.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
In order that you may not grieve at the things over that you fail to get, nor rejoice over that which has been given to you. And Allah likes not prideful boasters.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
Those who are misers and enjoin miserliness upon people. And whosoever turns away, then Allah is Rich, Worthy of all praise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
Indeed We have sent Our Messengers with clear proofs, and revealed with them the Scripture and the Mizan that mankind may keep up justice. And We brought forth iron wherein is mighty power, as well as many benefits for mankind, that Allah may test who it is that will help Him (His religion) and His Messengers in the unseen. Verily, Allah is Powerful, Almighty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And indeed, We sent Nuh and Ibrahim, and placed in their offspring prophethood and Scripture. And among them there are some who are guided; but many of them are rebellious.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then, We sent after them Our Messengers, and We sent `Isa the son of Maryam, and gave him the Injil. And We ordained in the hearts of those who followed him, compassion and mercy. But the monasticism which they invented for themselves, We did not prescribe for them, but (they sought it) only to please Allah therewith, but that they did not observe it with the right observance. So, We gave those among them who believed, their (due) reward; but many of them are rebellious.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O you who believe! Have Taqwa of Allah, and believe in His Messenger, He will give you a double portion of His mercy, and He will give you a light by which you shall walk (straight). And He will forgive you. And Allah is Oft-Forgiving, Most Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
So that the People of the Scriptures may know that they have no power whatsoever over the grace of Allah, and that (His) grace is in His Hand to bestow it on whomsoever He wills. And Allah is the Owner of great bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Indeed Allah has heard the statement of her that disputes with you concerning her husband, and complains to Allah. And Allah hears the argument between you both. Verily, Allah is All-Hearer, All-Seer.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those among you who make their wives unlawful to them by Zihar they cannot be their mothers. None can be their mothers except those who gave them birth. And verily, they utter an ill word and a lie. And verily, Allah is Oft-Pardoning, Oft-Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
And those who make unlawful to them (their wives) by Zihar and wish to free themselves from what they uttered, (the penalty) in that case is the freeing of a slave before they touch each other. That is an admonition to you. And Allah is All-Aware of what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And he who finds not, must fast two successive months before they both touch each other. And he who is unable to do so, should feed sixty of the poor. That is in order that you may have perfect faith in Allah and His Messenger. These are the limits set by Allah. And for disbelievers, there is a painful torment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Verily, those who oppose Allah and His Messenger will be disgraced as those before them were disgraced. And We have sent down clear Ayat. And for the disbelievers is a disgraceful torment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day when Allah will resurrect them all together and inform them of what they did. Allah has kept account of it, while they have forgotten it. And Allah is Witness over all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Have you not seen that Allah knows whatsoever is in the heavens and whatsoever is on the earth There is no Najwa of three but He is their fourth nor of five but He is their sixth nor of less than that or more but He is with them wheresoever they may be. And afterwards on the Day of Resurrection He will inform them of what they did. Verily, Allah is the All-Knower of everything.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Have you not seen those who were forbidden to hold secret counsels, and afterwards returned to that which they had been forbidden, and conspired together for sin and wrongdoing and disobedience to the Messenger. And when they come to you, they greet you with a greeting wherewith Allah greets you not, and say within themselves: ``Why should Allah punish us not for what we say" Hell will be sufficient for them; they will enter therein. And worst indeed is that destination!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O you who believe! When you hold secret counsel, do it not for sin and wrongdoing, and disobedience to the Messenger, but do it for Al-Birr and Taqwa; and have Taqwa of Allah unto Whom you shall be gathered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Secret counsels are only from Shaytan, in order that he may cause grief to the believers. But he cannot harm them in the least, except as Allah permits. And in Allah let the believers put their trust.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O you who believe! When you are told to make room in the assemblies, make room. Allah will give you room. And when you are told to rise up, then rise up. Allah will exalt in degress those of you who believe, and those who have been granted knowledge. And Allah is Well-Acquainted with what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O you who believe! When you (want to) consult the Messenger in private, spend something in charity before your private consultation. That will be better and purer for you. But if you find not (the means for it), then verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Are you afraid of spending in charity before your private consultation (with him) If then you do it not, and Allah has forgiven you, then perform Salah and give Zakah and obey Allah and His Messenger. And Allah is All-Aware of what you do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Have you not seen those who take as friends a people upon whom is the wrath of Allah They are neither of you nor of them, and they swear to a lie while they know.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has prepared for them a severe torment. Evil indeed is that which they used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They have made their oaths a screen. Thus they hinder (others) from the path of Allah, so they shall have a humiliating torment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Their children and their wealth will avail them nothing against Allah. They will be the dwellers of the Fire to dwell therein forever.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the Day when Allah will resurrect them all together; then they will swear to Him as they swear to you. And they think that they have something. Verily, they are liars!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
The Shaytan has overpowered them. So he has made them forget the remembrance of Allah. They are the party of Shaytan. Verily, it is the party of Shaytan that will be the losers!.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Those who oppose Allah and His Messenger, they will be among those most humiliated.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has decreed: ``Verily, I and My Messengers shall be the victorious." Verily, Allah is All-Powerful, Almighty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You will not find any people who believe in Allah and the Last Day, making friendship with those who oppose Allah and His Messenger, even though they were their fathers or their sons or their brothers or their kindred. For such He has written faith in their hearts, and strengthened them with Ruh from Himself. And He will admit them to Gardens under which rivers flow, to dwell therein (forever). Allah is well pleased with them, and they are well pleased with Him. They are the party of Allah. Verily, the party of Allah will be the successful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah. And He is the Almighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
He it is Who drove out the disbelievers among the People of the Scripture from their homes at the first gathering. You did not think that they would get out. And they thought that their fortresses would defend them from Allah! But Allah reached them from a place whereof they expected it not, and He cast terror into their hearts so that they demolished their own dwellings with their own hands and the hands of the believers. Then take admonition, O you with eyes.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And had it not been that Allah had decreed exile for them, He would certainly have punished them in this world; and in the Hereafter theirs shall be the torment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they opposed Allah and His Messenger. And whosoever opposes Allah, then verily, Allah is Severe in punishment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
What you cut down of the Linah, or you left them standing on their stems, it was by leave of Allah, and in order that He might disgrace the rebellious.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And what Allah gave as booty (Fai') to His Messenger from them -- for this you made no expedition with either cavalry or camelry. But Allah gives power to His Messengers over whomsoever He wills. And Allah is Able to do all things.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
What Allah gave as booty (Fai') to His Messenger from the people of the townships -- it is for Allah, His Messenger, the kindred, the orphans, the poor, and the wayfarer, in order that it may not become a fortune used by the rich among you. And whatsoever the Messenger gives you, take it; and whatsoever he forbids you, abstain (from it). And have Taqwa of Allah, verily, Allah is Severe in punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
(And there is also a share in this booty) for the poor emigrants, who were expelled from their homes and their property, seeking bounties from Allah and (His) good pleasure, and helping Allah and His Messenger. Such are indeed the truthful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And (it is also for) those who, before them, had homes and had adopted the faith, love those who emigrate to them, and have no jealousy in their breasts for that which they have been given, and give them preference over themselves even though they were in need of that. And whosoever is saved from his own greed, such are they who will be the successful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And those who came after them say: ``Our Lord! Forgive us and our brethren who have preceded us in faith, and put not in our hearts any hatred against those who have believed. Our Lord! You are indeed full of kindness, Most Merciful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Have you not observed the hypocrites who say to their disbelieving brethren among the People of the Scripture, ``If you are expelled, we indeed will go out with you, and we shall never obey anyone against you; and if you are attacked, we shall indeed help you." But Allah is Witness that they verily are liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
Surely, if they (the Jews) are expelled, never will they (hypocrites) go out with them; and if they are attacked, they will never help them. And (even) if they do help them, they (hypocrites) will turn their backs, and they will not be victorious.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
Verily, you are more fearful in their breasts than Allah. That is because they are a people who comprehend not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They fight not against you even together, except in fortified townships, or from behind walls. Their enmity among themselves is very great. You would think they were united, but their hearts are divided. That is because they are a people who understand not.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
They are like their immediate predecessors; they tasted the evil result of their conduct, and for them a painful torment.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
Like Shaytan, when he says to man: ``Disbelieve." But when he disbelieves, Shaytan says: ``I am free of you, I fear Allah, the Lord of all that exists!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
So, the end of both will be that they will be in the Fire, abiding therein. Such is the recompense of the wrongdoers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O you who believe! Have Taqwa of Allah and let every person look to what he has sent forth for tomorrow, and fear Allah. Verily, Allah is All-Aware of what you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be not like those who forgot Allah, and He caused them to forget themselves. Those are the rebellious.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the dwellers of the Fire and the dwellers of the Paradise. It is the dwellers of Paradise that will be successful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
Had We sent down this Qur'an on a mountain, you would surely have seen it humbling itself and rent asunder by the fear of Allah. Such are the parables which We put forward to mankind that they may reflect.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah, beside Whom La ilaha illa Huwa, the All-Knower of the unseen and the seen. He is the Most Gracious, the Most Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah, beside Whom La ilaha illa Huwa, Al-Malik, Al-Quddus, As-Salam, Al-Mu`min, Al-Muhaymin, Al-`Aziz, Al-Jabbar, Al-Mutakabbir. Glory be to Allah! Above all that they associate as partners with Him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, Al-Khaliq, Al-Bari, Al-Musawwir. To Him belong the Best Names. All that is in the heavens and the earth glorify Him. And He is the Almighty, the All-Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O you who believe! Take not My enemies and your enemies as protecting friends, showing affection towards them, while they have disbelieved in what has come to you of the truth, and have driven out the Messenger and yourselves because you believe in Allah, your Lord! If you have come forth to strive in My cause and to seek My good pleasure. You show friendship to them in secret, while I am All-Aware of what you conceal and what you reveal. And whosoever of you (Muslims) does that, then indeed he has gone (far) astray from the straight path.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
Should they gain the upper hand over you, they would behave to you as enemies, and stretch forth their hands and their tongues against you with evil, and they desire that you should disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Neither your relatives nor your children will benefit you on the Day of Resurrection. He will judge between you. And Allah is the All-Seer of what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
Indeed there has been an excellent example for you in Ibrahim and those with him, when they said to their people: ``Verily, we are free from you and whatever you worship besides Allah, we have rejected you, and there has started between us and you, hostility and hatred forever until you believe in Allah alone," -- except the saying of Ibrahim to his father: ``Verily, I will ask forgiveness for you, but I have no power to do anything for you before Allah." ``Our Lord! In You we put our trust, and to You we turn in repentance, and to You is the final Return."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
``Our Lord! Make us not a trial for the disbelievers, and forgive us, Our Lord! Verily, You, only You, are the Almighty, the All-Wise."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
Certainly, there has been in them an excellent example for you to follow - for those who look forward to (the meeting with) Allah and the Last Day. And whosoever turns away, then verily, Allah is Al-Ghani, Al-Hamid.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
Perhaps Allah will make friendship between you and those whom you hold as enemies. And Allah has power (over all things), and Allah is Oft-Forgiving, Most Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah does not forbid you to deal justly and kindly with those who fought not against you on account of religion nor drove you out of your homes. Verily, Allah loves those who deal with equity.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
It is only as regards those who fought against you on account of religion, and have driven you out of your homes, and helped to drive you out, that Allah forbids you to befriend them. And whosoever will befriend them, then such are the wrongdoers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O you who believe! When believing women come to you as emigrants, examine them; Allah knows best as to their faith, then if you ascertain that they are true believers, send them not back to the disbelievers. They are not lawful for the disbelievers nor are the disbelievers lawful for them. But give them (disbelievers) that which they have spent (on their dowery). And there will be no sin on you to marry them if you have paid their due to them. Likewise do not keep the disbelieving women, and ask for that which you have spent (on their dowery) and let them (the disbelievers) ask for that which they have spent. That is the judgement of Allah, He judges between you. And Allah is All-Knowing, All-Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if any of your wives have gone from you to the disbelievers then you succeed over them (gain victory); then pay those whose wives have gone, the equivalent of what they had spent. And have Taqwa of Allah, the One in Whom you are believers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet! When the believing women come to you pledging to you that they will not associate anything with Allah, and that they will not steal, and that they will not commit Zina, and that they will not kill their children, and that they will not utter slander, fabricating from between their hands and their feet, and that they will not disobey you in Ma`ruf (good), Allah said to the faithful believers,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O you who believe! Take not as friends the people who incurred the wrath of Allah. Surely, they have despaired of the Hereafter, just as the disbelievers have despaired of those (buried) in graves.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah. And He is the Almighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O you who believe! Why do you say that which you do not do\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
Most hateful it is with Allah that you say that which you do not do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Verily, Allah loves those who fight in His cause in rows as if they were a solid structure.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And when Musa said to his people: ``O my people! Why do you annoy me while you know certainly that I am the Messenger of Allah to you So, when they turned away (from the path of Allah), Allah turned their hearts away (from the right path). And Allah guides not the people who are rebellious.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And (remember) when `Isa, son of Maryam, said: ``O Children of Israel! I am the Messenger of Allah unto you, confirming the Tawrah [which came] before me, and giving glad tidings of a Messenger to come after me, whose name shall be Ahmad. ``But when he came to them with clear proofs, they said: ``This is plain magic."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who does more wrong than the one who invents a lie against Allah, while he is being invited to Islam And Allah guides not the people who are wrongdoers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They intend to put out the Light of Allah with their mouths. But Allah will bring His Light to perfection even though the disbelievers hate (it).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
He it is Who has sent His Messenger with guidance and the religion of truth to make it victorious over all religions even though idolators hate (it).\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O you who believe! Shall I guide you to a trade that will save you from a painful torment\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
That you believe in Allah and His Messenger, and that you strive hard and fight in the cause of Allah with your wealth and your lives, that will be better for you, if you but know!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
(If you do so) He will forgive you your sins, and admit you into Gardens under which rivers flow, and pleasant dwellings in `Adn (Eternal) Paradise; that is indeed the great success.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And also (He will give you) another (blessing) which you love, help from Allah and a near victory. And give glad tidings to the believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O you who believe! Be you helpers (in the cause) of Allah as said `Isa, son of Maryam, to the Hawariyyin (the disciples): ``Who are my helpers (in the cause) of Allah" The Hawariyyun said: ``We are Allah's helpers" (i.e., we will strive in His cause!). Then a group of the Children of Israel believed and a group disbelieved. So, We gave power to those who believed against their enemies, and they became the victorious (uppermost).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah -- the King, the Holy, the Almighty, the All-Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
He it is Who sent among the unlettered ones a Messenger from among themselves, reciting to them His Ayat, purifying them, and teaching them the Book and the Hikmah. And verily, they had been before in manifest error.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
And others among them who have not yet joined them. And He is the Almighty, the All-Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is the grace of Allah, which He bestows on whom He wills. And Allah is the Owner of mighty grace.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The likeness of those who were entrusted with the Tawrah, but did not carry it, is as the likeness of a donkey which carries huge burdens of books. How bad is the example of people who deny the Ayat of Allah. And Allah does not guide the people who are wrongdoers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say: ``O you Jews! If you pretend that you are friends of Allah, to the exclusion of (all) other people, then long for death if you are truthful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they will never long for it, because of what their hands have sent before them! And Allah knows well the wrongdoers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say: ``Verily, the death from which you flee, will surely meet you, then you will be sent back to the Knower of the unseen and the seen, and He will inform you about what you used to do."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O you who believe! When the call is proclaimed for the Salah on Al-Jumu`ah (Friday), then hasten (Fas`aw) to the remembrance of Allah and leave off business. That is better for you if you did but know!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
Then when the Salah is complete, you may disperse through the land, and seek the bounty of Allah, and remember Allah much, that you may be successful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
And when they see some merchandise or some amusement, they disperse headlong to it, and leave you standing. Say: ``That which Allah has is better than any amusement or merchandise! And Allah is the best of providers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come to you, they say: ``We bear witness that you are indeed the Messenger of Allah." Allah knows that you are indeed His Messenger, and Allah bears witness that the hypocrites are liars indeed.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have made their oaths a screen. Thus they hinder (others) from the path of Allah. Verily, evil is what they used to do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, and then disbelieved; therefore their hearts are sealed, so they understand not.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
And when you look at them, their bodies please you; and when they speak, you listen to their words. They are as blocks of wood propped up. They think that every cry is against them. They are the enemies, so beware of them. May Allah curse them! How are they denying the right path\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them: ``Come, so that the Messenger of Allah may ask forgiveness from Allah for you," they twist their heads, and you would see them turning away their faces in pride.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is equal to them whether you ask forgiveness or ask not forgiveness for them, Allah will never forgive them. Verily, Allah guides not the people who are the rebellious.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
They are the ones who say: ``Spend not on those who are with Allah's Messenger, until they desert him." And to Allah belong the treasures of the heavens and the earth, but the hypocrites comprehend not.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say: ``If we return to Al-Madinah, indeed the more honorable will expel therefrom the weaker." But Al-`Izzah belongs to Allah, and to His Messenger, and to the believers, but the hypocrites know not.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O you who believe! Let not your properties or your children divert you from the remembrance of Allah. And whosoever does that, then they are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And spend of that with which We have provided you before death comes to one of you, and he says: ``My Lord! If only You would give me respite for a little while, then I should give Sadaqah from my wealth, and be among the righteous.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
And Allah grants respite to none when his appointed time comes. And Allah is All-Aware of what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen Whatsoever is in the heavens and whatsoever is on the earth glorifies Allah. His is the dominion, and to Him belongs the praise, and He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
He it is Who created you, then some of you are disbelievers and some of you are believers. And Allah is All-Seer of what you do.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He has created the heavens and the earth with truth, and He shaped you and made good your shapes. And to Him is the return.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows what is in the heavens and on earth, and He knows what you conceal and what you reveal. And Allah is the All-Knower of what is in the breasts.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has not the news reached you of those who disbelieved aforetime And so they tasted the evil result of their disbelief, and theirs will be a painful torment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That was because there came to them their Messengers with Bayyinat, but they said: ``Shall mere men guide us" So they disbelieved and turned away. But Allah was not in need. And Allah is not in need, Worthy of all praise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
The disbelievers pretend that they will never be resurrected. Say: ``Yes! By my Lord, you will certainly be resurrected, then you will be informed of what you did; and that is easy for Allah."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
Therefore, believe in Allah and His Messenger and in the Light which We have sent down. And Allah is All-Aware of what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The Day when He will gather you on the Day of Gathering, that will be the Day of At-Taghabun. And whosoever believes in Allah and performs righteous deeds, He will expiate from him his sins, and will admit him to Gardens beneath which rivers flow, to dwell therein forever; that will be the great success.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
But those who disbelieved and denied Our Ayat, they will be the dwellers of the Fire, to dwell therein forever. And worst indeed is that destination\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No calamity occurs, but by the permission of Allah, and whosoever believes in Allah, He guides his heart. And Allah is the All-Knower of everything.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
Obey Allah, and obey the Messenger; but if you turn away, then the duty of Our Messenger is only to convey clearly.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah! La ilaha illa Huwa. And in Allah therefore let the believers put their trust.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O you who believe! Verily, among your wives and your children there are enemies for you; therefore beware of them! But if you pardon (them) and overlook, and forgive, then verily, Allah is Oft-Forgiving, Most Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and your children are only a Fitnah, whereas Allah! With Him is a great reward.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So have Taqwa of Allah as much as you can; listen and obey, and spend in charity; that is better for yourselves. And whosoever is saved from his own greed, then they are the successful ones.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you lend to Allah a handsome loan, He will double it for you, and will forgive you. And Allah is Shakur, Halim,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
All-Knower of the unseen and seen, the Almighty, the All-Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet! When you divorce women, divorce them at their `Iddah and count their `Iddah. And have Taqwa of Allah, your Lord. And turn them not out of their homes nor shall they leave, except in case they are guilty of Fahishah Mubayyinah. And those are the set limits of Allah. And whosoever transgresses the set limits of Allah, then indeed he has wronged himself. You know not, it may be that Allah will afterward bring some new thing to pass.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
Then when they are about to attain their term appointed, either take them back in a good manner or part with them in a good manner. And take as witness two just persons from among you. And establish the testimony for Allah. That will be an admonition given to him who believes in Allah and the Last Day. And whosoever has Taqwa of Allah, He will make a way for him to get out.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And He will provide him from where he never could imagine. And whosoever puts his trust in Allah, then He will suffice him. Verily, Allah will accomplish his purpose. Indeed Allah has set a measure for all things.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
Those in menopause among your women, for them the `Iddah, if you have doubt, is three months; and for those who have no courses. And for those who are pregnant, their `Iddah is until they lay down their burden; and whosoever has Taqwa of Allah, He will make his matter easy for him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is the command of Allah, which He has sent down to you; and whosoever has Taqwa of Allah, He will expiate from him his sins, and will increase his reward.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them where you dwell, according to what you have, and do not harm them so as to suppress them. And if they are pregnant, then spend on them till they lay down their burden. Then if they suckle the children for you, give them their due payment, and let each of you deal with each other in a mannerly way. But if you make difficulties for one another, then some other woman may suckle for him.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let the rich man spend according to his means; and the man whose resources are restricted, let him spend according to what Allah has given him. Allah puts no burden on any person beyond what He has given him. Allah will grant after hardship, ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
And many a town revolted against the command of its Lord and His Messengers; and We called it to a severe account, and We shall punish it with a horrible torment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
So it tasted the evil result of its affair, and the consequence of its affair was loss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has prepared for them a severe torment. So have Taqwa of Allah, O men of understanding, those who believe! Allah has indeed sent down to you a Reminder.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
A Messenger, who recites to you the Ayat of Allah containing clear explanations, that He may take out those who believe and do righteous good deeds, from the darkness to the light. And whosoever believes in Allah and performs righteous deeds, He will admit him into Gardens under which rivers flow, to dwell therein forever. Allah has indeed granted for him an excellent provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
It is Allah Who has created seven heavens and of the earth the like thereof. His command descends between them, that you may know that Allah has power over all things, and that Allah surrounds all things with (His) knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet! Why do you forbid that which Allah has allowed to you, seeking to please your wives And Allah is Oft-Forgiving, Most Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has already ordained for you (O men) the absolution from your oaths. And Allah is your Protector and He is the All-Knower, the All-Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
And (remember) when the Prophet disclosed a matter in confidence to one of his wives, then she told it. And Allah made it known to him; he informed part thereof and left a part. Then when he told her thereof, she said: ``Who told you this" He said: ``The All-Knower, the All-Aware has told me."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If you two turn in repentance to Allah, your hearts are indeed so inclined; but if you help one another against him, then verily, Allah is his Protector, and Jibril, and the righteous among the believers; and after that the angels are his helpers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
Maybe his Lord, if he divorces you, will give him instead of you, wives better than you - submitting, believers, obedient, turning to Allah in repentance, worshipping Allah sincerely, Sa'ihat, previously married, and virgins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O you who believe! Protect yourselves and your families against a Fire (Hell) whose fuel is men and stones, over which are (appointed) angels stern (and) severe, who disobey not the commands they receive from Allah, but do that which they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
(It will be said in the Hereafter) O you who disbelieve! Make no excuses this Day! You are being requited only for what you used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O you who believe! Turn to Allah with sincere repentance! It may be that your Lord will expiate from you your sins, and admit you into Gardens under which rivers flow -- the Day that Allah will not disgrace the Prophet and those who believe with him. Their light will run forward before them and in their right hands. They will say: ``Our Lord! Keep perfect our light for us and grant us forgiveness. Verily, You are Able to do all things."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet! Strive hard against the disbelievers and the hypocrites, and be severe against them; their abode will be Hell, and worst indeed is that destination.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah sets forth an example for those who disbelieve: the wife of Nuh and the wife of Lut. They were under two of our righteous servants, but they both betrayed them. So, they availed them not against Allah and it was said: ``Enter the Fire along with those who enter!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah has set forth an example for those who believe: the wife of Fir`awn, when she said: ``My Lord! Build for me a home with You in Paradise, and save me from Fir`awn and his work, and save me from the people who are wrongdoers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And Maryam, the daughter of `Imran who guarded her chastity (private part). And We breathed into it through Our Ruh, and she testified to the truth of her Lords Kalimat, and His Kutub, and she was of the Qanitin.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed be He in Whose Hand is the dominion; and He is Able to do all things.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
Who has created death and life that He may test you which of you is best in deed. And He is the Almighty, the Oft-Forgiving;\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
Who has created the seven heavens one above the other; you can see no fault in the creation of the Most Gracious. Then look again. Can you see any rifts\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then look again and yet again, your sight will return to you Khasi', and worn out.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And indeed We have adorned the nearest heaven with lamps, and We have made such lamps (as) missiles to drive away the Shayatin, and have prepared for them the torment of the blazing Fire.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieve in their Lord is the torment of Hell, and worst indeed is that destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are cast therein, they will hear its Shahiq while it is simmering.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
It almost bursts up with fury. Every time a group is cast therein, its keepers will ask: ``Did no warner come to you"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say: ``Yes, indeed a warner did come to us, but we rejected him and said: `Allah never sent down anything; you are only in great error."'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will say: ``Had we but listened or used our intelligence, we would not have been among the dwellers of the blazing Fire!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
Then they will confess their sin. So, away with the dwellers of the blazing Fire!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Verily, those who fear their Lord unseen, theirs will be forgiveness and a great reward.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And whether you keep your talk secret or disclose it, verily, He is the All-Knower of what is in the breasts.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Should not He Who has created know And He is the Most Kind and Courteous, All-Aware.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
He it is Who has made the earth subservient to you; so walk in the paths thereof and eat of His provision. And to Him will be the resurrection.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do you feel secure that He, Who is over the heaven, will not cause the earth to sink with you, and then it should quake\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or do you feel secure that He, Who is over the heaven, will not send against you a Hasib Then you shall know how has been My warning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
And indeed those before them rejected, then how terrible was My reproach\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Do they not see the birds above them, spreading out their wings and folding them in None upholds them except the Most Gracious. Verily, He is the All-Seer of everything.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Who is it besides the Most Gracious that can be an army to you to help you The disbelievers are in nothing but delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Who is it that can provide for you if He should withhold His provision Nay, but they continue to be in pride, and flee.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Is he who walks prone on his face, more rightly guided, or he who walks upright on a straight path\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say: ``It is He Who has created you, and endowed you with hearing and seeing, and hearts. Little thanks you give."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say: ``It is He Who has created you on the earth, and to Him shall you be gathered."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
They say: ``When will this promise come to pass, if you are telling the truth"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say: ``The knowledge is with Allah only, and I am only a plain warner."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
But when they will see it approaching, the faces of those who disbelieve will be sad and grievous, and it will be said: ``This is what you were calling for!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say: ``Tell me! If Allah destroys me, and those with me, or He bestows His mercy on us - who can save the disbelievers from a painful torment"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say: ``He is the Most Gracious, in Him we believe, and upon Him we rely. So, you will come to know who it is that is in manifest error."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say: ``Tell me! If (all) your water were to sink away, who then can supply you with flowing water"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. By the pen and by what they Yastur.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
You, by the grace of your Lord, are not insane.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
And verily, for you will be reward that is not Mamnun.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And verily, you are on an exalted character.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
You will see, and they will see,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is afflicted with madness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Verily, your Lord is the best Knower of him who has gone astray from His path, and He is the best Knower of those who are guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
So, do not obey the deniers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
They wish that you should compromise with them, so they (too) would compromise with you.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And do not obey every Hallaf Mahin.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
A Hammaz, going about with Namim,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
Hinderer of the good, transgressor, sinful,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
`Utul, and moreover Zanim.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
(He was so) because he had wealth and children.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our Ayat are recited to him, he says: ``Tales of the men of old!"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We shall brand him on the snout (nose)!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Verily, We have tried them as We tried the People of the Garden, when they swore to pluck the fruits in the morning,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
Without saying: ``If Allah wills."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
Then there passed over it a Ta'if from your Lord while they were asleep.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
So by the morning, it became like As-Sarim.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
Then they called out (one to another as soon) as the morning broke.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
Saying: ``Go to your tilth in the morning, if you would pluck (the fruits)."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they departed, and they were whispering:\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
``No poor person shall enter upon you into it today."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they went in the morning with Hard Qadirin.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw it, they said: ``Verily, we have gone astray."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
``Nay! Indeed we are deprived!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The Awsat among them said; ``Did I not tell you, `Why do you not Tusabbihun."'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said: ``Glory to Our Lord! Verily, we have been wrongdoers."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they turned one against another, blaming.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said: ``Woe to us! Verily, we were Taghin."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
``We hope that our Lord will give us in exchange better than it. Truly, we hope in our Lord."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the punishment, but truly, the punishment of the Hereafter is greater if they but knew.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Verily, for those who have Taqwa are Gardens of Delight with their Lord.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Shall We then treat the Muslims like the criminals\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is the matter with you How judge you\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or have you a Book wherein you learn,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
That you shall therein have all that you choose\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or have you oaths from Us, lasting until the Day of Judgement, that yours will be what you judge\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them, which of them will stand as surety for that!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or have they ``partners" Then let them bring their ``partners" if they are truthful!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
The Day when the Shin shall be laid bare and they shall be called to prostrate themselves, but they shall not be able to do so.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes will be cast down and ignominy will cover them; they used to be called to prostrate themselves, while they were.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
Then leave Me alone with whoever denies this narration. We shall punish them gradually from directions they perceive not.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
And I will grant them a respite. Verily, My plan is strong.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or is it that you ask them a wage, so that they are heavily burdened with debt\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or that the Unseen is in their hands, so that they can write it down\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
So, wait with patience for the decision of your Lord, and be not like the Companion of the Fish when he cried out (to Us) while he was Makzum.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
Had not a grace from his Lord reached him, he would indeed have been (left in the stomach of the fish, but We forgave him), so he was cast off on the naked shore, while he was to be blamed.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
Then his Lord chose him and made him of the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And verily, those who disbelieve would almost make you slip with their eyes (through hatred) when they hear the Reminder (the Qur'an), and they say: ``Verily, he is a madman!"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
But it is nothing else than a Reminder to all the creatures (`Alamin).\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen Al-Haqqah!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is Al-Haqqah\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what will make you know what Al-Haqqah is\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
Thamud and `Ad denied the Qari`ah!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
As for Thamud, they were destroyed by the Taghiyah!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for `Ad, they were destroyed by a wind, Sarsar `Atiyah!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
Which Allah imposed on them for seven nights and eight days Husum, so that you could see men lying toppled, as if they were trunks of date palms, Khawiyah!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Do you see any remnants of them\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And Fir`awn, and those before him, and the cities overthrown committed Al-Khati'ah.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
And they disobeyed their Lord's Messenger, so He seized them with a punishment that was Rabiyah.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Verily, when the water rose beyond its limits, We carried you in the ship.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
That We might make it an admonition for you and that it might be retained by the retaining ears.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
Then when the Trumpet will be blown with one blowing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth and the mountains shall be removed from their places, and crushed with a single crushing.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
Then on that Day shall the Event occur.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven will be rent asunder, for that Day it will be frail and torn up.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels will be on its sides, and eight angels will, that Day, bear the Throne of your Lord above them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
That Day shall you be brought to Judgement, not a secret of you will be hidden.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
Then as for him who will be given his Record in his right hand will say: ``Here! read my Record!"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
``Surely, I did believe that I shall meet my account!"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
So, he shall be in a life, well-pleasing.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In a lofty Paradise,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
The fruits in bunches whereof will be low and near at hand.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
Eat and drink at ease for that which you have sent on before you in days past!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But as for him who will be given his Record in his left hand, will say: ``I wish that I had not been given my Record!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
``And that I had never known how my account is!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
``Would that it had been my end!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
``My wealth has not availed me;"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
``My power has gone from me!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
(It will be said): ``Seize him and fetter him;"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
``Then throw him in the blazing Fire."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
``Then fasten him on a chain whereof the length is seventy cubits!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
Verily, he used not to believe in Allah, the Most Great,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
And urged not the feeding of the poor.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
So, no friend has he here this Day,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
Nor any food except filth from Ghislin.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
None will eat it except the Khati'un.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
So, I swear by whatsoever you see,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And by whatsoever you see not,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
That this is verily the word of an honored Messenger.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
It is not the word of a poet, little is that you believe!\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor is it the word of a soothsayer, little is that you remember!\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
This is the revelation sent down from the Lord of all that exists.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if he had forged a false saying concerning Us,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We surely would have seized him by his right hand,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
And then We certainly would have cut off Al-Watin from him,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
And none of you could have prevented it from him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
And verily, this is a Reminder for those who have Taqwa.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And verily, We know that there are some among you that deny.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And indeed it will be an anguish for the disbelievers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
And verily, it (this Qur'an) is an absolute truth with certainty.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So, glorify the Name of your Lord, the Most Great.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A questioner asked concerning a torment about to befall\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
Upon the disbelievers, which none can avert,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
From Allah, the Lord of the ways of ascent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
The angels and the Ruh ascend to Him in a Day the measure whereof is fifty thousand years.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
So be patient, with a good patience.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
Verily, they see it (the torment) afar off.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
But We see it near.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
The Day that the sky will be like the Al-Muhl.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the mountains will be like `Ihn.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And no friend will ask a friend,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
Though they shall be made to see one another, the criminal would desire to ransom himself from the punishment of that Day by his children.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his wife and his brother,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And his Fasilah who sheltered him,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And all that are in the earth, so that it might save him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
By no means! Verily, it will be the fire of Hell,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
Nazza`ah the Shawa!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
Calling (all) such as turn their backs and turn away their faces.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And collect (wealth) and hide it (from spending it in the cause of Allah).\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Verily, man was created very impatient;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
Apprehensive when evil touches him;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And suppressive when good touches him.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Except those who are devoted to Salah.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Those who with their Salah are Da'imun;\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those in whose wealth there is a recognized right.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the one who asks, and for the deprived.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who believe in the Day of Recompense.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who fear the torment of their Lord.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Verily, the torment of their Lord is that before which none can feel secure.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who guard their private part (chastity).\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Except from their wives or their right hand possessions -- for (then) they are not blameworthy.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But whosoever seeks beyond that, then it is those who are trespassers.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who keep their trusts and covenants.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who stand firm in their testimonies.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who are with their Salah, Yuhafizun.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
Such shall dwell in the Gardens, honored\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
So, what is the matter with those disbelievers, before you Muhti`in\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
On the right and on the left, `Izin.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Does every man of them hope to enter the Paradise of Delight\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
But no! Verily, We have created them out of that which they know!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
But no! I swear by the Lord of the easts and the wests that surely We are Able\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them by (others) better than them; and We are not to be outrun.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So, leave them to plunge in vain talk and play about, until they meet their Day which they are promised.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The Day when they will come out of the graves quickly as racing to a Nusub,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
With their eyes lowered in fear and humility, ignominy covering them (all over)! That is the Day which they were promised!\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen Verily, We sent Nuh to his people (saying): ``Warn your people before there comes to them a painful torment."\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said: ``O my people! Verily, I am a plain warner to you,"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
``That you should worship Allah, and have Taqwa of Him, and obey me,"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
``He will forgive you of your sins and respite you to an appointed term. Verily, the term of Allah when it comes, cannot be delayed, if you but know."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said: O my Lord! Verily, I have called to my people night and day,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
But all my calling added nothing but to (their) flight.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
And verily, every time I called unto them that You might forgive them, they thrust their fingers into their ears, covered themselves up with their garments, and persisted, and magnified themselves in pride.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
Then verily, I called to them openly (aloud).\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
Then verily, I proclaimed to them in public, and I have appealed to them in private.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
I said (to them): Ask forgiveness from your Lord, verily, He is Oft-Forgiving;\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will send rain to you Midrar,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
And give you increase in wealth and children, and bestow on you gardens and bestow on you rivers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What is the matter with you, that you do not hope for any Waqar from Allah\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
While He has created you (in) Atwar (stages).\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
See you not how Allah has created the seven heavens in tiers\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
And has made the moon a light therein, and made the sun a lamp\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And Allah has brought you forth from the (dust of) earth\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
Afterwards He will return you into it (the earth), and bring you forth.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And Allah has made for you the earth a wide expanse.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
That you may go about therein in broad roads.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Nuh said: ``My Lord! They have disobeyed me, and followed one whose wealth and children give him no increase but loss."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
``And they have plotted a mighty plot."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
``And they have said: `You shall not leave your gods, nor shall you leave Wadd, nor Suwa`, nor Yaghuth, and Ya`uq and Nasr.' ``\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
``And indeed they have led many astray. And (O Allah): `Grant no increase to the wrongdoers save error."'\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their sins they were drowned, then were made to enter the Fire. And they found none to help them instead of Allah.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Nuh said: ``My Lord! Leave not one of the disbelievers on the earth Dayyar!"\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
``If You leave them, they will mislead Your servants, and they will beget none but wicked disbelievers."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
``My Lord! Forgive me, and my parents, and him who enters my home as a believer, and all the believing men and women. And to the wrongdoers grant You no increase but destruction!") Allah says,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say: ``It has been revealed to me that a group of Jinn listened. They said: `Verily, we have heard a wonderful Recitation!'\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
`It guides to the right path, and we have believed therein, and we shall never join anything with our Lord.'\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
`And He, exalted be the Jadd of our Lord, has taken neither a wife nor a son.'\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
`And that the foolish among us used to utter against Allah that which was an enormity in falsehood.'\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
`And verily, we thought that men and Jinn would not utter a lie against Allah.'\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
`And verily, there were men among mankind who took shelter with the males among the Jinn, but they increased them in Rahaq.'\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
`And they thought as you thought, that Allah will not send any Messenger.'\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
`And we have sought to reach the heaven; but we found it filled with stern guards and flaming fires.'\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
`And verily, we used to sit there in stations, to (steal) a hearing, but any who listens now will find a flaming fire watching him in ambush.'\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
`And we know not whether evil is intended for those on the earth, or whether their Lord intends for them guidance.'\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
`There are among us some that are righteous, and some the contrary; we are groups having different ways.'\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
`And we think that we cannot escape Allah in the earth, nor can we escape Him by flight.'\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
`And indeed when we heard the Guidance, we believed therein, and whosoever believes in his Lord shall have no fear, either of a decrease in the reward of his good deeds or an increase in the punishment for his sins.'\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
`And of us some are Muslims, and of us some are Al-Qasitun. And whosoever has embraced Islam, then such have sought the right path.' ``\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
And as for the Qasitun, they shall be firewood for Hell.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
If they had believed in Allah, and went on the way, We would surely have bestowed on them water in abundance.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
That We might try them thereby. And whosoever turns away from the Reminder of his Lord, He will cause him to enter in a Sa`ad torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
And the Masjids are for Allah, so invoke not anyone along with Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
And when the servant of Allah stood up invoking Him in prayer they just made round him a dense crowd as if sticking one over the other.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say: ``I invoke only my Lord, and I associate none as partners along with Him."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say: ``It is not in my power to cause you harm, or to bring you to the right path."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say: ``None can protect me from Allah's punishment, nor can I find refuge except in Him."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
``(Mine is) but conveyance from Allah and His Messages, and whosoever disobeys Allah and His Messenger, then verily, for him is the fire of Hell, he shall dwell therein forever."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
Till, when they see that which they are promised, then they will know who it is that is weaker concerning helpers and less important concerning numbers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say: ``I know not whether that which you are promised is near or whether my Lord will appoint for it a distant term."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
``The All-Knower of the Unseen, and He reveals to none His Unseen."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Except to a Messenger whom He has chosen, and then He makes a band of watching guards to march before him and behind him.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
Till he knows that they have conveyed the Messages of their Lord. And He surrounds all that which is with them, and He keeps count of all things.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O you wrapped up!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Stand (to pray) all night, except a little.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
Half of it or less than that, a little.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or a little more. And Rattil the Qur'an Tartil.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Verily, We shall send down to you a Word Thaqil.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Verily, rising (Nashi'ah) at night is better for understanding and more suitable for speech (recitation).\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
Verily, for you in the day is lengthy Sabh.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
And remember the Name of your Lord and (Tabattil) devote yourself to Him with complete devotion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
Lord of the east and the west; La ilaha illa Huwa, so take Him as a trustee.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And be patient with what they say, and keep away from them in a good way.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And leave Me alone to deal with the deniers, those who are in possession of good things of life. And give them respite for a little.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
Verily, with Us are Ankal, and Jahim.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And a food that chokes, and a painful torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On the Day when the earth and the mountains will (Tarjufu) shake, and the mountains will be a heap of sand poured out.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Verily, We have sent to you a Messenger to be a witness over you, as We did send a Messenger to Fir`awn.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Fir`awn disobeyed the Messenger; so We seized him with a severe punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
Then how can you protect yourselves from the punishment, if you disbelieve, on a Day that will make the children gray-headed\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
Whereon the heaven will be cleft asunder His promise is certainly to be accomplished.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Verily, this is an admonition, therefore whosoever wills, let him take a path to His Lord!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Verily, your Lord knows that you do stand a little less than two-thirds of the night, or half the night, or a third of the night, and also a party of those with you. And Allah measures the night and the day. He knows that you are unable to pray the whole night, so He has turned to you. So, recite you of the Qur'an as much as may be easy for you. He knows that there will be some among you sick, others traveling through the land, seeking of Allah's bounty, yet others fighting in Allah's cause. So recite as much of the Qur'an as may be easy,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O you enveloped in garments!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise and warn!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And magnify your Lord!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And purify your garments!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And keep away from Ar-Rujz!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And give not a thing in order to have more.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
And be patient for the sake of your Lord!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
Then, when the Naqur is sounded.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
Truly, that Day will be a Hard Day.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
Far from easy for the disbelievers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me alone (to deal) with whom I created lonely.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And then granted him resources in abundance.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And children attending.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And made life smooth and comfortable for him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
After all that he desires that I should give more.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
Nay! Verily, he has been opposing Our Ayat.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
I shall force him to Sa`ud!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
Verily, he thought and plotted.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
So let him be cursed, how he plotted!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
And once more let him be cursed, how he plotted!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he thought.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then he frowned and he looked in a bad tempered way;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then he turned back, and was proud.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
Then he said: ``This is nothing but magic from that of old,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
``This is nothing but the word of a human being!"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I will cast him into Saqar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what will make you know (exactly) what Saqar is\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It spares not, nor does it leave (anything)!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
Scorching for the humans!\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are nineteen.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
And We have set none but angels as guardians of the Fire. And We have fixed their number only as a trial for the disbelievers, in order that the People of the Scripture may arrive at a certainty and that the believers may increase in faith, and that no doubt may be left for the People of the Scripture and the believers, and that those in whose hearts is a disease and the disbelievers may say: ``What does Allah intend by this example" Thus Allah leads astray whom He wills and guides whom He wills. And none can know the hosts of your Lord but He. And this is nothing but a reminder to mankind.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
Nay! And by the moon.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And by the night when it withdraws.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And by the dawn when it brightens.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
Verily, it is but one of the greatest (signs).\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
A warning to mankind\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
To any of you that chooses to go forward, or to remain behind.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every person is a pledge for what he has earned,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Except those on the Right.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
In Gardens they will ask one another,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
About criminals (and they will say to them):\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
``What has caused you to enter Hell"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will say: ``We were not of those who used to offer the Salah,"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
``Nor did we feed the poor;"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
``And we used to speak falsehood with vain speakers."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
``And we used to deny the Day of Recompense,"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
``Until Al-Yaqin came to us."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
So no intercession of intercessors will be of any use to them.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
Then what is wrong with them that they turn away from admonition\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As if they were wild donkeys.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing from a Qaswarah.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Nay, everyone of them desires that he should be given pages spread out.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
Nay! But they fear not the Hereafter.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
Nay, verily, this is an admonition.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
So, whosoever wills receives admonition from it!\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And they will not receive admonition unless Allah wills; He is the One, deserving of the Taqwa and He is the One Who forgives.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen Nay! I swear by the Day of Resurrection.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And nay! I swear by An-Nafs Al-Lawwamah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man think that We shall not assemble his bones\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yes, We are able to put together in perfect order the tips of his fingers.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
Nay! Man desires to break out ahead of himself.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asks: ``When will be this Day of Resurrection"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
So, when Bariqa the sight.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon will be eclipsed.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and moon will be joined together.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
On that Day man will say: ``Where (is the refuge) to flee"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No! There is no refuge!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
Unto your Lord will be the place of rest that Day.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
On that Day man will be informed of what he sent forward, and what he left behind.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
Nay! Man will be well informed about himself,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Though he may put forth his excuses.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Move not your tongue concerning to make haste therewith.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
It is for Us to collect it and that it be recited.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
And when We have recited it to you, then follow its recitation.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then it is for Us to make it clear.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
But no! Rather you love the present life of this world,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And neglect the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
Some faces that Day shall be Nadirah.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking at their Lord.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And some faces that Day will be Basirah,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Thinking that some calamity is about to fall on them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
Nay, when it rea- ches to the collarbones.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And it will be said: ``Who can cure him"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And he will think that it was the parting;\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And one shank will be joined with another shank.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
The drive will be on that Day to your Lord!\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
So, he neither believed nor prayed!\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But on the contrary, he denied and turned away!\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
Then he walked in conceit to his family admiring himself!\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Woe to you! And then woe to you!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Again, woe to you! And then woe to you!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man think that he will be left neglected\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Was he not a Nutfah of semen emitted\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he became an `Alaqah; then shaped and fashioned in due proportion.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And made of him two sexes, male and female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Is it not so then, that He would be able to give life to the dead\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Has there not been over man a period of time, when he was not a thing worth mentioning\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Verily, We have created man from Nutfah Amshaj, in order to try him, so, We made him hearer and seer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Verily, We guided him to the way, whether he be grateful or ungrateful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Verily, We have prepared for the disbelievers iron chains, iron collars, and Sa`ir.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Verily, the Abrar (righteous believers) shall drink of a cup mixed with Kafur.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
A spring wherefrom the servants of Allah will drink, causing it to gush forth abundantly.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They fulfill (their) vows, and they fear a Day whose evil will be wide-spreading.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And they give food, inspite of their love for it, to the poor, the orphan and the captive,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
(Saying): ``We feed you seeking Allah's Face only. We wish for no reward, nor thanks from you."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
``Verily, We fear from our Lord a Day that is `Abus and Qamtarir."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So, Allah saved them from the evil of that Day, and gave them Nadrah (a light of beauty) and joy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And their recompense shall be Paradise, and silken garments, because they were patient.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
Reclining therein on raised couches, they will see there neither the excessive heat, nor the excessive cold.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
And the shade thereof is close upon them, and the bunches of fruit thereof will hang low within their reach.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
And among them will be passed round vessels of silver and cups of crystal --\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
(Qawarir) Crystal-clear, made of silver. They will determine the measure thereof.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And they will be given to drink there of a cup (of wine) mixed with Zanjabil (ginger),\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
A spring there, called Salsabil.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
And round about them will (serve) boys of everlasting youth. If you see them, you would think them scattered pearls.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
And when you look there (in Paradise), you will see a delight (that cannot be imagined), and a great dominion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Their garments will be of fine green silk, and Istabraq. They will be adorned with bracelets of silver, and their Lord will give them a purifying drink.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
(And it will be said to them): ``Verily, this is a reward for you, and your endeavor has been accepted."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Verily, it is We Who have sent down the Qur'an to you by stages.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
Therefore be patient with constancy to the command of your Lord, and obey neither a sinner nor a disbeliever among them.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And remember the Name of your Lord every morning and afternoon.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And during the night, prostrate yourself to Him, and glorify Him a long night through.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Verily, these love the present life of this world, and put behind them a heavy Day.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
It is We Who created them, and We have made them of strong build. And when We will, We can replace them with others like them with a complete replacement.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Verily, this is an admonition, so whosoever wills, let him take a path to his Lord.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
But you cannot will, unless Allah wills. Verily, Allah is Ever All-Knowing, All-Wise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He will admit to His mercy whom He wills and as for the wrongdoers -- He has prepared a painful torment.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By the Mursalat `Urfa.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
The `Asifat `Asfa.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
And the Nashirat Nashra.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
The Fariqat that separate.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
The Mulqiyat that remind,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
Excusing or warning.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Surely, what you are promised will occur.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
Then when the stars lose their lights.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And when Furijat the heaven.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And when the mountains are blown away.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the Messengers are Uqqitat.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For what Day are these signs postponed\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of Sorting Out (the men of Paradise from the men destined for Hell).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what will explain to you what is the Day of Sorting Out\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the ancients\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
So shall We make later generations to follow them.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
Thus do We deal with the criminals.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe that Day to the deniers!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from a despised water\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
Then We placed it in a place of safety,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a known period\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
So We did measure; and We are the best to measure.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe that Day to the deniers!\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth Kifat (a receptacle)\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
For the living and the dead\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And have placed therein fixed towers, and have given you Furat water\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe that Day to the deniers!\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
(It will be said to the disbelievers): ``Depart you to that which you used to deny!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
``Depart you to a shadow in three columns,"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
``Neither shady nor of any use against the fierce flame of the Fire."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
Verily, it (Hell) throws sparks (huge) as Al-Qasr,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
As if they were Sufr camels.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
That will be a Day when they shall not speak (during some part of it),\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
And they will not be permitted to put forth any excuse.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
That will be a Day of Decision! We have brought you and the men of old together!\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
So, if you have a plot, use it against Me (Allah)!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe that Day to the deniers (of the Day of Resurrection)!\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Verily, those who had Taqwa, shall be amidst shades and springs.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And fruits, such as they desire.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
``Eat and drink comfortably for that which you used to do."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Verily, thus We reward the Muhsinin.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe that Day to the deniers!\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
Eat and enjoy yourselves for a little while. Verily, you are criminals.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe that Day to the deniers!\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said to them: ``Bow down yourself!" They bow not down.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe that Day to the deniers!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
Then in what statement after this will they believe\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen What are they asking about\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
About the great news,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
About which they are in disagreement.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
Nay, they will come to know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Nay, again, they will come to know!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth as a bed,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains as pegs\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We have created you in pairs.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And We have made your sleep as a thing for rest.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And We have made the night as a covering,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And We have made the day for livelihood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And We have built above you seven strong,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And We have made (therein) a shining lamp.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And We have sent down from the Mu`sirat water Thajjaj.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
That We may produce therewith grains and vegetations,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And gardens that are Alfaf.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Verily, the Day of Decision is a fixed time,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
The Day when the Trumpet will be blown, and you shall come forth in crowds.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heaven shall be opened, and it will become as gates.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains shall be moved away from their places and they will be as if they were a mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Truly, Hell is a place of ambush\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
A dwelling place for the Taghun,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
They will abide therein Ahqab.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
Nothing cool shall they taste therein, nor any drink.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Except Hamim, and Ghassaq\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
An exact recompense (according to their evil crimes).\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
For verily, they used not to look for a reckoning.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
But they denied Our Ayat Kidhdhaba.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
And all things We have recorded in a Book.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
So taste you. No increase shall We give you, except in torment.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Verily, for those who have Taqwa, there will be a success;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Hada'iq and vineyards,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And Kawa`ib Atrab,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And a cup Dihaq.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
No Laghw shall they hear therein, nor lying;\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
Rewarded from your Lord with a sufficient gift.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
The Lord of the heavens and the earth, and whatsoever is in between them, the Most Gracious, with Whom th- ey cannot dare to speak.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
The Day that Ar-Ruh and the angels will stand forth in rows, they will not speak except him whom Ar-Rahman allows, and he will speak what is right.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the True Day. So, whosoever wills, let him seek a place with His Lord!\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Verily, We have warned you of a near torment -- the Day when man will see that which his hands have sent forth, and the disbeliever will say: ``Woe to me! Would that I were dust!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those who pull out, drowning.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
By those who free briskly.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
And by the swimmers, swimming.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
And by the racers, racing.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And by those who arrange affairs.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the Day the Rajifah shakes,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
Followed by the Radifah.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
Hearts that Day will tremble.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Their vision humiliated.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They say: ``Shall we indeed be brought back from Al-Hafirah"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
``Even after we are bones Nakhirah"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say: ``It would in that case, be a return with loss!"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
But it will be only a single Zajrah.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
When behold, they are at As-Sahirah.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Has there come to you the story of Musa\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When his Lord called him in the holy valley of Tuwa,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
Go to Fir`awn; verily, he has transgressed all bounds.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
And say to him: ``Would you purify yourself"\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
``And that I guide you to your Lord, so you should fear Him"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
Then he showed him the great sign.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
But he denied and disobeyed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Then he turned back, striving.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
So he gathered and called out,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
Saying: ``I am your lord, most high."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So Allah seized him with punishing example for the Hereafter and the first (life).\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
In this is a lesson for whoever fears.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Are you more difficult to create or is the heaven that He constructed\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised its hei- ght, and has perfected it.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
Its night He covers and He brings out its forenoon.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And after that He spread the earth,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
And brought forth therefrom its water and its pasture.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains He has fixed firmly,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
As provision and benefit for you and your cattle.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when there comes the Greatest Catastrophe\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
The Day when man shall remember what he strove for.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And Hell shall be made apparent for whoever sees.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
Then for him who transgressed\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And preferred the life of this world,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Verily, his abode will be the Hell;\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But as for him who feared standing before his Lord, and forbade himself from desire.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Verily, Paradise will be his abode.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask you about the Hour when will be its appointed time\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
What do you have to mention of it.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
To your Lord it is limited.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You are only a warner for those who fear it,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
The Day they see it (it will be) as if they had not tarried (in this world) except an (`Ashiyyah) afternoon or its (Duha) morning.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen He frowned and turned away.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because there came to him the blind man.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
And how can you know that he might become pure\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or he might receive admonition, and the admonition might profit him\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As for him who thinks himself self-sufficient,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
To him you attend;\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
What does it matter to you if he will not become pure\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But as for him who came to you running,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
And is afraid.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
Of him you are neglectful and divert your attention to another.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
Nay; indeed it is an admonition.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So, whoever wills, let him pay attention to Him (it).\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
In Records held in honor,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted, purified.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
In the hands of ambassadors (Safarah),\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Honorable and obedient.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Qutila mankind! How ungrateful he is!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what thing did He create him\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a Nutfah He created him and then set him in due proportion.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then He made the path easy for him.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then He causes him to die and puts him in his grave.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then when it is His will, He will resurrect him.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
Nay, but has not done what He commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Then let man look at his food:\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
We pour forth water in abundance.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
And We split the earth in clefts.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
And We cause therein Habb to grow,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and Qadb,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olives and date palms,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And Ghulb Hada'iq,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruits (Fakihah) and herbage (Abb).\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
A provision and benefit for you and your cattle.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
Then when there comes As-Sakhkhah\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
That Day shall a man flee from his brother.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And from his mother and his father.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And from his wife and his children.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
Every man that Day will have enough to make him careless of others.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
Some faces that Day will be bright,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing at good news.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And other faces that Day will be dust-stained.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Darkness will cover them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Such will be the disbelieving, the wicked evil doers.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun is Kuwwirat.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
And when the stars Inkadarat.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
And when the mountains are made to pass away;\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
And when the pregnant she-camels are neglected;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
And when the wild beasts are gathered together.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
And when the seas become as blazing fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
And when the souls are joined with their mates.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
And when the female infant (Al-Maw'udah) buried alive is questioned (Su'ilat):\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what sin was she killed\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
And when the pages are laid open.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
And when the heaven is Kushitat;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
And when Hell is Su`irat.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when Paradise is brought near.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
Every person will know what he has brought.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
But nay! I swear by Al-Khunnas.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
Al-Jawar Al-Kunnas.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And by the night when it `As`as.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And by the day when it Tanaffas.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
Verily, this is the Word a most honorable messenger.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
Dhi Quwwah, with the Lord of the Throne -- Makin,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
Obeyed there, trustworthy.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
And your companion is not a madman.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
And indeed he saw him in the clear horizon.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And he withholds not a knowledge of the Unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
And it is not the word of the outcast Shaytan.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
Then where are you going\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
Verily, this is no less than a Reminder for the creatures.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
To whomsoever among you who wills to walk straight.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
And you cannot will unless that Allah wills -- the Lord of all that exists.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the heaven is cleft asunder (Infatarat).\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
And when the stars Intatharat.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
And when the seas Fujjirat.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And when the graves Bu`thirat.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
A person will know what he has sent forward and left behind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O man! What has made you careless about your Lord, the Most Generous\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Who created you, fashioned you perfectly, and gave you due proportion.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatever form He willed, He put you together.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
Nay! But you deny (the Day of) Ad-Din.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
But verily, over you to watch you\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Kiraman Katibin,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
They know all that you do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Verily, the Abrar (the righteous believers) will be in Delight;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And verily, the wicked will be in the blazing Fire (Hell),\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
Therein they will enter, and taste its burning flame on the Day of Recompense,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And they will not be absent therefrom.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what will make you know what the Day of Recompense is\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Again, what will make you know what the Day of Recompense is\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
(It will be) the Day when no person shall have power for another, and the Decision, that Day, will be with Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to Al-Mutaffifin.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Those who, when they have to receive by measure from men, demand full measure,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
And when they have to give by measure or weight to men, give less than due.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do they not think that they will be resurrected,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
On a Great Day\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
The Day when (all) mankind will stand before the Lord of all that exists\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
Nay! Truly, the Record of the wicked is in Sijjin.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And what will make you know what Sijjin is\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
A Register inscribed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe, that Day, to those who deny.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Those who deny the Day of Recompense.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
And none can deny it except every transgressor beyond bounds, the sinner!\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When Our Ayat are recited to him, he says: ``Tales of the ancients!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
Nay! But on their hearts is the Ran (covering) which they used to earn.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
Nay! Surely, they will be veiled from seeing their Lord that Day.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then verily, they will indeed enter the burning flame of Hell.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Then, it will be said to them: ``This is what you used to deny!"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
Nay! Verily, the Record of Al-Abrar (the righteous believers) is (preserved) in `Illiyyin.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what will make you know what `Illiyyin is\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
A Register inscribed,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
To which bear witness those nearest.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Verily, Al-Abrar (the righteous believers) will be in Delight.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On thrones, looking.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
You will recognize in their faces the brightness of delight.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be given to drink of pure sealed Rahiq.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
Sealed with musk, and for this let those strive who want to strive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
It will be mixed with Tasnim:\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A spring whereof drink those nearest to Allah.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Verily, those who committed crimes used to laugh at those who believed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And, whenever they passed by them, used to wink one to another.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they returned to their own people, they would return jesting;\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And when they saw them, they said: ``Verily, these have indeed gone astray!"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
But they were not sent as watchers over them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
But this Day those who believe will laugh at the disbelievers\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On thrones, looking.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Are not the disbelievers paid for what they used to do\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the heaven is split asunder,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And listens to and obeys its Lord -- and it must do so.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth is stretched forth,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And has cast out all that was in it and became empty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And listens to and obeys its Lord -- and it must do so.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O man! Verily, you are returning towards your Lord with your deeds and actions, a sure returning, and you will meet.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then as for him who will be given his Record in his right hand,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
He surely will receive an easy reckoning,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And will return to his family Masrur (in joy)!\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But whosoever is given his Record behind his back,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
He will invoke destruction,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And he shall enter a blazing Fire, and made to taste its burning.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Verily, he was among his people in joy!\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
Verily, he thought that he would never return!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
Yes! Verily, his Lord has been ever beholding him!\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
But no! I swear by Ash-Shafaq;\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And the night and what it Wasaqa,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And the moon when it Ittasaq.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
You shall certainly travel from stage\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
What is the matter with them, that they believe not\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And when the Qur'an is recited to them, they fall not prostrate.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
Nay, those who disbelieve deny.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
And Allah knows best what they gather,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So, announce to them a painful torment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Save those who believe and\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the heaven holding the Buruj.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And by by the Promised Day.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And by the Witness and by the Witnessed.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Cursed were the People of the Ditch.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
Of fire fed with fuel.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
When they sat by it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And they witnessed what they were doing against the believers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
And they had no fault except that they believed in Allah, the Almighty, Worthy of all praise!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
To Whom belongs the dominion of the heavens and the earth! And Allah is Witness over everything.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Verily, those who put into trial the believing men and believing women, and then do not turn in repentance, then they will have the torment of Hell, and they will have the punishment of the burning Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Verily, those who believe and do righteous good deeds, for them will be Gardens under which rivers flow. That is the supreme success.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Verily, the punishment of your Lord is severe and painful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Verily, He it is Who begins and repeats.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is Oft-Forgiving, Al-Wadud.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Owner of the Throne, Al-Majid (the Glorious).\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Doer of what He intends.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has the story reached you of the hosts.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
Of Fir`awn and Thamud\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
Nay! The disbelievers (persisted) in denying.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
And Allah encompasses them from behind!\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
Nay! This is a Glorious Qur'an,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
In Al-Lawh Al-Mahfuz!\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the heaven, and At-Tariq;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And what will make you to know what At-Tariq is\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
The star, Ath-Thaqib.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is no human being but has a protector over him.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So, let man see from what he is created!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He is created from a water gushing forth,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
Proceeding from between the backbone and the ribs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Verily, He is Able to bring him back!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
The Day when all the secrets will be examined.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
Then he will have no power, nor any helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the sky which gives rain, again and again.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And the earth which splits.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Verily, this is the Word that separates.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
And it is not a thing for amusement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
Verily, they are but plotting a plot.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
And I am planning a plan.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So, give a respite to the disbelievers; deal gently with them for a while.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Glorify the Name of your Lord, the Most High.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who has created, and then proportioned it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
And Who has measured; and then guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
And Who brings out the pasturage,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
And then makes it dark stubble.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We shall make you recite, so you shall not forget,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Except what Allah may will He knows what is apparent and what is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We shall make easy for you the easy.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
Therefore remind in case the reminder profits.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
The reminder will be received by him who fears,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
But it will be avoided by the wretched,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
Who will enter the great Fire.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
There he will neither die nor live.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
Indeed whosoever purifies himself shall achieve success.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And remembers the Name of his Lord, and performs Salah.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
Rather you prefer the life of this world.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
Although the Hereafter is better and more lasting.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Verily, this is in the former Scriptures\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
The Scriptures of Ibrahim and Musa.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Has there come to you the narration of Al-Ghashiyah (the overwhelming)\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
Some faces that Day will be Khashi`ah.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Laboring, weary.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
They will enter into Fire, Hamiyah.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
They will be given to drink from a boiling (Aniyah) spring,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
No food will there be for them but from Dari`,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which will neither nourish nor avail against hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
Faces that Day will be joyful,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
Glad with their endeavor.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In a lofty Paradise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
Where they shall neither hear harmful speech nor falsehood.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
Therein will be a running spring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
Therein will be thrones raised high.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And cups set at hand.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And Namariq, set in rows.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And Zarabi, spread out (Mabthuthah).\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Do they not look at the camels, how they are created\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And at the heaven, how it is raised\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And at the mountains, how they are rooted\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And at the earth, how it is outspread\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
So remind them -- you are only one who reminds.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
You are not a Musaytir over them.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
Save the one who turns away and disbelieves.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Then Allah will punish him with the greatest punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Verily, to Us will be their return;\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then verily, for Us will be their reckoning.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
And by the ten nights,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And by the even and the odd.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And by the night when it departs.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there (not) in them sufficient proofs for men of understanding!\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Saw you not how your Lord dealt with `Ad\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
Iram of the pillars,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The like of which were not created in the land\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And Thamud, who hewed out rocks in the valley\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And Fir`awn with Al-Awtad\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
Who did transgress beyond bounds in the lands.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And made therein much mischief.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
So, your Lord poured on them different kinds of severe torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Verily, your Lord is Ever Watchful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
As for man, when his Lord tries him by giving him honor and bounties, then he says: ``My Lord has honored me."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when He tries him by straitening his means of life, he says: ``My Lord has humiliated me!"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
But no! But you treat not the orphans with kindness and generosity!\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
And urge not one another on the feeding of the Miskin!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And you devour the Turath -- devouring with greed.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And you love wealth with love Jamma.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
Nay! When the earth is flatened, Dakkan Dakka.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And your Lord comes with the angels in rows.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And Hell will be brought near that Day. On that Day will man remember, but how will that remembrance avail him\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say: ``Alas! Would that I had sent forth for my life!"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
So on that Day none will punish as He will punish.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
And none will bind as He will bind.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
``O tranquil soul!"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
``Come back to your Lord, -- well-pleased and well-pleasing!"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
``Enter then among My servants,"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
``And enter My Paradise!"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen Nay! I swear by this city;\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And you are free in this city.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And by the begetter and that which he begot.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
Verily, We have created man in Kabad.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Does he think that none can overcome him\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He says: ``I have wasted wealth in abundance!"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Does he think that none sees him\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not made for him two eyes\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue and two lips\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And shown him the two ways\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he has not attempted to pass on the path that is steep.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what will make you know the path that is steep\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
Freeing a neck\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or giving food in a day full of Masghabah,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
To an orphan near of kin.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or to a Miskin cleaving to dust.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
Then he became one of those who believed and recommended one another to patience, and recommended one another to compassion.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
They are those on the Right,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But those who disbelieved in Our Ayat, they are those on the Left.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Upon them Fire will Mu'sadah.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and Duhaha.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
By the moon as it Talaha.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
By the day as it Jallaha.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
By the night as it Yaghshaha.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
By the heaven and Ma Banaha.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
By the earth and Ma Tahhaha.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
By Nafs, and Ma Sawwaha (Who apportioned it).\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
Then He showed it its Fujur and its Taqwa.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
Indeed he succeeds who purifies it.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And indeed he fails who Dassaha.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamud denied through their trans- gression.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
When their most wicked went forth.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
But the Messenger of Allah said to them: ``Be cautious! That is the she-camel of Allah! (Do not harm it) and (bar it not from having) its drink!"\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
Then they denied him and they killed it. So their Lord destroyed them because of their sin, Fasawwaha!\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And He feared not the consequences thereof.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night as it envelops.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
By the day as it appears.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
By Him Who created male and female.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Certainly, your efforts and deeds are diverse.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for him who gives and has Taqwa,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And believes in Al-Husna.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We will make smooth for him the path of ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But he who is greedy and thinks himself self-sufficient,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And denies Al-Husna.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We will make smooth for him the path to evil.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
And what will his wealth avail him when he goes down (in destruction)\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Truly, on Us is (to give) guidance.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And truly, unto Us (belong) the last (Hereafter) and the first (this world).\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
Therefore I have warned you of a Fire Talazza.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None shall enter it save the most wretched.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
Who denies and turns away.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
And those with Taqwa will be far removed from it.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
He who gives of his wealth for self-purification.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And who has (in mind) no favor from anyone to be paid back.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
Except to seek the Face of his Lord, the Most High.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
He, surely, will be pleased.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the forenoon.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
By the night when it darkens.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Your Lord has neither forsaken you nor hates you.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And indeed the Hereafter is better for you than the present.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And verily, your Lord will give you so that you shall be well-pleased.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you an orphan and gave you a refuge\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And He found you unaware and guided you\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And He found you poor and made you rich\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
Therefore, treat not the orphan with oppression.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
And repulse not the one who asks.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
And proclaim the grace of your Lord.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Have We not opened your breast for you\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And removed from you your burden.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which weighed down your back\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And have We not raised high your fame\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
Verily, along with every hardship is relief,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Verily, along with every hardship is relief.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So when you have finished, devote yourself to Allah's worship.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And to your Lord turn intentions and hopes.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By At-Tin and Az-Zaytun.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
By Tur Sinin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
By this city of security.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
Verily, We created man in the best form.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Then We reduced him to the lowest of the low.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Save those who believe and do righteous deeds. Then they shall have a reward without end.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
Then what causes you to deny after this the Recompense\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the best of judges\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Read! In the Name of your Lord Who created.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
He has created man from a clot.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Read! And your Lord is the Most Generous.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
Who has taught by the pen.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
He has taught man that which he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
Nay! Verily, man does transgress.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
Because he considers himself self-sufficient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Surely, unto your Lord is the return.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Have you seen him who prevents\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A servant when he prays\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Have you seen if he is on the guidance\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or enjoins Taqwa\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Have you seen if he denies and turns away\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Knows he not that Allah sees\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
Nay! If he ceases not, We will scorch his forehead --\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A lying, sinful forehead!\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Then let him call upon his council.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will call out the guards of Hell!\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
Nay! Do not obey him. Fall prostrate and draw near (to Allah)!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Verily, We have sent it down in the Night of Al-Qadr.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what will make you know what the Night of Al-Qadr is\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Al-Qadr is better than a thousand months.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
Therein descend the angels and the Ruh by their Lord's permission with every matter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
There is peace until the appearance of dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieve from among the People of the Scripture and the idolators, were not going to leave until there came to them the Bayyinah.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
A Messenger from Allah reciting purified pages.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
Wherein are upright Books.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
And the People of the Scripture differed not until after there came to them the Bayyinah.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they were commanded not, but that they should worship Allah, making religion purely for Him alone, Hunafa', and that they perform Salah and give Zakah, and that is the right religion.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Verily, those who disbelieve from among the People of the Scripture and idolators, will abide in the fire of Hell. They are the worst of creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
Verily, those who believe and do righteous good deeds, they are the best of creatures.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward with their Lord is Eternal Gardens, underneath which rivers flow. They will abide therein forever, Allah will be pleased with them, and they well-pleased with Him. That is for him who fears his Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth quakes with its Zilzal.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And when the earth throws out its burdens.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man will say: ``What is the matter with it"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
That Day it will declare its information.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
Because your Lord will inspire it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
That Day mankind will proceed in scattered groups that they may be shown their deeds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
So, whosoever does good equal to the weight of a speck of dust shall see it.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whosoever does evil equal to the weight of a speck of dust shall see it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the `Adiyat (steeds), snorting.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
Striking sparks of fire.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And scouring to the raid at dawn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
And raise the dust in clouds the while.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
And penetrating forthwith as one into the midst.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Verily, man is ungrateful to his Lord.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And to that He bears witness.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And verily, he is violent in the love of wealth.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
Knows he not that when the contents of the graves are poured forth\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And that which is in the breasts shall be made known\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
Verily, that Day their Lord will be Well-Acquainted with them.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen Al-Qari`ah.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is Al-Qari`ah\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what will make you know what Al-Qari`ah is\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
It is a Day whereon mankind will be like moths scattered about.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains will be like wool, carded.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then as for him whose Balance will be heavy,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He will live a pleasant life.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
But as for him whose Balance will be light,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
His mother will be Hawiyah.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what will make you know what it is\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
A fire Hamiyah!\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen The mutual increase diverts you,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until you visit the graves.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
Nay! You shall come to know!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Again nay! You shall come to know!\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
Nay! If you knew with a sure knowledge.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
Verily, you shall see the blazing Fire!\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
And again, you shall see it with certainty of sight!\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then on that Day you shall be asked about the delights!\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By Al-`Asr.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Verily, man is in loss.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Except those who believe and do righteous deeds, and recommend one another to the truth, and recommend one another to patience.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every Humazah Lumazah.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who has gathered wealth and counted it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
He thinks that his wealth will make him last forever!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
But no! Verily, he will be thrown into Al-Hutamah.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what will make you know what Al-Hutamah is\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
The fire of Allah, Al-Muqadah,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
Which leaps up over the hearts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Verily, it shall Mu'sadah upon them,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In pillars stretched forth.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Have you not seen how your Lord dealt with the Owners of the Elephant\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not make their plot go astray\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He sent against them birds, in flocks (Ababil).\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Striking them with stones of Sijjil.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
And He made them like `Asf, Ma'kul.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the Ilaf of the Quraysh.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
Their Ilaf caravans, in winter and in summer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
So, let them worship the Lord of this House.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who has fed them against hunger, and has made them safe from fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Have you seen him who denies Ad-Din\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
That is he who repulses the orphan,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And urges not the feeding of Al-Miskin.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So, woe unto those performers of Salah,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
Those who with their Salah are Sahun.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Those who do good deeds only to be seen,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
And withhold Al-Ma`un.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Verily, We have granted you Al-Kawthar.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
Therefore turn in prayer to your Lord and sacrifice.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
For he who hates you, he will be cut off.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say: ``O disbelievers!"\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
``I worship not that which you worship."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
``Nor will you worship whom I worship."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
``And I shall not worship that which you are worshipping."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
``Nor will you worship that which I worship."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
``To you be your religion, and to me my religion."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When there comes the help of Allah and the Conquest.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And you see that the people enter Allah's religion in crowds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
So, glorify the praises of your Lord, and ask His forgiveness. Verily, He is the One Who accepts the repentance and Who forgives.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen Perish the two hands of Abu Lahab and perish he!\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth and his children will not benefit him!\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
He will enter a Fire full of flames!\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And his wife too, who carries wood.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
In her neck is a twisted rope of Masad.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say: ``He is Allah, One."\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
``Allah As-Samad."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
``He begets not, nor was He begotten."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
``And there is none comparable to Him."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say: ``I seek refuge with the Lord of Al-Falaq,"\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
``From the evil of what He has created,"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
``And from the evil of the Ghasiq when Waqab,"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
``And from the evil of the blowers in knots,"\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
``And from the evil of the envier when he envies."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say: ``I seek refuge with the Lord of An-Nas,"\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
``The King of An-Nas,"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
``The God of An-Nas,"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
``From the evil of the whisperer who withdraws."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
``Who whispers in the breasts of An-Nas."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
``Of Jinn and An-Nas."\qt@no{6}}%
%% End of file `qurantext-enviii.translation.def'
