\qt@newcmd\qurantrans@en@i{%
In the name of Allah, the Entirely Merciful, the Especially Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ii{%
[All] praise is [due] to Allah, Lord of the worlds -\qt@no{2}}%
\qt@newcmd\qurantrans@en@iii{%
The Entirely Merciful, the Especially Merciful,\qt@no{3}}%
\qt@newcmd\qurantrans@en@iv{%
Sovereign of the Day of Recompense.\qt@no{4}}%
\qt@newcmd\qurantrans@en@v{%
It is You we worship and You we ask for help.\qt@no{5}}%
\qt@newcmd\qurantrans@en@vi{%
Guide us to the straight path -\qt@no{6}}%
\qt@newcmd\qurantrans@en@vii{%
The path of those upon whom You have bestowed favor, not of those who have evoked [Your] anger or of those who are astray.\qt@no{7}}%
\qt@newcmd\qurantrans@en@viii{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ix{%
This is the Book about which there is no doubt, a guidance for those conscious of Allah -\qt@no{2}}%
\qt@newcmd\qurantrans@en@x{%
Who believe in the unseen, establish prayer, and spend out of what We have provided for them,\qt@no{3}}%
\qt@newcmd\qurantrans@en@xi{%
And who believe in what has been revealed to you, [O Muhammad], and what was revealed before you, and of the Hereafter they are certain [in faith].\qt@no{4}}%
\qt@newcmd\qurantrans@en@xii{%
Those are upon [right] guidance from their Lord, and it is those who are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@xiii{%
Indeed, those who disbelieve - it is all the same for them whether you warn them or do not warn them - they will not believe.\qt@no{6}}%
\qt@newcmd\qurantrans@en@xiv{%
Allah has set a seal upon their hearts and upon their hearing, and over their vision is a veil. And for them is a great punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@xv{%
And of the people are some who say, ``We believe in Allah and the Last Day," but they are not believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@xvi{%
They [think to] deceive Allah and those who believe, but they deceive not except themselves and perceive [it] not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@xvii{%
In their hearts is disease, so Allah has increased their disease; and for them is a painful punishment because they [habitually] used to lie.\qt@no{10}}%
\qt@newcmd\qurantrans@en@xviii{%
And when it is said to them, ``Do not cause corruption on the earth," they say, ``We are but reformers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@xix{%
Unquestionably, it is they who are the corrupters, but they perceive [it] not.\qt@no{12}}%
\qt@newcmd\qurantrans@en@xx{%
And when it is said to them, ``Believe as the people have believed," they say, ``Should we believe as the foolish have believed?" Unquestionably, it is they who are the foolish, but they know [it] not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@xxi{%
And when they meet those who believe, they say, ``We believe"; but when they are alone with their evil ones, they say, ``Indeed, we are with you; we were only mockers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@xxii{%
[But] Allah mocks them and prolongs them in their transgression [while] they wander blindly.\qt@no{15}}%
\qt@newcmd\qurantrans@en@xxiii{%
Those are the ones who have purchased error [in exchange] for guidance, so their transaction has brought no profit, nor were they guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@xxiv{%
Their example is that of one who kindled a fire, but when it illuminated what was around him, Allah took away their light and left them in darkness [so] they could not see.\qt@no{17}}%
\qt@newcmd\qurantrans@en@xxv{%
Deaf, dumb and blind - so they will not return [to the right path].\qt@no{18}}%
\qt@newcmd\qurantrans@en@xxvi{%
Or [it is] like a rainstorm from the sky within which is darkness, thunder and lightning. They put their fingers in their ears against the thunderclaps in dread of death. But Allah is encompassing of the disbelievers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@xxvii{%
The lightning almost snatches away their sight. Every time it lights [the way] for them, they walk therein; but when darkness comes over them, they stand [still]. And if Allah had willed, He could have taken away their hearing and their sight. Indeed, Allah is over all things competent.\qt@no{20}}%
\qt@newcmd\qurantrans@en@xxviii{%
O mankind, worship your Lord, who created you and those before you, that you may become righteous -\qt@no{21}}%
\qt@newcmd\qurantrans@en@xxix{%
[He] who made for you the earth a bed [spread out] and the sky a ceiling and sent down from the sky, rain and brought forth thereby fruits as provision for you. So do not attribute to Allah equals while you know [that there is nothing similar to Him].\qt@no{22}}%
\qt@newcmd\qurantrans@en@xxx{%
And if you are in doubt about what We have sent down upon Our Servant [Muhammad], then produce a surah the like thereof and call upon your witnesses other than Allah, if you should be truthful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@xxxi{%
But if you do not - and you will never be able to - then fear the Fire, whose fuel is men and stones, prepared for the disbelievers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@xxxii{%
And give good tidings to those who believe and do righteous deeds that they will have gardens [in Paradise] beneath which rivers flow. Whenever they are provided with a provision of fruit therefrom, they will say, ``This is what we were provided with before." And it is given to them in likeness. And they will have therein purified spouses, and they will abide therein eternally.\qt@no{25}}%
\qt@newcmd\qurantrans@en@xxxiii{%
Indeed, Allah is not timid to present an example - that of a mosquito or what is smaller than it. And those who have believed know that it is the truth from their Lord. But as for those who disbelieve, they say, ``What did Allah intend by this as an example?" He misleads many thereby and guides many thereby. And He misleads not except the defiantly disobedient,\qt@no{26}}%
\qt@newcmd\qurantrans@en@xxxiv{%
Who break the covenant of Allah after contracting it and sever that which Allah has ordered to be joined and cause corruption on earth. It is those who are the losers.\qt@no{27}}%
\qt@newcmd\qurantrans@en@xxxv{%
How can you disbelieve in Allah when you were lifeless and He brought you to life; then He will cause you to die, then He will bring you [back] to life, and then to Him you will be returned.\qt@no{28}}%
\qt@newcmd\qurantrans@en@xxxvi{%
It is He who created for you all of that which is on the earth. Then He directed Himself to the heaven, [His being above all creation], and made them seven heavens, and He is Knowing of all things.\qt@no{29}}%
\qt@newcmd\qurantrans@en@xxxvii{%
And [mention, O Muhammad], when your Lord said to the angels, ``Indeed, I will make upon the earth a successive authority." They said, ``Will You place upon it one who causes corruption therein and sheds blood, while we declare Your praise and sanctify You?" Allah said, ``Indeed, I know that which you do not know."\qt@no{30}}%
\qt@newcmd\qurantrans@en@xxxviii{%
And He taught Adam the names - all of them. Then He showed them to the angels and said, ``Inform Me of the names of these, if you are truthful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@xxxix{%
They said, ``Exalted are You; we have no knowledge except what You have taught us. Indeed, it is You who is the Knowing, the Wise."\qt@no{32}}%
\qt@newcmd\qurantrans@en@xl{%
He said, ``O Adam, inform them of their names." And when he had informed them of their names, He said, ``Did I not tell you that I know the unseen [aspects] of the heavens and the earth? And I know what you reveal and what you have concealed."\qt@no{33}}%
\qt@newcmd\qurantrans@en@xli{%
And [mention] when We said to the angels, ``Prostrate before Adam"; so they prostrated, except for Iblees. He refused and was arrogant and became of the disbelievers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@xlii{%
And We said, ``O Adam, dwell, you and your wife, in Paradise and eat therefrom in [ease and] abundance from wherever you will. But do not approach this tree, lest you be among the wrongdoers."\qt@no{35}}%
\qt@newcmd\qurantrans@en@xliii{%
But Satan caused them to slip out of it and removed them from that [condition] in which they had been. And We said, ``Go down, [all of you], as enemies to one another, and you will have upon the earth a place of settlement and provision for a time."\qt@no{36}}%
\qt@newcmd\qurantrans@en@xliv{%
Then Adam received from his Lord [some] words, and He accepted his repentance. Indeed, it is He who is the Accepting of repentance, the Merciful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@xlv{%
We said, ``Go down from it, all of you. And when guidance comes to you from Me, whoever follows My guidance - there will be no fear concerning them, nor will they grieve.\qt@no{38}}%
\qt@newcmd\qurantrans@en@xlvi{%
And those who disbelieve and deny Our signs - those will be companions of the Fire; they will abide therein eternally."\qt@no{39}}%
\qt@newcmd\qurantrans@en@xlvii{%
O Children of Israel, remember My favor which I have bestowed upon you and fulfill My covenant [upon you] that I will fulfill your covenant [from Me], and be afraid of [only] Me.\qt@no{40}}%
\qt@newcmd\qurantrans@en@xlviii{%
And believe in what I have sent down confirming that which is [already] with you, and be not the first to disbelieve in it. And do not exchange My signs for a small price, and fear [only] Me.\qt@no{41}}%
\qt@newcmd\qurantrans@en@xlix{%
And do not mix the truth with falsehood or conceal the truth while you know [it].\qt@no{42}}%
\qt@newcmd\qurantrans@en@l{%
And establish prayer and give zakah and bow with those who bow [in worship and obedience].\qt@no{43}}%
\qt@newcmd\qurantrans@en@li{%
Do you order righteousness of the people and forget yourselves while you recite the Scripture? Then will you not reason?\qt@no{44}}%
\qt@newcmd\qurantrans@en@lii{%
And seek help through patience and prayer, and indeed, it is difficult except for the humbly submissive [to Allah]\qt@no{45}}%
\qt@newcmd\qurantrans@en@liii{%
Who are certain that they will meet their Lord and that they will return to Him.\qt@no{46}}%
\qt@newcmd\qurantrans@en@liv{%
O Children of Israel, remember My favor that I have bestowed upon you and that I preferred you over the worlds.\qt@no{47}}%
\qt@newcmd\qurantrans@en@lv{%
And fear a Day when no soul will suffice for another soul at all, nor will intercession be accepted from it, nor will compensation be taken from it, nor will they be aided.\qt@no{48}}%
\qt@newcmd\qurantrans@en@lvi{%
And [recall] when We saved your forefathers from the people of Pharaoh, who afflicted you with the worst torment, slaughtering your [newborn] sons and keeping your females alive. And in that was a great trial from your Lord.\qt@no{49}}%
\qt@newcmd\qurantrans@en@lvii{%
And [recall] when We parted the sea for you and saved you and drowned the people of Pharaoh while you were looking on.\qt@no{50}}%
\qt@newcmd\qurantrans@en@lviii{%
And [recall] when We made an appointment with Moses for forty nights. Then you took [for worship] the calf after him, while you were wrongdoers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@lix{%
Then We forgave you after that so perhaps you would be grateful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@lx{%
And [recall] when We gave Moses the Scripture and criterion that perhaps you would be guided.\qt@no{53}}%
\qt@newcmd\qurantrans@en@lxi{%
And [recall] when Moses said to his people, ``O my people, indeed you have wronged yourselves by your taking of the calf [for worship]. So repent to your Creator and kill yourselves. That is best for [all of] you in the sight of your Creator." Then He accepted your repentance; indeed, He is the Accepting of repentance, the Merciful.\qt@no{54}}%
\qt@newcmd\qurantrans@en@lxii{%
And [recall] when you said, ``O Moses, we will never believe you until we see Allah outright"; so the thunderbolt took you while you were looking on.\qt@no{55}}%
\qt@newcmd\qurantrans@en@lxiii{%
Then We revived you after your death that perhaps you would be grateful.\qt@no{56}}%
\qt@newcmd\qurantrans@en@lxiv{%
And We shaded you with clouds and sent down to you manna and quails, [saying], ``Eat from the good things with which We have provided you." And they wronged Us not - but they were [only] wronging themselves.\qt@no{57}}%
\qt@newcmd\qurantrans@en@lxv{%
And [recall] when We said, ``Enter this city and eat from it wherever you will in [ease and] abundance, and enter the gate bowing humbly and say, 'Relieve us of our burdens.' We will [then] forgive your sins for you, and We will increase the doers of good [in goodness and reward]."\qt@no{58}}%
\qt@newcmd\qurantrans@en@lxvi{%
But those who wronged changed [those words] to a statement other than that which had been said to them, so We sent down upon those who wronged a punishment from the sky because they were defiantly disobeying.\qt@no{59}}%
\qt@newcmd\qurantrans@en@lxvii{%
And [recall] when Moses prayed for water for his people, so We said, ``Strike with your staff the stone." And there gushed forth from it twelve springs, and every people knew its watering place. ``Eat and drink from the provision of Allah, and do not commit abuse on the earth, spreading corruption."\qt@no{60}}%
\qt@newcmd\qurantrans@en@lxviii{%
And [recall] when you said, ``O Moses, we can never endure one [kind of] food. So call upon your Lord to bring forth for us from the earth its green herbs and its cucumbers and its garlic and its lentils and its onions." [Moses] said, ``Would you exchange what is better for what is less? Go into [any] settlement and indeed, you will have what you have asked." And they were covered with humiliation and poverty and returned with anger from Allah [upon them]. That was because they [repeatedly] disbelieved in the signs of Allah and killed the prophets without right. That was because they disobeyed and were [habitually] transgressing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@lxix{%
Indeed, those who believed and those who were Jews or Christians or Sabeans [before Prophet Muhammad] - those [among them] who believed in Allah and the Last Day and did righteousness - will have their reward with their Lord, and no fear will there be concerning them, nor will they grieve.\qt@no{62}}%
\qt@newcmd\qurantrans@en@lxx{%
And [recall] when We took your covenant, [O Children of Israel, to abide by the Torah] and We raised over you the mount, [saying], ``Take what We have given you with determination and remember what is in it that perhaps you may become righteous."\qt@no{63}}%
\qt@newcmd\qurantrans@en@lxxi{%
Then you turned away after that. And if not for the favor of Allah upon you and His mercy, you would have been among the losers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@lxxii{%
And you had already known about those who transgressed among you concerning the sabbath, and We said to them, ``Be apes, despised."\qt@no{65}}%
\qt@newcmd\qurantrans@en@lxxiii{%
And We made it a deterrent punishment for those who were present and those who succeeded [them] and a lesson for those who fear Allah.\qt@no{66}}%
\qt@newcmd\qurantrans@en@lxxiv{%
And [recall] when Moses said to his people, ``Indeed, Allah commands you to slaughter a cow." They said, ``Do you take us in ridicule?" He said, ``I seek refuge in Allah from being among the ignorant."\qt@no{67}}%
\qt@newcmd\qurantrans@en@lxxv{%
They said, ``Call upon your Lord to make clear to us what it is." [Moses] said, ``[Allah] says, 'It is a cow which is neither old nor virgin, but median between that,' so do what you are commanded."\qt@no{68}}%
\qt@newcmd\qurantrans@en@lxxvi{%
They said, ``Call upon your Lord to show us what is her color." He said, ``He says, 'It is a yellow cow, bright in color - pleasing to the observers.' ``\qt@no{69}}%
\qt@newcmd\qurantrans@en@lxxvii{%
They said, ``Call upon your Lord to make clear to us what it is. Indeed, [all] cows look alike to us. And indeed we, if Allah wills, will be guided."\qt@no{70}}%
\qt@newcmd\qurantrans@en@lxxviii{%
He said, ``He says, 'It is a cow neither trained to plow the earth nor to irrigate the field, one free from fault with no spot upon her.' `` They said, ``Now you have come with the truth." So they slaughtered her, but they could hardly do it.\qt@no{71}}%
\qt@newcmd\qurantrans@en@lxxix{%
And [recall] when you slew a man and disputed over it, but Allah was to bring out that which you were concealing.\qt@no{72}}%
\qt@newcmd\qurantrans@en@lxxx{%
So, We said, ``Strike the slain man with part of it." Thus does Allah bring the dead to life, and He shows you His signs that you might reason.\qt@no{73}}%
\qt@newcmd\qurantrans@en@lxxxi{%
Then your hearts became hardened after that, being like stones or even harder. For indeed, there are stones from which rivers burst forth, and there are some of them that split open and water comes out, and there are some of them that fall down for fear of Allah. And Allah is not unaware of what you do.\qt@no{74}}%
\qt@newcmd\qurantrans@en@lxxxii{%
Do you covet [the hope, O believers], that they would believe for you while a party of them used to hear the words of Allah and then distort the Torah after they had understood it while they were knowing?\qt@no{75}}%
\qt@newcmd\qurantrans@en@lxxxiii{%
And when they meet those who believe, they say, ``We have believed"; but when they are alone with one another, they say, ``Do you talk to them about what Allah has revealed to you so they can argue with you about it before your Lord?" Then will you not reason?\qt@no{76}}%
\qt@newcmd\qurantrans@en@lxxxiv{%
But do they not know that Allah knows what they conceal and what they declare?\qt@no{77}}%
\qt@newcmd\qurantrans@en@lxxxv{%
And among them are unlettered ones who do not know the Scripture except in wishful thinking, but they are only assuming.\qt@no{78}}%
\qt@newcmd\qurantrans@en@lxxxvi{%
So woe to those who write the ``scripture" with their own hands, then say, ``This is from Allah," in order to exchange it for a small price. Woe to them for what their hands have written and woe to them for what they earn.\qt@no{79}}%
\qt@newcmd\qurantrans@en@lxxxvii{%
And they say, ``Never will the Fire touch us, except for a few days." Say, ``Have you taken a covenant with Allah? For Allah will never break His covenant. Or do you say about Allah that which you do not know?"\qt@no{80}}%
\qt@newcmd\qurantrans@en@lxxxviii{%
Yes, whoever earns evil and his sin has encompassed him - those are the companions of the Fire; they will abide therein eternally.\qt@no{81}}%
\qt@newcmd\qurantrans@en@lxxxix{%
But they who believe and do righteous deeds - those are the companions of Paradise; they will abide therein eternally.\qt@no{82}}%
\qt@newcmd\qurantrans@en@xc{%
And [recall] when We took the covenant from the Children of Israel, [enjoining upon them], ``Do not worship except Allah; and to parents do good and to relatives, orphans, and the needy. And speak to people good [words] and establish prayer and give zakah." Then you turned away, except a few of you, and you were refusing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@xci{%
And [recall] when We took your covenant, [saying], ``Do not shed each other's blood or evict one another from your homes." Then you acknowledged [this] while you were witnessing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@xcii{%
Then, you are those [same ones who are] killing one another and evicting a party of your people from their homes, cooperating against them in sin and aggression. And if they come to you as captives, you ransom them, although their eviction was forbidden to you. So do you believe in part of the Scripture and disbelieve in part? Then what is the recompense for those who do that among you except disgrace in worldly life; and on the Day of Resurrection they will be sent back to the severest of punishment. And Allah is not unaware of what you do.\qt@no{85}}%
\qt@newcmd\qurantrans@en@xciii{%
Those are the ones who have bought the life of this world [in exchange] for the Hereafter, so the punishment will not be lightened for them, nor will they be aided.\qt@no{86}}%
\qt@newcmd\qurantrans@en@xciv{%
And We did certainly give Moses the Torah and followed up after him with messengers. And We gave Jesus, the son of Mary, clear proofs and supported him with the Pure Spirit. But is it [not] that every time a messenger came to you, [O Children of Israel], with what your souls did not desire, you were arrogant? And a party [of messengers] you denied and another party you killed.\qt@no{87}}%
\qt@newcmd\qurantrans@en@xcv{%
And they said, ``Our hearts are wrapped." But, [in fact], Allah has cursed them for their disbelief, so little is it that they believe.\qt@no{88}}%
\qt@newcmd\qurantrans@en@xcvi{%
And when there came to them a Book from Allah confirming that which was with them - although before they used to pray for victory against those who disbelieved - but [then] when there came to them that which they recognized, they disbelieved in it; so the curse of Allah will be upon the disbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@xcvii{%
How wretched is that for which they sold themselves - that they would disbelieve in what Allah has revealed through [their] outrage that Allah would send down His favor upon whom He wills from among His servants. So they returned having [earned] wrath upon wrath. And for the disbelievers is a humiliating punishment.\qt@no{90}}%
\qt@newcmd\qurantrans@en@xcviii{%
And when it is said to them, ``Believe in what Allah has revealed," they say, ``We believe [only] in what was revealed to us." And they disbelieve in what came after it, while it is the truth confirming that which is with them. Say, ``Then why did you kill the prophets of Allah before, if you are [indeed] believers?"\qt@no{91}}%
\qt@newcmd\qurantrans@en@xcix{%
And Moses had certainly brought you clear proofs. Then you took the calf [in worship] after that, while you were wrongdoers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@c{%
And [recall] when We took your covenant and raised over you the mount, [saying], ``Take what We have given you with determination and listen." They said [instead], ``We hear and disobey." And their hearts absorbed [the worship of] the calf because of their disbelief. Say, ``How wretched is that which your faith enjoins upon you, if you should be believers."\qt@no{93}}%
\qt@newcmd\qurantrans@en@ci{%
Say, [O Muhammad], ``If the home of the Hereafter with Allah is for you alone and not the [other] people, then wish for death, if you should be truthful.\qt@no{94}}%
\qt@newcmd\qurantrans@en@cii{%
But they will never wish for it, ever, because of what their hands have put forth. And Allah is Knowing of the wrongdoers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ciii{%
And you will surely find them the most greedy of people for life - [even] more than those who associate others with Allah. One of them wishes that he could be granted life a thousand years, but it would not remove him in the least from the [coming] punishment that he should be granted life. And Allah is Seeing of what they do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@civ{%
Say, ``Whoever is an enemy to Gabriel - it is [none but] he who has brought the Qur'an down upon your heart, [O Muhammad], by permission of Allah, confirming that which was before it and as guidance and good tidings for the believers."\qt@no{97}}%
\qt@newcmd\qurantrans@en@cv{%
Whoever is an enemy to Allah and His angels and His messengers and Gabriel and Michael - then indeed, Allah is an enemy to the disbelievers.\qt@no{98}}%
\qt@newcmd\qurantrans@en@cvi{%
And We have certainly revealed to you verses [which are] clear proofs, and no one would deny them except the defiantly disobedient.\qt@no{99}}%
\qt@newcmd\qurantrans@en@cvii{%
Is it not [true] that every time they took a covenant a party of them threw it away? But, [in fact], most of them do not believe.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cviii{%
And when a messenger from Allah came to them confirming that which was with them, a party of those who had been given the Scripture threw the Scripture of Allah behind their backs as if they did not know [what it contained].\qt@no{101}}%
\qt@newcmd\qurantrans@en@cix{%
And they followed [instead] what the devils had recited during the reign of Solomon. It was not Solomon who disbelieved, but the devils disbelieved, teaching people magic and that which was revealed to the two angels at Babylon, Harut and Marut. But the two angels do not teach anyone unless they say, ``We are a trial, so do not disbelieve [by practicing magic]." And [yet] they learn from them that by which they cause separation between a man and his wife. But they do not harm anyone through it except by permission of Allah. And the people learn what harms them and does not benefit them. But the Children of Israel certainly knew that whoever purchased the magic would not have in the Hereafter any share. And wretched is that for which they sold themselves, if they only knew.\qt@no{102}}%
\qt@newcmd\qurantrans@en@cx{%
And if they had believed and feared Allah, then the reward from Allah would have been [far] better, if they only knew.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cxi{%
O you who have believed, say not [to Allah 's Messenger], ``Ra'ina" but say, ``Unthurna" and listen. And for the disbelievers is a painful punishment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cxii{%
Neither those who disbelieve from the People of the Scripture nor the polytheists wish that any good should be sent down to you from your Lord. But Allah selects for His mercy whom He wills, and Allah is the possessor of great bounty.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cxiii{%
We do not abrogate a verse or cause it to be forgotten except that We bring forth [one] better than it or similar to it. Do you not know that Allah is over all things competent?\qt@no{106}}%
\qt@newcmd\qurantrans@en@cxiv{%
Do you not know that to Allah belongs the dominion of the heavens and the earth and [that] you have not besides Allah any protector or any helper?\qt@no{107}}%
\qt@newcmd\qurantrans@en@cxv{%
Or do you intend to ask your Messenger as Moses was asked before? And whoever exchanges faith for disbelief has certainly strayed from the soundness of the way.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cxvi{%
Many of the People of the Scripture wish they could turn you back to disbelief after you have believed, out of envy from themselves [even] after the truth has become clear to them. So pardon and overlook until Allah delivers His command. Indeed, Allah is over all things competent.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cxvii{%
And establish prayer and give zakah, and whatever good you put forward for yourselves - you will find it with Allah. Indeed, Allah of what you do, is Seeing.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cxviii{%
And they say, ``None will enter Paradise except one who is a Jew or a Christian." That is [merely] their wishful thinking, Say, ``Produce your proof, if you should be truthful."\qt@no{111}}%
\qt@newcmd\qurantrans@en@cxix{%
Yes [on the contrary], whoever submits his face in Islam to Allah while being a doer of good will have his reward with his Lord. And no fear will there be concerning them, nor will they grieve.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cxx{%
The Jews say ``The Christians have nothing [true] to stand on," and the Christians say, ``The Jews have nothing to stand on," although they [both] recite the Scripture. Thus the polytheists speak the same as their words. But Allah will judge between them on the Day of Resurrection concerning that over which they used to differ.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cxxi{%
And who are more unjust than those who prevent the name of Allah from being mentioned in His mosques and strive toward their destruction. It is not for them to enter them except in fear. For them in this world is disgrace, and they will have in the Hereafter a great punishment.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cxxii{%
And to Allah belongs the east and the west. So wherever you [might] turn, there is the Face of Allah. Indeed, Allah is all-Encompassing and Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cxxiii{%
They say, ``Allah has taken a son." Exalted is He! Rather, to Him belongs whatever is in the heavens and the earth. All are devoutly obedient to Him,\qt@no{116}}%
\qt@newcmd\qurantrans@en@cxxiv{%
Originator of the heavens and the earth. When He decrees a matter, He only says to it, ``Be," and it is.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cxxv{%
Those who do not know say, ``Why does Allah not speak to us or there come to us a sign?" Thus spoke those before them like their words. Their hearts resemble each other. We have shown clearly the signs to a people who are certain [in faith].\qt@no{118}}%
\qt@newcmd\qurantrans@en@cxxvi{%
Indeed, We have sent you, [O Muhammad], with the truth as a bringer of good tidings and a warner, and you will not be asked about the companions of Hellfire.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cxxvii{%
And never will the Jews or the Christians approve of you until you follow their religion. Say, ``Indeed, the guidance of Allah is the [only] guidance." If you were to follow their desires after what has come to you of knowledge, you would have against Allah no protector or helper.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cxxviii{%
Those to whom We have given the Book recite it with its true recital. They [are the ones who] believe in it. And whoever disbelieves in it - it is they who are the losers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@cxxix{%
O Children of Israel, remember My favor which I have bestowed upon you and that I preferred you over the worlds.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cxxx{%
And fear a Day when no soul will suffice for another soul at all, and no compensation will be accepted from it, nor will any intercession benefit it, nor will they be aided.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cxxxi{%
And [mention, O Muhammad], when Abraham was tried by his Lord with commands and he fulfilled them. [Allah] said, ``Indeed, I will make you a leader for the people." [Abraham] said, ``And of my descendants?" [Allah] said, ``My covenant does not include the wrongdoers."\qt@no{124}}%
\qt@newcmd\qurantrans@en@cxxxii{%
And [mention] when We made the House a place of return for the people and [a place of] security. And take, [O believers], from the standing place of Abraham a place of prayer. And We charged Abraham and Ishmael, [saying], ``Purify My House for those who perform Tawaf and those who are staying [there] for worship and those who bow and prostrate [in prayer]."\qt@no{125}}%
\qt@newcmd\qurantrans@en@cxxxiii{%
And [mention] when Abraham said, ``My Lord, make this a secure city and provide its people with fruits - whoever of them believes in Allah and the Last Day." [Allah] said. ``And whoever disbelieves - I will grant him enjoyment for a little; then I will force him to the punishment of the Fire, and wretched is the destination."\qt@no{126}}%
\qt@newcmd\qurantrans@en@cxxxiv{%
And [mention] when Abraham was raising the foundations of the House and [with him] Ishmael, [saying], ``Our Lord, accept [this] from us. Indeed You are the Hearing, the Knowing.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cxxxv{%
Our Lord, and make us Muslims [in submission] to You and from our descendants a Muslim nation [in submission] to You. And show us our rites and accept our repentance. Indeed, You are the Accepting of repentance, the Merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cxxxvi{%
Our Lord, and send among them a messenger from themselves who will recite to them Your verses and teach them the Book and wisdom and purify them. Indeed, You are the Exalted in Might, the Wise."\qt@no{129}}%
\qt@newcmd\qurantrans@en@cxxxvii{%
And who would be averse to the religion of Abraham except one who makes a fool of himself. And We had chosen him in this world, and indeed he, in the Hereafter, will be among the righteous.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cxxxviii{%
When his Lord said to him, ``Submit", he said ``I have submitted [in Islam] to the Lord of the worlds."\qt@no{131}}%
\qt@newcmd\qurantrans@en@cxxxix{%
And Abraham instructed his sons [to do the same] and [so did] Jacob, [saying], ``O my sons, indeed Allah has chosen for you this religion, so do not die except while you are Muslims."\qt@no{132}}%
\qt@newcmd\qurantrans@en@cxl{%
Or were you witnesses when death approached Jacob, when he said to his sons, ``What will you worship after me?" They said, ``We will worship your God and the God of your fathers, Abraham and Ishmael and Isaac - one God. And we are Muslims [in submission] to Him."\qt@no{133}}%
\qt@newcmd\qurantrans@en@cxli{%
That was a nation which has passed on. It will have [the consequence of] what it earned, and you will have what you have earned. And you will not be asked about what they used to do.\qt@no{134}}%
\qt@newcmd\qurantrans@en@cxlii{%
They say, ``Be Jews or Christians [so] you will be guided." Say, ``Rather, [we follow] the religion of Abraham, inclining toward truth, and he was not of the polytheists."\qt@no{135}}%
\qt@newcmd\qurantrans@en@cxliii{%
Say, [O believers], ``We have believed in Allah and what has been revealed to us and what has been revealed to Abraham and Ishmael and Isaac and Jacob and the Descendants and what was given to Moses and Jesus and what was given to the prophets from their Lord. We make no distinction between any of them, and we are Muslims [in submission] to Him."\qt@no{136}}%
\qt@newcmd\qurantrans@en@cxliv{%
So if they believe in the same as you believe in, then they have been [rightly] guided; but if they turn away, they are only in dissension, and Allah will be sufficient for you against them. And He is the Hearing, the Knowing.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cxlv{%
[And say, ``Ours is] the religion of Allah. And who is better than Allah in [ordaining] religion? And we are worshippers of Him."\qt@no{138}}%
\qt@newcmd\qurantrans@en@cxlvi{%
Say, [O Muhammad], ``Do you argue with us about Allah while He is our Lord and your Lord? For us are our deeds, and for you are your deeds. And we are sincere [in deed and intention] to Him."\qt@no{139}}%
\qt@newcmd\qurantrans@en@cxlvii{%
Or do you say that Abraham and Ishmael and Isaac and Jacob and the Descendants were Jews or Christians? Say, ``Are you more knowing or is Allah?" And who is more unjust than one who conceals a testimony he has from Allah? And Allah is not unaware of what you do.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cxlviii{%
That is a nation which has passed on. It will have [the consequence of] what it earned, and you will have what you have earned. And you will not be asked about what they used to do.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cxlix{%
The foolish among the people will say, ``What has turned them away from their qiblah, which they used to face?" Say, ``To Allah belongs the east and the west. He guides whom He wills to a straight path."\qt@no{142}}%
\qt@newcmd\qurantrans@en@cl{%
And thus we have made you a just community that you will be witnesses over the people and the Messenger will be a witness over you. And We did not make the qiblah which you used to face except that We might make evident who would follow the Messenger from who would turn back on his heels. And indeed, it is difficult except for those whom Allah has guided. And never would Allah have caused you to lose your faith. Indeed Allah is, to the people, Kind and Merciful.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cli{%
We have certainly seen the turning of your face, [O Muhammad], toward the heaven, and We will surely turn you to a qiblah with which you will be pleased. So turn your face toward al-Masjid al-Haram. And wherever you [believers] are, turn your faces toward it [in prayer]. Indeed, those who have been given the Scripture well know that it is the truth from their Lord. And Allah is not unaware of what they do.\qt@no{144}}%
\qt@newcmd\qurantrans@en@clii{%
And if you brought to those who were given the Scripture every sign, they would not follow your qiblah. Nor will you be a follower of their qiblah. Nor would they be followers of one another's qiblah. So if you were to follow their desires after what has come to you of knowledge, indeed, you would then be among the wrongdoers.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cliii{%
Those to whom We gave the Scripture know him as they know their own sons. But indeed, a party of them conceal the truth while they know [it].\qt@no{146}}%
\qt@newcmd\qurantrans@en@cliv{%
The truth is from your Lord, so never be among the doubters.\qt@no{147}}%
\qt@newcmd\qurantrans@en@clv{%
For each [religious following] is a direction toward which it faces. So race to [all that is] good. Wherever you may be, Allah will bring you forth [for judgement] all together. Indeed, Allah is over all things competent.\qt@no{148}}%
\qt@newcmd\qurantrans@en@clvi{%
So from wherever you go out [for prayer, O Muhammad] turn your face toward al- Masjid al-Haram, and indeed, it is the truth from your Lord. And Allah is not unaware of what you do.\qt@no{149}}%
\qt@newcmd\qurantrans@en@clvii{%
And from wherever you go out [for prayer], turn your face toward al-Masjid al-Haram. And wherever you [believers] may be, turn your faces toward it in order that the people will not have any argument against you, except for those of them who commit wrong; so fear them not but fear Me. And [it is] so I may complete My favor upon you and that you may be guided.\qt@no{150}}%
\qt@newcmd\qurantrans@en@clviii{%
Just as We have sent among you a messenger from yourselves reciting to you Our verses and purifying you and teaching you the Book and wisdom and teaching you that which you did not know.\qt@no{151}}%
\qt@newcmd\qurantrans@en@clix{%
So remember Me; I will remember you. And be grateful to Me and do not deny Me.\qt@no{152}}%
\qt@newcmd\qurantrans@en@clx{%
O you who have believed, seek help through patience and prayer. Indeed, Allah is with the patient.\qt@no{153}}%
\qt@newcmd\qurantrans@en@clxi{%
And do not say about those who are killed in the way of Allah, ``They are dead." Rather, they are alive, but you perceive [it] not.\qt@no{154}}%
\qt@newcmd\qurantrans@en@clxii{%
And We will surely test you with something of fear and hunger and a loss of wealth and lives and fruits, but give good tidings to the patient,\qt@no{155}}%
\qt@newcmd\qurantrans@en@clxiii{%
Who, when disaster strikes them, say, ``Indeed we belong to Allah, and indeed to Him we will return."\qt@no{156}}%
\qt@newcmd\qurantrans@en@clxiv{%
Those are the ones upon whom are blessings from their Lord and mercy. And it is those who are the [rightly] guided.\qt@no{157}}%
\qt@newcmd\qurantrans@en@clxv{%
Indeed, as-Safa and al-Marwah are among the symbols of Allah. So whoever makes Hajj to the House or performs 'umrah - there is no blame upon him for walking between them. And whoever volunteers good - then indeed, Allah is appreciative and Knowing.\qt@no{158}}%
\qt@newcmd\qurantrans@en@clxvi{%
Indeed, those who conceal what We sent down of clear proofs and guidance after We made it clear for the people in the Scripture - those are cursed by Allah and cursed by those who curse,\qt@no{159}}%
\qt@newcmd\qurantrans@en@clxvii{%
Except for those who repent and correct themselves and make evident [what they concealed]. Those - I will accept their repentance, and I am the Accepting of repentance, the Merciful.\qt@no{160}}%
\qt@newcmd\qurantrans@en@clxviii{%
Indeed, those who disbelieve and die while they are disbelievers - upon them will be the curse of Allah and of the angels and the people, all together,\qt@no{161}}%
\qt@newcmd\qurantrans@en@clxix{%
Abiding eternally therein. The punishment will not be lightened for them, nor will they be reprieved.\qt@no{162}}%
\qt@newcmd\qurantrans@en@clxx{%
And your god is one God. There is no deity [worthy of worship] except Him, the Entirely Merciful, the Especially Merciful.\qt@no{163}}%
\qt@newcmd\qurantrans@en@clxxi{%
Indeed, in the creation of the heavens and earth, and the alternation of the night and the day, and the [great] ships which sail through the sea with that which benefits people, and what Allah has sent down from the heavens of rain, giving life thereby to the earth after its lifelessness and dispersing therein every [kind of] moving creature, and [His] directing of the winds and the clouds controlled between the heaven and the earth are signs for a people who use reason.\qt@no{164}}%
\qt@newcmd\qurantrans@en@clxxii{%
And [yet], among the people are those who take other than Allah as equals [to Him]. They love them as they [should] love Allah. But those who believe are stronger in love for Allah. And if only they who have wronged would consider [that] when they see the punishment, [they will be certain] that all power belongs to Allah and that Allah is severe in punishment.\qt@no{165}}%
\qt@newcmd\qurantrans@en@clxxiii{%
[And they should consider that] when those who have been followed disassociate themselves from those who followed [them], and they [all] see the punishment, and cut off from them are the ties [of relationship],\qt@no{166}}%
\qt@newcmd\qurantrans@en@clxxiv{%
Those who followed will say, ``If only we had another turn [at worldly life] so we could disassociate ourselves from them as they have disassociated themselves from us." Thus will Allah show them their deeds as regrets upon them. And they are never to emerge from the Fire.\qt@no{167}}%
\qt@newcmd\qurantrans@en@clxxv{%
O mankind, eat from whatever is on earth [that is] lawful and good and do not follow the footsteps of Satan. Indeed, he is to you a clear enemy.\qt@no{168}}%
\qt@newcmd\qurantrans@en@clxxvi{%
He only orders you to evil and immorality and to say about Allah what you do not know.\qt@no{169}}%
\qt@newcmd\qurantrans@en@clxxvii{%
And when it is said to them, ``Follow what Allah has revealed," they say, ``Rather, we will follow that which we found our fathers doing." Even though their fathers understood nothing, nor were they guided?\qt@no{170}}%
\qt@newcmd\qurantrans@en@clxxviii{%
The example of those who disbelieve is like that of one who shouts at what hears nothing but calls and cries cattle or sheep - deaf, dumb and blind, so they do not understand.\qt@no{171}}%
\qt@newcmd\qurantrans@en@clxxix{%
O you who have believed, eat from the good things which We have provided for you and be grateful to Allah if it is [indeed] Him that you worship.\qt@no{172}}%
\qt@newcmd\qurantrans@en@clxxx{%
He has only forbidden to you dead animals, blood, the flesh of swine, and that which has been dedicated to other than Allah. But whoever is forced [by necessity], neither desiring [it] nor transgressing [its limit], there is no sin upon him. Indeed, Allah is Forgiving and Merciful.\qt@no{173}}%
\qt@newcmd\qurantrans@en@clxxxi{%
Indeed, they who conceal what Allah has sent down of the Book and exchange it for a small price - those consume not into their bellies except the Fire. And Allah will not speak to them on the Day of Resurrection, nor will He purify them. And they will have a painful punishment.\qt@no{174}}%
\qt@newcmd\qurantrans@en@clxxxii{%
Those are the ones who have exchanged guidance for error and forgiveness for punishment. How patient they are in pursuit of the Fire!\qt@no{175}}%
\qt@newcmd\qurantrans@en@clxxxiii{%
That is [deserved by them] because Allah has sent down the Book in truth. And indeed, those who differ over the Book are in extreme dissension.\qt@no{176}}%
\qt@newcmd\qurantrans@en@clxxxiv{%
Righteousness is not that you turn your faces toward the east or the west, but [true] righteousness is [in] one who believes in Allah, the Last Day, the angels, the Book, and the prophets and gives wealth, in spite of love for it, to relatives, orphans, the needy, the traveler, those who ask [for help], and for freeing slaves; [and who] establishes prayer and gives zakah; [those who] fulfill their promise when they promise; and [those who] are patient in poverty and hardship and during battle. Those are the ones who have been true, and it is those who are the righteous.\qt@no{177}}%
\qt@newcmd\qurantrans@en@clxxxv{%
O you who have believed, prescribed for you is legal retribution for those murdered - the free for the free, the slave for the slave, and the female for the female. But whoever overlooks from his brother anything, then there should be a suitable follow-up and payment to him with good conduct. This is an alleviation from your Lord and a mercy. But whoever transgresses after that will have a painful punishment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@clxxxvi{%
And there is for you in legal retribution [saving of] life, O you [people] of understanding, that you may become righteous.\qt@no{179}}%
\qt@newcmd\qurantrans@en@clxxxvii{%
Prescribed for you when death approaches [any] one of you if he leaves wealth [is that he should make] a bequest for the parents and near relatives according to what is acceptable - a duty upon the righteous.\qt@no{180}}%
\qt@newcmd\qurantrans@en@clxxxviii{%
Then whoever alters the bequest after he has heard it - the sin is only upon those who have altered it. Indeed, Allah is Hearing and Knowing.\qt@no{181}}%
\qt@newcmd\qurantrans@en@clxxxix{%
But if one fears from the bequeather [some] error or sin and corrects that which is between them, there is no sin upon him. Indeed, Allah is Forgiving and Merciful.\qt@no{182}}%
\qt@newcmd\qurantrans@en@cxc{%
O you who have believed, decreed upon you is fasting as it was decreed upon those before you that you may become righteous -\qt@no{183}}%
\qt@newcmd\qurantrans@en@cxci{%
[Fasting for] a limited number of days. So whoever among you is ill or on a journey [during them] - then an equal number of days [are to be made up]. And upon those who are able [to fast, but with hardship] - a ransom [as substitute] of feeding a poor person [each day]. And whoever volunteers excess - it is better for him. But to fast is best for you, if you only knew.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cxcii{%
The month of Ramadhan [is that] in which was revealed the Qur'an, a guidance for the people and clear proofs of guidance and criterion. So whoever sights [the new moon of] the month, let him fast it; and whoever is ill or on a journey - then an equal number of other days. Allah intends for you ease and does not intend for you hardship and [wants] for you to complete the period and to glorify Allah for that [to] which He has guided you; and perhaps you will be grateful.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cxciii{%
And when My servants ask you, [O Muhammad], concerning Me - indeed I am near. I respond to the invocation of the supplicant when he calls upon Me. So let them respond to Me [by obedience] and believe in Me that they may be [rightly] guided.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cxciv{%
It has been made permissible for you the night preceding fasting to go to your wives [for sexual relations]. They are clothing for you and you are clothing for them. Allah knows that you used to deceive yourselves, so He accepted your repentance and forgave you. So now, have relations with them and seek that which Allah has decreed for you. And eat and drink until the white thread of dawn becomes distinct to you from the black thread [of night]. Then complete the fast until the sunset. And do not have relations with them as long as you are staying for worship in the mosques. These are the limits [set by] Allah, so do not approach them. Thus does Allah make clear His ordinances to the people that they may become righteous.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cxcv{%
And do not consume one another's wealth unjustly or send it [in bribery] to the rulers in order that [they might aid] you [to] consume a portion of the wealth of the people in sin, while you know [it is unlawful].\qt@no{188}}%
\qt@newcmd\qurantrans@en@cxcvi{%
They ask you, [O Muhammad], about the new moons. Say, ``They are measurements of time for the people and for Hajj." And it is not righteousness to enter houses from the back, but righteousness is [in] one who fears Allah. And enter houses from their doors. And fear Allah that you may succeed.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cxcvii{%
Fight in the way of Allah those who fight you but do not transgress. Indeed. Allah does not like transgressors.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cxcviii{%
And kill them wherever you overtake them and expel them from wherever they have expelled you, and fitnah is worse than killing. And do not fight them at al-Masjid al- Haram until they fight you there. But if they fight you, then kill them. Such is the recompense of the disbelievers.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cxcix{%
And if they cease, then indeed, Allah is Forgiving and Merciful.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cc{%
Fight them until there is no [more] fitnah and [until] worship is [acknowledged to be] for Allah. But if they cease, then there is to be no aggression except against the oppressors.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cci{%
[Fighting in] the sacred month is for [aggression committed in] the sacred month, and for [all] violations is legal retribution. So whoever has assaulted you, then assault him in the same way that he has assaulted you. And fear Allah and know that Allah is with those who fear Him.\qt@no{194}}%
\qt@newcmd\qurantrans@en@ccii{%
And spend in the way of Allah and do not throw [yourselves] with your [own] hands into destruction [by refraining]. And do good; indeed, Allah loves the doers of good.\qt@no{195}}%
\qt@newcmd\qurantrans@en@cciii{%
And complete the Hajj and 'umrah for Allah. But if you are prevented, then [offer] what can be obtained with ease of sacrificial animals. And do not shave your heads until the sacrificial animal has reached its place of slaughter. And whoever among you is ill or has an ailment of the head [making shaving necessary must offer] a ransom of fasting [three days] or charity or sacrifice. And when you are secure, then whoever performs 'umrah [during the Hajj months] followed by Hajj [offers] what can be obtained with ease of sacrificial animals. And whoever cannot find [or afford such an animal] - then a fast of three days during Hajj and of seven when you have returned [home]. Those are ten complete [days]. This is for those whose family is not in the area of al-Masjid al-Haram. And fear Allah and know that Allah is severe in penalty.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cciv{%
Hajj is [during] well-known months, so whoever has made Hajj obligatory upon himself therein [by entering the state of ihram], there is [to be for him] no sexual relations and no disobedience and no disputing during Hajj. And whatever good you do - Allah knows it. And take provisions, but indeed, the best provision is fear of Allah. And fear Me, O you of understanding.\qt@no{197}}%
\qt@newcmd\qurantrans@en@ccv{%
There is no blame upon you for seeking bounty from your Lord [during Hajj]. But when you depart from 'Arafat, remember Allah at al- Mash'ar al-Haram. And remember Him, as He has guided you, for indeed, you were before that among those astray.\qt@no{198}}%
\qt@newcmd\qurantrans@en@ccvi{%
Then depart from the place from where [all] the people depart and ask forgiveness of Allah. Indeed, Allah is Forgiving and Merciful.\qt@no{199}}%
\qt@newcmd\qurantrans@en@ccvii{%
And when you have completed your rites, remember Allah like your [previous] remembrance of your fathers or with [much] greater remembrance. And among the people is he who says, ``Our Lord, give us in this world," and he will have in the Hereafter no share.\qt@no{200}}%
\qt@newcmd\qurantrans@en@ccviii{%
But among them is he who says, ``Our Lord, give us in this world [that which is] good and in the Hereafter [that which is] good and protect us from the punishment of the Fire."\qt@no{201}}%
\qt@newcmd\qurantrans@en@ccix{%
Those will have a share of what they have earned, and Allah is swift in account.\qt@no{202}}%
\qt@newcmd\qurantrans@en@ccx{%
And remember Allah during [specific] numbered days. Then whoever hastens [his departure] in two days - there is no sin upon him; and whoever delays [until the third] - there is no sin upon him - for him who fears Allah. And fear Allah and know that unto Him you will be gathered.\qt@no{203}}%
\qt@newcmd\qurantrans@en@ccxi{%
And of the people is he whose speech pleases you in worldly life, and he calls Allah to witness as to what is in his heart, yet he is the fiercest of opponents.\qt@no{204}}%
\qt@newcmd\qurantrans@en@ccxii{%
And when he goes away, he strives throughout the land to cause corruption therein and destroy crops and animals. And Allah does not like corruption.\qt@no{205}}%
\qt@newcmd\qurantrans@en@ccxiii{%
And when it is said to him, ``Fear Allah," pride in the sin takes hold of him. Sufficient for him is Hellfire, and how wretched is the resting place.\qt@no{206}}%
\qt@newcmd\qurantrans@en@ccxiv{%
And of the people is he who sells himself, seeking means to the approval of Allah. And Allah is kind to [His] servants.\qt@no{207}}%
\qt@newcmd\qurantrans@en@ccxv{%
O you who have believed, enter into Islam completely [and perfectly] and do not follow the footsteps of Satan. Indeed, he is to you a clear enemy.\qt@no{208}}%
\qt@newcmd\qurantrans@en@ccxvi{%
But if you deviate after clear proofs have come to you, then know that Allah is Exalted in Might and Wise.\qt@no{209}}%
\qt@newcmd\qurantrans@en@ccxvii{%
Do they await but that Allah should come to them in covers of clouds and the angels [as well] and the matter is [then] decided? And to Allah [all] matters are returned.\qt@no{210}}%
\qt@newcmd\qurantrans@en@ccxviii{%
Ask the Children of Israel how many a sign of evidence We have given them. And whoever exchanges the favor of Allah [for disbelief] after it has come to him - then indeed, Allah is severe in penalty.\qt@no{211}}%
\qt@newcmd\qurantrans@en@ccxix{%
Beautified for those who disbelieve is the life of this world, and they ridicule those who believe. But those who fear Allah are above them on the Day of Resurrection. And Allah gives provision to whom He wills without account.\qt@no{212}}%
\qt@newcmd\qurantrans@en@ccxx{%
Mankind was [of] one religion [before their deviation]; then Allah sent the prophets as bringers of good tidings and warners and sent down with them the Scripture in truth to judge between the people concerning that in which they differed. And none differed over the Scripture except those who were given it - after the clear proofs came to them - out of jealous animosity among themselves. And Allah guided those who believed to the truth concerning that over which they had differed, by His permission. And Allah guides whom He wills to a straight path.\qt@no{213}}%
\qt@newcmd\qurantrans@en@ccxxi{%
Or do you think that you will enter Paradise while such [trial] has not yet come to you as came to those who passed on before you? They were touched by poverty and hardship and were shaken until [even their] messenger and those who believed with him said, ``When is the help of Allah?" Unquestionably, the help of Allah is near.\qt@no{214}}%
\qt@newcmd\qurantrans@en@ccxxii{%
They ask you, [O Muhammad], what they should spend. Say, ``Whatever you spend of good is [to be] for parents and relatives and orphans and the needy and the traveler. And whatever you do of good - indeed, Allah is Knowing of it."\qt@no{215}}%
\qt@newcmd\qurantrans@en@ccxxiii{%
Fighting has been enjoined upon you while it is hateful to you. But perhaps you hate a thing and it is good for you; and perhaps you love a thing and it is bad for you. And Allah Knows, while you know not.\qt@no{216}}%
\qt@newcmd\qurantrans@en@ccxxiv{%
They ask you about the sacred month - about fighting therein. Say, ``Fighting therein is great [sin], but averting [people] from the way of Allah and disbelief in Him and [preventing access to] al-Masjid al-Haram and the expulsion of its people therefrom are greater [evil] in the sight of Allah. And fitnah is greater than killing." And they will continue to fight you until they turn you back from your religion if they are able. And whoever of you reverts from his religion [to disbelief] and dies while he is a disbeliever - for those, their deeds have become worthless in this world and the Hereafter, and those are the companions of the Fire, they will abide therein eternally.\qt@no{217}}%
\qt@newcmd\qurantrans@en@ccxxv{%
Indeed, those who have believed and those who have emigrated and fought in the cause of Allah - those expect the mercy of Allah. And Allah is Forgiving and Merciful.\qt@no{218}}%
\qt@newcmd\qurantrans@en@ccxxvi{%
They ask you about wine and gambling. Say, ``In them is great sin and [yet, some] benefit for people. But their sin is greater than their benefit." And they ask you what they should spend. Say, ``The excess [beyond needs]." Thus Allah makes clear to you the verses [of revelation] that you might give thought.\qt@no{219}}%
\qt@newcmd\qurantrans@en@ccxxvii{%
To this world and the Hereafter. And they ask you about orphans. Say, ``Improvement for them is best. And if you mix your affairs with theirs - they are your brothers. And Allah knows the corrupter from the amender. And if Allah had willed, He could have put you in difficulty. Indeed, Allah is Exalted in Might and Wise.\qt@no{220}}%
\qt@newcmd\qurantrans@en@ccxxviii{%
And do not marry polytheistic women until they believe. And a believing slave woman is better than a polytheist, even though she might please you. And do not marry polytheistic men [to your women] until they believe. And a believing slave is better than a polytheist, even though he might please you. Those invite [you] to the Fire, but Allah invites to Paradise and to forgiveness, by His permission. And He makes clear His verses to the people that perhaps they may remember.\qt@no{221}}%
\qt@newcmd\qurantrans@en@ccxxix{%
And they ask you about menstruation. Say, ``It is harm, so keep away from wives during menstruation. And do not approach them until they are pure. And when they have purified themselves, then come to them from where Allah has ordained for you. Indeed, Allah loves those who are constantly repentant and loves those who purify themselves."\qt@no{222}}%
\qt@newcmd\qurantrans@en@ccxxx{%
Your wives are a place of sowing of seed for you, so come to your place of cultivation however you wish and put forth [righteousness] for yourselves. And fear Allah and know that you will meet Him. And give good tidings to the believers.\qt@no{223}}%
\qt@newcmd\qurantrans@en@ccxxxi{%
And do not make [your oath by] Allah an excuse against being righteous and fearing Allah and making peace among people. And Allah is Hearing and Knowing.\qt@no{224}}%
\qt@newcmd\qurantrans@en@ccxxxii{%
Allah does not impose blame upon you for what is unintentional in your oaths, but He imposes blame upon you for what your hearts have earned. And Allah is Forgiving and Forbearing.\qt@no{225}}%
\qt@newcmd\qurantrans@en@ccxxxiii{%
For those who swear not to have sexual relations with their wives is a waiting time of four months, but if they return [to normal relations] - then indeed, Allah is Forgiving and Merciful.\qt@no{226}}%
\qt@newcmd\qurantrans@en@ccxxxiv{%
And if they decide on divorce - then indeed, Allah is Hearing and Knowing.\qt@no{227}}%
\qt@newcmd\qurantrans@en@ccxxxv{%
Divorced women remain in waiting for three periods, and it is not lawful for them to conceal what Allah has created in their wombs if they believe in Allah and the Last Day. And their husbands have more right to take them back in this [period] if they want reconciliation. And due to the wives is similar to what is expected of them, according to what is reasonable. But the men have a degree over them [in responsibility and authority]. And Allah is Exalted in Might and Wise.\qt@no{228}}%
\qt@newcmd\qurantrans@en@ccxxxvi{%
Divorce is twice. Then, either keep [her] in an acceptable manner or release [her] with good treatment. And it is not lawful for you to take anything of what you have given them unless both fear that they will not be able to keep [within] the limits of Allah. But if you fear that they will not keep [within] the limits of Allah, then there is no blame upon either of them concerning that by which she ransoms herself. These are the limits of Allah, so do not transgress them. And whoever transgresses the limits of Allah - it is those who are the wrongdoers.\qt@no{229}}%
\qt@newcmd\qurantrans@en@ccxxxvii{%
And if he has divorced her [for the third time], then she is not lawful to him afterward until [after] she marries a husband other than him. And if the latter husband divorces her [or dies], there is no blame upon the woman and her former husband for returning to each other if they think that they can keep [within] the limits of Allah. These are the limits of Allah, which He makes clear to a people who know.\qt@no{230}}%
\qt@newcmd\qurantrans@en@ccxxxviii{%
And when you divorce women and they have [nearly] fulfilled their term, either retain them according to acceptable terms or release them according to acceptable terms, and do not keep them, intending harm, to transgress [against them]. And whoever does that has certainly wronged himself. And do not take the verses of Allah in jest. And remember the favor of Allah upon you and what has been revealed to you of the Book and wisdom by which He instructs you. And fear Allah and know that Allah is Knowing of all things.\qt@no{231}}%
\qt@newcmd\qurantrans@en@ccxxxix{%
And when you divorce women and they have fulfilled their term, do not prevent them from remarrying their [former] husbands if they agree among themselves on an acceptable basis. That is instructed to whoever of you believes in Allah and the Last Day. That is better for you and purer, and Allah knows and you know not.\qt@no{232}}%
\qt@newcmd\qurantrans@en@ccxl{%
Mothers may breastfeed their children two complete years for whoever wishes to complete the nursing [period]. Upon the father is the mothers' provision and their clothing according to what is acceptable. No person is charged with more than his capacity. No mother should be harmed through her child, and no father through his child. And upon the [father's] heir is [a duty] like that [of the father]. And if they both desire weaning through mutual consent from both of them and consultation, there is no blame upon either of them. And if you wish to have your children nursed by a substitute, there is no blame upon you as long as you give payment according to what is acceptable. And fear Allah and know that Allah is Seeing of what you do.\qt@no{233}}%
\qt@newcmd\qurantrans@en@ccxli{%
And those who are taken in death among you and leave wives behind - they, [the wives, shall] wait four months and ten [days]. And when they have fulfilled their term, then there is no blame upon you for what they do with themselves in an acceptable manner. And Allah is [fully] Acquainted with what you do.\qt@no{234}}%
\qt@newcmd\qurantrans@en@ccxlii{%
There is no blame upon you for that to which you [indirectly] allude concerning a proposal to women or for what you conceal within yourselves. Allah knows that you will have them in mind. But do not promise them secretly except for saying a proper saying. And do not determine to undertake a marriage contract until the decreed period reaches its end. And know that Allah knows what is within yourselves, so beware of Him. And know that Allah is Forgiving and Forbearing.\qt@no{235}}%
\qt@newcmd\qurantrans@en@ccxliii{%
There is no blame upon you if you divorce women you have not touched nor specified for them an obligation. But give them [a gift of] compensation - the wealthy according to his capability and the poor according to his capability - a provision according to what is acceptable, a duty upon the doers of good.\qt@no{236}}%
\qt@newcmd\qurantrans@en@ccxliv{%
And if you divorce them before you have touched them and you have already specified for them an obligation, then [give] half of what you specified - unless they forego the right or the one in whose hand is the marriage contract foregoes it. And to forego it is nearer to righteousness. And do not forget graciousness between you. Indeed Allah, of whatever you do, is Seeing.\qt@no{237}}%
\qt@newcmd\qurantrans@en@ccxlv{%
Maintain with care the [obligatory] prayers and [in particular] the middle prayer and stand before Allah, devoutly obedient.\qt@no{238}}%
\qt@newcmd\qurantrans@en@ccxlvi{%
And if you fear [an enemy, then pray] on foot or riding. But when you are secure, then remember Allah [in prayer], as He has taught you that which you did not [previously] know.\qt@no{239}}%
\qt@newcmd\qurantrans@en@ccxlvii{%
And those who are taken in death among you and leave wives behind - for their wives is a bequest: maintenance for one year without turning [them] out. But if they leave [of their own accord], then there is no blame upon you for what they do with themselves in an acceptable way. And Allah is Exalted in Might and Wise.\qt@no{240}}%
\qt@newcmd\qurantrans@en@ccxlviii{%
And for divorced women is a provision according to what is acceptable - a duty upon the righteous.\qt@no{241}}%
\qt@newcmd\qurantrans@en@ccxlix{%
Thus does Allah make clear to you His verses that you might use reason.\qt@no{242}}%
\qt@newcmd\qurantrans@en@ccl{%
Have you not considered those who left their homes in many thousands, fearing death? Allah said to them, ``Die"; then He restored them to life. And Allah is full of bounty to the people, but most of the people do not show gratitude.\qt@no{243}}%
\qt@newcmd\qurantrans@en@ccli{%
And fight in the cause of Allah and know that Allah is Hearing and Knowing.\qt@no{244}}%
\qt@newcmd\qurantrans@en@cclii{%
Who is it that would loan Allah a goodly loan so He may multiply it for him many times over? And it is Allah who withholds and grants abundance, and to Him you will be returned.\qt@no{245}}%
\qt@newcmd\qurantrans@en@ccliii{%
Have you not considered the assembly of the Children of Israel after [the time of] Moses when they said to a prophet of theirs, ``Send to us a king, and we will fight in the way of Allah ``? He said, ``Would you perhaps refrain from fighting if fighting was prescribed for you?" They said, ``And why should we not fight in the cause of Allah when we have been driven out from our homes and from our children?" But when fighting was prescribed for them, they turned away, except for a few of them. And Allah is Knowing of the wrongdoers.\qt@no{246}}%
\qt@newcmd\qurantrans@en@ccliv{%
And their prophet said to them, ``Indeed, Allah has sent to you Saul as a king." They said, ``How can he have kingship over us while we are more worthy of kingship than him and he has not been given any measure of wealth?" He said, ``Indeed, Allah has chosen him over you and has increased him abundantly in knowledge and stature. And Allah gives His sovereignty to whom He wills. And Allah is all-Encompassing [in favor] and Knowing."\qt@no{247}}%
\qt@newcmd\qurantrans@en@cclv{%
And their prophet said to them, ``Indeed, a sign of his kingship is that the chest will come to you in which is assurance from your Lord and a remnant of what the family of Moses and the family of Aaron had left, carried by the angels. Indeed in that is a sign for you, if you are believers."\qt@no{248}}%
\qt@newcmd\qurantrans@en@cclvi{%
And when Saul went forth with the soldiers, he said, ``Indeed, Allah will be testing you with a river. So whoever drinks from it is not of me, and whoever does not taste it is indeed of me, excepting one who takes [from it] in the hollow of his hand." But they drank from it, except a [very] few of them. Then when he had crossed it along with those who believed with him, they said, ``There is no power for us today against Goliath and his soldiers." But those who were certain that they would meet Allah said, ``How many a small company has overcome a large company by permission of Allah. And Allah is with the patient."\qt@no{249}}%
\qt@newcmd\qurantrans@en@cclvii{%
And when they went forth to [face] Goliath and his soldiers, they said, ``Our Lord, pour upon us patience and plant firmly our feet and give us victory over the disbelieving people."\qt@no{250}}%
\qt@newcmd\qurantrans@en@cclviii{%
So they defeated them by permission of Allah, and David killed Goliath, and Allah gave him the kingship and prophethood and taught him from that which He willed. And if it were not for Allah checking [some] people by means of others, the earth would have been corrupted, but Allah is full of bounty to the worlds.\qt@no{251}}%
\qt@newcmd\qurantrans@en@cclix{%
These are the verses of Allah which We recite to you, [O Muhammad], in truth. And indeed, you are from among the messengers.\qt@no{252}}%
\qt@newcmd\qurantrans@en@cclx{%
Those messengers - some of them We caused to exceed others. Among them were those to whom Allah spoke, and He raised some of them in degree. And We gave Jesus, the Son of Mary, clear proofs, and We supported him with the Pure Spirit. If Allah had willed, those [generations] succeeding them would not have fought each other after the clear proofs had come to them. But they differed, and some of them believed and some of them disbelieved. And if Allah had willed, they would not have fought each other, but Allah does what He intends.\qt@no{253}}%
\qt@newcmd\qurantrans@en@cclxi{%
O you who have believed, spend from that which We have provided for you before there comes a Day in which there is no exchange and no friendship and no intercession. And the disbelievers - they are the wrongdoers.\qt@no{254}}%
\qt@newcmd\qurantrans@en@cclxii{%
Allah - there is no deity except Him, the Ever-Living, the Sustainer of [all] existence. Neither drowsiness overtakes Him nor sleep. To Him belongs whatever is in the heavens and whatever is on the earth. Who is it that can intercede with Him except by His permission? He knows what is [presently] before them and what will be after them, and they encompass not a thing of His knowledge except for what He wills. His Kursi extends over the heavens and the earth, and their preservation tires Him not. And He is the Most High, the Most Great.\qt@no{255}}%
\qt@newcmd\qurantrans@en@cclxiii{%
There shall be no compulsion in [acceptance of] the religion. The right course has become clear from the wrong. So whoever disbelieves in Taghut and believes in Allah has grasped the most trustworthy handhold with no break in it. And Allah is Hearing and Knowing.\qt@no{256}}%
\qt@newcmd\qurantrans@en@cclxiv{%
Allah is the ally of those who believe. He brings them out from darknesses into the light. And those who disbelieve - their allies are Taghut. They take them out of the light into darknesses. Those are the companions of the Fire; they will abide eternally therein.\qt@no{257}}%
\qt@newcmd\qurantrans@en@cclxv{%
Have you not considered the one who argued with Abraham about his Lord [merely] because Allah had given him kingship? When Abraham said, ``My Lord is the one who gives life and causes death," he said, ``I give life and cause death." Abraham said, ``Indeed, Allah brings up the sun from the east, so bring it up from the west." So the disbeliever was overwhelmed [by astonishment], and Allah does not guide the wrongdoing people.\qt@no{258}}%
\qt@newcmd\qurantrans@en@cclxvi{%
Or [consider such an example] as the one who passed by a township which had fallen into ruin. He said, ``How will Allah bring this to life after its death?" So Allah caused him to die for a hundred years; then He revived him. He said, ``How long have you remained?" The man said, ``I have remained a day or part of a day." He said, ``Rather, you have remained one hundred years. Look at your food and your drink; it has not changed with time. And look at your donkey; and We will make you a sign for the people. And look at the bones [of this donkey] - how We raise them and then We cover them with flesh." And when it became clear to him, he said, ``I know that Allah is over all things competent."\qt@no{259}}%
\qt@newcmd\qurantrans@en@cclxvii{%
And [mention] when Abraham said, ``My Lord, show me how You give life to the dead." [Allah] said, ``Have you not believed?" He said, ``Yes, but [I ask] only that my heart may be satisfied." [Allah] said, ``Take four birds and commit them to yourself. Then [after slaughtering them] put on each hill a portion of them; then call them - they will come [flying] to you in haste. And know that Allah is Exalted in Might and Wise."\qt@no{260}}%
\qt@newcmd\qurantrans@en@cclxviii{%
The example of those who spend their wealth in the way of Allah is like a seed [of grain] which grows seven spikes; in each spike is a hundred grains. And Allah multiplies [His reward] for whom He wills. And Allah is all-Encompassing and Knowing.\qt@no{261}}%
\qt@newcmd\qurantrans@en@cclxix{%
Those who spend their wealth in the way of Allah and then do not follow up what they have spent with reminders [of it] or [other] injury will have their reward with their Lord, and there will be no fear concerning them, nor will they grieve.\qt@no{262}}%
\qt@newcmd\qurantrans@en@cclxx{%
Kind speech and forgiveness are better than charity followed by injury. And Allah is Free of need and Forbearing.\qt@no{263}}%
\qt@newcmd\qurantrans@en@cclxxi{%
O you who have believed, do not invalidate your charities with reminders or injury as does one who spends his wealth [only] to be seen by the people and does not believe in Allah and the Last Day. His example is like that of a [large] smooth stone upon which is dust and is hit by a downpour that leaves it bare. They are unable [to keep] anything of what they have earned. And Allah does not guide the disbelieving people.\qt@no{264}}%
\qt@newcmd\qurantrans@en@cclxxii{%
And the example of those who spend their wealth seeking means to the approval of Allah and assuring [reward for] themselves is like a garden on high ground which is hit by a downpour - so it yields its fruits in double. And [even] if it is not hit by a downpour, then a drizzle [is sufficient]. And Allah, of what you do, is Seeing.\qt@no{265}}%
\qt@newcmd\qurantrans@en@cclxxiii{%
Would one of you like to have a garden of palm trees and grapevines underneath which rivers flow in which he has from every fruit? But he is afflicted with old age and has weak offspring, and it is hit by a whirlwind containing fire and is burned. Thus does Allah make clear to you [His] verses that you might give thought.\qt@no{266}}%
\qt@newcmd\qurantrans@en@cclxxiv{%
O you who have believed, spend from the good things which you have earned and from that which We have produced for you from the earth. And do not aim toward the defective therefrom, spending [from that] while you would not take it [yourself] except with closed eyes. And know that Allah is Free of need and Praiseworthy.\qt@no{267}}%
\qt@newcmd\qurantrans@en@cclxxv{%
Satan threatens you with poverty and orders you to immorality, while Allah promises you forgiveness from Him and bounty. And Allah is all-Encompassing and Knowing.\qt@no{268}}%
\qt@newcmd\qurantrans@en@cclxxvi{%
He gives wisdom to whom He wills, and whoever has been given wisdom has certainly been given much good. And none will remember except those of understanding.\qt@no{269}}%
\qt@newcmd\qurantrans@en@cclxxvii{%
And whatever you spend of expenditures or make of vows - indeed, Allah knows of it. And for the wrongdoers there are no helpers.\qt@no{270}}%
\qt@newcmd\qurantrans@en@cclxxviii{%
If you disclose your charitable expenditures, they are good; but if you conceal them and give them to the poor, it is better for you, and He will remove from you some of your misdeeds [thereby]. And Allah, with what you do, is [fully] Acquainted.\qt@no{271}}%
\qt@newcmd\qurantrans@en@cclxxix{%
Not upon you, [O Muhammad], is [responsibility for] their guidance, but Allah guides whom He wills. And whatever good you [believers] spend is for yourselves, and you do not spend except seeking the countenance of Allah. And whatever you spend of good - it will be fully repaid to you, and you will not be wronged.\qt@no{272}}%
\qt@newcmd\qurantrans@en@cclxxx{%
[Charity is] for the poor who have been restricted for the cause of Allah, unable to move about in the land. An ignorant [person] would think them self-sufficient because of their restraint, but you will know them by their [characteristic] sign. They do not ask people persistently [or at all]. And whatever you spend of good - indeed, Allah is Knowing of it.\qt@no{273}}%
\qt@newcmd\qurantrans@en@cclxxxi{%
Those who spend their wealth [in Allah 's way] by night and by day, secretly and publicly - they will have their reward with their Lord. And no fear will there be concerning them, nor will they grieve.\qt@no{274}}%
\qt@newcmd\qurantrans@en@cclxxxii{%
Those who consume interest cannot stand [on the Day of Resurrection] except as one stands who is being beaten by Satan into insanity. That is because they say, ``Trade is [just] like interest." But Allah has permitted trade and has forbidden interest. So whoever has received an admonition from his Lord and desists may have what is past, and his affair rests with Allah. But whoever returns to [dealing in interest or usury] - those are the companions of the Fire; they will abide eternally therein.\qt@no{275}}%
\qt@newcmd\qurantrans@en@cclxxxiii{%
Allah destroys interest and gives increase for charities. And Allah does not like every sinning disbeliever.\qt@no{276}}%
\qt@newcmd\qurantrans@en@cclxxxiv{%
Indeed, those who believe and do righteous deeds and establish prayer and give zakah will have their reward with their Lord, and there will be no fear concerning them, nor will they grieve.\qt@no{277}}%
\qt@newcmd\qurantrans@en@cclxxxv{%
O you who have believed, fear Allah and give up what remains [due to you] of interest, if you should be believers.\qt@no{278}}%
\qt@newcmd\qurantrans@en@cclxxxvi{%
And if you do not, then be informed of a war [against you] from Allah and His Messenger. But if you repent, you may have your principal - [thus] you do no wrong, nor are you wronged.\qt@no{279}}%
\qt@newcmd\qurantrans@en@cclxxxvii{%
And if someone is in hardship, then [let there be] postponement until [a time of] ease. But if you give [from your right as] charity, then it is better for you, if you only knew.\qt@no{280}}%
\qt@newcmd\qurantrans@en@cclxxxviii{%
And fear a Day when you will be returned to Allah. Then every soul will be compensated for what it earned, and they will not be treated unjustly.\qt@no{281}}%
\qt@newcmd\qurantrans@en@cclxxxix{%
O you who have believed, when you contract a debt for a specified term, write it down. And let a scribe write [it] between you in justice. Let no scribe refuse to write as Allah has taught him. So let him write and let the one who has the obligation dictate. And let him fear Allah, his Lord, and not leave anything out of it. But if the one who has the obligation is of limited understanding or weak or unable to dictate himself, then let his guardian dictate in justice. And bring to witness two witnesses from among your men. And if there are not two men [available], then a man and two women from those whom you accept as witnesses - so that if one of the women errs, then the other can remind her. And let not the witnesses refuse when they are called upon. And do not be [too] weary to write it, whether it is small or large, for its [specified] term. That is more just in the sight of Allah and stronger as evidence and more likely to prevent doubt between you, except when it is an immediate transaction which you conduct among yourselves. For [then] there is no blame upon you if you do not write it. And take witnesses when you conclude a contract. Let no scribe be harmed or any witness. For if you do so, indeed, it is [grave] disobedience in you. And fear Allah. And Allah teaches you. And Allah is Knowing of all things.\qt@no{282}}%
\qt@newcmd\qurantrans@en@ccxc{%
And if you are on a journey and cannot find a scribe, then a security deposit [should be] taken. And if one of you entrusts another, then let him who is entrusted discharge his trust [faithfully] and let him fear Allah, his Lord. And do not conceal testimony, for whoever conceals it - his heart is indeed sinful, and Allah is Knowing of what you do.\qt@no{283}}%
\qt@newcmd\qurantrans@en@ccxci{%
To Allah belongs whatever is in the heavens and whatever is in the earth. Whether you show what is within yourselves or conceal it, Allah will bring you to account for it. Then He will forgive whom He wills and punish whom He wills, and Allah is over all things competent.\qt@no{284}}%
\qt@newcmd\qurantrans@en@ccxcii{%
The Messenger has believed in what was revealed to him from his Lord, and [so have] the believers. All of them have believed in Allah and His angels and His books and His messengers, [saying], ``We make no distinction between any of His messengers." And they say, ``We hear and we obey. [We seek] Your forgiveness, our Lord, and to You is the [final] destination."\qt@no{285}}%
\qt@newcmd\qurantrans@en@ccxciii{%
Allah does not charge a soul except [with that within] its capacity. It will have [the consequence of] what [good] it has gained, and it will bear [the consequence of] what [evil] it has earned. ``Our Lord, do not impose blame upon us if we have forgotten or erred. Our Lord, and lay not upon us a burden like that which You laid upon those before us. Our Lord, and burden us not with that which we have no ability to bear. And pardon us; and forgive us; and have mercy upon us. You are our protector, so give us victory over the disbelieving people."\qt@no{286}}%
\qt@newcmd\qurantrans@en@ccxciv{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@ccxcv{%
Allah - there is no deity except Him, the Ever-Living, the Sustainer of existence.\qt@no{2}}%
\qt@newcmd\qurantrans@en@ccxcvi{%
He has sent down upon you, [O Muhammad], the Book in truth, confirming what was before it. And He revealed the Torah and the Gospel.\qt@no{3}}%
\qt@newcmd\qurantrans@en@ccxcvii{%
Before, as guidance for the people. And He revealed the Qur'an. Indeed, those who disbelieve in the verses of Allah will have a severe punishment, and Allah is exalted in Might, the Owner of Retribution.\qt@no{4}}%
\qt@newcmd\qurantrans@en@ccxcviii{%
Indeed, from Allah nothing is hidden in the earth nor in the heaven.\qt@no{5}}%
\qt@newcmd\qurantrans@en@ccxcix{%
It is He who forms you in the wombs however He wills. There is no deity except Him, the Exalted in Might, the Wise.\qt@no{6}}%
\qt@newcmd\qurantrans@en@ccc{%
It is He who has sent down to you, [O Muhammad], the Book; in it are verses [that are] precise - they are the foundation of the Book - and others unspecific. As for those in whose hearts is deviation [from truth], they will follow that of it which is unspecific, seeking discord and seeking an interpretation [suitable to them]. And no one knows its [true] interpretation except Allah. But those firm in knowledge say, ``We believe in it. All [of it] is from our Lord." And no one will be reminded except those of understanding.\qt@no{7}}%
\qt@newcmd\qurantrans@en@ccci{%
[Who say], ``Our Lord, let not our hearts deviate after You have guided us and grant us from Yourself mercy. Indeed, You are the Bestower.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cccii{%
Our Lord, surely You will gather the people for a Day about which there is no doubt. Indeed, Allah does not fail in His promise."\qt@no{9}}%
\qt@newcmd\qurantrans@en@ccciii{%
Indeed, those who disbelieve - never will their wealth or their children avail them against Allah at all. And it is they who are fuel for the Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@ccciv{%
[Theirs is] like the custom of the people of Pharaoh and those before them. They denied Our signs, so Allah seized them for their sins. And Allah is severe in penalty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cccv{%
Say to those who disbelieve, ``You will be overcome and gathered together to Hell, and wretched is the resting place."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cccvi{%
Already there has been for you a sign in the two armies which met - one fighting in the cause of Allah and another of disbelievers. They saw them [to be] twice their [own] number by [their] eyesight. But Allah supports with His victory whom He wills. Indeed in that is a lesson for those of vision.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cccvii{%
Beautified for people is the love of that which they desire - of women and sons, heaped-up sums of gold and silver, fine branded horses, and cattle and tilled land. That is the enjoyment of worldly life, but Allah has with Him the best return.\qt@no{14}}%
\qt@newcmd\qurantrans@en@cccviii{%
Say, ``Shall I inform you of [something] better than that? For those who fear Allah will be gardens in the presence of their Lord beneath which rivers flow, wherein they abide eternally, and purified spouses and approval from Allah. And Allah is Seeing of [His] servants -\qt@no{15}}%
\qt@newcmd\qurantrans@en@cccix{%
Those who say, ``Our Lord, indeed we have believed, so forgive us our sins and protect us from the punishment of the Fire,"\qt@no{16}}%
\qt@newcmd\qurantrans@en@cccx{%
The patient, the true, the obedient, those who spend [in the way of Allah], and those who seek forgiveness before dawn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@cccxi{%
Allah witnesses that there is no deity except Him, and [so do] the angels and those of knowledge - [that He is] maintaining [creation] in justice. There is no deity except Him, the Exalted in Might, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@cccxii{%
Indeed, the religion in the sight of Allah is Islam. And those who were given the Scripture did not differ except after knowledge had come to them - out of jealous animosity between themselves. And whoever disbelieves in the verses of Allah, then indeed, Allah is swift in [taking] account.\qt@no{19}}%
\qt@newcmd\qurantrans@en@cccxiii{%
So if they argue with you, say, ``I have submitted myself to Allah [in Islam], and [so have] those who follow me." And say to those who were given the Scripture and [to] the unlearned, ``Have you submitted yourselves?" And if they submit [in Islam], they are rightly guided; but if they turn away - then upon you is only the [duty of] notification. And Allah is Seeing of [His] servants.\qt@no{20}}%
\qt@newcmd\qurantrans@en@cccxiv{%
Those who disbelieve in the signs of Allah and kill the prophets without right and kill those who order justice from among the people - give them tidings of a painful punishment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@cccxv{%
They are the ones whose deeds have become worthless in this world and the Hereafter, and for them there will be no helpers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@cccxvi{%
Do you not consider, [O Muhammad], those who were given a portion of the Scripture? They are invited to the Scripture of Allah that it should arbitrate between them; then a party of them turns away, and they are refusing.\qt@no{23}}%
\qt@newcmd\qurantrans@en@cccxvii{%
That is because they say, ``Never will the Fire touch us except for [a few] numbered days," and [because] they were deluded in their religion by what they were inventing.\qt@no{24}}%
\qt@newcmd\qurantrans@en@cccxviii{%
So how will it be when We assemble them for a Day about which there is no doubt? And each soul will be compensated [in full for] what it earned, and they will not be wronged.\qt@no{25}}%
\qt@newcmd\qurantrans@en@cccxix{%
Say, ``O Allah, Owner of Sovereignty, You give sovereignty to whom You will and You take sovereignty away from whom You will. You honor whom You will and You humble whom You will. In Your hand is [all] good. Indeed, You are over all things competent.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cccxx{%
You cause the night to enter the day, and You cause the day to enter the night; and You bring the living out of the dead, and You bring the dead out of the living. And You give provision to whom You will without account."\qt@no{27}}%
\qt@newcmd\qurantrans@en@cccxxi{%
Let not believers take disbelievers as allies rather than believers. And whoever [of you] does that has nothing with Allah, except when taking precaution against them in prudence. And Allah warns you of Himself, and to Allah is the [final] destination.\qt@no{28}}%
\qt@newcmd\qurantrans@en@cccxxii{%
Say, ``Whether you conceal what is in your breasts or reveal it, Allah knows it. And He knows that which is in the heavens and that which is on the earth. And Allah is over all things competent.\qt@no{29}}%
\qt@newcmd\qurantrans@en@cccxxiii{%
The Day every soul will find what it has done of good present [before it] and what it has done of evil, it will wish that between itself and that [evil] was a great distance. And Allah warns you of Himself, and Allah is Kind to [His] servants."\qt@no{30}}%
\qt@newcmd\qurantrans@en@cccxxiv{%
Say, [O Muhammad], ``If you should love Allah, then follow me, [so] Allah will love you and forgive you your sins. And Allah is Forgiving and Merciful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@cccxxv{%
Say, ``Obey Allah and the Messenger." But if they turn away - then indeed, Allah does not like the disbelievers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cccxxvi{%
Indeed, Allah chose Adam and Noah and the family of Abraham and the family of 'Imran over the worlds -\qt@no{33}}%
\qt@newcmd\qurantrans@en@cccxxvii{%
Descendants, some of them from others. And Allah is Hearing and Knowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@cccxxviii{%
[Mention, O Muhammad], when the wife of 'Imran said, ``My Lord, indeed I have pledged to You what is in my womb, consecrated [for Your service], so accept this from me. Indeed, You are the Hearing, the Knowing."\qt@no{35}}%
\qt@newcmd\qurantrans@en@cccxxix{%
But when she delivered her, she said, ``My Lord, I have delivered a female." And Allah was most knowing of what she delivered, ``And the male is not like the female. And I have named her Mary, and I seek refuge for her in You and [for] her descendants from Satan, the expelled [from the mercy of Allah]."\qt@no{36}}%
\qt@newcmd\qurantrans@en@cccxxx{%
So her Lord accepted her with good acceptance and caused her to grow in a good manner and put her in the care of Zechariah. Every time Zechariah entered upon her in the prayer chamber, he found with her provision. He said, ``O Mary, from where is this [coming] to you?" She said, ``It is from Allah. Indeed, Allah provides for whom He wills without account."\qt@no{37}}%
\qt@newcmd\qurantrans@en@cccxxxi{%
At that, Zechariah called upon his Lord, saying, ``My Lord, grant me from Yourself a good offspring. Indeed, You are the Hearer of supplication."\qt@no{38}}%
\qt@newcmd\qurantrans@en@cccxxxii{%
So the angels called him while he was standing in prayer in the chamber, ``Indeed, Allah gives you good tidings of John, confirming a word from Allah and [who will be] honorable, abstaining [from women], and a prophet from among the righteous."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cccxxxiii{%
He said, ``My Lord, how will I have a boy when I have reached old age and my wife is barren?" The angel said, ``Such is Allah; He does what He wills."\qt@no{40}}%
\qt@newcmd\qurantrans@en@cccxxxiv{%
He said, ``My Lord, make for me a sign." He Said, ``Your sign is that you will not [be able to] speak to the people for three days except by gesture. And remember your Lord much and exalt [Him with praise] in the evening and the morning."\qt@no{41}}%
\qt@newcmd\qurantrans@en@cccxxxv{%
And [mention] when the angels said, ``O Mary, indeed Allah has chosen you and purified you and chosen you above the women of the worlds.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cccxxxvi{%
O Mary, be devoutly obedient to your Lord and prostrate and bow with those who bow [in prayer]."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cccxxxvii{%
That is from the news of the unseen which We reveal to you, [O Muhammad]. And you were not with them when they cast their pens as to which of them should be responsible for Mary. Nor were you with them when they disputed.\qt@no{44}}%
\qt@newcmd\qurantrans@en@cccxxxviii{%
[And mention] when the angels said, ``O Mary, indeed Allah gives you good tidings of a word from Him, whose name will be the Messiah, Jesus, the son of Mary - distinguished in this world and the Hereafter and among those brought near [to Allah].\qt@no{45}}%
\qt@newcmd\qurantrans@en@cccxxxix{%
He will speak to the people in the cradle and in maturity and will be of the righteous."\qt@no{46}}%
\qt@newcmd\qurantrans@en@cccxl{%
She said, ``My Lord, how will I have a child when no man has touched me?" [The angel] said, ``Such is Allah; He creates what He wills. When He decrees a matter, He only says to it, 'Be,' and it is.\qt@no{47}}%
\qt@newcmd\qurantrans@en@cccxli{%
And He will teach him writing and wisdom and the Torah and the Gospel\qt@no{48}}%
\qt@newcmd\qurantrans@en@cccxlii{%
And [make him] a messenger to the Children of Israel, [who will say], 'Indeed I have come to you with a sign from your Lord in that I design for you from clay [that which is] like the form of a bird, then I breathe into it and it becomes a bird by permission of Allah. And I cure the blind and the leper, and I give life to the dead - by permission of Allah. And I inform you of what you eat and what you store in your houses. Indeed in that is a sign for you, if you are believers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@cccxliii{%
And [I have come] confirming what was before me of the Torah and to make lawful for you some of what was forbidden to you. And I have come to you with a sign from your Lord, so fear Allah and obey me.\qt@no{50}}%
\qt@newcmd\qurantrans@en@cccxliv{%
Indeed, Allah is my Lord and your Lord, so worship Him. That is the straight path."\qt@no{51}}%
\qt@newcmd\qurantrans@en@cccxlv{%
But when Jesus felt [persistence in] disbelief from them, he said, ``Who are my supporters for [the cause of] Allah?" The disciples said, ``We are supporters for Allah. We have believed in Allah and testify that we are Muslims [submitting to Him].\qt@no{52}}%
\qt@newcmd\qurantrans@en@cccxlvi{%
Our Lord, we have believed in what You revealed and have followed the messenger Jesus, so register us among the witnesses [to truth]."\qt@no{53}}%
\qt@newcmd\qurantrans@en@cccxlvii{%
And the disbelievers planned, but Allah planned. And Allah is the best of planners.\qt@no{54}}%
\qt@newcmd\qurantrans@en@cccxlviii{%
[Mention] when Allah said, ``O Jesus, indeed I will take you and raise you to Myself and purify you from those who disbelieve and make those who follow you [in submission to Allah alone] superior to those who disbelieve until the Day of Resurrection. Then to Me is your return, and I will judge between you concerning that in which you used to differ.\qt@no{55}}%
\qt@newcmd\qurantrans@en@cccxlix{%
And as for those who disbelieved, I will punish them with a severe punishment in this world and the Hereafter, and they will have no helpers."\qt@no{56}}%
\qt@newcmd\qurantrans@en@cccl{%
But as for those who believed and did righteous deeds, He will give them in full their rewards, and Allah does not like the wrongdoers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@cccli{%
This is what We recite to you, [O Muhammad], of [Our] verses and the precise [and wise] message.\qt@no{58}}%
\qt@newcmd\qurantrans@en@ccclii{%
Indeed, the example of Jesus to Allah is like that of Adam. He created Him from dust; then He said to him, ``Be," and he was.\qt@no{59}}%
\qt@newcmd\qurantrans@en@cccliii{%
The truth is from your Lord, so do not be among the doubters.\qt@no{60}}%
\qt@newcmd\qurantrans@en@cccliv{%
Then whoever argues with you about it after [this] knowledge has come to you - say, ``Come, let us call our sons and your sons, our women and your women, ourselves and yourselves, then supplicate earnestly [together] and invoke the curse of Allah upon the liars [among us]."\qt@no{61}}%
\qt@newcmd\qurantrans@en@ccclv{%
Indeed, this is the true narration. And there is no deity except Allah. And indeed, Allah is the Exalted in Might, the Wise.\qt@no{62}}%
\qt@newcmd\qurantrans@en@ccclvi{%
But if they turn away, then indeed - Allah is Knowing of the corrupters.\qt@no{63}}%
\qt@newcmd\qurantrans@en@ccclvii{%
Say, ``O People of the Scripture, come to a word that is equitable between us and you - that we will not worship except Allah and not associate anything with Him and not take one another as lords instead of Allah." But if they turn away, then say, ``Bear witness that we are Muslims [submitting to Him]."\qt@no{64}}%
\qt@newcmd\qurantrans@en@ccclviii{%
O People of the Scripture, why do you argue about Abraham while the Torah and the Gospel were not revealed until after him? Then will you not reason?\qt@no{65}}%
\qt@newcmd\qurantrans@en@ccclix{%
Here you are - those who have argued about that of which you have [some] knowledge, but why do you argue about that of which you have no knowledge? And Allah knows, while you know not.\qt@no{66}}%
\qt@newcmd\qurantrans@en@ccclx{%
Abraham was neither a Jew nor a Christian, but he was one inclining toward truth, a Muslim [submitting to Allah]. And he was not of the polytheists.\qt@no{67}}%
\qt@newcmd\qurantrans@en@ccclxi{%
Indeed, the most worthy of Abraham among the people are those who followed him [in submission to Allah] and this prophet, and those who believe [in his message]. And Allah is the ally of the believers.\qt@no{68}}%
\qt@newcmd\qurantrans@en@ccclxii{%
A faction of the people of the Scripture wish they could mislead you. But they do not mislead except themselves, and they perceive [it] not.\qt@no{69}}%
\qt@newcmd\qurantrans@en@ccclxiii{%
O People of the Scripture, why do you disbelieve in the verses of Allah while you witness [to their truth]?\qt@no{70}}%
\qt@newcmd\qurantrans@en@ccclxiv{%
O People of the Scripture, why do you confuse the truth with falsehood and conceal the truth while you know [it]?\qt@no{71}}%
\qt@newcmd\qurantrans@en@ccclxv{%
And a faction of the People of the Scripture say [to each other], ``Believe in that which was revealed to the believers at the beginning of the day and reject it at its end that perhaps they will abandon their religion,\qt@no{72}}%
\qt@newcmd\qurantrans@en@ccclxvi{%
And do not trust except those who follow your religion." Say, ``Indeed, the [true] guidance is the guidance of Allah. [Do you fear] lest someone be given [knowledge] like you were given or that they would [thereby] argue with you before your Lord?" Say, ``Indeed, [all] bounty is in the hand of Allah - He grants it to whom He wills. And Allah is all-Encompassing and Wise."\qt@no{73}}%
\qt@newcmd\qurantrans@en@ccclxvii{%
He selects for His mercy whom He wills. And Allah is the possessor of great bounty.\qt@no{74}}%
\qt@newcmd\qurantrans@en@ccclxviii{%
And among the People of the Scripture is he who, if you entrust him with a great amount [of wealth], he will return it to you. And among them is he who, if you entrust him with a [single] silver coin, he will not return it to you unless you are constantly standing over him [demanding it]. That is because they say, ``There is no blame upon us concerning the unlearned." And they speak untruth about Allah while they know [it].\qt@no{75}}%
\qt@newcmd\qurantrans@en@ccclxix{%
But yes, whoever fulfills his commitment and fears Allah - then indeed, Allah loves those who fear Him.\qt@no{76}}%
\qt@newcmd\qurantrans@en@ccclxx{%
Indeed, those who exchange the covenant of Allah and their [own] oaths for a small price will have no share in the Hereafter, and Allah will not speak to them or look at them on the Day of Resurrection, nor will He purify them; and they will have a painful punishment.\qt@no{77}}%
\qt@newcmd\qurantrans@en@ccclxxi{%
And indeed, there is among them a party who alter the Scripture with their tongues so you may think it is from the Scripture, but it is not from the Scripture. And they say, ``This is from Allah," but it is not from Allah. And they speak untruth about Allah while they know.\qt@no{78}}%
\qt@newcmd\qurantrans@en@ccclxxii{%
It is not for a human [prophet] that Allah should give him the Scripture and authority and prophethood and then he would say to the people, ``Be servants to me rather than Allah," but [instead, he would say], ``Be pious scholars of the Lord because of what you have taught of the Scripture and because of what you have studied."\qt@no{79}}%
\qt@newcmd\qurantrans@en@ccclxxiii{%
Nor could he order you to take the angels and prophets as lords. Would he order you to disbelief after you had been Muslims?\qt@no{80}}%
\qt@newcmd\qurantrans@en@ccclxxiv{%
And [recall, O People of the Scripture], when Allah took the covenant of the prophets, [saying], ``Whatever I give you of the Scripture and wisdom and then there comes to you a messenger confirming what is with you, you [must] believe in him and support him." [Allah] said, ``Have you acknowledged and taken upon that My commitment?" They said, ``We have acknowledged it." He said, ``Then bear witness, and I am with you among the witnesses."\qt@no{81}}%
\qt@newcmd\qurantrans@en@ccclxxv{%
And whoever turned away after that - they were the defiantly disobedient.\qt@no{82}}%
\qt@newcmd\qurantrans@en@ccclxxvi{%
So is it other than the religion of Allah they desire, while to Him have submitted [all] those within the heavens and earth, willingly or by compulsion, and to Him they will be returned?\qt@no{83}}%
\qt@newcmd\qurantrans@en@ccclxxvii{%
Say, ``We have believed in Allah and in what was revealed to us and what was revealed to Abraham, Ishmael, Isaac, Jacob, and the Descendants, and in what was given to Moses and Jesus and to the prophets from their Lord. We make no distinction between any of them, and we are Muslims [submitting] to Him."\qt@no{84}}%
\qt@newcmd\qurantrans@en@ccclxxviii{%
And whoever desires other than Islam as religion - never will it be accepted from him, and he, in the Hereafter, will be among the losers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@ccclxxix{%
How shall Allah guide a people who disbelieved after their belief and had witnessed that the Messenger is true and clear signs had come to them? And Allah does not guide the wrongdoing people.\qt@no{86}}%
\qt@newcmd\qurantrans@en@ccclxxx{%
Those - their recompense will be that upon them is the curse of Allah and the angels and the people, all together,\qt@no{87}}%
\qt@newcmd\qurantrans@en@ccclxxxi{%
Abiding eternally therein. The punishment will not be lightened for them, nor will they be reprieved.\qt@no{88}}%
\qt@newcmd\qurantrans@en@ccclxxxii{%
Except for those who repent after that and correct themselves. For indeed, Allah is Forgiving and Merciful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@ccclxxxiii{%
Indeed, those who reject the message after their belief and then increase in disbelief - never will their [claimed] repentance be accepted, and they are the ones astray.\qt@no{90}}%
\qt@newcmd\qurantrans@en@ccclxxxiv{%
Indeed, those who disbelieve and die while they are disbelievers - never would the [whole] capacity of the earth in gold be accepted from one of them if he would [seek to] ransom himself with it. For those there will be a painful punishment, and they will have no helpers.\qt@no{91}}%
\qt@newcmd\qurantrans@en@ccclxxxv{%
Never will you attain the good [reward] until you spend [in the way of Allah] from that which you love. And whatever you spend - indeed, Allah is Knowing of it.\qt@no{92}}%
\qt@newcmd\qurantrans@en@ccclxxxvi{%
All food was lawful to the Children of Israel except what Israel had made unlawful to himself before the Torah was revealed. Say, [O Muhammad], ``So bring the Torah and recite it, if you should be truthful."\qt@no{93}}%
\qt@newcmd\qurantrans@en@ccclxxxvii{%
And whoever invents about Allah untruth after that - then those are [truly] the wrongdoers.\qt@no{94}}%
\qt@newcmd\qurantrans@en@ccclxxxviii{%
Say, ``Allah has told the truth. So follow the religion of Abraham, inclining toward truth; and he was not of the polytheists."\qt@no{95}}%
\qt@newcmd\qurantrans@en@ccclxxxix{%
Indeed, the first House [of worship] established for mankind was that at Makkah - blessed and a guidance for the worlds.\qt@no{96}}%
\qt@newcmd\qurantrans@en@cccxc{%
In it are clear signs [such as] the standing place of Abraham. And whoever enters it shall be safe. And [due] to Allah from the people is a pilgrimage to the House - for whoever is able to find thereto a way. But whoever disbelieves - then indeed, Allah is free from need of the worlds.\qt@no{97}}%
\qt@newcmd\qurantrans@en@cccxci{%
Say, ``O People of the Scripture, why do you disbelieve in the verses of Allah while Allah is Witness over what you do?"\qt@no{98}}%
\qt@newcmd\qurantrans@en@cccxcii{%
Say, ``O People of the Scripture, why do you avert from the way of Allah those who believe, seeking to make it [seem] deviant, while you are witnesses [to the truth]? And Allah is not unaware of what you do."\qt@no{99}}%
\qt@newcmd\qurantrans@en@cccxciii{%
O you who have believed, if you obey a party of those who were given the Scripture, they would turn you back, after your belief, [to being] unbelievers.\qt@no{100}}%
\qt@newcmd\qurantrans@en@cccxciv{%
And how could you disbelieve while to you are being recited the verses of Allah and among you is His Messenger? And whoever holds firmly to Allah has [indeed] been guided to a straight path.\qt@no{101}}%
\qt@newcmd\qurantrans@en@cccxcv{%
O you who have believed, fear Allah as He should be feared and do not die except as Muslims [in submission to Him].\qt@no{102}}%
\qt@newcmd\qurantrans@en@cccxcvi{%
And hold firmly to the rope of Allah all together and do not become divided. And remember the favor of Allah upon you - when you were enemies and He brought your hearts together and you became, by His favor, brothers. And you were on the edge of a pit of the Fire, and He saved you from it. Thus does Allah make clear to you His verses that you may be guided.\qt@no{103}}%
\qt@newcmd\qurantrans@en@cccxcvii{%
And let there be [arising] from you a nation inviting to [all that is] good, enjoining what is right and forbidding what is wrong, and those will be the successful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@cccxcviii{%
And do not be like the ones who became divided and differed after the clear proofs had come to them. And those will have a great punishment.\qt@no{105}}%
\qt@newcmd\qurantrans@en@cccxcix{%
On the Day [some] faces will turn white and [some] faces will turn black. As for those whose faces turn black, [to them it will be said], ``Did you disbelieve after your belief? Then taste the punishment for what you used to reject."\qt@no{106}}%
\qt@newcmd\qurantrans@en@cd{%
But as for those whose faces will turn white, [they will be] within the mercy of Allah. They will abide therein eternally.\qt@no{107}}%
\qt@newcmd\qurantrans@en@cdi{%
These are the verses of Allah. We recite them to you, [O Muhammad], in truth; and Allah wants no injustice to the worlds.\qt@no{108}}%
\qt@newcmd\qurantrans@en@cdii{%
To Allah belongs whatever is in the heavens and whatever is on the earth. And to Allah will [all] matters be returned.\qt@no{109}}%
\qt@newcmd\qurantrans@en@cdiii{%
You are the best nation produced [as an example] for mankind. You enjoin what is right and forbid what is wrong and believe in Allah. If only the People of the Scripture had believed, it would have been better for them. Among them are believers, but most of them are defiantly disobedient.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cdiv{%
They will not harm you except for [some] annoyance. And if they fight you, they will show you their backs; then they will not be aided.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cdv{%
They have been put under humiliation [by Allah] wherever they are overtaken, except for a covenant from Allah and a rope from the Muslims. And they have drawn upon themselves anger from Allah and have been put under destitution. That is because they disbelieved in the verses of Allah and killed the prophets without right. That is because they disobeyed and [habitually] transgressed.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cdvi{%
They are not [all] the same; among the People of the Scripture is a community standing [in obedience], reciting the verses of Allah during periods of the night and prostrating [in prayer].\qt@no{113}}%
\qt@newcmd\qurantrans@en@cdvii{%
They believe in Allah and the Last Day, and they enjoin what is right and forbid what is wrong and hasten to good deeds. And those are among the righteous.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cdviii{%
And whatever good they do - never will it be removed from them. And Allah is Knowing of the righteous.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cdix{%
Indeed, those who disbelieve - never will their wealth or their children avail them against Allah at all, and those are the companions of the Fire; they will abide therein eternally.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cdx{%
The example of what they spend in this worldly life is like that of a wind containing frost which strikes the harvest of a people who have wronged themselves and destroys it. And Allah has not wronged them, but they wrong themselves.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cdxi{%
O you who have believed, do not take as intimates those other than yourselves, for they will not spare you [any] ruin. They wish you would have hardship. Hatred has already appeared from their mouths, and what their breasts conceal is greater. We have certainly made clear to you the signs, if you will use reason.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cdxii{%
Here you are loving them but they are not loving you, while you believe in the Scripture - all of it. And when they meet you, they say, ``We believe." But when they are alone, they bite their fingertips at you in rage. Say, ``Die in your rage. Indeed, Allah is Knowing of that within the breasts."\qt@no{119}}%
\qt@newcmd\qurantrans@en@cdxiii{%
If good touches you, it distresses them; but if harm strikes you, they rejoice at it. And if you are patient and fear Allah, their plot will not harm you at all. Indeed, Allah is encompassing of what they do.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cdxiv{%
And [remember] when you, [O Muhammad], left your family in the morning to post the believers at their stations for the battle [of Uhud] - and Allah is Hearing and Knowing -\qt@no{121}}%
\qt@newcmd\qurantrans@en@cdxv{%
When two parties among you were about to lose courage, but Allah was their ally; and upon Allah the believers should rely.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cdxvi{%
And already had Allah given you victory at [the battle of] Badr while you were few in number. Then fear Allah; perhaps you will be grateful.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cdxvii{%
[Remember] when you said to the believers, ``Is it not sufficient for you that your Lord should reinforce you with three thousand angels sent down?\qt@no{124}}%
\qt@newcmd\qurantrans@en@cdxviii{%
Yes, if you remain patient and conscious of Allah and the enemy come upon you [attacking] in rage, your Lord will reinforce you with five thousand angels having marks [of distinction]\qt@no{125}}%
\qt@newcmd\qurantrans@en@cdxix{%
And Allah made it not except as [a sign of] good tidings for you and to reassure your hearts thereby. And victory is not except from Allah, the Exalted in Might, the Wise -\qt@no{126}}%
\qt@newcmd\qurantrans@en@cdxx{%
That He might cut down a section of the disbelievers or suppress them so that they turn back disappointed.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cdxxi{%
Not for you, [O Muhammad, but for Allah], is the decision whether He should [cut them down] or forgive them or punish them, for indeed, they are wrongdoers.\qt@no{128}}%
\qt@newcmd\qurantrans@en@cdxxii{%
And to Allah belongs whatever is in the heavens and whatever is on the earth. He forgives whom He wills and punishes whom He wills. And Allah is Forgiving and Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cdxxiii{%
O you who have believed, do not consume usury, doubled and multiplied, but fear Allah that you may be successful.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cdxxiv{%
And fear the Fire, which has been prepared for the disbelievers.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cdxxv{%
And obey Allah and the Messenger that you may obtain mercy.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cdxxvi{%
And hasten to forgiveness from your Lord and a garden as wide as the heavens and earth, prepared for the righteous\qt@no{133}}%
\qt@newcmd\qurantrans@en@cdxxvii{%
Who spend [in the cause of Allah] during ease and hardship and who restrain anger and who pardon the people - and Allah loves the doers of good;\qt@no{134}}%
\qt@newcmd\qurantrans@en@cdxxviii{%
And those who, when they commit an immorality or wrong themselves [by transgression], remember Allah and seek forgiveness for their sins - and who can forgive sins except Allah? - and [who] do not persist in what they have done while they know.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cdxxix{%
Those - their reward is forgiveness from their Lord and gardens beneath which rivers flow [in Paradise], wherein they will abide eternally; and excellent is the reward of the [righteous] workers.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cdxxx{%
Similar situations [as yours] have passed on before you, so proceed throughout the earth and observe how was the end of those who denied.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cdxxxi{%
This [Qur'an] is a clear statement to [all] the people and a guidance and instruction for those conscious of Allah.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cdxxxii{%
So do not weaken and do not grieve, and you will be superior if you are [true] believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cdxxxiii{%
If a wound should touch you - there has already touched the [opposing] people a wound similar to it. And these days [of varying conditions] We alternate among the people so that Allah may make evident those who believe and [may] take to Himself from among you martyrs - and Allah does not like the wrongdoers -\qt@no{140}}%
\qt@newcmd\qurantrans@en@cdxxxiv{%
And that Allah may purify the believers [through trials] and destroy the disbelievers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cdxxxv{%
Or do you think that you will enter Paradise while Allah has not yet made evident those of you who fight in His cause and made evident those who are steadfast?\qt@no{142}}%
\qt@newcmd\qurantrans@en@cdxxxvi{%
And you had certainly wished for martyrdom before you encountered it, and you have [now] seen it [before you] while you were looking on.\qt@no{143}}%
\qt@newcmd\qurantrans@en@cdxxxvii{%
Muhammad is not but a messenger. [Other] messengers have passed on before him. So if he was to die or be killed, would you turn back on your heels [to unbelief]? And he who turns back on his heels will never harm Allah at all; but Allah will reward the grateful.\qt@no{144}}%
\qt@newcmd\qurantrans@en@cdxxxviii{%
And it is not [possible] for one to die except by permission of Allah at a decree determined. And whoever desires the reward of this world - We will give him thereof; and whoever desires the reward of the Hereafter - We will give him thereof. And we will reward the grateful.\qt@no{145}}%
\qt@newcmd\qurantrans@en@cdxxxix{%
And how many a prophet [fought and] with him fought many religious scholars. But they never lost assurance due to what afflicted them in the cause of Allah, nor did they weaken or submit. And Allah loves the steadfast.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cdxl{%
And their words were not but that they said, ``Our Lord, forgive us our sins and the excess [committed] in our affairs and plant firmly our feet and give us victory over the disbelieving people."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cdxli{%
So Allah gave them the reward of this world and the good reward of the Hereafter. And Allah loves the doers of good.\qt@no{148}}%
\qt@newcmd\qurantrans@en@cdxlii{%
O you who have believed, if you obey those who disbelieve, they will turn you back on your heels, and you will [then] become losers.\qt@no{149}}%
\qt@newcmd\qurantrans@en@cdxliii{%
But Allah is your protector, and He is the best of helpers.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cdxliv{%
We will cast terror into the hearts of those who disbelieve for what they have associated with Allah of which He had not sent down [any] authority. And their refuge will be the Fire, and wretched is the residence of the wrongdoers.\qt@no{151}}%
\qt@newcmd\qurantrans@en@cdxlv{%
And Allah had certainly fulfilled His promise to you when you were killing the enemy by His permission until [the time] when you lost courage and fell to disputing about the order [given by the Prophet] and disobeyed after He had shown you that which you love. Among you are some who desire this world, and among you are some who desire the Hereafter. Then he turned you back from them [defeated] that He might test you. And He has already forgiven you, and Allah is the possessor of bounty for the believers.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cdxlvi{%
[Remember] when you [fled and] climbed [the mountain] without looking aside at anyone while the Messenger was calling you from behind. So Allah repaid you with distress upon distress so you would not grieve for that which had escaped you [of victory and spoils of war] or [for] that which had befallen you [of injury and death]. And Allah is [fully] Acquainted with what you do.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cdxlvii{%
Then after distress, He sent down upon you security [in the form of] drowsiness, overcoming a faction of you, while another faction worried about themselves, thinking of Allah other than the truth - the thought of ignorance, saying, ``Is there anything for us [to have done] in this matter?" Say, ``Indeed, the matter belongs completely to Allah." They conceal within themselves what they will not reveal to you. They say, ``If there was anything we could have done in the matter, some of us would not have been killed right here." Say, ``Even if you had been inside your houses, those decreed to be killed would have come out to their death beds." [It was] so that Allah might test what is in your breasts and purify what is in your hearts. And Allah is Knowing of that within the breasts.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cdxlviii{%
Indeed, those of you who turned back on the day the two armies met, it was Satan who caused them to slip because of some [blame] they had earned. But Allah has already forgiven them. Indeed, Allah is Forgiving and Forbearing.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cdxlix{%
O you who have believed, do not be like those who disbelieved and said about their brothers when they traveled through the land or went out to fight, ``If they had been with us, they would not have died or have been killed," so Allah makes that [misconception] a regret within their hearts. And it is Allah who gives life and causes death, and Allah is Seeing of what you do.\qt@no{156}}%
\qt@newcmd\qurantrans@en@cdl{%
And if you are killed in the cause of Allah or die - then forgiveness from Allah and mercy are better than whatever they accumulate [in this world].\qt@no{157}}%
\qt@newcmd\qurantrans@en@cdli{%
And whether you die or are killed, unto Allah you will be gathered.\qt@no{158}}%
\qt@newcmd\qurantrans@en@cdlii{%
So by mercy from Allah, [O Muhammad], you were lenient with them. And if you had been rude [in speech] and harsh in heart, they would have disbanded from about you. So pardon them and ask forgiveness for them and consult them in the matter. And when you have decided, then rely upon Allah. Indeed, Allah loves those who rely [upon Him].\qt@no{159}}%
\qt@newcmd\qurantrans@en@cdliii{%
If Allah should aid you, no one can overcome you; but if He should forsake you, who is there that can aid you after Him? And upon Allah let the believers rely.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cdliv{%
It is not [attributable] to any prophet that he would act unfaithfully [in regard to war booty]. And whoever betrays, [taking unlawfully], will come with what he took on the Day of Resurrection. Then will every soul be [fully] compensated for what it earned, and they will not be wronged.\qt@no{161}}%
\qt@newcmd\qurantrans@en@cdlv{%
So is one who pursues the pleasure of Allah like one who brings upon himself the anger of Allah and whose refuge is Hell? And wretched is the destination.\qt@no{162}}%
\qt@newcmd\qurantrans@en@cdlvi{%
They are [varying] degrees in the sight of Allah, and Allah is Seeing of whatever they do.\qt@no{163}}%
\qt@newcmd\qurantrans@en@cdlvii{%
Certainly did Allah confer [great] favor upon the believers when He sent among them a Messenger from themselves, reciting to them His verses and purifying them and teaching them the Book and wisdom, although they had been before in manifest error.\qt@no{164}}%
\qt@newcmd\qurantrans@en@cdlviii{%
Why [is it that] when a [single] disaster struck you [on the day of Uhud], although you had struck [the enemy in the battle of Badr] with one twice as great, you said, ``From where is this?" Say, ``It is from yourselves." Indeed, Allah is over all things competent.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cdlix{%
And what struck you on the day the two armies met was by permission of Allah that He might make evident the [true] believers.\qt@no{166}}%
\qt@newcmd\qurantrans@en@cdlx{%
And that He might make evident those who are hypocrites. For it was said to them, ``Come, fight in the way of Allah or [at least] defend." They said, ``If we had known [there would be] fighting, we would have followed you." They were nearer to disbelief that day than to faith, saying with their mouths what was not in their hearts. And Allah is most Knowing of what they conceal -\qt@no{167}}%
\qt@newcmd\qurantrans@en@cdlxi{%
Those who said about their brothers while sitting [at home], ``If they had obeyed us, they would not have been killed." Say, ``Then prevent death from yourselves, if you should be truthful."\qt@no{168}}%
\qt@newcmd\qurantrans@en@cdlxii{%
And never think of those who have been killed in the cause of Allah as dead. Rather, they are alive with their Lord, receiving provision,\qt@no{169}}%
\qt@newcmd\qurantrans@en@cdlxiii{%
Rejoicing in what Allah has bestowed upon them of His bounty, and they receive good tidings about those [to be martyred] after them who have not yet joined them - that there will be no fear concerning them, nor will they grieve.\qt@no{170}}%
\qt@newcmd\qurantrans@en@cdlxiv{%
They receive good tidings of favor from Allah and bounty and [of the fact] that Allah does not allow the reward of believers to be lost -\qt@no{171}}%
\qt@newcmd\qurantrans@en@cdlxv{%
Those [believers] who responded to Allah and the Messenger after injury had struck them. For those who did good among them and feared Allah is a great reward -\qt@no{172}}%
\qt@newcmd\qurantrans@en@cdlxvi{%
Those to whom hypocrites said, ``Indeed, the people have gathered against you, so fear them." But it [merely] increased them in faith, and they said, ``Sufficient for us is Allah, and [He is] the best Disposer of affairs."\qt@no{173}}%
\qt@newcmd\qurantrans@en@cdlxvii{%
So they returned with favor from Allah and bounty, no harm having touched them. And they pursued the pleasure of Allah, and Allah is the possessor of great bounty.\qt@no{174}}%
\qt@newcmd\qurantrans@en@cdlxviii{%
That is only Satan who frightens [you] of his supporters. So fear them not, but fear Me, if you are [indeed] believers.\qt@no{175}}%
\qt@newcmd\qurantrans@en@cdlxix{%
And do not be grieved, [O Muhammad], by those who hasten into disbelief. Indeed, they will never harm Allah at all. Allah intends that He should give them no share in the Hereafter, and for them is a great punishment.\qt@no{176}}%
\qt@newcmd\qurantrans@en@cdlxx{%
Indeed, those who purchase disbelief [in exchange] for faith - never will they harm Allah at all, and for them is a painful punishment.\qt@no{177}}%
\qt@newcmd\qurantrans@en@cdlxxi{%
And let not those who disbelieve ever think that [because] We extend their time [of enjoyment] it is better for them. We only extend it for them so that they may increase in sin, and for them is a humiliating punishment.\qt@no{178}}%
\qt@newcmd\qurantrans@en@cdlxxii{%
Allah would not leave the believers in that [state] you are in [presently] until He separates the evil from the good. Nor would Allah reveal to you the unseen. But [instead], Allah chooses of His messengers whom He wills, so believe in Allah and His messengers. And if you believe and fear Him, then for you is a great reward.\qt@no{179}}%
\qt@newcmd\qurantrans@en@cdlxxiii{%
And let not those who [greedily] withhold what Allah has given them of His bounty ever think that it is better for them. Rather, it is worse for them. Their necks will be encircled by what they withheld on the Day of Resurrection. And to Allah belongs the heritage of the heavens and the earth. And Allah, with what you do, is [fully] Acquainted.\qt@no{180}}%
\qt@newcmd\qurantrans@en@cdlxxiv{%
Allah has certainly heard the statement of those [Jews] who said, ``Indeed, Allah is poor, while we are rich." We will record what they said and their killing of the prophets without right and will say, ``Taste the punishment of the Burning Fire.\qt@no{181}}%
\qt@newcmd\qurantrans@en@cdlxxv{%
That is for what your hands have put forth and because Allah is not ever unjust to [His] servants."\qt@no{182}}%
\qt@newcmd\qurantrans@en@cdlxxvi{%
[They are] those who said, ``Indeed, Allah has taken our promise not to believe any messenger until he brings us an offering which fire [from heaven] will consume." Say, ``There have already come to you messengers before me with clear proofs and [even] that of which you speak. So why did you kill them, if you should be truthful?"\qt@no{183}}%
\qt@newcmd\qurantrans@en@cdlxxvii{%
Then if they deny you, [O Muhammad] - so were messengers denied before you, who brought clear proofs and written ordinances and the enlightening Scripture.\qt@no{184}}%
\qt@newcmd\qurantrans@en@cdlxxviii{%
Every soul will taste death, and you will only be given your [full] compensation on the Day of Resurrection. So he who is drawn away from the Fire and admitted to Paradise has attained [his desire]. And what is the life of this world except the enjoyment of delusion.\qt@no{185}}%
\qt@newcmd\qurantrans@en@cdlxxix{%
You will surely be tested in your possessions and in yourselves. And you will surely hear from those who were given the Scripture before you and from those who associate others with Allah much abuse. But if you are patient and fear Allah - indeed, that is of the matters [worthy] of determination.\qt@no{186}}%
\qt@newcmd\qurantrans@en@cdlxxx{%
And [mention, O Muhammad], when Allah took a covenant from those who were given the Scripture, [saying], ``You must make it clear to the people and not conceal it." But they threw it away behind their backs and exchanged it for a small price. And wretched is that which they purchased.\qt@no{187}}%
\qt@newcmd\qurantrans@en@cdlxxxi{%
And never think that those who rejoice in what they have perpetrated and like to be praised for what they did not do - never think them [to be] in safety from the punishment, and for them is a painful punishment.\qt@no{188}}%
\qt@newcmd\qurantrans@en@cdlxxxii{%
And to Allah belongs the dominion of the heavens and the earth, and Allah is over all things competent.\qt@no{189}}%
\qt@newcmd\qurantrans@en@cdlxxxiii{%
Indeed, in the creation of the heavens and the earth and the alternation of the night and the day are signs for those of understanding.\qt@no{190}}%
\qt@newcmd\qurantrans@en@cdlxxxiv{%
Who remember Allah while standing or sitting or [lying] on their sides and give thought to the creation of the heavens and the earth, [saying], ``Our Lord, You did not create this aimlessly; exalted are You [above such a thing]; then protect us from the punishment of the Fire.\qt@no{191}}%
\qt@newcmd\qurantrans@en@cdlxxxv{%
Our Lord, indeed whoever You admit to the Fire - You have disgraced him, and for the wrongdoers there are no helpers.\qt@no{192}}%
\qt@newcmd\qurantrans@en@cdlxxxvi{%
Our Lord, indeed we have heard a caller calling to faith, [saying], 'Believe in your Lord,' and we have believed. Our Lord, so forgive us our sins and remove from us our misdeeds and cause us to die with the righteous.\qt@no{193}}%
\qt@newcmd\qurantrans@en@cdlxxxvii{%
Our Lord, and grant us what You promised us through Your messengers and do not disgrace us on the Day of Resurrection. Indeed, You do not fail in [Your] promise."\qt@no{194}}%
\qt@newcmd\qurantrans@en@cdlxxxviii{%
And their Lord responded to them, ``Never will I allow to be lost the work of [any] worker among you, whether male or female; you are of one another. So those who emigrated or were evicted from their homes or were harmed in My cause or fought or were killed - I will surely remove from them their misdeeds, and I will surely admit them to gardens beneath which rivers flow as reward from Allah, and Allah has with Him the best reward."\qt@no{195}}%
\qt@newcmd\qurantrans@en@cdlxxxix{%
Be not deceived by the [uninhibited] movement of the disbelievers throughout the land.\qt@no{196}}%
\qt@newcmd\qurantrans@en@cdxc{%
[It is but] a small enjoyment; then their [final] refuge is Hell, and wretched is the resting place.\qt@no{197}}%
\qt@newcmd\qurantrans@en@cdxci{%
But those who feared their Lord will have gardens beneath which rivers flow, abiding eternally therein, as accommodation from Allah. And that which is with Allah is best for the righteous.\qt@no{198}}%
\qt@newcmd\qurantrans@en@cdxcii{%
And indeed, among the People of the Scripture are those who believe in Allah and what was revealed to you and what was revealed to them, [being] humbly submissive to Allah. They do not exchange the verses of Allah for a small price. Those will have their reward with their Lord. Indeed, Allah is swift in account.\qt@no{199}}%
\qt@newcmd\qurantrans@en@cdxciii{%
O you who have believed, persevere and endure and remain stationed and fear Allah that you may be successful.\qt@no{200}}%
\qt@newcmd\qurantrans@en@cdxciv{%
\basmalahen O mankind, fear your Lord, who created you from one soul and created from it its mate and dispersed from both of them many men and women. And fear Allah, through whom you ask one another, and the wombs. Indeed Allah is ever, over you, an Observer.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cdxcv{%
And give to the orphans their properties and do not substitute the defective [of your own] for the good [of theirs]. And do not consume their properties into your own. Indeed, that is ever a great sin.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cdxcvi{%
And if you fear that you will not deal justly with the orphan girls, then marry those that please you of [other] women, two or three or four. But if you fear that you will not be just, then [marry only] one or those your right hand possesses. That is more suitable that you may not incline [to injustice].\qt@no{3}}%
\qt@newcmd\qurantrans@en@cdxcvii{%
And give the women [upon marriage] their [bridal] gifts graciously. But if they give up willingly to you anything of it, then take it in satisfaction and ease.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cdxcviii{%
And do not give the weak-minded your property, which Allah has made a means of sustenance for you, but provide for them with it and clothe them and speak to them words of appropriate kindness.\qt@no{5}}%
\qt@newcmd\qurantrans@en@cdxcix{%
And test the orphans [in their abilities] until they reach marriageable age. Then if you perceive in them sound judgement, release their property to them. And do not consume it excessively and quickly, [anticipating] that they will grow up. And whoever, [when acting as guardian], is self-sufficient should refrain [from taking a fee]; and whoever is poor - let him take according to what is acceptable. Then when you release their property to them, bring witnesses upon them. And sufficient is Allah as Accountant.\qt@no{6}}%
\qt@newcmd\qurantrans@en@d{%
For men is a share of what the parents and close relatives leave, and for women is a share of what the parents and close relatives leave, be it little or much - an obligatory share.\qt@no{7}}%
\qt@newcmd\qurantrans@en@di{%
And when [other] relatives and orphans and the needy are present at the [time of] division, then provide for them [something] out of the estate and speak to them words of appropriate kindness.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dii{%
And let those [executors and guardians] fear [injustice] as if they [themselves] had left weak offspring behind and feared for them. So let them fear Allah and speak words of appropriate justice.\qt@no{9}}%
\qt@newcmd\qurantrans@en@diii{%
Indeed, those who devour the property of orphans unjustly are only consuming into their bellies fire. And they will be burned in a Blaze.\qt@no{10}}%
\qt@newcmd\qurantrans@en@div{%
Allah instructs you concerning your children: for the male, what is equal to the share of two females. But if there are [only] daughters, two or more, for them is two thirds of one's estate. And if there is only one, for her is half. And for one's parents, to each one of them is a sixth of his estate if he left children. But if he had no children and the parents [alone] inherit from him, then for his mother is one third. And if he had brothers [or sisters], for his mother is a sixth, after any bequest he [may have] made or debt. Your parents or your children - you know not which of them are nearest to you in benefit. [These shares are] an obligation [imposed] by Allah. Indeed, Allah is ever Knowing and Wise.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dv{%
And for you is half of what your wives leave if they have no child. But if they have a child, for you is one fourth of what they leave, after any bequest they [may have] made or debt. And for the wives is one fourth if you leave no child. But if you leave a child, then for them is an eighth of what you leave, after any bequest you [may have] made or debt. And if a man or woman leaves neither ascendants nor descendants but has a brother or a sister, then for each one of them is a sixth. But if they are more than two, they share a third, after any bequest which was made or debt, as long as there is no detriment [caused]. [This is] an ordinance from Allah, and Allah is Knowing and Forbearing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dvi{%
These are the limits [set by] Allah, and whoever obeys Allah and His Messenger will be admitted by Him to gardens [in Paradise] under which rivers flow, abiding eternally therein; and that is the great attainment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dvii{%
And whoever disobeys Allah and His Messenger and transgresses His limits - He will put him into the Fire to abide eternally therein, and he will have a humiliating punishment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dviii{%
Those who commit unlawful sexual intercourse of your women - bring against them four [witnesses] from among you. And if they testify, confine the guilty women to houses until death takes them or Allah ordains for them [another] way.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dix{%
And the two who commit it among you, dishonor them both. But if they repent and correct themselves, leave them alone. Indeed, Allah is ever Accepting of repentance and Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dx{%
The repentance accepted by Allah is only for those who do wrong in ignorance [or carelessness] and then repent soon after. It is those to whom Allah will turn in forgiveness, and Allah is ever Knowing and Wise.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dxi{%
But repentance is not [accepted] of those who [continue to] do evil deeds up until, when death comes to one of them, he says, ``Indeed, I have repented now," or of those who die while they are disbelievers. For them We have prepared a painful punishment.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dxii{%
O you who have believed, it is not lawful for you to inherit women by compulsion. And do not make difficulties for them in order to take [back] part of what you gave them unless they commit a clear immorality. And live with them in kindness. For if you dislike them - perhaps you dislike a thing and Allah makes therein much good.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dxiii{%
But if you want to replace one wife with another and you have given one of them a great amount [in gifts], do not take [back] from it anything. Would you take it in injustice and manifest sin?\qt@no{20}}%
\qt@newcmd\qurantrans@en@dxiv{%
And how could you take it while you have gone in unto each other and they have taken from you a solemn covenant?\qt@no{21}}%
\qt@newcmd\qurantrans@en@dxv{%
And do not marry those [women] whom your fathers married, except what has already occurred. Indeed, it was an immorality and hateful [to Allah] and was evil as a way.\qt@no{22}}%
\qt@newcmd\qurantrans@en@dxvi{%
Prohibited to you [for marriage] are your mothers, your daughters, your sisters, your father's sisters, your mother's sisters, your brother's daughters, your sister's daughters, your [milk] mothers who nursed you, your sisters through nursing, your wives' mothers, and your step-daughters under your guardianship [born] of your wives unto whom you have gone in. But if you have not gone in unto them, there is no sin upon you. And [also prohibited are] the wives of your sons who are from your [own] loins, and that you take [in marriage] two sisters simultaneously, except for what has already occurred. Indeed, Allah is ever Forgiving and Merciful.\qt@no{23}}%
\qt@newcmd\qurantrans@en@dxvii{%
And [also prohibited to you are all] married women except those your right hands possess. [This is] the decree of Allah upon you. And lawful to you are [all others] beyond these, [provided] that you seek them [in marriage] with [gifts from] your property, desiring chastity, not unlawful sexual intercourse. So for whatever you enjoy [of marriage] from them, give them their due compensation as an obligation. And there is no blame upon you for what you mutually agree to beyond the obligation. Indeed, Allah is ever Knowing and Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dxviii{%
And whoever among you cannot [find] the means to marry free, believing women, then [he may marry] from those whom your right hands possess of believing slave girls. And Allah is most knowing about your faith. You [believers] are of one another. So marry them with the permission of their people and give them their due compensation according to what is acceptable. [They should be] chaste, neither [of] those who commit unlawful intercourse randomly nor those who take [secret] lovers. But once they are sheltered in marriage, if they should commit adultery, then for them is half the punishment for free [unmarried] women. This [allowance] is for him among you who fears sin, but to be patient is better for you. And Allah is Forgiving and Merciful.\qt@no{25}}%
\qt@newcmd\qurantrans@en@dxix{%
Allah wants to make clear to you [the lawful from the unlawful] and guide you to the [good] practices of those before you and to accept your repentance. And Allah is Knowing and Wise.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dxx{%
Allah wants to accept your repentance, but those who follow [their] passions want you to digress [into] a great deviation.\qt@no{27}}%
\qt@newcmd\qurantrans@en@dxxi{%
And Allah wants to lighten for you [your difficulties]; and mankind was created weak.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dxxii{%
O you who have believed, do not consume one another's wealth unjustly but only [in lawful] business by mutual consent. And do not kill yourselves [or one another]. Indeed, Allah is to you ever Merciful.\qt@no{29}}%
\qt@newcmd\qurantrans@en@dxxiii{%
And whoever does that in aggression and injustice - then We will drive him into a Fire. And that, for Allah, is [always] easy.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dxxiv{%
If you avoid the major sins which you are forbidden, We will remove from you your lesser sins and admit you to a noble entrance [into Paradise].\qt@no{31}}%
\qt@newcmd\qurantrans@en@dxxv{%
And do not wish for that by which Allah has made some of you exceed others. For men is a share of what they have earned, and for women is a share of what they have earned. And ask Allah of his bounty. Indeed Allah is ever, of all things, Knowing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dxxvi{%
And for all, We have made heirs to what is left by parents and relatives. And to those whom your oaths have bound [to you] - give them their share. Indeed Allah is ever, over all things, a Witness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dxxvii{%
Men are in charge of women by [right of] what Allah has given one over the other and what they spend [for maintenance] from their wealth. So righteous women are devoutly obedient, guarding in [the husband's] absence what Allah would have them guard. But those [wives] from whom you fear arrogance - [first] advise them; [then if they persist], forsake them in bed; and [finally], strike them. But if they obey you [once more], seek no means against them. Indeed, Allah is ever Exalted and Grand.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dxxviii{%
And if you fear dissension between the two, send an arbitrator from his people and an arbitrator from her people. If they both desire reconciliation, Allah will cause it between them. Indeed, Allah is ever Knowing and Acquainted [with all things].\qt@no{35}}%
\qt@newcmd\qurantrans@en@dxxix{%
Worship Allah and associate nothing with Him, and to parents do good, and to relatives, orphans, the needy, the near neighbor, the neighbor farther away, the companion at your side, the traveler, and those whom your right hands possess. Indeed, Allah does not like those who are self-deluding and boastful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dxxx{%
Who are stingy and enjoin upon [other] people stinginess and conceal what Allah has given them of His bounty - and We have prepared for the disbelievers a humiliating punishment -\qt@no{37}}%
\qt@newcmd\qurantrans@en@dxxxi{%
And [also] those who spend of their wealth to be seen by the people and believe not in Allah nor in the Last Day. And he to whom Satan is a companion - then evil is he as a companion.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dxxxii{%
And what [harm would come] upon them if they believed in Allah and the Last Day and spent out of what Allah provided for them? And Allah is ever, about them, Knowing.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dxxxiii{%
Indeed, Allah does not do injustice, [even] as much as an atom's weight; while if there is a good deed, He multiplies it and gives from Himself a great reward.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dxxxiv{%
So how [will it be] when We bring from every nation a witness and we bring you, [O Muhammad] against these [people] as a witness?\qt@no{41}}%
\qt@newcmd\qurantrans@en@dxxxv{%
That Day, those who disbelieved and disobeyed the Messenger will wish they could be covered by the earth. And they will not conceal from Allah a [single] statement.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dxxxvi{%
O you who have believed, do not approach prayer while you are intoxicated until you know what you are saying or in a state of janabah, except those passing through [a place of prayer], until you have washed [your whole body]. And if you are ill or on a journey or one of you comes from the place of relieving himself or you have contacted women and find no water, then seek clean earth and wipe over your faces and your hands [with it]. Indeed, Allah is ever Pardoning and Forgiving.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dxxxvii{%
Have you not seen those who were given a portion of the Scripture, purchasing error [in exchange for it] and wishing you would lose the way?\qt@no{44}}%
\qt@newcmd\qurantrans@en@dxxxviii{%
And Allah is most knowing of your enemies; and sufficient is Allah as an ally, and sufficient is Allah as a helper.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dxxxix{%
Among the Jews are those who distort words from their [proper] usages and say, ``We hear and disobey" and ``Hear but be not heard" and ``Ra'ina," twisting their tongues and defaming the religion. And if they had said [instead], ``We hear and obey" and ``Wait for us [to understand]," it would have been better for them and more suitable. But Allah has cursed them for their disbelief, so they believe not, except for a few.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dxl{%
O you who were given the Scripture, believe in what We have sent down [to Muhammad], confirming that which is with you, before We obliterate faces and turn them toward their backs or curse them as We cursed the sabbath-breakers. And ever is the decree of Allah accomplished.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dxli{%
Indeed, Allah does not forgive association with Him, but He forgives what is less than that for whom He wills. And he who associates others with Allah has certainly fabricated a tremendous sin.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dxlii{%
Have you not seen those who claim themselves to be pure? Rather, Allah purifies whom He wills, and injustice is not done to them, [even] as much as a thread [inside a date seed].\qt@no{49}}%
\qt@newcmd\qurantrans@en@dxliii{%
Look how they invent about Allah untruth, and sufficient is that as a manifest sin.\qt@no{50}}%
\qt@newcmd\qurantrans@en@dxliv{%
Have you not seen those who were given a portion of the Scripture, who believe in superstition and false objects of worship and say about the disbelievers, ``These are better guided than the believers as to the way"?\qt@no{51}}%
\qt@newcmd\qurantrans@en@dxlv{%
Those are the ones whom Allah has cursed; and he whom Allah curses - never will you find for him a helper.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dxlvi{%
Or have they a share of dominion? Then [if that were so], they would not give the people [even as much as] the speck on a date seed.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dxlvii{%
Or do they envy people for what Allah has given them of His bounty? But we had already given the family of Abraham the Scripture and wisdom and conferred upon them a great kingdom.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dxlviii{%
And some among them believed in it, and some among them were averse to it. And sufficient is Hell as a blaze.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dxlix{%
Indeed, those who disbelieve in Our verses - We will drive them into a Fire. Every time their skins are roasted through We will replace them with other skins so they may taste the punishment. Indeed, Allah is ever Exalted in Might and Wise.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dl{%
But those who believe and do righteous deeds - We will admit them to gardens beneath which rivers flow, wherein they abide forever. For them therein are purified spouses, and We will admit them to deepening shade.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dli{%
Indeed, Allah commands you to render trusts to whom they are due and when you judge between people to judge with justice. Excellent is that which Allah instructs you. Indeed, Allah is ever Hearing and Seeing.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dlii{%
O you who have believed, obey Allah and obey the Messenger and those in authority among you. And if you disagree over anything, refer it to Allah and the Messenger, if you should believe in Allah and the Last Day. That is the best [way] and best in result.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dliii{%
Have you not seen those who claim to have believed in what was revealed to you, [O Muhammad], and what was revealed before you? They wish to refer legislation to Taghut, while they were commanded to reject it; and Satan wishes to lead them far astray.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dliv{%
And when it is said to them, ``Come to what Allah has revealed and to the Messenger," you see the hypocrites turning away from you in aversion.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dlv{%
So how [will it be] when disaster strikes them because of what their hands have put forth and then they come to you swearing by Allah, ``We intended nothing but good conduct and accommodation."\qt@no{62}}%
\qt@newcmd\qurantrans@en@dlvi{%
Those are the ones of whom Allah knows what is in their hearts, so turn away from them but admonish them and speak to them a far-reaching word.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dlvii{%
And We did not send any messenger except to be obeyed by permission of Allah. And if, when they wronged themselves, they had come to you, [O Muhammad], and asked forgiveness of Allah and the Messenger had asked forgiveness for them, they would have found Allah Accepting of repentance and Merciful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dlviii{%
But no, by your Lord, they will not [truly] believe until they make you, [O Muhammad], judge concerning that over which they dispute among themselves and then find within themselves no discomfort from what you have judged and submit in [full, willing] submission.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dlix{%
And if We had decreed upon them, ``Kill yourselves" or ``Leave your homes," they would not have done it, except for a few of them. But if they had done what they were instructed, it would have been better for them and a firmer position [for them in faith].\qt@no{66}}%
\qt@newcmd\qurantrans@en@dlx{%
And then We would have given them from Us a great reward.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dlxi{%
And We would have guided them to a straight path.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dlxii{%
And whoever obeys Allah and the Messenger - those will be with the ones upon whom Allah has bestowed favor of the prophets, the steadfast affirmers of truth, the martyrs and the righteous. And excellent are those as companions.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dlxiii{%
That is the bounty from Allah, and sufficient is Allah as Knower.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dlxiv{%
O you who have believed, take your precaution and [either] go forth in companies or go forth all together.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dlxv{%
And indeed, there is among you he who lingers behind; and if disaster strikes you, he says, ``Allah has favored me in that I was not present with them."\qt@no{72}}%
\qt@newcmd\qurantrans@en@dlxvi{%
But if bounty comes to you from Allah, he will surely say, as if there had never been between you and him any affection. ``Oh, I wish I had been with them so I could have attained a great attainment."\qt@no{73}}%
\qt@newcmd\qurantrans@en@dlxvii{%
So let those fight in the cause of Allah who sell the life of this world for the Hereafter. And he who fights in the cause of Allah and is killed or achieves victory - We will bestow upon him a great reward.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dlxviii{%
And what is [the matter] with you that you fight not in the cause of Allah and [for] the oppressed among men, women, and children who say, ``Our Lord, take us out of this city of oppressive people and appoint for us from Yourself a protector and appoint for us from Yourself a helper?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@dlxix{%
Those who believe fight in the cause of Allah, and those who disbelieve fight in the cause of Taghut. So fight against the allies of Satan. Indeed, the plot of Satan has ever been weak.\qt@no{76}}%
\qt@newcmd\qurantrans@en@dlxx{%
Have you not seen those who were told, ``Restrain your hands [from fighting] and establish prayer and give zakah"? But then when fighting was ordained for them, at once a party of them feared men as they fear Allah or with [even] greater fear. They said, ``Our Lord, why have You decreed upon us fighting? If only You had postponed [it for] us for a short time." Say, The enjoyment of this world is little, and the Hereafter is better for he who fears Allah. And injustice will not be done to you, [even] as much as a thread [inside a date seed]."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dlxxi{%
Wherever you may be, death will overtake you, even if you should be within towers of lofty construction. But if good comes to them, they say, ``This is from Allah ``; and if evil befalls them, they say, ``This is from you." Say, ``All [things] are from Allah." So what is [the matter] with those people that they can hardly understand any statement?\qt@no{78}}%
\qt@newcmd\qurantrans@en@dlxxii{%
What comes to you of good is from Allah, but what comes to you of evil, [O man], is from yourself. And We have sent you, [O Muhammad], to the people as a messenger, and sufficient is Allah as Witness.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dlxxiii{%
He who obeys the Messenger has obeyed Allah; but those who turn away - We have not sent you over them as a guardian.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dlxxiv{%
And they say, ``[We pledge] obedience." But when they leave you, a group of them spend the night determining to do other than what you say. But Allah records what they plan by night. So leave them alone and rely upon Allah. And sufficient is Allah as Disposer of affairs.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dlxxv{%
Then do they not reflect upon the Qur'an? If it had been from [any] other than Allah, they would have found within it much contradiction.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dlxxvi{%
And when there comes to them information about [public] security or fear, they spread it around. But if they had referred it back to the Messenger or to those of authority among them, then the ones who [can] draw correct conclusions from it would have known about it. And if not for the favor of Allah upon you and His mercy, you would have followed Satan, except for a few.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dlxxvii{%
So fight, [O Muhammad], in the cause of Allah; you are not held responsible except for yourself. And encourage the believers [to join you] that perhaps Allah will restrain the [military] might of those who disbelieve. And Allah is greater in might and stronger in [exemplary] punishment.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dlxxviii{%
Whoever intercedes for a good cause will have a reward therefrom; and whoever intercedes for an evil cause will have a burden therefrom. And ever is Allah, over all things, a Keeper.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dlxxix{%
And when you are greeted with a greeting, greet [in return] with one better than it or [at least] return it [in a like manner]. Indeed, Allah is ever, over all things, an Accountant.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dlxxx{%
Allah - there is no deity except Him. He will surely assemble you for [account on] the Day of Resurrection, about which there is no doubt. And who is more truthful than Allah in statement.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dlxxxi{%
What is [the matter] with you [that you are] two groups concerning the hypocrites, while Allah has made them fall back [into error and disbelief] for what they earned. Do you wish to guide those whom Allah has sent astray? And he whom Allah sends astray - never will you find for him a way [of guidance].\qt@no{88}}%
\qt@newcmd\qurantrans@en@dlxxxii{%
They wish you would disbelieve as they disbelieved so you would be alike. So do not take from among them allies until they emigrate for the cause of Allah. But if they turn away, then seize them and kill them wherever you find them and take not from among them any ally or helper.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dlxxxiii{%
Except for those who take refuge with a people between yourselves and whom is a treaty or those who come to you, their hearts strained at [the prospect of] fighting you or fighting their own people. And if Allah had willed, He could have given them power over you, and they would have fought you. So if they remove themselves from you and do not fight you and offer you peace, then Allah has not made for you a cause [for fighting] against them.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dlxxxiv{%
You will find others who wish to obtain security from you and [to] obtain security from their people. Every time they are returned to [the influence of] disbelief, they fall back into it. So if they do not withdraw from you or offer you peace or restrain their hands, then seize them and kill them wherever you overtake them. And those - We have made for you against them a clear authorization.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dlxxxv{%
And never is it for a believer to kill a believer except by mistake. And whoever kills a believer by mistake - then the freeing of a believing slave and a compensation payment presented to the deceased's family [is required] unless they give [up their right as] charity. But if the deceased was from a people at war with you and he was a believer - then [only] the freeing of a believing slave; and if he was from a people with whom you have a treaty - then a compensation payment presented to his family and the freeing of a believing slave. And whoever does not find [one or cannot afford to buy one] - then [instead], a fast for two months consecutively, [seeking] acceptance of repentance from Allah. And Allah is ever Knowing and Wise.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dlxxxvi{%
But whoever kills a believer intentionally - his recompense is Hell, wherein he will abide eternally, and Allah has become angry with him and has cursed him and has prepared for him a great punishment.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dlxxxvii{%
O you who have believed, when you go forth [to fight] in the cause of Allah, investigate; and do not say to one who gives you [a greeting of] peace ``You are not a believer," aspiring for the goods of worldly life; for with Allah are many acquisitions. You [yourselves] were like that before; then Allah conferred His favor upon you, so investigate. Indeed Allah is ever, with what you do, Acquainted.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dlxxxviii{%
Not equal are those believers remaining [at home] - other than the disabled - and the mujahideen, [who strive and fight] in the cause of Allah with their wealth and their lives. Allah has preferred the mujahideen through their wealth and their lives over those who remain [behind], by degrees. And to both Allah has promised the best [reward]. But Allah has preferred the mujahideen over those who remain [behind] with a great reward -\qt@no{95}}%
\qt@newcmd\qurantrans@en@dlxxxix{%
Degrees [of high position] from Him and forgiveness and mercy. And Allah is ever Forgiving and Merciful.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dxc{%
Indeed, those whom the angels take [in death] while wronging themselves - [the angels] will say, ``In what [condition] were you?" They will say, ``We were oppressed in the land." The angels will say, ``Was not the earth of Allah spacious [enough] for you to emigrate therein?" For those, their refuge is Hell - and evil it is as a destination.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dxci{%
Except for the oppressed among men, women and children who cannot devise a plan nor are they directed to a way -\qt@no{98}}%
\qt@newcmd\qurantrans@en@dxcii{%
For those it is expected that Allah will pardon them, and Allah is ever Pardoning and Forgiving.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dxciii{%
And whoever emigrates for the cause of Allah will find on the earth many [alternative] locations and abundance. And whoever leaves his home as an emigrant to Allah and His Messenger and then death overtakes him - his reward has already become incumbent upon Allah. And Allah is ever Forgiving and Merciful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dxciv{%
And when you travel throughout the land, there is no blame upon you for shortening the prayer, [especially] if you fear that those who disbelieve may disrupt [or attack] you. Indeed, the disbelievers are ever to you a clear enemy.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dxcv{%
And when you are among them and lead them in prayer, let a group of them stand [in prayer] with you and let them carry their arms. And when they have prostrated, let them be [in position] behind you and have the other group come forward which has not [yet] prayed and let them pray with you, taking precaution and carrying their arms. Those who disbelieve wish that you would neglect your weapons and your baggage so they could come down upon you in one [single] attack. But there is no blame upon you, if you are troubled by rain or are ill, for putting down your arms, but take precaution. Indeed, Allah has prepared for the disbelievers a humiliating punishment.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dxcvi{%
And when you have completed the prayer, remember Allah standing, sitting, or [lying] on your sides. But when you become secure, re-establish [regular] prayer. Indeed, prayer has been decreed upon the believers a decree of specified times.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dxcvii{%
And do not weaken in pursuit of the enemy. If you should be suffering - so are they suffering as you are suffering, but you expect from Allah that which they expect not. And Allah is ever Knowing and Wise.\qt@no{104}}%
\qt@newcmd\qurantrans@en@dxcviii{%
Indeed, We have revealed to you, [O Muhammad], the Book in truth so you may judge between the people by that which Allah has shown you. And do not be for the deceitful an advocate.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dxcix{%
And seek forgiveness of Allah. Indeed, Allah is ever Forgiving and Merciful.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dc{%
And do not argue on behalf of those who deceive themselves. Indeed, Allah loves not one who is a habitually sinful deceiver.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dci{%
They conceal [their evil intentions and deeds] from the people, but they cannot conceal [them] from Allah, and He is with them [in His knowledge] when they spend the night in such as He does not accept of speech. And ever is Allah, of what they do, encompassing.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcii{%
Here you are - those who argue on their behalf in [this] worldly life - but who will argue with Allah for them on the Day of Resurrection, or who will [then] be their representative?\qt@no{109}}%
\qt@newcmd\qurantrans@en@dciii{%
And whoever does a wrong or wrongs himself but then seeks forgiveness of Allah will find Allah Forgiving and Merciful.\qt@no{110}}%
\qt@newcmd\qurantrans@en@dciv{%
And whoever commits a sin only earns it against himself. And Allah is ever Knowing and Wise.\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcv{%
But whoever earns an offense or a sin and then blames it on an innocent [person] has taken upon himself a slander and manifest sin.\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcvi{%
And if it was not for the favor of Allah upon you, [O Muhammad], and His mercy, a group of them would have determined to mislead you. But they do not mislead except themselves, and they will not harm you at all. And Allah has revealed to you the Book and wisdom and has taught you that which you did not know. And ever has the favor of Allah upon you been great.\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcvii{%
No good is there in much of their private conversation, except for those who enjoin charity or that which is right or conciliation between people. And whoever does that seeking means to the approval of Allah - then We are going to give him a great reward.\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcviii{%
And whoever opposes the Messenger after guidance has become clear to him and follows other than the way of the believers - We will give him what he has taken and drive him into Hell, and evil it is as a destination.\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcix{%
Indeed, Allah does not forgive association with Him, but He forgives what is less than that for whom He wills. And he who associates others with Allah has certainly gone far astray.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcx{%
They call upon instead of Him none but female [deities], and they [actually] call upon none but a rebellious Satan.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcxi{%
Whom Allah has cursed. For he had said, ``I will surely take from among Your servants a specific portion.\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcxii{%
And I will mislead them, and I will arouse in them [sinful] desires, and I will command them so they will slit the ears of cattle, and I will command them so they will change the creation of Allah." And whoever takes Satan as an ally instead of Allah has certainly sustained a clear loss.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcxiii{%
Satan promises them and arouses desire in them. But Satan does not promise them except delusion.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dcxiv{%
The refuge of those will be Hell, and they will not find from it an escape.\qt@no{121}}%
\qt@newcmd\qurantrans@en@dcxv{%
But the ones who believe and do righteous deeds - We will admit them to gardens beneath which rivers flow, wherein they will abide forever. [It is] the promise of Allah, [which is] truth, and who is more truthful than Allah in statement.\qt@no{122}}%
\qt@newcmd\qurantrans@en@dcxvi{%
Paradise is not [obtained] by your wishful thinking nor by that of the People of the Scripture. Whoever does a wrong will be recompensed for it, and he will not find besides Allah a protector or a helper.\qt@no{123}}%
\qt@newcmd\qurantrans@en@dcxvii{%
And whoever does righteous deeds, whether male or female, while being a believer - those will enter Paradise and will not be wronged, [even as much as] the speck on a date seed.\qt@no{124}}%
\qt@newcmd\qurantrans@en@dcxviii{%
And who is better in religion than one who submits himself to Allah while being a doer of good and follows the religion of Abraham, inclining toward truth? And Allah took Abraham as an intimate friend.\qt@no{125}}%
\qt@newcmd\qurantrans@en@dcxix{%
And to Allah belongs whatever is in the heavens and whatever is on the earth. And ever is Allah, of all things, encompassing.\qt@no{126}}%
\qt@newcmd\qurantrans@en@dcxx{%
And they request from you, [O Muhammad], a [legal] ruling concerning women. Say, ``Allah gives you a ruling about them and [about] what has been recited to you in the Book concerning the orphan girls to whom you do not give what is decreed for them - and [yet] you desire to marry them - and concerning the oppressed among children and that you maintain for orphans [their rights] in justice." And whatever you do of good - indeed, Allah is ever Knowing of it.\qt@no{127}}%
\qt@newcmd\qurantrans@en@dcxxi{%
And if a woman fears from her husband contempt or evasion, there is no sin upon them if they make terms of settlement between them - and settlement is best. And present in [human] souls is stinginess. But if you do good and fear Allah - then indeed Allah is ever, with what you do, Acquainted.\qt@no{128}}%
\qt@newcmd\qurantrans@en@dcxxii{%
And you will never be able to be equal [in feeling] between wives, even if you should strive [to do so]. So do not incline completely [toward one] and leave another hanging. And if you amend [your affairs] and fear Allah - then indeed, Allah is ever Forgiving and Merciful.\qt@no{129}}%
\qt@newcmd\qurantrans@en@dcxxiii{%
But if they separate [by divorce], Allah will enrich each [of them] from His abundance. And ever is Allah Encompassing and Wise.\qt@no{130}}%
\qt@newcmd\qurantrans@en@dcxxiv{%
And to Allah belongs whatever is in the heavens and whatever is on the earth. And We have instructed those who were given the Scripture before you and yourselves to fear Allah. But if you disbelieve - then to Allah belongs whatever is in the heavens and whatever is on the earth. And ever is Allah Free of need and Praiseworthy.\qt@no{131}}%
\qt@newcmd\qurantrans@en@dcxxv{%
And to Allah belongs whatever is in the heavens and whatever is on the earth. And sufficient is Allah as Disposer of affairs.\qt@no{132}}%
\qt@newcmd\qurantrans@en@dcxxvi{%
If He wills, He can do away with you, O people, and bring others [in your place]. And ever is Allah competent to do that.\qt@no{133}}%
\qt@newcmd\qurantrans@en@dcxxvii{%
Whoever desires the reward of this world - then with Allah is the reward of this world and the Hereafter. And ever is Allah Hearing and Seeing.\qt@no{134}}%
\qt@newcmd\qurantrans@en@dcxxviii{%
O you who have believed, be persistently standing firm in justice, witnesses for Allah, even if it be against yourselves or parents and relatives. Whether one is rich or poor, Allah is more worthy of both. So follow not [personal] inclination, lest you not be just. And if you distort [your testimony] or refuse [to give it], then indeed Allah is ever, with what you do, Acquainted.\qt@no{135}}%
\qt@newcmd\qurantrans@en@dcxxix{%
O you who have believed, believe in Allah and His Messenger and the Book that He sent down upon His Messenger and the Scripture which He sent down before. And whoever disbelieves in Allah, His angels, His books, His messengers, and the Last Day has certainly gone far astray.\qt@no{136}}%
\qt@newcmd\qurantrans@en@dcxxx{%
Indeed, those who have believed then disbelieved, then believed, then disbelieved, and then increased in disbelief - never will Allah forgive them, nor will He guide them to a way.\qt@no{137}}%
\qt@newcmd\qurantrans@en@dcxxxi{%
Give tidings to the hypocrites that there is for them a painful punishment -\qt@no{138}}%
\qt@newcmd\qurantrans@en@dcxxxii{%
Those who take disbelievers as allies instead of the believers. Do they seek with them honor [through power]? But indeed, honor belongs to Allah entirely.\qt@no{139}}%
\qt@newcmd\qurantrans@en@dcxxxiii{%
And it has already come down to you in the Book that when you hear the verses of Allah [recited], they are denied [by them] and ridiculed; so do not sit with them until they enter into another conversation. Indeed, you would then be like them. Indeed Allah will gather the hypocrites and disbelievers in Hell all together -\qt@no{140}}%
\qt@newcmd\qurantrans@en@dcxxxiv{%
Those who wait [and watch] you. Then if you gain a victory from Allah, they say, ``Were we not with you?" But if the disbelievers have a success, they say [to them], ``Did we not gain the advantage over you, but we protected you from the believers?" Allah will judge between [all of] you on the Day of Resurrection, and never will Allah give the disbelievers over the believers a way [to overcome them].\qt@no{141}}%
\qt@newcmd\qurantrans@en@dcxxxv{%
Indeed, the hypocrites [think to] deceive Allah, but He is deceiving them. And when they stand for prayer, they stand lazily, showing [themselves to] the people and not remembering Allah except a little,\qt@no{142}}%
\qt@newcmd\qurantrans@en@dcxxxvi{%
Wavering between them, [belonging] neither to the believers nor to the disbelievers. And whoever Allah leaves astray - never will you find for him a way.\qt@no{143}}%
\qt@newcmd\qurantrans@en@dcxxxvii{%
O you who have believed, do not take the disbelievers as allies instead of the believers. Do you wish to give Allah against yourselves a clear case?\qt@no{144}}%
\qt@newcmd\qurantrans@en@dcxxxviii{%
Indeed, the hypocrites will be in the lowest depths of the Fire - and never will you find for them a helper -\qt@no{145}}%
\qt@newcmd\qurantrans@en@dcxxxix{%
Except for those who repent, correct themselves, hold fast to Allah, and are sincere in their religion for Allah, for those will be with the believers. And Allah is going to give the believers a great reward.\qt@no{146}}%
\qt@newcmd\qurantrans@en@dcxl{%
What would Allah do with your punishment if you are grateful and believe? And ever is Allah Appreciative and Knowing.\qt@no{147}}%
\qt@newcmd\qurantrans@en@dcxli{%
Allah does not like the public mention of evil except by one who has been wronged. And ever is Allah Hearing and Knowing.\qt@no{148}}%
\qt@newcmd\qurantrans@en@dcxlii{%
If [instead] you show [some] good or conceal it or pardon an offense - indeed, Allah is ever Pardoning and Competent.\qt@no{149}}%
\qt@newcmd\qurantrans@en@dcxliii{%
Indeed, those who disbelieve in Allah and His messengers and wish to discriminate between Allah and His messengers and say, ``We believe in some and disbelieve in others," and wish to adopt a way in between -\qt@no{150}}%
\qt@newcmd\qurantrans@en@dcxliv{%
Those are the disbelievers, truly. And We have prepared for the disbelievers a humiliating punishment.\qt@no{151}}%
\qt@newcmd\qurantrans@en@dcxlv{%
But they who believe in Allah and His messengers and do not discriminate between any of them - to those He is going to give their rewards. And ever is Allah Forgiving and Merciful.\qt@no{152}}%
\qt@newcmd\qurantrans@en@dcxlvi{%
The People of the Scripture ask you to bring down to them a book from the heaven. But they had asked of Moses [even] greater than that and said, ``Show us Allah outright," so the thunderbolt struck them for their wrongdoing. Then they took the calf [for worship] after clear evidences had come to them, and We pardoned that. And We gave Moses a clear authority.\qt@no{153}}%
\qt@newcmd\qurantrans@en@dcxlvii{%
And We raised over them the mount for [refusal of] their covenant; and We said to them, ``Enter the gate bowing humbly", and We said to them, ``Do not transgress on the sabbath", and We took from them a solemn covenant.\qt@no{154}}%
\qt@newcmd\qurantrans@en@dcxlviii{%
And [We cursed them] for their breaking of the covenant and their disbelief in the signs of Allah and their killing of the prophets without right and their saying, ``Our hearts are wrapped". Rather, Allah has sealed them because of their disbelief, so they believe not, except for a few.\qt@no{155}}%
\qt@newcmd\qurantrans@en@dcxlix{%
And [We cursed them] for their disbelief and their saying against Mary a great slander,\qt@no{156}}%
\qt@newcmd\qurantrans@en@dcl{%
And [for] their saying, ``Indeed, we have killed the Messiah, Jesus, the son of Mary, the messenger of Allah." And they did not kill him, nor did they crucify him; but [another] was made to resemble him to them. And indeed, those who differ over it are in doubt about it. They have no knowledge of it except the following of assumption. And they did not kill him, for certain.\qt@no{157}}%
\qt@newcmd\qurantrans@en@dcli{%
Rather, Allah raised him to Himself. And ever is Allah Exalted in Might and Wise.\qt@no{158}}%
\qt@newcmd\qurantrans@en@dclii{%
And there is none from the People of the Scripture but that he will surely believe in Jesus before his death. And on the Day of Resurrection he will be against them a witness.\qt@no{159}}%
\qt@newcmd\qurantrans@en@dcliii{%
For wrongdoing on the part of the Jews, We made unlawful for them [certain] good foods which had been lawful to them, and for their averting from the way of Allah many [people],\qt@no{160}}%
\qt@newcmd\qurantrans@en@dcliv{%
And [for] their taking of usury while they had been forbidden from it, and their consuming of the people's wealth unjustly. And we have prepared for the disbelievers among them a painful punishment.\qt@no{161}}%
\qt@newcmd\qurantrans@en@dclv{%
But those firm in knowledge among them and the believers believe in what has been revealed to you, [O Muhammad], and what was revealed before you. And the establishers of prayer [especially] and the givers of zakah and the believers in Allah and the Last Day - those We will give a great reward.\qt@no{162}}%
\qt@newcmd\qurantrans@en@dclvi{%
Indeed, We have revealed to you, [O Muhammad], as We revealed to Noah and the prophets after him. And we revealed to Abraham, Ishmael, Isaac, Jacob, the Descendants, Jesus, Job, Jonah, Aaron, and Solomon, and to David We gave the book [of Psalms].\qt@no{163}}%
\qt@newcmd\qurantrans@en@dclvii{%
And [We sent] messengers about whom We have related [their stories] to you before and messengers about whom We have not related to you. And Allah spoke to Moses with [direct] speech.\qt@no{164}}%
\qt@newcmd\qurantrans@en@dclviii{%
[We sent] messengers as bringers of good tidings and warners so that mankind will have no argument against Allah after the messengers. And ever is Allah Exalted in Might and Wise.\qt@no{165}}%
\qt@newcmd\qurantrans@en@dclix{%
But Allah bears witness to that which He has revealed to you. He has sent it down with His knowledge, and the angels bear witness [as well]. And sufficient is Allah as Witness.\qt@no{166}}%
\qt@newcmd\qurantrans@en@dclx{%
Indeed, those who disbelieve and avert [people] from the way of Allah have certainly gone far astray.\qt@no{167}}%
\qt@newcmd\qurantrans@en@dclxi{%
Indeed, those who disbelieve and commit wrong [or injustice] - never will Allah forgive them, nor will He guide them to a path.\qt@no{168}}%
\qt@newcmd\qurantrans@en@dclxii{%
Except the path of Hell; they will abide therein forever. And that, for Allah, is [always] easy.\qt@no{169}}%
\qt@newcmd\qurantrans@en@dclxiii{%
O Mankind, the Messenger has come to you with the truth from your Lord, so believe; it is better for you. But if you disbelieve - then indeed, to Allah belongs whatever is in the heavens and earth. And ever is Allah Knowing and Wise.\qt@no{170}}%
\qt@newcmd\qurantrans@en@dclxiv{%
O People of the Scripture, do not commit excess in your religion or say about Allah except the truth. The Messiah, Jesus, the son of Mary, was but a messenger of Allah and His word which He directed to Mary and a soul [created at a command] from Him. So believe in Allah and His messengers. And do not say, ``Three"; desist - it is better for you. Indeed, Allah is but one God. Exalted is He above having a son. To Him belongs whatever is in the heavens and whatever is on the earth. And sufficient is Allah as Disposer of affairs.\qt@no{171}}%
\qt@newcmd\qurantrans@en@dclxv{%
Never would the Messiah disdain to be a servant of Allah, nor would the angels near [to Him]. And whoever disdains His worship and is arrogant - He will gather them to Himself all together.\qt@no{172}}%
\qt@newcmd\qurantrans@en@dclxvi{%
And as for those who believed and did righteous deeds, He will give them in full their rewards and grant them extra from His bounty. But as for those who disdained and were arrogant, He will punish them with a painful punishment, and they will not find for themselves besides Allah any protector or helper.\qt@no{173}}%
\qt@newcmd\qurantrans@en@dclxvii{%
O mankind, there has come to you a conclusive proof from your Lord, and We have sent down to you a clear light.\qt@no{174}}%
\qt@newcmd\qurantrans@en@dclxviii{%
So those who believe in Allah and hold fast to Him - He will admit them to mercy from Himself and bounty and guide them to Himself on a straight path.\qt@no{175}}%
\qt@newcmd\qurantrans@en@dclxix{%
They request from you a [legal] ruling. Say, ``Allah gives you a ruling concerning one having neither descendants nor ascendants [as heirs]." If a man dies, leaving no child but [only] a sister, she will have half of what he left. And he inherits from her if she [dies and] has no child. But if there are two sisters [or more], they will have two-thirds of what he left. If there are both brothers and sisters, the male will have the share of two females. Allah makes clear to you [His law], lest you go astray. And Allah is Knowing of all things.\qt@no{176}}%
\qt@newcmd\qurantrans@en@dclxx{%
\basmalahen O you who have believed, fulfill [all] contracts. Lawful for you are the animals of grazing livestock except for that which is recited to you [in this Qur'an] - hunting not being permitted while you are in the state of ihram. Indeed, Allah ordains what He intends.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dclxxi{%
O you who have believed, do not violate the rites of Allah or [the sanctity of] the sacred month or [neglect the marking of] the sacrificial animals and garlanding [them] or [violate the safety of] those coming to the Sacred House seeking bounty from their Lord and [His] approval. But when you come out of ihram, then [you may] hunt. And do not let the hatred of a people for having obstructed you from al-Masjid al-Haram lead you to transgress. And cooperate in righteousness and piety, but do not cooperate in sin and aggression. And fear Allah; indeed, Allah is severe in penalty.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dclxxii{%
Prohibited to you are dead animals, blood, the flesh of swine, and that which has been dedicated to other than Allah, and [those animals] killed by strangling or by a violent blow or by a head-long fall or by the goring of horns, and those from which a wild animal has eaten, except what you [are able to] slaughter [before its death], and those which are sacrificed on stone altars, and [prohibited is] that you seek decision through divining arrows. That is grave disobedience. This day those who disbelieve have despaired of [defeating] your religion; so fear them not, but fear Me. This day I have perfected for you your religion and completed My favor upon you and have approved for you Islam as religion. But whoever is forced by severe hunger with no inclination to sin - then indeed, Allah is Forgiving and Merciful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dclxxiii{%
They ask you, [O Muhammad], what has been made lawful for them. Say, ``Lawful for you are [all] good foods and [game caught by] what you have trained of hunting animals which you train as Allah has taught you. So eat of what they catch for you, and mention the name of Allah upon it, and fear Allah." Indeed, Allah is swift in account.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dclxxiv{%
This day [all] good foods have been made lawful, and the food of those who were given the Scripture is lawful for you and your food is lawful for them. And [lawful in marriage are] chaste women from among the believers and chaste women from among those who were given the Scripture before you, when you have given them their due compensation, desiring chastity, not unlawful sexual intercourse or taking [secret] lovers. And whoever denies the faith - his work has become worthless, and he, in the Hereafter, will be among the losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dclxxv{%
O you who have believed, when you rise to [perform] prayer, wash your faces and your forearms to the elbows and wipe over your heads and wash your feet to the ankles. And if you are in a state of janabah, then purify yourselves. But if you are ill or on a journey or one of you comes from the place of relieving himself or you have contacted women and do not find water, then seek clean earth and wipe over your faces and hands with it. Allah does not intend to make difficulty for you, but He intends to purify you and complete His favor upon you that you may be grateful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dclxxvi{%
And remember the favor of Allah upon you and His covenant with which He bound you when you said, ``We hear and we obey"; and fear Allah. Indeed, Allah is Knowing of that within the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@dclxxvii{%
O you who have believed, be persistently standing firm for Allah, witnesses in justice, and do not let the hatred of a people prevent you from being just. Be just; that is nearer to righteousness. And fear Allah; indeed, Allah is Acquainted with what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dclxxviii{%
Allah has promised those who believe and do righteous deeds [that] for them there is forgiveness and great reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dclxxix{%
But those who disbelieve and deny Our signs - those are the companions of Hellfire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dclxxx{%
O you who have believed, remember the favor of Allah upon you when a people determined to extend their hands [in aggression] against you, but He withheld their hands from you; and fear Allah. And upon Allah let the believers rely.\qt@no{11}}%
\qt@newcmd\qurantrans@en@dclxxxi{%
And Allah had already taken a covenant from the Children of Israel, and We delegated from among them twelve leaders. And Allah said, ``I am with you. If you establish prayer and give zakah and believe in My messengers and support them and loan Allah a goodly loan, I will surely remove from you your misdeeds and admit you to gardens beneath which rivers flow. But whoever of you disbelieves after that has certainly strayed from the soundness of the way."\qt@no{12}}%
\qt@newcmd\qurantrans@en@dclxxxii{%
So for their breaking of the covenant We cursed them and made their hearts hard. They distort words from their [proper] usages and have forgotten a portion of that of which they were reminded. And you will still observe deceit among them, except a few of them. But pardon them and overlook [their misdeeds]. Indeed, Allah loves the doers of good.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dclxxxiii{%
And from those who say, ``We are Christians" We took their covenant; but they forgot a portion of that of which they were reminded. So We caused among them animosity and hatred until the Day of Resurrection. And Allah is going to inform them about what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@dclxxxiv{%
O People of the Scripture, there has come to you Our Messenger making clear to you much of what you used to conceal of the Scripture and overlooking much. There has come to you from Allah a light and a clear Book.\qt@no{15}}%
\qt@newcmd\qurantrans@en@dclxxxv{%
By which Allah guides those who pursue His pleasure to the ways of peace and brings them out from darknesses into the light, by His permission, and guides them to a straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dclxxxvi{%
They have certainly disbelieved who say that Allah is Christ, the son of Mary. Say, ``Then who could prevent Allah at all if He had intended to destroy Christ, the son of Mary, or his mother or everyone on the earth?" And to Allah belongs the dominion of the heavens and the earth and whatever is between them. He creates what He wills, and Allah is over all things competent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dclxxxvii{%
But the Jews and the Christians say, ``We are the children of Allah and His beloved." Say, ``Then why does He punish you for your sins?" Rather, you are human beings from among those He has created. He forgives whom He wills, and He punishes whom He wills. And to Allah belongs the dominion of the heavens and the earth and whatever is between them, and to Him is the [final] destination.\qt@no{18}}%
\qt@newcmd\qurantrans@en@dclxxxviii{%
O People of the Scripture, there has come to you Our Messenger to make clear to you [the religion] after a period [of suspension] of messengers, lest you say, ``There came not to us any bringer of good tidings or a warner." But there has come to you a bringer of good tidings and a warner. And Allah is over all things competent.\qt@no{19}}%
\qt@newcmd\qurantrans@en@dclxxxix{%
And [mention, O Muhammad], when Moses said to his people, ``O my people, remember the favor of Allah upon you when He appointed among you prophets and made you possessors and gave you that which He had not given anyone among the worlds.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcxc{%
O my people, enter the Holy Land which Allah has assigned to you and do not turn back [from fighting in Allah 's cause] and [thus] become losers."\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcxci{%
They said, ``O Moses, indeed within it is a people of tyrannical strength, and indeed, we will never enter it until they leave it; but if they leave it, then we will enter."\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcxcii{%
Said two men from those who feared [to disobey] upon whom Allah had bestowed favor, ``Enter upon them through the gate, for when you have entered it, you will be predominant. And upon Allah rely, if you should be believers."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcxciii{%
They said, ``O Moses, indeed we will not enter it, ever, as long as they are within it; so go, you and your Lord, and fight. Indeed, we are remaining right here."\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcxciv{%
[Moses] said, ``My Lord, indeed I do not possess except myself and my brother, so part us from the defiantly disobedient people."\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcxcv{%
[Allah] said, ``Then indeed, it is forbidden to them for forty years [in which] they will wander throughout the land. So do not grieve over the defiantly disobedient people."\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcxcvi{%
And recite to them the story of Adam's two sons, in truth, when they both offered a sacrifice [to Allah], and it was accepted from one of them but was not accepted from the other. Said [the latter], ``I will surely kill you." Said [the former], ``Indeed, Allah only accepts from the righteous [who fear Him].\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcxcvii{%
If you should raise your hand against me to kill me - I shall not raise my hand against you to kill you. Indeed, I fear Allah, Lord of the worlds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcxcviii{%
Indeed I want you to obtain [thereby] my sin and your sin so you will be among the companions of the Fire. And that is the recompense of wrongdoers."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcxcix{%
And his soul permitted to him the murder of his brother, so he killed him and became among the losers.\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcc{%
Then Allah sent a crow searching in the ground to show him how to hide the disgrace of his brother. He said, ``O woe to me! Have I failed to be like this crow and hide the body of my brother?" And he became of the regretful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcci{%
Because of that, We decreed upon the Children of Israel that whoever kills a soul unless for a soul or for corruption [done] in the land - it is as if he had slain mankind entirely. And whoever saves one - it is as if he had saved mankind entirely. And our messengers had certainly come to them with clear proofs. Then indeed many of them, [even] after that, throughout the land, were transgressors.\qt@no{32}}%
\qt@newcmd\qurantrans@en@dccii{%
Indeed, the penalty for those who wage war against Allah and His Messenger and strive upon earth [to cause] corruption is none but that they be killed or crucified or that their hands and feet be cut off from opposite sides or that they be exiled from the land. That is for them a disgrace in this world; and for them in the Hereafter is a great punishment,\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcciii{%
Except for those who return [repenting] before you apprehend them. And know that Allah is Forgiving and Merciful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcciv{%
O you who have believed, fear Allah and seek the means [of nearness] to Him and strive in His cause that you may succeed.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dccv{%
Indeed, those who disbelieve - if they should have all that is in the earth and the like of it with it by which to ransom themselves from the punishment of the Day of Resurrection, it will not be accepted from them, and for them is a painful punishment\qt@no{36}}%
\qt@newcmd\qurantrans@en@dccvi{%
They will wish to get out of the Fire, but never are they to emerge therefrom, and for them is an enduring punishment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@dccvii{%
[As for] the thief, the male and the female, amputate their hands in recompense for what they committed as a deterrent [punishment] from Allah. And Allah is Exalted in Might and Wise.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dccviii{%
But whoever repents after his wrongdoing and reforms, indeed, Allah will turn to him in forgiveness. Indeed, Allah is Forgiving and Merciful.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dccix{%
Do you not know that to Allah belongs the dominion of the heavens and the earth? He punishes whom He wills and forgives whom He wills, and Allah is over all things competent.\qt@no{40}}%
\qt@newcmd\qurantrans@en@dccx{%
O Messenger, let them not grieve you who hasten into disbelief of those who say, ``We believe" with their mouths, but their hearts believe not, and from among the Jews. [They are] avid listeners to falsehood, listening to another people who have not come to you. They distort words beyond their [proper] usages, saying ``If you are given this, take it; but if you are not given it, then beware." But he for whom Allah intends fitnah - never will you possess [power to do] for him a thing against Allah. Those are the ones for whom Allah does not intend to purify their hearts. For them in this world is disgrace, and for them in the Hereafter is a great punishment.\qt@no{41}}%
\qt@newcmd\qurantrans@en@dccxi{%
[They are] avid listeners to falsehood, devourers of [what is] unlawful. So if they come to you, [O Muhammad], judge between them or turn away from them. And if you turn away from them - never will they harm you at all. And if you judge, judge between them with justice. Indeed, Allah loves those who act justly.\qt@no{42}}%
\qt@newcmd\qurantrans@en@dccxii{%
But how is it that they come to you for judgement while they have the Torah, in which is the judgement of Allah? Then they turn away, [even] after that; but those are not [in fact] believers.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dccxiii{%
Indeed, We sent down the Torah, in which was guidance and light. The prophets who submitted [to Allah] judged by it for the Jews, as did the rabbis and scholars by that with which they were entrusted of the Scripture of Allah, and they were witnesses thereto. So do not fear the people but fear Me, and do not exchange My verses for a small price. And whoever does not judge by what Allah has revealed - then it is those who are the disbelievers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dccxiv{%
And We ordained for them therein a life for a life, an eye for an eye, a nose for a nose, an ear for an ear, a tooth for a tooth, and for wounds is legal retribution. But whoever gives [up his right as] charity, it is an expiation for him. And whoever does not judge by what Allah has revealed - then it is those who are the wrongdoers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dccxv{%
And We sent, following in their footsteps, Jesus, the son of Mary, confirming that which came before him in the Torah; and We gave him the Gospel, in which was guidance and light and confirming that which preceded it of the Torah as guidance and instruction for the righteous.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dccxvi{%
And let the People of the Gospel judge by what Allah has revealed therein. And whoever does not judge by what Allah has revealed - then it is those who are the defiantly disobedient.\qt@no{47}}%
\qt@newcmd\qurantrans@en@dccxvii{%
And We have revealed to you, [O Muhammad], the Book in truth, confirming that which preceded it of the Scripture and as a criterion over it. So judge between them by what Allah has revealed and do not follow their inclinations away from what has come to you of the truth. To each of you We prescribed a law and a method. Had Allah willed, He would have made you one nation [united in religion], but [He intended] to test you in what He has given you; so race to [all that is] good. To Allah is your return all together, and He will [then] inform you concerning that over which you used to differ.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dccxviii{%
And judge, [O Muhammad], between them by what Allah has revealed and do not follow their inclinations and beware of them, lest they tempt you away from some of what Allah has revealed to you. And if they turn away - then know that Allah only intends to afflict them with some of their [own] sins. And indeed, many among the people are defiantly disobedient.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dccxix{%
Then is it the judgement of [the time of] ignorance they desire? But who is better than Allah in judgement for a people who are certain [in faith].\qt@no{50}}%
\qt@newcmd\qurantrans@en@dccxx{%
O you who have believed, do not take the Jews and the Christians as allies. They are [in fact] allies of one another. And whoever is an ally to them among you - then indeed, he is [one] of them. Indeed, Allah guides not the wrongdoing people.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dccxxi{%
So you see those in whose hearts is disease hastening into [association with] them, saying, ``We are afraid a misfortune may strike us." But perhaps Allah will bring conquest or a decision from Him, and they will become, over what they have been concealing within themselves, regretful.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dccxxii{%
And those who believe will say, ``Are these the ones who swore by Allah their strongest oaths that indeed they were with you?" Their deeds have become worthless, and they have become losers.\qt@no{53}}%
\qt@newcmd\qurantrans@en@dccxxiii{%
O you who have believed, whoever of you should revert from his religion - Allah will bring forth [in place of them] a people He will love and who will love Him [who are] humble toward the believers, powerful against the disbelievers; they strive in the cause of Allah and do not fear the blame of a critic. That is the favor of Allah; He bestows it upon whom He wills. And Allah is all-Encompassing and Knowing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@dccxxiv{%
Your ally is none but Allah and [therefore] His Messenger and those who have believed - those who establish prayer and give zakah, and they bow [in worship].\qt@no{55}}%
\qt@newcmd\qurantrans@en@dccxxv{%
And whoever is an ally of Allah and His Messenger and those who have believed - indeed, the party of Allah - they will be the predominant.\qt@no{56}}%
\qt@newcmd\qurantrans@en@dccxxvi{%
O you who have believed, take not those who have taken your religion in ridicule and amusement among the ones who were given the Scripture before you nor the disbelievers as allies. And fear Allah, if you should [truly] be believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@dccxxvii{%
And when you call to prayer, they take it in ridicule and amusement. That is because they are a people who do not use reason.\qt@no{58}}%
\qt@newcmd\qurantrans@en@dccxxviii{%
Say, ``O People of the Scripture, do you resent us except [for the fact] that we have believed in Allah and what was revealed to us and what was revealed before and because most of you are defiantly disobedient?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@dccxxix{%
Say, ``Shall I inform you of [what is] worse than that as penalty from Allah? [It is that of] those whom Allah has cursed and with whom He became angry and made of them apes and pigs and slaves of Taghut. Those are worse in position and further astray from the sound way."\qt@no{60}}%
\qt@newcmd\qurantrans@en@dccxxx{%
And when they come to you, they say, ``We believe." But they have entered with disbelief [in their hearts], and they have certainly left with it. And Allah is most knowing of what they were concealing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@dccxxxi{%
And you see many of them hastening into sin and aggression and the devouring of [what is] unlawful. How wretched is what they have been doing.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccxxxii{%
Why do the rabbis and religious scholars not forbid them from saying what is sinful and devouring what is unlawful? How wretched is what they have been practicing.\qt@no{63}}%
\qt@newcmd\qurantrans@en@dccxxxiii{%
And the Jews say, ``The hand of Allah is chained." Chained are their hands, and cursed are they for what they say. Rather, both His hands are extended; He spends however He wills. And that which has been revealed to you from your Lord will surely increase many of them in transgression and disbelief. And We have cast among them animosity and hatred until the Day of Resurrection. Every time they kindled the fire of war [against you], Allah extinguished it. And they strive throughout the land [causing] corruption, and Allah does not like corrupters.\qt@no{64}}%
\qt@newcmd\qurantrans@en@dccxxxiv{%
And if only the People of the Scripture had believed and feared Allah, We would have removed from them their misdeeds and admitted them to Gardens of Pleasure.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccxxxv{%
And if only they upheld [the law of] the Torah, the Gospel, and what has been revealed to them from their Lord, they would have consumed [provision] from above them and from beneath their feet. Among them are a moderate community, but many of them - evil is that which they do.\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccxxxvi{%
O Messenger, announce that which has been revealed to you from your Lord, and if you do not, then you have not conveyed His message. And Allah will protect you from the people. Indeed, Allah does not guide the disbelieving people.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccxxxvii{%
Say, ``O People of the Scripture, you are [standing] on nothing until you uphold [the law of] the Torah, the Gospel, and what has been revealed to you from your Lord." And that which has been revealed to you from your Lord will surely increase many of them in transgression and disbelief. So do not grieve over the disbelieving people.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccxxxviii{%
Indeed, those who have believed [in Prophet Muhammad] and those [before Him] who were Jews or Sabeans or Christians - those [among them] who believed in Allah and the Last Day and did righteousness - no fear will there be concerning them, nor will they grieve.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccxxxix{%
We had already taken the covenant of the Children of Israel and had sent to them messengers. Whenever there came to them a messenger with what their souls did not desire, a party [of messengers] they denied, and another party they killed.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccxl{%
And they thought there would be no [resulting] punishment, so they became blind and deaf. Then Allah turned to them in forgiveness; then [again] many of them became blind and deaf. And Allah is Seeing of what they do.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccxli{%
They have certainly disbelieved who say, ``Allah is the Messiah, the son of Mary" while the Messiah has said, ``O Children of Israel, worship Allah, my Lord and your Lord." Indeed, he who associates others with Allah - Allah has forbidden him Paradise, and his refuge is the Fire. And there are not for the wrongdoers any helpers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccxlii{%
They have certainly disbelieved who say, ``Allah is the third of three." And there is no god except one God. And if they do not desist from what they are saying, there will surely afflict the disbelievers among them a painful punishment.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccxliii{%
So will they not repent to Allah and seek His forgiveness? And Allah is Forgiving and Merciful.\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccxliv{%
The Messiah, son of Mary, was not but a messenger; [other] messengers have passed on before him. And his mother was a supporter of truth. They both used to eat food. Look how We make clear to them the signs; then look how they are deluded.\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccxlv{%
Say, ``Do you worship besides Allah that which holds for you no [power of] harm or benefit while it is Allah who is the Hearing, the Knowing?"\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccxlvi{%
Say, ``O People of the Scripture, do not exceed limits in your religion beyond the truth and do not follow the inclinations of a people who had gone astray before and misled many and have strayed from the soundness of the way."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccxlvii{%
Cursed were those who disbelieved among the Children of Israel by the tongue of David and of Jesus, the son of Mary. That was because they disobeyed and [habitually] transgressed.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccxlviii{%
They used not to prevent one another from wrongdoing that they did. How wretched was that which they were doing.\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccxlix{%
You see many of them becoming allies of those who disbelieved. How wretched is that which they have put forth for themselves in that Allah has become angry with them, and in the punishment they will abide eternally.\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccl{%
And if they had believed in Allah and the Prophet and in what was revealed to him, they would not have taken them as allies; but many of them are defiantly disobedient.\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccli{%
You will surely find the most intense of the people in animosity toward the believers [to be] the Jews and those who associate others with Allah; and you will find the nearest of them in affection to the believers those who say, ``We are Christians." That is because among them are priests and monks and because they are not arrogant.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dcclii{%
And when they hear what has been revealed to the Messenger, you see their eyes overflowing with tears because of what they have recognized of the truth. They say, ``Our Lord, we have believed, so register us among the witnesses.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccliii{%
And why should we not believe in Allah and what has come to us of the truth? And we aspire that our Lord will admit us [to Paradise] with the righteous people."\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccliv{%
So Allah rewarded them for what they said with gardens [in Paradise] beneath which rivers flow, wherein they abide eternally. And that is the reward of doers of good.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dcclv{%
But those who disbelieved and denied Our signs - they are the companions of Hellfire.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dcclvi{%
O you who have believed, do not prohibit the good things which Allah has made lawful to you and do not transgress. Indeed, Allah does not like transgressors.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dcclvii{%
And eat of what Allah has provided for you [which is] lawful and good. And fear Allah, in whom you are believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dcclviii{%
Allah will not impose blame upon you for what is meaningless in your oaths, but He will impose blame upon you for [breaking] what you intended of oaths. So its expiation is the feeding of ten needy people from the average of that which you feed your [own] families or clothing them or the freeing of a slave. But whoever cannot find [or afford it] - then a fast of three days [is required]. That is the expiation for oaths when you have sworn. But guard your oaths. Thus does Allah make clear to you His verses that you may be grateful.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dcclix{%
O you who have believed, indeed, intoxicants, gambling, [sacrificing on] stone alters [to other than Allah], and divining arrows are but defilement from the work of Satan, so avoid it that you may be successful.\qt@no{90}}%
\qt@newcmd\qurantrans@en@dcclx{%
Satan only wants to cause between you animosity and hatred through intoxicants and gambling and to avert you from the remembrance of Allah and from prayer. So will you not desist?\qt@no{91}}%
\qt@newcmd\qurantrans@en@dcclxi{%
And obey Allah and obey the Messenger and beware. And if you turn away - then know that upon Our Messenger is only [the responsibility for] clear notification.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dcclxii{%
There is not upon those who believe and do righteousness [any] blame concerning what they have eaten [in the past] if they [now] fear Allah and believe and do righteous deeds, and then fear Allah and believe, and then fear Allah and do good; and Allah loves the doers of good.\qt@no{93}}%
\qt@newcmd\qurantrans@en@dcclxiii{%
O you who have believed, Allah will surely test you through something of the game that your hands and spears [can] reach, that Allah may make evident those who fear Him unseen. And whoever transgresses after that - for him is a painful punishment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@dcclxiv{%
O you who have believed, do not kill game while you are in the state of ihram. And whoever of you kills it intentionally - the penalty is an equivalent from sacrificial animals to what he killed, as judged by two just men among you as an offering [to Allah] delivered to the Ka'bah, or an expiation: the feeding of needy people or the equivalent of that in fasting, that he may taste the consequence of his deed. Allah has pardoned what is past; but whoever returns [to violation], then Allah will take retribution from him. And Allah is Exalted in Might and Owner of Retribution.\qt@no{95}}%
\qt@newcmd\qurantrans@en@dcclxv{%
Lawful to you is game from the sea and its food as provision for you and the travelers, but forbidden to you is game from the land as long as you are in the state of ihram. And fear Allah to whom you will be gathered.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dcclxvi{%
Allah has made the Ka'bah, the Sacred House, standing for the people and [has sanctified] the sacred months and the sacrificial animals and the garlands [by which they are identified]. That is so you may know that Allah knows what is in the heavens and what is in the earth and that Allah is Knowing of all things.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dcclxvii{%
Know that Allah is severe in penalty and that Allah is Forgiving and Merciful.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dcclxviii{%
Not upon the Messenger is [responsibility] except [for] notification. And Allah knows whatever you reveal and whatever you conceal.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dcclxix{%
Say, ``Not equal are the evil and the good, although the abundance of evil might impress you." So fear Allah, O you of understanding, that you may be successful.\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcclxx{%
O you who have believed, do not ask about things which, if they are shown to you, will distress you. But if you ask about them while the Qur'an is being revealed, they will be shown to you. Allah has pardoned that which is past; and Allah is Forgiving and Forbearing.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcclxxi{%
A people asked such [questions] before you; then they became thereby disbelievers.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcclxxii{%
Allah has not appointed [such innovations as] bahirah or sa'ibah or wasilah or ham. But those who disbelieve invent falsehood about Allah, and most of them do not reason.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcclxxiii{%
And when it is said to them, ``Come to what Allah has revealed and to the Messenger," they say, ``Sufficient for us is that upon which we found our fathers." Even though their fathers knew nothing, nor were they guided?\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcclxxiv{%
O you who have believed, upon you is [responsibility for] yourselves. Those who have gone astray will not harm you when you have been guided. To Allah is you return all together; then He will inform you of what you used to do.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcclxxv{%
O you who have believed, testimony [should be taken] among you when death approaches one of you at the time of bequest - [that of] two just men from among you or two others from outside if you are traveling through the land and the disaster of death should strike you. Detain them after the prayer and let them both swear by Allah if you doubt [their testimony, saying], ``We will not exchange our oath for a price, even if he should be a near relative, and we will not withhold the testimony of Allah. Indeed, we would then be of the sinful."\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcclxxvi{%
But if it is found that those two were guilty of perjury, let two others stand in their place [who are] foremost [in claim] from those who have a lawful right. And let them swear by Allah, ``Our testimony is truer than their testimony, and we have not transgressed. Indeed, we would then be of the wrongdoers."\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcclxxvii{%
That is more likely that they will give testimony according to its [true] objective, or [at least] they would fear that [other] oaths might be taken after their oaths. And fear Allah and listen; and Allah does not guide the defiantly disobedient people.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcclxxviii{%
[Be warned of] the Day when Allah will assemble the messengers and say, ``What was the response you received?" They will say, ``We have no knowledge. Indeed, it is You who is Knower of the unseen"\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcclxxix{%
[The Day] when Allah will say, ``O Jesus, Son of Mary, remember My favor upon you and upon your mother when I supported you with the Pure Spirit and you spoke to the people in the cradle and in maturity; and [remember] when I taught you writing and wisdom and the Torah and the Gospel; and when you designed from clay [what was] like the form of a bird with My permission, then you breathed into it, and it became a bird with My permission; and you healed the blind and the leper with My permission; and when you brought forth the dead with My permission; and when I restrained the Children of Israel from [killing] you when you came to them with clear proofs and those who disbelieved among them said, ``This is not but obvious magic."\qt@no{110}}%
\qt@newcmd\qurantrans@en@dcclxxx{%
And [remember] when I inspired to the disciples, ``Believe in Me and in My messenger Jesus." They said, ``We have believed, so bear witness that indeed we are Muslims [in submission to Allah]."\qt@no{111}}%
\qt@newcmd\qurantrans@en@dcclxxxi{%
[And remember] when the disciples said, ``O Jesus, Son of Mary, can your Lord send down to us a table [spread with food] from the heaven? [Jesus] said," Fear Allah, if you should be believers."\qt@no{112}}%
\qt@newcmd\qurantrans@en@dcclxxxii{%
They said, ``We wish to eat from it and let our hearts be reassured and know that you have been truthful to us and be among its witnesses."\qt@no{113}}%
\qt@newcmd\qurantrans@en@dcclxxxiii{%
Said Jesus, the son of Mary, ``O Allah, our Lord, send down to us a table [spread with food] from the heaven to be for us a festival for the first of us and the last of us and a sign from You. And provide for us, and You are the best of providers."\qt@no{114}}%
\qt@newcmd\qurantrans@en@dcclxxxiv{%
Allah said, ``Indeed, I will sent it down to you, but whoever disbelieves afterwards from among you - then indeed will I punish him with a punishment by which I have not punished anyone among the worlds."\qt@no{115}}%
\qt@newcmd\qurantrans@en@dcclxxxv{%
And [beware the Day] when Allah will say, ``O Jesus, Son of Mary, did you say to the people, 'Take me and my mother as deities besides Allah?'" He will say, ``Exalted are You! It was not for me to say that to which I have no right. If I had said it, You would have known it. You know what is within myself, and I do not know what is within Yourself. Indeed, it is You who is Knower of the unseen.\qt@no{116}}%
\qt@newcmd\qurantrans@en@dcclxxxvi{%
I said not to them except what You commanded me - to worship Allah, my Lord and your Lord. And I was a witness over them as long as I was among them; but when You took me up, You were the Observer over them, and You are, over all things, Witness.\qt@no{117}}%
\qt@newcmd\qurantrans@en@dcclxxxvii{%
If You should punish them - indeed they are Your servants; but if You forgive them - indeed it is You who is the Exalted in Might, the Wise.\qt@no{118}}%
\qt@newcmd\qurantrans@en@dcclxxxviii{%
Allah will say, ``This is the Day when the truthful will benefit from their truthfulness." For them are gardens [in Paradise] beneath which rivers flow, wherein they will abide forever, Allah being pleased with them, and they with Him. That is the great attainment.\qt@no{119}}%
\qt@newcmd\qurantrans@en@dcclxxxix{%
To Allah belongs the dominion of the heavens and the earth and whatever is within them. And He is over all things competent.\qt@no{120}}%
\qt@newcmd\qurantrans@en@dccxc{%
\basmalahen [All] praise is [due] to Allah, who created the heavens and the earth and made the darkness and the light. Then those who disbelieve equate [others] with their Lord.\qt@no{1}}%
\qt@newcmd\qurantrans@en@dccxci{%
It is He who created you from clay and then decreed a term and a specified time [known] to Him; then [still] you are in dispute.\qt@no{2}}%
\qt@newcmd\qurantrans@en@dccxcii{%
And He is Allah, [the only deity] in the heavens and the earth. He knows your secret and what you make public, and He knows that which you earn.\qt@no{3}}%
\qt@newcmd\qurantrans@en@dccxciii{%
And no sign comes to them from the signs of their Lord except that they turn away therefrom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@dccxciv{%
For they had denied the truth when it came to them, but there is going to reach them the news of what they used to ridicule.\qt@no{5}}%
\qt@newcmd\qurantrans@en@dccxcv{%
Have they not seen how many generations We destroyed before them which We had established upon the earth as We have not established you? And We sent [rain from] the sky upon them in showers and made rivers flow beneath them; then We destroyed them for their sins and brought forth after them a generation of others.\qt@no{6}}%
\qt@newcmd\qurantrans@en@dccxcvi{%
And even if We had sent down to you, [O Muhammad], a written scripture on a page and they touched it with their hands, the disbelievers would say, ``This is not but obvious magic."\qt@no{7}}%
\qt@newcmd\qurantrans@en@dccxcvii{%
And they say, ``Why was there not sent down to him an angel?" But if We had sent down an angel, the matter would have been decided; then they would not be reprieved.\qt@no{8}}%
\qt@newcmd\qurantrans@en@dccxcviii{%
And if We had made him an angel, We would have made him [appear as] a man, and We would have covered them with that in which they cover themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@dccxcix{%
And already were messengers ridiculed before you, but those who mocked them were enveloped by that which they used to ridicule.\qt@no{10}}%
\qt@newcmd\qurantrans@en@dccc{%
Say, ``Travel through the land; then observe how was the end of the deniers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@dccci{%
Say, ``To whom belongs whatever is in the heavens and earth?" Say, ``To Allah." He has decreed upon Himself mercy. He will surely assemble you for the Day of Resurrection, about which there is no doubt. Those who will lose themselves [that Day] do not believe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@dcccii{%
And to Him belongs that which reposes by night and by day, and He is the Hearing, the Knowing.\qt@no{13}}%
\qt@newcmd\qurantrans@en@dccciii{%
Say, ``Is it other than Allah I should take as a protector, Creator of the heavens and the earth, while it is He who feeds and is not fed?" Say, [O Muhammad], ``Indeed, I have been commanded to be the first [among you] who submit [to Allah] and [was commanded], 'Do not ever be of the polytheists.' ``\qt@no{14}}%
\qt@newcmd\qurantrans@en@dccciv{%
Say, ``Indeed I fear, if I should disobey my Lord, the punishment of a tremendous Day."\qt@no{15}}%
\qt@newcmd\qurantrans@en@dcccv{%
He from whom it is averted that Day - [Allah] has granted him mercy. And that is the clear attainment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@dcccvi{%
And if Allah should touch you with adversity, there is no remover of it except Him. And if He touches you with good - then He is over all things competent.\qt@no{17}}%
\qt@newcmd\qurantrans@en@dcccvii{%
And He is the subjugator over His servants. And He is the Wise, the Acquainted [with all].\qt@no{18}}%
\qt@newcmd\qurantrans@en@dcccviii{%
Say, ``What thing is greatest in testimony?" Say, ``Allah is witness between me and you. And this Qur'an was revealed to me that I may warn you thereby and whomever it reaches. Do you [truly] testify that with Allah there are other deities?" Say, ``I will not testify [with you]." Say, ``Indeed, He is but one God, and indeed, I am free of what you associate [with Him]."\qt@no{19}}%
\qt@newcmd\qurantrans@en@dcccix{%
Those to whom We have given the Scripture recognize it as they recognize their [own] sons. Those who will lose themselves [in the Hereafter] do not believe.\qt@no{20}}%
\qt@newcmd\qurantrans@en@dcccx{%
And who is more unjust than one who invents about Allah a lie or denies His verses? Indeed, the wrongdoers will not succeed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@dcccxi{%
And [mention, O Muhammad], the Day We will gather them all together; then We will say to those who associated others with Allah, ``Where are your 'partners' that you used to claim [with Him]?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@dcccxii{%
Then there will be no [excuse upon] examination except they will say, ``By Allah, our Lord, we were not those who associated."\qt@no{23}}%
\qt@newcmd\qurantrans@en@dcccxiii{%
See how they will lie about themselves. And lost from them will be what they used to invent.\qt@no{24}}%
\qt@newcmd\qurantrans@en@dcccxiv{%
And among them are those who listen to you, but We have placed over their hearts coverings, lest they understand it, and in their ears deafness. And if they should see every sign, they will not believe in it. Even when they come to you arguing with you, those who disbelieve say, ``This is not but legends of the former peoples."\qt@no{25}}%
\qt@newcmd\qurantrans@en@dcccxv{%
And they prevent [others] from him and are [themselves] remote from him. And they do not destroy except themselves, but they perceive [it] not.\qt@no{26}}%
\qt@newcmd\qurantrans@en@dcccxvi{%
If you could but see when they are made to stand before the Fire and will say, ``Oh, would that we could be returned [to life on earth] and not deny the signs of our Lord and be among the believers."\qt@no{27}}%
\qt@newcmd\qurantrans@en@dcccxvii{%
But what they concealed before has [now] appeared to them. And even if they were returned, they would return to that which they were forbidden; and indeed, they are liars.\qt@no{28}}%
\qt@newcmd\qurantrans@en@dcccxviii{%
And they say, ``There is none but our worldly life, and we will not be resurrected."\qt@no{29}}%
\qt@newcmd\qurantrans@en@dcccxix{%
If you could but see when they will be made to stand before their Lord. He will say, ``Is this not the truth?" They will say, ``Yes, by our Lord." He will [then] say, ``So taste the punishment because you used to disbelieve."\qt@no{30}}%
\qt@newcmd\qurantrans@en@dcccxx{%
Those will have lost who deny the meeting with Allah, until when the Hour [of resurrection] comes upon them unexpectedly, they will say, ``Oh, [how great is] our regret over what we neglected concerning it," while they bear their burdens on their backs. Unquestionably, evil is that which they bear.\qt@no{31}}%
\qt@newcmd\qurantrans@en@dcccxxi{%
And the worldly life is not but amusement and diversion; but the home of the Hereafter is best for those who fear Allah, so will you not reason?\qt@no{32}}%
\qt@newcmd\qurantrans@en@dcccxxii{%
We know that you, [O Muhammad], are saddened by what they say. And indeed, they do not call you untruthful, but it is the verses of Allah that the wrongdoers reject.\qt@no{33}}%
\qt@newcmd\qurantrans@en@dcccxxiii{%
And certainly were messengers denied before you, but they were patient over [the effects of] denial, and they were harmed until Our victory came to them. And none can alter the words of Allah. And there has certainly come to you some information about the [previous] messengers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@dcccxxiv{%
And if their evasion is difficult for you, then if you are able to seek a tunnel into the earth or a stairway into the sky to bring them a sign, [then do so]. But if Allah had willed, He would have united them upon guidance. So never be of the ignorant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@dcccxxv{%
Only those who hear will respond. But the dead - Allah will resurrect them; then to Him they will be returned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@dcccxxvi{%
And they say, ``Why has a sign not been sent down to him from his Lord?" Say, ``Indeed, Allah is Able to send down a sign, but most of them do not know."\qt@no{37}}%
\qt@newcmd\qurantrans@en@dcccxxvii{%
And there is no creature on [or within] the earth or bird that flies with its wings except [that they are] communities like you. We have not neglected in the Register a thing. Then unto their Lord they will be gathered.\qt@no{38}}%
\qt@newcmd\qurantrans@en@dcccxxviii{%
But those who deny Our verses are deaf and dumb within darknesses. Whomever Allah wills - He leaves astray; and whomever He wills - He puts him on a straight path.\qt@no{39}}%
\qt@newcmd\qurantrans@en@dcccxxix{%
Say, ``Have you considered: if there came to you the punishment of Allah or there came to you the Hour - is it other than Allah you would invoke, if you should be truthful?"\qt@no{40}}%
\qt@newcmd\qurantrans@en@dcccxxx{%
No, it is Him [alone] you would invoke, and He would remove that for which you invoked Him if He willed, and you would forget what you associate [with Him].\qt@no{41}}%
\qt@newcmd\qurantrans@en@dcccxxxi{%
And We have already sent [messengers] to nations before you, [O Muhammad]; then We seized them with poverty and hardship that perhaps they might humble themselves [to Us].\qt@no{42}}%
\qt@newcmd\qurantrans@en@dcccxxxii{%
Then why, when Our punishment came to them, did they not humble themselves? But their hearts became hardened, and Satan made attractive to them that which they were doing.\qt@no{43}}%
\qt@newcmd\qurantrans@en@dcccxxxiii{%
So when they forgot that by which they had been reminded, We opened to them the doors of every [good] thing until, when they rejoiced in that which they were given, We seized them suddenly, and they were [then] in despair.\qt@no{44}}%
\qt@newcmd\qurantrans@en@dcccxxxiv{%
So the people that committed wrong were eliminated. And praise to Allah, Lord of the worlds.\qt@no{45}}%
\qt@newcmd\qurantrans@en@dcccxxxv{%
Say, ``Have you considered: if Allah should take away your hearing and your sight and set a seal upon your hearts, which deity other than Allah could bring them [back] to you?" Look how we diversify the verses; then they [still] turn away.\qt@no{46}}%
\qt@newcmd\qurantrans@en@dcccxxxvi{%
Say, ``Have you considered: if the punishment of Allah should come to you unexpectedly or manifestly, will any be destroyed but the wrongdoing people?"\qt@no{47}}%
\qt@newcmd\qurantrans@en@dcccxxxvii{%
And We send not the messengers except as bringers of good tidings and warners. So whoever believes and reforms - there will be no fear concerning them, nor will they grieve.\qt@no{48}}%
\qt@newcmd\qurantrans@en@dcccxxxviii{%
But those who deny Our verses - the punishment will touch them for their defiant disobedience.\qt@no{49}}%
\qt@newcmd\qurantrans@en@dcccxxxix{%
Say, [O Muhammad], ``I do not tell you that I have the depositories [containing the provision] of Allah or that I know the unseen, nor do I tell you that I am an angel. I only follow what is revealed to me." Say, ``Is the blind equivalent to the seeing? Then will you not give thought?"\qt@no{50}}%
\qt@newcmd\qurantrans@en@dcccxl{%
And warn by the Qur'an those who fear that they will be gathered before their Lord - for them besides Him will be no protector and no intercessor - that they might become righteous.\qt@no{51}}%
\qt@newcmd\qurantrans@en@dcccxli{%
And do not send away those who call upon their Lord morning and afternoon, seeking His countenance. Not upon you is anything of their account and not upon them is anything of your account. So were you to send them away, you would [then] be of the wrongdoers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@dcccxlii{%
And thus We have tried some of them through others that the disbelievers might say, ``Is it these whom Allah has favored among us?" Is not Allah most knowing of those who are grateful?\qt@no{53}}%
\qt@newcmd\qurantrans@en@dcccxliii{%
And when those come to you who believe in Our verses, say, ``Peace be upon you. Your Lord has decreed upon Himself mercy: that any of you who does wrong out of ignorance and then repents after that and corrects himself - indeed, He is Forgiving and Merciful."\qt@no{54}}%
\qt@newcmd\qurantrans@en@dcccxliv{%
And thus do We detail the verses, and [thus] the way of the criminals will become evident.\qt@no{55}}%
\qt@newcmd\qurantrans@en@dcccxlv{%
Say, ``Indeed, I have been forbidden to worship those you invoke besides Allah." Say, ``I will not follow your desires, for I would then have gone astray, and I would not be of the [rightly] guided."\qt@no{56}}%
\qt@newcmd\qurantrans@en@dcccxlvi{%
Say, ``Indeed, I am on clear evidence from my Lord, and you have denied it. I do not have that for which you are impatient. The decision is only for Allah. He relates the truth, and He is the best of deciders."\qt@no{57}}%
\qt@newcmd\qurantrans@en@dcccxlvii{%
Say, ``If I had that for which you are impatient, the matter would have been decided between me and you, but Allah is most knowing of the wrongdoers."\qt@no{58}}%
\qt@newcmd\qurantrans@en@dcccxlviii{%
And with Him are the keys of the unseen; none knows them except Him. And He knows what is on the land and in the sea. Not a leaf falls but that He knows it. And no grain is there within the darknesses of the earth and no moist or dry [thing] but that it is [written] in a clear record.\qt@no{59}}%
\qt@newcmd\qurantrans@en@dcccxlix{%
And it is He who takes your souls by night and knows what you have committed by day. Then He revives you therein that a specified term may be fulfilled. Then to Him will be your return; then He will inform you about what you used to do.\qt@no{60}}%
\qt@newcmd\qurantrans@en@dcccl{%
And He is the subjugator over His servants, and He sends over you guardian-angels until, when death comes to one of you, Our messengers take him, and they do not fail [in their duties].\qt@no{61}}%
\qt@newcmd\qurantrans@en@dcccli{%
Then they His servants are returned to Allah, their true Lord. Unquestionably, His is the judgement, and He is the swiftest of accountants.\qt@no{62}}%
\qt@newcmd\qurantrans@en@dccclii{%
Say, ``Who rescues you from the darknesses of the land and sea [when] you call upon Him imploring [aloud] and privately, 'If He should save us from this [crisis], we will surely be among the thankful.' ``\qt@no{63}}%
\qt@newcmd\qurantrans@en@dcccliii{%
Say, ``It is Allah who saves you from it and from every distress; then you [still] associate others with Him."\qt@no{64}}%
\qt@newcmd\qurantrans@en@dcccliv{%
Say, ``He is the [one] Able to send upon you affliction from above you or from beneath your feet or to confuse you [so you become] sects and make you taste the violence of one another." Look how We diversify the signs that they might understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@dccclv{%
But your people have denied it while it is the truth. Say, ``I am not over you a manager."\qt@no{66}}%
\qt@newcmd\qurantrans@en@dccclvi{%
For every happening is a finality; and you are going to know.\qt@no{67}}%
\qt@newcmd\qurantrans@en@dccclvii{%
And when you see those who engage in [offensive] discourse concerning Our verses, then turn away from them until they enter into another conversation. And if Satan should cause you to forget, then do not remain after the reminder with the wrongdoing people.\qt@no{68}}%
\qt@newcmd\qurantrans@en@dccclviii{%
And those who fear Allah are not held accountable for the disbelievers at all, but [only for] a reminder - that perhaps they will fear Him.\qt@no{69}}%
\qt@newcmd\qurantrans@en@dccclix{%
And leave those who take their religion as amusement and diversion and whom the worldly life has deluded. But remind with the Qur'an, lest a soul be given up to destruction for what it earned; it will have other than Allah no protector and no intercessor. And if it should offer every compensation, it would not be taken from it. Those are the ones who are given to destruction for what they have earned. For them will be a drink of scalding water and a painful punishment because they used to disbelieve.\qt@no{70}}%
\qt@newcmd\qurantrans@en@dccclx{%
Say, ``Shall we invoke instead of Allah that which neither benefits us nor harms us and be turned back on our heels after Allah has guided us? [We would then be] like one whom the devils enticed [to wander] upon the earth confused, [while] he has companions inviting him to guidance, [calling], 'Come to us.' `` Say, ``Indeed, the guidance of Allah is the [only] guidance; and we have been commanded to submit to the Lord of the worlds.\qt@no{71}}%
\qt@newcmd\qurantrans@en@dccclxi{%
And to establish prayer and fear Him." And it is He to whom you will be gathered.\qt@no{72}}%
\qt@newcmd\qurantrans@en@dccclxii{%
And it is He who created the heavens and earth in truth. And the day He says, ``Be," and it is, His word is the truth. And His is the dominion [on] the Day the Horn is blown. [He is] Knower of the unseen and the witnessed; and He is the Wise, the Acquainted.\qt@no{73}}%
\qt@newcmd\qurantrans@en@dccclxiii{%
And [mention, O Muhammad], when Abraham said to his father Azar, ``Do you take idols as deities? Indeed, I see you and your people to be in manifest error."\qt@no{74}}%
\qt@newcmd\qurantrans@en@dccclxiv{%
And thus did We show Abraham the realm of the heavens and the earth that he would be among the certain [in faith]\qt@no{75}}%
\qt@newcmd\qurantrans@en@dccclxv{%
So when the night covered him [with darkness], he saw a star. He said, ``This is my lord." But when it set, he said, ``I like not those that disappear."\qt@no{76}}%
\qt@newcmd\qurantrans@en@dccclxvi{%
And when he saw the moon rising, he said, ``This is my lord." But when it set, he said, ``Unless my Lord guides me, I will surely be among the people gone astray."\qt@no{77}}%
\qt@newcmd\qurantrans@en@dccclxvii{%
And when he saw the sun rising, he said, ``This is my lord; this is greater." But when it set, he said, ``O my people, indeed I am free from what you associate with Allah.\qt@no{78}}%
\qt@newcmd\qurantrans@en@dccclxviii{%
Indeed, I have turned my face toward He who created the heavens and the earth, inclining toward truth, and I am not of those who associate others with Allah."\qt@no{79}}%
\qt@newcmd\qurantrans@en@dccclxix{%
And his people argued with him. He said, ``Do you argue with me concerning Allah while He has guided me? And I fear not what you associate with Him [and will not be harmed] unless my Lord should will something. My Lord encompasses all things in knowledge; then will you not remember?\qt@no{80}}%
\qt@newcmd\qurantrans@en@dccclxx{%
And how should I fear what you associate while you do not fear that you have associated with Allah that for which He has not sent down to you any authority? So which of the two parties has more right to security, if you should know?\qt@no{81}}%
\qt@newcmd\qurantrans@en@dccclxxi{%
They who believe and do not mix their belief with injustice - those will have security, and they are [rightly] guided.\qt@no{82}}%
\qt@newcmd\qurantrans@en@dccclxxii{%
And that was Our [conclusive] argument which We gave Abraham against his people. We raise by degrees whom We will. Indeed, your Lord is Wise and Knowing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@dccclxxiii{%
And We gave to Abraham, Isaac and Jacob - all [of them] We guided. And Noah, We guided before; and among his descendants, David and Solomon and Job and Joseph and Moses and Aaron. Thus do We reward the doers of good.\qt@no{84}}%
\qt@newcmd\qurantrans@en@dccclxxiv{%
And Zechariah and John and Jesus and Elias - and all were of the righteous.\qt@no{85}}%
\qt@newcmd\qurantrans@en@dccclxxv{%
And Ishmael and Elisha and Jonah and Lot - and all [of them] We preferred over the worlds.\qt@no{86}}%
\qt@newcmd\qurantrans@en@dccclxxvi{%
And [some] among their fathers and their descendants and their brothers - and We chose them and We guided them to a straight path.\qt@no{87}}%
\qt@newcmd\qurantrans@en@dccclxxvii{%
That is the guidance of Allah by which He guides whomever He wills of His servants. But if they had associated others with Allah, then worthless for them would be whatever they were doing.\qt@no{88}}%
\qt@newcmd\qurantrans@en@dccclxxviii{%
Those are the ones to whom We gave the Scripture and authority and prophethood. But if the disbelievers deny it, then We have entrusted it to a people who are not therein disbelievers.\qt@no{89}}%
\qt@newcmd\qurantrans@en@dccclxxix{%
Those are the ones whom Allah has guided, so from their guidance take an example. Say, ``I ask of you for this message no payment. It is not but a reminder for the worlds."\qt@no{90}}%
\qt@newcmd\qurantrans@en@dccclxxx{%
And they did not appraise Allah with true appraisal when they said, ``Allah did not reveal to a human being anything." Say, ``Who revealed the Scripture that Moses brought as light and guidance to the people? You [Jews] make it into pages, disclosing [some of] it and concealing much. And you were taught that which you knew not - neither you nor your fathers." Say, ``Allah [revealed it]." Then leave them in their [empty] discourse, amusing themselves.\qt@no{91}}%
\qt@newcmd\qurantrans@en@dccclxxxi{%
And this is a Book which We have sent down, blessed and confirming what was before it, that you may warn the Mother of Cities and those around it. Those who believe in the Hereafter believe in it, and they are maintaining their prayers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@dccclxxxii{%
And who is more unjust than one who invents a lie about Allah or says, ``It has been inspired to me," while nothing has been inspired to him, and one who says, ``I will reveal [something] like what Allah revealed." And if you could but see when the wrongdoers are in the overwhelming pangs of death while the angels extend their hands, [saying], ``Discharge your souls! Today you will be awarded the punishment of [extreme] humiliation for what you used to say against Allah other than the truth and [that] you were, toward His verses, being arrogant."\qt@no{93}}%
\qt@newcmd\qurantrans@en@dccclxxxiii{%
[It will be said to them], ``And you have certainly come to Us alone as We created you the first time, and you have left whatever We bestowed upon you behind you. And We do not see with you your 'intercessors' which you claimed that they were among you associates [of Allah]. It has [all] been severed between you, and lost from you is what you used to claim."\qt@no{94}}%
\qt@newcmd\qurantrans@en@dccclxxxiv{%
Indeed, Allah is the cleaver of grain and date seeds. He brings the living out of the dead and brings the dead out of the living. That is Allah; so how are you deluded?\qt@no{95}}%
\qt@newcmd\qurantrans@en@dccclxxxv{%
[He is] the cleaver of daybreak and has made the night for rest and the sun and moon for calculation. That is the determination of the Exalted in Might, the Knowing.\qt@no{96}}%
\qt@newcmd\qurantrans@en@dccclxxxvi{%
And it is He who placed for you the stars that you may be guided by them through the darknesses of the land and sea. We have detailed the signs for a people who know.\qt@no{97}}%
\qt@newcmd\qurantrans@en@dccclxxxvii{%
And it is He who produced you from one soul and [gave you] a place of dwelling and of storage. We have detailed the signs for a people who understand.\qt@no{98}}%
\qt@newcmd\qurantrans@en@dccclxxxviii{%
And it is He who sends down rain from the sky, and We produce thereby the growth of all things. We produce from it greenery from which We produce grains arranged in layers. And from the palm trees - of its emerging fruit are clusters hanging low. And [We produce] gardens of grapevines and olives and pomegranates, similar yet varied. Look at [each of] its fruit when it yields and [at] its ripening. Indeed in that are signs for a people who believe.\qt@no{99}}%
\qt@newcmd\qurantrans@en@dccclxxxix{%
But they have attributed to Allah partners - the jinn, while He has created them - and have fabricated for Him sons and daughters. Exalted is He and high above what they describe\qt@no{100}}%
\qt@newcmd\qurantrans@en@dcccxc{%
[He is] Originator of the heavens and the earth. How could He have a son when He does not have a companion and He created all things? And He is, of all things, Knowing.\qt@no{101}}%
\qt@newcmd\qurantrans@en@dcccxci{%
That is Allah, your Lord; there is no deity except Him, the Creator of all things, so worship Him. And He is Disposer of all things.\qt@no{102}}%
\qt@newcmd\qurantrans@en@dcccxcii{%
Vision perceives Him not, but He perceives [all] vision; and He is the Subtle, the Acquainted.\qt@no{103}}%
\qt@newcmd\qurantrans@en@dcccxciii{%
There has come to you enlightenment from your Lord. So whoever will see does so for [the benefit of] his soul, and whoever is blind [does harm] against it. And [say], ``I am not a guardian over you."\qt@no{104}}%
\qt@newcmd\qurantrans@en@dcccxciv{%
And thus do We diversify the verses so the disbelievers will say, ``You have studied," and so We may make the Qur'an clear for a people who know.\qt@no{105}}%
\qt@newcmd\qurantrans@en@dcccxcv{%
Follow, [O Muhammad], what has been revealed to you from your Lord - there is no deity except Him - and turn away from those who associate others with Allah.\qt@no{106}}%
\qt@newcmd\qurantrans@en@dcccxcvi{%
But if Allah had willed, they would not have associated. And We have not appointed you over them as a guardian, nor are you a manager over them.\qt@no{107}}%
\qt@newcmd\qurantrans@en@dcccxcvii{%
And do not insult those they invoke other than Allah, lest they insult Allah in enmity without knowledge. Thus We have made pleasing to every community their deeds. Then to their Lord is their return, and He will inform them about what they used to do.\qt@no{108}}%
\qt@newcmd\qurantrans@en@dcccxcviii{%
And they swear by Allah their strongest oaths that if a sign came to them, they would surely believe in it. Say, ``The signs are only with Allah." And what will make you perceive that even if a sign came, they would not believe.\qt@no{109}}%
\qt@newcmd\qurantrans@en@dcccxcix{%
And We will turn away their hearts and their eyes just as they refused to believe in it the first time. And We will leave them in their transgression, wandering blindly.\qt@no{110}}%
\qt@newcmd\qurantrans@en@cm{%
And even if We had sent down to them the angels [with the message] and the dead spoke to them [of it] and We gathered together every [created] thing in front of them, they would not believe unless Allah should will. But most of them, [of that], are ignorant.\qt@no{111}}%
\qt@newcmd\qurantrans@en@cmi{%
And thus We have made for every prophet an enemy - devils from mankind and jinn, inspiring to one another decorative speech in delusion. But if your Lord had willed, they would not have done it, so leave them and that which they invent.\qt@no{112}}%
\qt@newcmd\qurantrans@en@cmii{%
And [it is] so the hearts of those who disbelieve in the Hereafter will incline toward it and that they will be satisfied with it and that they will commit that which they are committing.\qt@no{113}}%
\qt@newcmd\qurantrans@en@cmiii{%
[Say], ``Then is it other than Allah I should seek as judge while it is He who has revealed to you the Book explained in detail?" And those to whom We [previously] gave the Scripture know that it is sent down from your Lord in truth, so never be among the doubters.\qt@no{114}}%
\qt@newcmd\qurantrans@en@cmiv{%
And the word of your Lord has been fulfilled in truth and in justice. None can alter His words, and He is the Hearing, the Knowing.\qt@no{115}}%
\qt@newcmd\qurantrans@en@cmv{%
And if you obey most of those upon the earth, they will mislead you from the way of Allah. They follow not except assumption, and they are not but falsifying.\qt@no{116}}%
\qt@newcmd\qurantrans@en@cmvi{%
Indeed, your Lord is most knowing of who strays from His way, and He is most knowing of the [rightly] guided.\qt@no{117}}%
\qt@newcmd\qurantrans@en@cmvii{%
So eat of that [meat] upon which the name of Allah has been mentioned, if you are believers in His verses.\qt@no{118}}%
\qt@newcmd\qurantrans@en@cmviii{%
And why should you not eat of that upon which the name of Allah has been mentioned while He has explained in detail to you what He has forbidden you, excepting that to which you are compelled. And indeed do many lead [others] astray through their [own] inclinations without knowledge. Indeed, your Lord - He is most knowing of the transgressors.\qt@no{119}}%
\qt@newcmd\qurantrans@en@cmix{%
And leave what is apparent of sin and what is concealed thereof. Indeed, those who earn [blame for] sin will be recompensed for that which they used to commit.\qt@no{120}}%
\qt@newcmd\qurantrans@en@cmx{%
And do not eat of that upon which the name of Allah has not been mentioned, for indeed, it is grave disobedience. And indeed do the devils inspire their allies [among men] to dispute with you. And if you were to obey them, indeed, you would be associators [of others with Him].\qt@no{121}}%
\qt@newcmd\qurantrans@en@cmxi{%
And is one who was dead and We gave him life and made for him light by which to walk among the people like one who is in darkness, never to emerge therefrom? Thus it has been made pleasing to the disbelievers that which they were doing.\qt@no{122}}%
\qt@newcmd\qurantrans@en@cmxii{%
And thus We have placed within every city the greatest of its criminals to conspire therein. But they conspire not except against themselves, and they perceive [it] not.\qt@no{123}}%
\qt@newcmd\qurantrans@en@cmxiii{%
And when a sign comes to them, they say, ``Never will we believe until we are given like that which was given to the messengers of Allah." Allah is most knowing of where He places His message. There will afflict those who committed crimes debasement before Allah and severe punishment for what they used to conspire.\qt@no{124}}%
\qt@newcmd\qurantrans@en@cmxiv{%
So whoever Allah wants to guide - He expands his breast to [contain] Islam; and whoever He wants to misguide - He makes his breast tight and constricted as though he were climbing into the sky. Thus does Allah place defilement upon those who do not believe.\qt@no{125}}%
\qt@newcmd\qurantrans@en@cmxv{%
And this is the path of your Lord, [leading] straight. We have detailed the verses for a people who remember.\qt@no{126}}%
\qt@newcmd\qurantrans@en@cmxvi{%
For them will be the Home of Peace with their Lord. And He will be their protecting friend because of what they used to do.\qt@no{127}}%
\qt@newcmd\qurantrans@en@cmxvii{%
And [mention, O Muhammad], the Day when He will gather them together [and say], ``O company of jinn, you have [misled] many of mankind." And their allies among mankind will say, ``Our Lord, some of us made use of others, and we have [now] reached our term, which you appointed for us." He will say, ``The Fire is your residence, wherein you will abide eternally, except for what Allah wills. Indeed, your Lord is Wise and Knowing."\qt@no{128}}%
\qt@newcmd\qurantrans@en@cmxviii{%
And thus will We make some of the wrongdoers allies of others for what they used to earn.\qt@no{129}}%
\qt@newcmd\qurantrans@en@cmxix{%
``O company of jinn and mankind, did there not come to you messengers from among you, relating to you My verses and warning you of the meeting of this Day of yours?" They will say, ``We bear witness against ourselves"; and the worldly life had deluded them, and they will bear witness against themselves that they were disbelievers.\qt@no{130}}%
\qt@newcmd\qurantrans@en@cmxx{%
That is because your Lord would not destroy the cities for wrongdoing while their people were unaware.\qt@no{131}}%
\qt@newcmd\qurantrans@en@cmxxi{%
And for all are degrees from what they have done. And your Lord is not unaware of what they do.\qt@no{132}}%
\qt@newcmd\qurantrans@en@cmxxii{%
And your Lord is the Free of need, the possessor of mercy. If He wills, he can do away with you and give succession after you to whomever He wills, just as He produced you from the descendants of another people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@cmxxiii{%
Indeed, what you are promised is coming, and you will not cause failure [to Allah].\qt@no{134}}%
\qt@newcmd\qurantrans@en@cmxxiv{%
Say, ``O my people, work according to your position; [for] indeed, I am working. And you are going to know who will have succession in the home. Indeed, the wrongdoers will not succeed.\qt@no{135}}%
\qt@newcmd\qurantrans@en@cmxxv{%
And the polytheists assign to Allah from that which He created of crops and livestock a share and say, ``This is for Allah," by their claim, ``and this is for our partners [associated with Him]." But what is for their ``partners" does not reach Allah, while what is for Allah - this reaches their ``partners." Evil is that which they rule.\qt@no{136}}%
\qt@newcmd\qurantrans@en@cmxxvi{%
And likewise, to many of the polytheists their partners have made [to seem] pleasing the killing of their children in order to bring about their destruction and to cover them with confusion in their religion. And if Allah had willed, they would not have done so. So leave them and that which they invent.\qt@no{137}}%
\qt@newcmd\qurantrans@en@cmxxvii{%
And they say, ``These animals and crops are forbidden; no one may eat from them except whom we will," by their claim. And there are those [camels] whose backs are forbidden [by them] and those upon which the name of Allah is not mentioned - [all of this] an invention of untruth about Him. He will punish them for what they were inventing.\qt@no{138}}%
\qt@newcmd\qurantrans@en@cmxxviii{%
And they say, ``What is in the bellies of these animals is exclusively for our males and forbidden to our females. But if it is [born] dead, then all of them have shares therein." He will punish them for their description. Indeed, He is Wise and Knowing.\qt@no{139}}%
\qt@newcmd\qurantrans@en@cmxxix{%
Those will have lost who killed their children in foolishness without knowledge and prohibited what Allah had provided for them, inventing untruth about Allah. They have gone astray and were not [rightly] guided.\qt@no{140}}%
\qt@newcmd\qurantrans@en@cmxxx{%
And He it is who causes gardens to grow, [both] trellised and untrellised, and palm trees and crops of different [kinds of] food and olives and pomegranates, similar and dissimilar. Eat of [each of] its fruit when it yields and give its due [zakah] on the day of its harvest. And be not excessive. Indeed, He does not like those who commit excess.\qt@no{141}}%
\qt@newcmd\qurantrans@en@cmxxxi{%
And of the grazing livestock are carriers [of burdens] and those [too] small. Eat of what Allah has provided for you and do not follow the footsteps of Satan. Indeed, he is to you a clear enemy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@cmxxxii{%
[They are] eight mates - of the sheep, two and of the goats, two. Say, ``Is it the two males He has forbidden or the two females or that which the wombs of the two females contain? Inform me with knowledge, if you should be truthful."\qt@no{143}}%
\qt@newcmd\qurantrans@en@cmxxxiii{%
And of the camels, two and of the cattle, two. Say, ``Is it the two males He has forbidden or the two females or that which the wombs of the two females contain? Or were you witnesses when Allah charged you with this? Then who is more unjust than one who invents a lie about Allah to mislead the people by [something] other than knowledge? Indeed, Allah does not guide the wrongdoing people."\qt@no{144}}%
\qt@newcmd\qurantrans@en@cmxxxiv{%
Say, ``I do not find within that which was revealed to me [anything] forbidden to one who would eat it unless it be a dead animal or blood spilled out or the flesh of swine - for indeed, it is impure - or it be [that slaughtered in] disobedience, dedicated to other than Allah. But whoever is forced [by necessity], neither desiring [it] nor transgressing [its limit], then indeed, your Lord is Forgiving and Merciful."\qt@no{145}}%
\qt@newcmd\qurantrans@en@cmxxxv{%
And to those who are Jews We prohibited every animal of uncloven hoof; and of the cattle and the sheep We prohibited to them their fat, except what adheres to their backs or the entrails or what is joined with bone. [By] that We repaid them for their injustice. And indeed, We are truthful.\qt@no{146}}%
\qt@newcmd\qurantrans@en@cmxxxvi{%
So if they deny you, [O Muhammad], say, ``Your Lord is the possessor of vast mercy; but His punishment cannot be repelled from the people who are criminals."\qt@no{147}}%
\qt@newcmd\qurantrans@en@cmxxxvii{%
Those who associated with Allah will say, ``If Allah had willed, we would not have associated [anything] and neither would our fathers, nor would we have prohibited anything." Likewise did those before deny until they tasted Our punishment. Say, ``Do you have any knowledge that you can produce for us? You follow not except assumption, and you are not but falsifying."\qt@no{148}}%
\qt@newcmd\qurantrans@en@cmxxxviii{%
Say, ``With Allah is the far-reaching argument. If He had willed, He would have guided you all."\qt@no{149}}%
\qt@newcmd\qurantrans@en@cmxxxix{%
Say, [O Muhammad], ``Bring forward your witnesses who will testify that Allah has prohibited this." And if they testify, do not testify with them. And do not follow the desires of those who deny Our verses and those who do not believe in the Hereafter, while they equate [others] with their Lord.\qt@no{150}}%
\qt@newcmd\qurantrans@en@cmxl{%
Say, ``Come, I will recite what your Lord has prohibited to you. [He commands] that you not associate anything with Him, and to parents, good treatment, and do not kill your children out of poverty; We will provide for you and them. And do not approach immoralities - what is apparent of them and what is concealed. And do not kill the soul which Allah has forbidden [to be killed] except by [legal] right. This has He instructed you that you may use reason."\qt@no{151}}%
\qt@newcmd\qurantrans@en@cmxli{%
And do not approach the orphan's property except in a way that is best until he reaches maturity. And give full measure and weight in justice. We do not charge any soul except [with that within] its capacity. And when you testify, be just, even if [it concerns] a near relative. And the covenant of Allah fulfill. This has He instructed you that you may remember.\qt@no{152}}%
\qt@newcmd\qurantrans@en@cmxlii{%
And, [moreover], this is My path, which is straight, so follow it; and do not follow [other] ways, for you will be separated from His way. This has He instructed you that you may become righteous.\qt@no{153}}%
\qt@newcmd\qurantrans@en@cmxliii{%
Then We gave Moses the Scripture, making complete [Our favor] upon the one who did good and as a detailed explanation of all things and as guidance and mercy that perhaps in [the matter of] the meeting with their Lord they would believe.\qt@no{154}}%
\qt@newcmd\qurantrans@en@cmxliv{%
And this [Qur'an] is a Book We have revealed [which is] blessed, so follow it and fear Allah that you may receive mercy.\qt@no{155}}%
\qt@newcmd\qurantrans@en@cmxlv{%
[We revealed it] lest you say, ``The Scripture was only sent down to two groups before us, but we were of their study unaware,"\qt@no{156}}%
\qt@newcmd\qurantrans@en@cmxlvi{%
Or lest you say, ``If only the Scripture had been revealed to us, we would have been better guided than they." So there has [now] come to you a clear evidence from your Lord and a guidance and mercy. Then who is more unjust than one who denies the verses of Allah and turns away from them? We will recompense those who turn away from Our verses with the worst of punishment for their having turned away.\qt@no{157}}%
\qt@newcmd\qurantrans@en@cmxlvii{%
Do they [then] wait for anything except that the angels should come to them or your Lord should come or that there come some of the signs of your Lord? The Day that some of the signs of your Lord will come no soul will benefit from its faith as long as it had not believed before or had earned through its faith some good. Say, ``Wait. Indeed, we [also] are waiting."\qt@no{158}}%
\qt@newcmd\qurantrans@en@cmxlviii{%
Indeed, those who have divided their religion and become sects - you, [O Muhammad], are not [associated] with them in anything. Their affair is only [left] to Allah; then He will inform them about what they used to do.\qt@no{159}}%
\qt@newcmd\qurantrans@en@cmxlix{%
Whoever comes [on the Day of Judgement] with a good deed will have ten times the like thereof [to his credit], and whoever comes with an evil deed will not be recompensed except the like thereof; and they will not be wronged.\qt@no{160}}%
\qt@newcmd\qurantrans@en@cml{%
Say, ``Indeed, my Lord has guided me to a straight path - a correct religion - the way of Abraham, inclining toward truth. And he was not among those who associated others with Allah."\qt@no{161}}%
\qt@newcmd\qurantrans@en@cmli{%
Say, ``Indeed, my prayer, my rites of sacrifice, my living and my dying are for Allah, Lord of the worlds.\qt@no{162}}%
\qt@newcmd\qurantrans@en@cmlii{%
No partner has He. And this I have been commanded, and I am the first [among you] of the Muslims."\qt@no{163}}%
\qt@newcmd\qurantrans@en@cmliii{%
Say, ``Is it other than Allah I should desire as a lord while He is the Lord of all things? And every soul earns not [blame] except against itself, and no bearer of burdens will bear the burden of another. Then to your Lord is your return, and He will inform you concerning that over which you used to differ."\qt@no{164}}%
\qt@newcmd\qurantrans@en@cmliv{%
And it is He who has made you successors upon the earth and has raised some of you above others in degrees [of rank] that He may try you through what He has given you. Indeed, your Lord is swift in penalty; but indeed, He is Forgiving and Merciful.\qt@no{165}}%
\qt@newcmd\qurantrans@en@cmlv{%
\basmalahen Alif, Lam, Meem, Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@cmlvi{%
[This is] a Book revealed to you, [O Muhammad] - so let there not be in your breast distress therefrom - that you may warn thereby and as a reminder to the believers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@cmlvii{%
Follow, [O mankind], what has been revealed to you from your Lord and do not follow other than Him any allies. Little do you remember.\qt@no{3}}%
\qt@newcmd\qurantrans@en@cmlviii{%
And how many cities have We destroyed, and Our punishment came to them at night or while they were sleeping at noon.\qt@no{4}}%
\qt@newcmd\qurantrans@en@cmlix{%
And their declaration when Our punishment came to them was only that they said, ``Indeed, we were wrongdoers!"\qt@no{5}}%
\qt@newcmd\qurantrans@en@cmlx{%
Then We will surely question those to whom [a message] was sent, and We will surely question the messengers.\qt@no{6}}%
\qt@newcmd\qurantrans@en@cmlxi{%
Then We will surely relate [their deeds] to them with knowledge, and We were not [at all] absent.\qt@no{7}}%
\qt@newcmd\qurantrans@en@cmlxii{%
And the weighing [of deeds] that Day will be the truth. So those whose scales are heavy - it is they who will be the successful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@cmlxiii{%
And those whose scales are light - they are the ones who will lose themselves for what injustice they were doing toward Our verses.\qt@no{9}}%
\qt@newcmd\qurantrans@en@cmlxiv{%
And We have certainly established you upon the earth and made for you therein ways of livelihood. Little are you grateful.\qt@no{10}}%
\qt@newcmd\qurantrans@en@cmlxv{%
And We have certainly created you, [O Mankind], and given you [human] form. Then We said to the angels, ``Prostrate to Adam"; so they prostrated, except for Iblees. He was not of those who prostrated.\qt@no{11}}%
\qt@newcmd\qurantrans@en@cmlxvi{%
[Allah] said, ``What prevented you from prostrating when I commanded you?" [Satan] said, ``I am better than him. You created me from fire and created him from clay."\qt@no{12}}%
\qt@newcmd\qurantrans@en@cmlxvii{%
[Allah] said, ``Descend from Paradise, for it is not for you to be arrogant therein. So get out; indeed, you are of the debased.\qt@no{13}}%
\qt@newcmd\qurantrans@en@cmlxviii{%
[Satan] said, ``Reprieve me until the Day they are resurrected."\qt@no{14}}%
\qt@newcmd\qurantrans@en@cmlxix{%
[Allah] said, ``Indeed, you are of those reprieved."\qt@no{15}}%
\qt@newcmd\qurantrans@en@cmlxx{%
[Satan] said, ``Because You have put me in error, I will surely sit in wait for them on Your straight path.\qt@no{16}}%
\qt@newcmd\qurantrans@en@cmlxxi{%
Then I will come to them from before them and from behind them and on their right and on their left, and You will not find most of them grateful [to You]."\qt@no{17}}%
\qt@newcmd\qurantrans@en@cmlxxii{%
[Allah] said, ``Get out of Paradise, reproached and expelled. Whoever follows you among them - I will surely fill Hell with you, all together."\qt@no{18}}%
\qt@newcmd\qurantrans@en@cmlxxiii{%
And ``O Adam, dwell, you and your wife, in Paradise and eat from wherever you will but do not approach this tree, lest you be among the wrongdoers."\qt@no{19}}%
\qt@newcmd\qurantrans@en@cmlxxiv{%
But Satan whispered to them to make apparent to them that which was concealed from them of their private parts. He said, ``Your Lord did not forbid you this tree except that you become angels or become of the immortal."\qt@no{20}}%
\qt@newcmd\qurantrans@en@cmlxxv{%
And he swore [by Allah] to them, ``Indeed, I am to you from among the sincere advisors."\qt@no{21}}%
\qt@newcmd\qurantrans@en@cmlxxvi{%
So he made them fall, through deception. And when they tasted of the tree, their private parts became apparent to them, and they began to fasten together over themselves from the leaves of Paradise. And their Lord called to them, ``Did I not forbid you from that tree and tell you that Satan is to you a clear enemy?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@cmlxxvii{%
They said, ``Our Lord, we have wronged ourselves, and if You do not forgive us and have mercy upon us, we will surely be among the losers."\qt@no{23}}%
\qt@newcmd\qurantrans@en@cmlxxviii{%
[Allah] said, ``Descend, being to one another enemies. And for you on the earth is a place of settlement and enjoyment for a time."\qt@no{24}}%
\qt@newcmd\qurantrans@en@cmlxxix{%
He said, ``Therein you will live, and therein you will die, and from it you will be brought forth."\qt@no{25}}%
\qt@newcmd\qurantrans@en@cmlxxx{%
O children of Adam, We have bestowed upon you clothing to conceal your private parts and as adornment. But the clothing of righteousness - that is best. That is from the signs of Allah that perhaps they will remember.\qt@no{26}}%
\qt@newcmd\qurantrans@en@cmlxxxi{%
O children of Adam, let not Satan tempt you as he removed your parents from Paradise, stripping them of their clothing to show them their private parts. Indeed, he sees you, he and his tribe, from where you do not see them. Indeed, We have made the devils allies to those who do not believe.\qt@no{27}}%
\qt@newcmd\qurantrans@en@cmlxxxii{%
And when they commit an immorality, they say, ``We found our fathers doing it, and Allah has ordered us to do it." Say, ``Indeed, Allah does not order immorality. Do you say about Allah that which you do not know?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@cmlxxxiii{%
Say, [O Muhammad], ``My Lord has ordered justice and that you maintain yourselves [in worship of Him] at every place [or time] of prostration, and invoke Him, sincere to Him in religion." Just as He originated you, you will return [to life] -\qt@no{29}}%
\qt@newcmd\qurantrans@en@cmlxxxiv{%
A group [of you] He guided, and a group deserved [to be in] error. Indeed, they had taken the devils as allies instead of Allah while they thought that they were guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@cmlxxxv{%
O children of Adam, take your adornment at every masjid, and eat and drink, but be not excessive. Indeed, He likes not those who commit excess.\qt@no{31}}%
\qt@newcmd\qurantrans@en@cmlxxxvi{%
Say, ``Who has forbidden the adornment of Allah which He has produced for His servants and the good [lawful] things of provision?" Say, ``They are for those who believe during the worldly life [but] exclusively for them on the Day of Resurrection." Thus do We detail the verses for a people who know.\qt@no{32}}%
\qt@newcmd\qurantrans@en@cmlxxxvii{%
Say, ``My Lord has only forbidden immoralities - what is apparent of them and what is concealed - and sin, and oppression without right, and that you associate with Allah that for which He has not sent down authority, and that you say about Allah that which you do not know."\qt@no{33}}%
\qt@newcmd\qurantrans@en@cmlxxxviii{%
And for every nation is a [specified] term. So when their time has come, they will not remain behind an hour, nor will they precede [it].\qt@no{34}}%
\qt@newcmd\qurantrans@en@cmlxxxix{%
O children of Adam, if there come to you messengers from among you relating to you My verses, then whoever fears Allah and reforms - there will be no fear concerning them, nor will they grieve.\qt@no{35}}%
\qt@newcmd\qurantrans@en@cmxc{%
But the ones who deny Our verses and are arrogant toward them - those are the companions of the Fire; they will abide therein eternally.\qt@no{36}}%
\qt@newcmd\qurantrans@en@cmxci{%
And who is more unjust than one who invents about Allah a lie or denies His verses? Those will attain their portion of the decree until when Our messengers come to them to take them in death, they will say, ``Where are those you used to invoke besides Allah?" They will say, ``They have departed from us," and will bear witness against themselves that they were disbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@cmxcii{%
[Allah] will say, ``Enter among nations which had passed on before you of jinn and mankind into the Fire." Every time a nation enters, it will curse its sister until, when they have all overtaken one another therein, the last of them will say about the first of them ``Our Lord, these had misled us, so give them a double punishment of the Fire. He will say, ``For each is double, but you do not know."\qt@no{38}}%
\qt@newcmd\qurantrans@en@cmxciii{%
And the first of them will say to the last of them, ``Then you had not any favor over us, so taste the punishment for what you used to earn."\qt@no{39}}%
\qt@newcmd\qurantrans@en@cmxciv{%
Indeed, those who deny Our verses and are arrogant toward them - the gates of Heaven will not be opened for them, nor will they enter Paradise until a camel enters into the eye of a needle. And thus do We recompense the criminals.\qt@no{40}}%
\qt@newcmd\qurantrans@en@cmxcv{%
They will have from Hell a bed and over them coverings [of fire]. And thus do We recompense the wrongdoers.\qt@no{41}}%
\qt@newcmd\qurantrans@en@cmxcvi{%
But those who believed and did righteous deeds - We charge no soul except [within] its capacity. Those are the companions of Paradise; they will abide therein eternally.\qt@no{42}}%
\qt@newcmd\qurantrans@en@cmxcvii{%
And We will have removed whatever is within their breasts of resentment, [while] flowing beneath them are rivers. And they will say, ``Praise to Allah, who has guided us to this; and we would never have been guided if Allah had not guided us. Certainly the messengers of our Lord had come with the truth." And they will be called, ``This is Paradise, which you have been made to inherit for what you used to do."\qt@no{43}}%
\qt@newcmd\qurantrans@en@cmxcviii{%
And the companions of Paradise will call out to the companions of the Fire, ``We have already found what our Lord promised us to be true. Have you found what your Lord promised to be true?" They will say, ``Yes." Then an announcer will announce among them, ``The curse of Allah shall be upon the wrongdoers."\qt@no{44}}%
\qt@newcmd\qurantrans@en@cmxcix{%
Who averted [people] from the way of Allah and sought to make it [seem] deviant while they were, concerning the Hereafter, disbelievers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@m{%
And between them will be a partition, and on [its] elevations are men who recognize all by their mark. And they call out to the companions of Paradise, ``Peace be upon you." They have not [yet] entered it, but they long intensely.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mi{%
And when their eyes are turned toward the companions of the Fire, they say, ``Our Lord, do not place us with the wrongdoing people."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mii{%
And the companions of the Elevations will call to men [within Hell] whom they recognize by their mark, saying, ``Of no avail to you was your gathering and [the fact] that you were arrogant."\qt@no{48}}%
\qt@newcmd\qurantrans@en@miii{%
[Allah will say], ``Are these the ones whom you [inhabitants of Hell] swore that Allah would never offer them mercy? Enter Paradise, [O People of the Elevations]. No fear will there be concerning you, nor will you grieve."\qt@no{49}}%
\qt@newcmd\qurantrans@en@miv{%
And the companions of the Fire will call to the companions of Paradise, ``Pour upon us some water or from whatever Allah has provided you." They will say, ``Indeed, Allah has forbidden them both to the disbelievers."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mv{%
Who took their religion as distraction and amusement and whom the worldly life deluded." So today We will forget them just as they forgot the meeting of this Day of theirs and for having rejected Our verses.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mvi{%
And We had certainly brought them a Book which We detailed by knowledge - as guidance and mercy to a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mvii{%
Do they await except its result? The Day its result comes those who had ignored it before will say, ``The messengers of our Lord had come with the truth, so are there [now] any intercessors to intercede for us or could we be sent back to do other than we used to do?" They will have lost themselves, and lost from them is what they used to invent.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mviii{%
Indeed, your Lord is Allah, who created the heavens and earth in six days and then established Himself above the Throne. He covers the night with the day, [another night] chasing it rapidly; and [He created] the sun, the moon, and the stars, subjected by His command. Unquestionably, His is the creation and the command; blessed is Allah, Lord of the worlds.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mix{%
Call upon your Lord in humility and privately; indeed, He does not like transgressors.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mx{%
And cause not corruption upon the earth after its reformation. And invoke Him in fear and aspiration. Indeed, the mercy of Allah is near to the doers of good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mxi{%
And it is He who sends the winds as good tidings before His mercy until, when they have carried heavy rainclouds, We drive them to a dead land and We send down rain therein and bring forth thereby [some] of all the fruits. Thus will We bring forth the dead; perhaps you may be reminded.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mxii{%
And the good land - its vegetation emerges by permission of its Lord; but that which is bad - nothing emerges except sparsely, with difficulty. Thus do We diversify the signs for a people who are grateful.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mxiii{%
We had certainly sent Noah to his people, and he said, ``O my people, worship Allah; you have no deity other than Him. Indeed, I fear for you the punishment of a tremendous Day.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mxiv{%
Said the eminent among his people, ``Indeed, we see you in clear error."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mxv{%
[Noah] said, ``O my people, there is not error in me, but I am a messenger from the Lord of the worlds."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mxvi{%
I convey to you the messages of my Lord and advise you; and I know from Allah what you do not know.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mxvii{%
Then do you wonder that there has come to you a reminder from your Lord through a man from among you, that he may warn you and that you may fear Allah so you might receive mercy."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mxviii{%
But they denied him, so We saved him and those who were with him in the ship. And We drowned those who denied Our signs. Indeed, they were a blind people.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mxix{%
And to the 'Aad [We sent] their brother Hud. He said, ``O my people, worship Allah; you have no deity other than Him. Then will you not fear Him?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mxx{%
Said the eminent ones who disbelieved among his people, ``Indeed, we see you in foolishness, and indeed, we think you are of the liars."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mxxi{%
[Hud] said, ``O my people, there is not foolishness in me, but I am a messenger from the Lord of the worlds."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mxxii{%
I convey to you the messages of my Lord, and I am to you a trustworthy adviser.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mxxiii{%
Then do you wonder that there has come to you a reminder from your Lord through a man from among you, that he may warn you? And remember when He made you successors after the people of Noah and increased you in stature extensively. So remember the favors of Allah that you might succeed.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mxxiv{%
They said, ``Have you come to us that we should worship Allah alone and leave what our fathers have worshipped? Then bring us what you promise us, if you should be of the truthful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mxxv{%
[Hud] said, ``Already have defilement and anger fallen upon you from your Lord. Do you dispute with me concerning [mere] names you have named them, you and your fathers, for which Allah has not sent down any authority? Then wait; indeed, I am with you among those who wait."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mxxvi{%
So We saved him and those with him by mercy from Us. And We eliminated those who denied Our signs, and they were not [at all] believers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mxxvii{%
And to the Thamud [We sent] their brother Salih. He said, ``O my people, worship Allah; you have no deity other than Him. There has come to you clear evidence from your Lord. This is the she-camel of Allah [sent] to you as a sign. So leave her to eat within Allah 's land and do not touch her with harm, lest there seize you a painful punishment.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mxxviii{%
And remember when He made you successors after the 'Aad and settled you in the land, [and] you take for yourselves palaces from its plains and carve from the mountains, homes. Then remember the favors of Allah and do not commit abuse on the earth, spreading corruption."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mxxix{%
Said the eminent ones who were arrogant among his people to those who were oppressed - to those who believed among them, ``Do you [actually] know that Salih is sent from his Lord?" They said, ``Indeed we, in that with which he was sent, are believers."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mxxx{%
Said those who were arrogant, ``Indeed we, in that which you have believed, are disbelievers."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mxxxi{%
So they hamstrung the she-camel and were insolent toward the command of their Lord and said, ``O Salih, bring us what you promise us, if you should be of the messengers."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mxxxii{%
So the earthquake seized them, and they became within their home [corpses] fallen prone.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mxxxiii{%
And he turned away from them and said, ``O my people, I had certainly conveyed to you the message of my Lord and advised you, but you do not like advisors."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mxxxiv{%
And [We had sent] Lot when he said to his people, ``Do you commit such immorality as no one has preceded you with from among the worlds?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mxxxv{%
Indeed, you approach men with desire, instead of women. Rather, you are a transgressing people."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mxxxvi{%
But the answer of his people was only that they said, ``Evict them from your city! Indeed, they are men who keep themselves pure."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mxxxvii{%
So We saved him and his family, except for his wife; she was of those who remained [with the evildoers].\qt@no{83}}%
\qt@newcmd\qurantrans@en@mxxxviii{%
And We rained upon them a rain [of stones]. Then see how was the end of the criminals.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mxxxix{%
And to [the people of] Madyan [We sent] their brother Shu'ayb. He said, ``O my people, worship Allah; you have no deity other than Him. There has come to you clear evidence from your Lord. So fulfill the measure and weight and do not deprive people of their due and cause not corruption upon the earth after its reformation. That is better for you, if you should be believers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mxl{%
And do not sit on every path, threatening and averting from the way of Allah those who believe in Him, seeking to make it [seem] deviant. And remember when you were few and He increased you. And see how was the end of the corrupters.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mxli{%
And if there should be a group among you who has believed in that with which I have been sent and a group that has not believed, then be patient until Allah judges between us. And He is the best of judges."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mxlii{%
Said the eminent ones who were arrogant among his people, ``We will surely evict you, O Shu'ayb, and those who have believed with you from our city, or you must return to our religion." He said, ``Even if we were unwilling?"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mxliii{%
We would have invented against Allah a lie if we returned to your religion after Allah had saved us from it. And it is not for us to return to it except that Allah, our Lord, should will. Our Lord has encompassed all things in knowledge. Upon Allah we have relied. Our Lord, decide between us and our people in truth, and You are the best of those who give decision."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mxliv{%
Said the eminent ones who disbelieved among his people, ``If you should follow Shu'ayb, indeed, you would then be losers."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mxlv{%
So the earthquake seized them, and they became within their home [corpses] fallen prone.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mxlvi{%
Those who denied Shu'ayb - it was as though they had never resided there. Those who denied Shu'ayb - it was they who were the losers.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mxlvii{%
And he turned away from them and said, ``O my people, I had certainly conveyed to you the messages of my Lord and advised you, so how could I grieve for a disbelieving people?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mxlviii{%
And We sent to no city a prophet [who was denied] except that We seized its people with poverty and hardship that they might humble themselves [to Allah].\qt@no{94}}%
\qt@newcmd\qurantrans@en@mxlix{%
Then We exchanged in place of the bad [condition], good, until they increased [and prospered] and said, ``Our fathers [also] were touched with hardship and ease." So We seized them suddenly while they did not perceive.\qt@no{95}}%
\qt@newcmd\qurantrans@en@ml{%
And if only the people of the cities had believed and feared Allah, We would have opened upon them blessings from the heaven and the earth; but they denied [the messengers], so We seized them for what they were earning."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mli{%
Then, did the people of the cities feel secure from Our punishment coming to them at night while they were asleep?\qt@no{97}}%
\qt@newcmd\qurantrans@en@mlii{%
Or did the people of the cities feel secure from Our punishment coming to them in the morning while they were at play?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mliii{%
Then did they feel secure from the plan of Allah? But no one feels secure from the plan of Allah except the losing people.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mliv{%
Has it not become clear to those who inherited the earth after its [previous] people that if We willed, We could afflict them for their sins? But We seal over their hearts so they do not hear.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mlv{%
Those cities - We relate to you, [O Muhammad], some of their news. And certainly did their messengers come to them with clear proofs, but they were not to believe in that which they had denied before. Thus does Allah seal over the hearts of the disbelievers.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mlvi{%
And We did not find for most of them any covenant; but indeed, We found most of them defiantly disobedient.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mlvii{%
Then We sent after them Moses with Our signs to Pharaoh and his establishment, but they were unjust toward them. So see how was the end of the corrupters.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mlviii{%
And Moses said, ``O Pharaoh, I am a messenger from the Lord of the worlds\qt@no{104}}%
\qt@newcmd\qurantrans@en@mlix{%
[Who is] obligated not to say about Allah except the truth. I have come to you with clear evidence from your Lord, so send with me the Children of Israel."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mlx{%
[Pharaoh] said, ``If you have come with a sign, then bring it forth, if you should be of the truthful."\qt@no{106}}%
\qt@newcmd\qurantrans@en@mlxi{%
So Moses threw his staff, and suddenly it was a serpent, manifest.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mlxii{%
And he drew out his hand; thereupon it was white [with radiance] for the observers.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mlxiii{%
Said the eminent among the people of Pharaoh, ``Indeed, this is a learned magician\qt@no{109}}%
\qt@newcmd\qurantrans@en@mlxiv{%
Who wants to expel you from your land [through magic], so what do you instruct?"\qt@no{110}}%
\qt@newcmd\qurantrans@en@mlxv{%
They said, ``Postpone [the matter of] him and his brother and send among the cities gatherers\qt@no{111}}%
\qt@newcmd\qurantrans@en@mlxvi{%
Who will bring you every learned magician."\qt@no{112}}%
\qt@newcmd\qurantrans@en@mlxvii{%
And the magicians came to Pharaoh. They said, ``Indeed for us is a reward if we are the predominant."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mlxviii{%
He said, ``Yes, and, [moreover], you will be among those made near [to me]."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mlxix{%
They said, ``O Moses, either you throw [your staff], or we will be the ones to throw [first]."\qt@no{115}}%
\qt@newcmd\qurantrans@en@mlxx{%
He said, ``Throw," and when they threw, they bewitched the eyes of the people and struck terror into them, and they presented a great [feat of] magic.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mlxxi{%
And We inspired to Moses, ``Throw your staff," and at once it devoured what they were falsifying.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mlxxii{%
So the truth was established, and abolished was what they were doing.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mlxxiii{%
And Pharaoh and his people were overcome right there and became debased.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mlxxiv{%
And the magicians fell down in prostration [to Allah].\qt@no{120}}%
\qt@newcmd\qurantrans@en@mlxxv{%
They said, ``We have believed in the Lord of the worlds,\qt@no{121}}%
\qt@newcmd\qurantrans@en@mlxxvi{%
The Lord of Moses and Aaron."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mlxxvii{%
Said Pharaoh, ``You believed in him before I gave you permission. Indeed, this is a conspiracy which you conspired in the city to expel therefrom its people. But you are going to know.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mlxxviii{%
I will surely cut off your hands and your feet on opposite sides; then I will surely crucify you all."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mlxxix{%
They said, ``Indeed, to our Lord we will return.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mlxxx{%
And you do not resent us except because we believed in the signs of our Lord when they came to us. Our Lord, pour upon us patience and let us die as Muslims [in submission to You]."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mlxxxi{%
And the eminent among the people of Pharaoh said," Will you leave Moses and his people to cause corruption in the land and abandon you and your gods?" [Pharaoh] said, ``We will kill their sons and keep their women alive; and indeed, we are subjugators over them."\qt@no{127}}%
\qt@newcmd\qurantrans@en@mlxxxii{%
Said Moses to his people, ``Seek help through Allah and be patient. Indeed, the earth belongs to Allah. He causes to inherit it whom He wills of His servants. And the [best] outcome is for the righteous."\qt@no{128}}%
\qt@newcmd\qurantrans@en@mlxxxiii{%
They said, ``We have been harmed before you came to us and after you have come to us." He said, ``Perhaps your Lord will destroy your enemy and grant you succession in the land and see how you will do."\qt@no{129}}%
\qt@newcmd\qurantrans@en@mlxxxiv{%
And We certainly seized the people of Pharaoh with years of famine and a deficiency in fruits that perhaps they would be reminded.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mlxxxv{%
But when good came to them, they said, ``This is ours [by right]." And if a bad [condition] struck them, they saw an evil omen in Moses and those with him. Unquestionably, their fortune is with Allah, but most of them do not know.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mlxxxvi{%
And they said, ``No matter what sign you bring us with which to bewitch us, we will not be believers in you."\qt@no{132}}%
\qt@newcmd\qurantrans@en@mlxxxvii{%
So We sent upon them the flood and locusts and lice and frogs and blood as distinct signs, but they were arrogant and were a criminal people.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mlxxxviii{%
And when the punishment descended upon them, they said, ``O Moses, invoke for us your Lord by what He has promised you. If you [can] remove the punishment from us, we will surely believe you, and we will send with you the Children of Israel."\qt@no{134}}%
\qt@newcmd\qurantrans@en@mlxxxix{%
But when We removed the punishment from them until a term which they were to reach, then at once they broke their word.\qt@no{135}}%
\qt@newcmd\qurantrans@en@mxc{%
So We took retribution from them, and We drowned them in the sea because they denied Our signs and were heedless of them.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mxci{%
And We caused the people who had been oppressed to inherit the eastern regions of the land and the western ones, which We had blessed. And the good word of your Lord was fulfilled for the Children of Israel because of what they had patiently endured. And We destroyed [all] that Pharaoh and his people were producing and what they had been building.\qt@no{137}}%
\qt@newcmd\qurantrans@en@mxcii{%
And We took the Children of Israel across the sea; then they came upon a people intent in devotion to [some] idols of theirs. They said, ``O Moses, make for us a god just as they have gods." He said, ``Indeed, you are a people behaving ignorantly.\qt@no{138}}%
\qt@newcmd\qurantrans@en@mxciii{%
Indeed, those [worshippers] - destroyed is that in which they are [engaged], and worthless is whatever they were doing."\qt@no{139}}%
\qt@newcmd\qurantrans@en@mxciv{%
He said, ``Is it other than Allah I should desire for you as a god while He has preferred you over the worlds?"\qt@no{140}}%
\qt@newcmd\qurantrans@en@mxcv{%
And [recall, O Children of Israel], when We saved you from the people of Pharaoh, [who were] afflicting you with the worst torment - killing your sons and keeping your women alive. And in that was a great trial from your Lord.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mxcvi{%
And We made an appointment with Moses for thirty nights and perfected them by [the addition of] ten; so the term of his Lord was completed as forty nights. And Moses said to his brother Aaron, ``Take my place among my people, do right [by them], and do not follow the way of the corrupters."\qt@no{142}}%
\qt@newcmd\qurantrans@en@mxcvii{%
And when Moses arrived at Our appointed time and his Lord spoke to him, he said, ``My Lord, show me [Yourself] that I may look at You." [Allah] said, ``You will not see Me, but look at the mountain; if it should remain in place, then you will see Me." But when his Lord appeared to the mountain, He rendered it level, and Moses fell unconscious. And when he awoke, he said, ``Exalted are You! I have repented to You, and I am the first of the believers."\qt@no{143}}%
\qt@newcmd\qurantrans@en@mxcviii{%
[Allah] said, ``O Moses, I have chosen you over the people with My messages and My words [to you]. So take what I have given you and be among the grateful."\qt@no{144}}%
\qt@newcmd\qurantrans@en@mxcix{%
And We wrote for him on the tablets [something] of all things - instruction and explanation for all things, [saying], ``Take them with determination and order your people to take the best of it. I will show you the home of the defiantly disobedient."\qt@no{145}}%
\qt@newcmd\qurantrans@en@mc{%
I will turn away from My signs those who are arrogant upon the earth without right; and if they should see every sign, they will not believe in it. And if they see the way of consciousness, they will not adopt it as a way; but if they see the way of error, they will adopt it as a way. That is because they have denied Our signs and they were heedless of them.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mci{%
Those who denied Our signs and the meeting of the Hereafter - their deeds have become worthless. Are they recompensed except for what they used to do?\qt@no{147}}%
\qt@newcmd\qurantrans@en@mcii{%
And the people of Moses made, after [his departure], from their ornaments a calf - an image having a lowing sound. Did they not see that it could neither speak to them nor guide them to a way? They took it [for worship], and they were wrongdoers.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mciii{%
And when regret overcame them and they saw that they had gone astray, they said, ``If our Lord does not have mercy upon us and forgive us, we will surely be among the losers."\qt@no{149}}%
\qt@newcmd\qurantrans@en@mciv{%
And when Moses returned to his people, angry and grieved, he said, ``How wretched is that by which you have replaced me after [my departure]. Were you impatient over the matter of your Lord?" And he threw down the tablets and seized his brother by [the hair of] his head, pulling him toward him. [Aaron] said, ``O son of my mother, indeed the people oppressed me and were about to kill me, so let not the enemies rejoice over me and do not place me among the wrongdoing people."\qt@no{150}}%
\qt@newcmd\qurantrans@en@mcv{%
[Moses] said, ``My Lord, forgive me and my brother and admit us into Your mercy, for You are the most merciful of the merciful."\qt@no{151}}%
\qt@newcmd\qurantrans@en@mcvi{%
Indeed, those who took the calf [for worship] will obtain anger from their Lord and humiliation in the life of this world, and thus do We recompense the inventors [of falsehood].\qt@no{152}}%
\qt@newcmd\qurantrans@en@mcvii{%
But those who committed misdeeds and then repented after them and believed - indeed your Lord, thereafter, is Forgiving and Merciful.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mcviii{%
And when the anger subsided in Moses, he took up the tablets; and in their inscription was guidance and mercy for those who are fearful of their Lord.\qt@no{154}}%
\qt@newcmd\qurantrans@en@mcix{%
And Moses chose from his people seventy men for Our appointment. And when the earthquake seized them, he said, ``My Lord, if You had willed, You could have destroyed them before and me [as well]. Would You destroy us for what the foolish among us have done? This is not but Your trial by which You send astray whom You will and guide whom You will. You are our Protector, so forgive us and have mercy upon us; and You are the best of forgivers.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mcx{%
And decree for us in this world [that which is] good and [also] in the Hereafter; indeed, we have turned back to You." [Allah] said, ``My punishment - I afflict with it whom I will, but My mercy encompasses all things." So I will decree it [especially] for those who fear Me and give zakah and those who believe in Our verses -\qt@no{156}}%
\qt@newcmd\qurantrans@en@mcxi{%
Those who follow the Messenger, the unlettered prophet, whom they find written in what they have of the Torah and the Gospel, who enjoins upon them what is right and forbids them what is wrong and makes lawful for them the good things and prohibits for them the evil and relieves them of their burden and the shackles which were upon them. So they who have believed in him, honored him, supported him and followed the light which was sent down with him - it is those who will be the successful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mcxii{%
Say, [O Muhammad], ``O mankind, indeed I am the Messenger of Allah to you all, [from Him] to whom belongs the dominion of the heavens and the earth. There is no deity except Him; He gives life and causes death." So believe in Allah and His Messenger, the unlettered prophet, who believes in Allah and His words, and follow him that you may be guided.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mcxiii{%
And among the people of Moses is a community which guides by truth and by it establishes justice.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mcxiv{%
And We divided them into twelve descendant tribes [as distinct] nations. And We inspired to Moses when his people implored him for water, ``Strike with your staff the stone," and there gushed forth from it twelve springs. Every people knew its watering place. And We shaded them with clouds and sent down upon them manna and quails, [saying], ``Eat from the good things with which We have provided you." And they wronged Us not, but they were [only] wronging themselves.\qt@no{160}}%
\qt@newcmd\qurantrans@en@mcxv{%
And [mention, O Muhammad], when it was said to them, ``Dwell in this city and eat from it wherever you will and say, 'Relieve us of our burdens,' and enter the gate bowing humbly; We will [then] forgive you your sins. We will increase the doers of good [in goodness and reward]."\qt@no{161}}%
\qt@newcmd\qurantrans@en@mcxvi{%
But those who wronged among them changed [the words] to a statement other than that which had been said to them. So We sent upon them a punishment from the sky for the wrong that they were doing.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mcxvii{%
And ask them about the town that was by the sea - when they transgressed in [the matter of] the sabbath - when their fish came to them openly on their sabbath day, and the day they had no sabbath they did not come to them. Thus did We give them trial because they were defiantly disobedient.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mcxviii{%
And when a community among them said, ``Why do you advise [or warn] a people whom Allah is [about] to destroy or to punish with a severe punishment?" they [the advisors] said, ``To be absolved before your Lord and perhaps they may fear Him."\qt@no{164}}%
\qt@newcmd\qurantrans@en@mcxix{%
And when they forgot that by which they had been reminded, We saved those who had forbidden evil and seized those who wronged, with a wretched punishment, because they were defiantly disobeying.\qt@no{165}}%
\qt@newcmd\qurantrans@en@mcxx{%
So when they were insolent about that which they had been forbidden, We said to them, ``Be apes, despised."\qt@no{166}}%
\qt@newcmd\qurantrans@en@mcxxi{%
And [mention] when your Lord declared that He would surely [continue to] send upon them until the Day of Resurrection those who would afflict them with the worst torment. Indeed, your Lord is swift in penalty; but indeed, He is Forgiving and Merciful.\qt@no{167}}%
\qt@newcmd\qurantrans@en@mcxxii{%
And We divided them throughout the earth into nations. Of them some were righteous, and of them some were otherwise. And We tested them with good [times] and bad that perhaps they would return [to obedience].\qt@no{168}}%
\qt@newcmd\qurantrans@en@mcxxiii{%
And there followed them successors who inherited the Scripture [while] taking the commodities of this lower life and saying, ``It will be forgiven for us." And if an offer like it comes to them, they will [again] take it. Was not the covenant of the Scripture taken from them that they would not say about Allah except the truth, and they studied what was in it? And the home of the Hereafter is better for those who fear Allah, so will you not use reason?\qt@no{169}}%
\qt@newcmd\qurantrans@en@mcxxiv{%
But those who hold fast to the Book and establish prayer - indeed, We will not allow to be lost the reward of the reformers.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mcxxv{%
And [mention] when We raised the mountain above them as if it was a dark cloud and they were certain that it would fall upon them, [and Allah said], ``Take what We have given you with determination and remember what is in it that you might fear Allah."\qt@no{171}}%
\qt@newcmd\qurantrans@en@mcxxvi{%
And [mention] when your Lord took from the children of Adam - from their loins - their descendants and made them testify of themselves, [saying to them], ``Am I not your Lord?" They said, ``Yes, we have testified." [This] - lest you should say on the day of Resurrection, ``Indeed, we were of this unaware."\qt@no{172}}%
\qt@newcmd\qurantrans@en@mcxxvii{%
Or [lest] you say, ``It was only that our fathers associated [others in worship] with Allah before, and we were but descendants after them. Then would You destroy us for what the falsifiers have done?"\qt@no{173}}%
\qt@newcmd\qurantrans@en@mcxxviii{%
And thus do We [explain in] detail the verses, and perhaps they will return.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mcxxix{%
And recite to them, [O Muhammad], the news of him to whom we gave [knowledge of] Our signs, but he detached himself from them; so Satan pursued him, and he became of the deviators.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mcxxx{%
And if We had willed, we could have elevated him thereby, but he adhered [instead] to the earth and followed his own desire. So his example is like that of the dog: if you chase him, he pants, or if you leave him, he [still] pants. That is the example of the people who denied Our signs. So relate the stories that perhaps they will give thought.\qt@no{176}}%
\qt@newcmd\qurantrans@en@mcxxxi{%
How evil an example [is that of] the people who denied Our signs and used to wrong themselves.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mcxxxii{%
Whoever Allah guides - he is the [rightly] guided; and whoever He sends astray - it is those who are the losers.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mcxxxiii{%
And We have certainly created for Hell many of the jinn and mankind. They have hearts with which they do not understand, they have eyes with which they do not see, and they have ears with which they do not hear. Those are like livestock; rather, they are more astray. It is they who are the heedless.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mcxxxiv{%
And to Allah belong the best names, so invoke Him by them. And leave [the company of] those who practice deviation concerning His names. They will be recompensed for what they have been doing.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mcxxxv{%
And among those We created is a community which guides by truth and thereby establishes justice.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mcxxxvi{%
But those who deny Our signs - We will progressively lead them [to destruction] from where they do not know.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mcxxxvii{%
And I will give them time. Indeed, my plan is firm.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mcxxxviii{%
Then do they not give thought? There is in their companion [Muhammad] no madness. He is not but a clear warner.\qt@no{184}}%
\qt@newcmd\qurantrans@en@mcxxxix{%
Do they not look into the realm of the heavens and the earth and everything that Allah has created and [think] that perhaps their appointed time has come near? So in what statement hereafter will they believe?\qt@no{185}}%
\qt@newcmd\qurantrans@en@mcxl{%
Whoever Allah sends astray - there is no guide for him. And He leaves them in their transgression, wandering blindly.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mcxli{%
They ask you, [O Muhammad], about the Hour: when is its arrival? Say, ``Its knowledge is only with my Lord. None will reveal its time except Him. It lays heavily upon the heavens and the earth. It will not come upon you except unexpectedly." They ask you as if you are familiar with it. Say, ``Its knowledge is only with Allah, but most of the people do not know."\qt@no{187}}%
\qt@newcmd\qurantrans@en@mcxlii{%
Say, ``I hold not for myself [the power of] benefit or harm, except what Allah has willed. And if I knew the unseen, I could have acquired much wealth, and no harm would have touched me. I am not except a warner and a bringer of good tidings to a people who believe."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mcxliii{%
It is He who created you from one soul and created from it its mate that he might dwell in security with her. And when he covers her, she carries a light burden and continues therein. And when it becomes heavy, they both invoke Allah, their Lord, ``If You should give us a good [child], we will surely be among the grateful."\qt@no{189}}%
\qt@newcmd\qurantrans@en@mcxliv{%
But when He gives them a good [child], they ascribe partners to Him concerning that which He has given them. Exalted is Allah above what they associate with Him.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mcxlv{%
Do they associate with Him those who create nothing and they are [themselves] created?\qt@no{191}}%
\qt@newcmd\qurantrans@en@mcxlvi{%
And the false deities are unable to [give] them help, nor can they help themselves.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mcxlvii{%
And if you [believers] invite them to guidance, they will not follow you. It is all the same for you whether you invite them or you are silent.\qt@no{193}}%
\qt@newcmd\qurantrans@en@mcxlviii{%
Indeed, those you [polytheists] call upon besides Allah are servants like you. So call upon them and let them respond to you, if you should be truthful.\qt@no{194}}%
\qt@newcmd\qurantrans@en@mcxlix{%
Do they have feet by which they walk? Or do they have hands by which they strike? Or do they have eyes by which they see? Or do they have ears by which they hear? Say, [O Muhammad], ``Call your 'partners' and then conspire against me and give me no respite.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mcl{%
Indeed, my protector is Allah, who has sent down the Book; and He is an ally to the righteous.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mcli{%
And those you call upon besides Him are unable to help you, nor can they help themselves."\qt@no{197}}%
\qt@newcmd\qurantrans@en@mclii{%
And if you invite them to guidance, they do not hear; and you see them looking at you while they do not see.\qt@no{198}}%
\qt@newcmd\qurantrans@en@mcliii{%
Take what is given freely, enjoin what is good, and turn away from the ignorant.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mcliv{%
And if an evil suggestion comes to you from Satan, then seek refuge in Allah. Indeed, He is Hearing and Knowing.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mclv{%
Indeed, those who fear Allah - when an impulse touches them from Satan, they remember [Him] and at once they have insight.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mclvi{%
But their brothers - the devils increase them in error; then they do not stop short.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mclvii{%
And when you, [O Muhammad], do not bring them a sign, they say, ``Why have you not contrived it?" Say, ``I only follow what is revealed to me from my Lord. This [Qur'an] is enlightenment from your Lord and guidance and mercy for a people who believe."\qt@no{203}}%
\qt@newcmd\qurantrans@en@mclviii{%
So when the Qur'an is recited, then listen to it and pay attention that you may receive mercy.\qt@no{204}}%
\qt@newcmd\qurantrans@en@mclix{%
And remember your Lord within yourself in humility and in fear without being apparent in speech - in the mornings and the evenings. And do not be among the heedless.\qt@no{205}}%
\qt@newcmd\qurantrans@en@mclx{%
Indeed, those who are near your Lord are not prevented by arrogance from His worship, and they exalt Him, and to Him they prostrate.\qt@no{206}}%
\qt@newcmd\qurantrans@en@mclxi{%
\basmalahen They ask you, [O Muhammad], about the bounties [of war]. Say, ``The [decision concerning] bounties is for Allah and the Messenger." So fear Allah and amend that which is between you and obey Allah and His Messenger, if you should be believers.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mclxii{%
The believers are only those who, when Allah is mentioned, their hearts become fearful, and when His verses are recited to them, it increases them in faith; and upon their Lord they rely -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mclxiii{%
The ones who establish prayer, and from what We have provided them, they spend.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mclxiv{%
Those are the believers, truly. For them are degrees [of high position] with their Lord and forgiveness and noble provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mclxv{%
[It is] just as when your Lord brought you out of your home [for the battle of Badr] in truth, while indeed, a party among the believers were unwilling,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mclxvi{%
Arguing with you concerning the truth after it had become clear, as if they were being driven toward death while they were looking on.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mclxvii{%
[Remember, O believers], when Allah promised you one of the two groups - that it would be yours - and you wished that the unarmed one would be yours. But Allah intended to establish the truth by His words and to eliminate the disbelievers\qt@no{7}}%
\qt@newcmd\qurantrans@en@mclxviii{%
That He should establish the truth and abolish falsehood, even if the criminals disliked it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mclxix{%
[Remember] when you asked help of your Lord, and He answered you, ``Indeed, I will reinforce you with a thousand from the angels, following one another."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mclxx{%
And Allah made it not but good tidings and so that your hearts would be assured thereby. And victory is not but from Allah. Indeed, Allah is Exalted in Might and Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mclxxi{%
[Remember] when He overwhelmed you with drowsiness [giving] security from Him and sent down upon you from the sky, rain by which to purify you and remove from you the evil [suggestions] of Satan and to make steadfast your hearts and plant firmly thereby your feet.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mclxxii{%
[Remember] when your Lord inspired to the angels, ``I am with you, so strengthen those who have believed. I will cast terror into the hearts of those who disbelieved, so strike [them] upon the necks and strike from them every fingertip."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mclxxiii{%
That is because they opposed Allah and His Messenger. And whoever opposes Allah and His Messenger - indeed, Allah is severe in penalty.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mclxxiv{%
``That [is yours], so taste it." And indeed for the disbelievers is the punishment of the Fire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mclxxv{%
O you who have believed, when you meet those who disbelieve advancing [for battle], do not turn to them your backs [in flight].\qt@no{15}}%
\qt@newcmd\qurantrans@en@mclxxvi{%
And whoever turns his back to them on such a day, unless swerving [as a strategy] for war or joining [another] company, has certainly returned with anger [upon him] from Allah, and his refuge is Hell - and wretched is the destination.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mclxxvii{%
And you did not kill them, but it was Allah who killed them. And you threw not, [O Muhammad], when you threw, but it was Allah who threw that He might test the believers with a good test. Indeed, Allah is Hearing and Knowing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mclxxviii{%
That [is so], and [also] that Allah will weaken the plot of the disbelievers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mclxxix{%
If you [disbelievers] seek the victory - the defeat has come to you. And if you desist [from hostilities], it is best for you; but if you return [to war], We will return, and never will you be availed by your [large] company at all, even if it should increase; and [that is] because Allah is with the believers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mclxxx{%
O you who have believed, obey Allah and His Messenger and do not turn from him while you hear [his order].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mclxxxi{%
And do not be like those who say, ``We have heard," while they do not hear.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mclxxxii{%
Indeed, the worst of living creatures in the sight of Allah are the deaf and dumb who do not use reason.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mclxxxiii{%
Had Allah known any good in them, He would have made them hear. And if He had made them hear, they would [still] have turned away, while they were refusing.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mclxxxiv{%
O you who have believed, respond to Allah and to the Messenger when he calls you to that which gives you life. And know that Allah intervenes between a man and his heart and that to Him you will be gathered.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mclxxxv{%
And fear a trial which will not strike those who have wronged among you exclusively, and know that Allah is severe in penalty.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mclxxxvi{%
And remember when you were few and oppressed in the land, fearing that people might abduct you, but He sheltered you, supported you with His victory, and provided you with good things - that you might be grateful.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mclxxxvii{%
O you who have believed, do not betray Allah and the Messenger or betray your trusts while you know [the consequence].\qt@no{27}}%
\qt@newcmd\qurantrans@en@mclxxxviii{%
And know that your properties and your children are but a trial and that Allah has with Him a great reward.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mclxxxix{%
O you who have believed, if you fear Allah, He will grant you a criterion and will remove from you your misdeeds and forgive you. And Allah is the possessor of great bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcxc{%
And [remember, O Muhammad], when those who disbelieved plotted against you to restrain you or kill you or evict you [from Makkah]. But they plan, and Allah plans. And Allah is the best of planners.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcxci{%
And when Our verses are recited to them, they say, ``We have heard. If we willed, we could say [something] like this. This is not but legends of the former peoples."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcxcii{%
And [remember] when they said, ``O Allah, if this should be the truth from You, then rain down upon us stones from the sky or bring us a painful punishment."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcxciii{%
But Allah would not punish them while you, [O Muhammad], are among them, and Allah would not punish them while they seek forgiveness.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcxciv{%
But why should Allah not punish them while they obstruct [people] from al-Masjid al- Haram and they were not [fit to be] its guardians? Its [true] guardians are not but the righteous, but most of them do not know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcxcv{%
And their prayer at the House was not except whistling and handclapping. So taste the punishment for what you disbelieved.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcxcvi{%
Indeed, those who disbelieve spend their wealth to avert [people] from the way of Allah. So they will spend it; then it will be for them a [source of] regret; then they will be overcome. And those who have disbelieved - unto Hell they will be gathered.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcxcvii{%
[This is] so that Allah may distinguish the wicked from the good and place the wicked some of them upon others and heap them all together and put them into Hell. It is those who are the losers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcxcviii{%
Say to those who have disbelieved [that] if they cease, what has previously occurred will be forgiven for them. But if they return [to hostility] - then the precedent of the former [rebellious] peoples has already taken place.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcxcix{%
And fight them until there is no fitnah and [until] the religion, all of it, is for Allah. And if they cease - then indeed, Allah is Seeing of what they do.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcc{%
But if they turn away - then know that Allah is your protector. Excellent is the protector, and Excellent is the helper.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcci{%
And know that anything you obtain of war booty - then indeed, for Allah is one fifth of it and for the Messenger and for [his] near relatives and the orphans, the needy, and the [stranded] traveler, if you have believed in Allah and in that which We sent down to Our Servant on the day of criterion - the day when the two armies met. And Allah, over all things, is competent.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mccii{%
[Remember] when you were on the near side of the valley, and they were on the farther side, and the caravan was lower [in position] than you. If you had made an appointment [to meet], you would have missed the appointment. But [it was] so that Allah might accomplish a matter already destined - that those who perished [through disbelief] would perish upon evidence and those who lived [in faith] would live upon evidence; and indeed, Allah is Hearing and Knowing.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcciii{%
[Remember, O Muhammad], when Allah showed them to you in your dream as few; and if He had shown them to you as many, you [believers] would have lost courage and would have disputed in the matter [of whether to fight], but Allah saved [you from that]. Indeed, He is Knowing of that within the breasts.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcciv{%
And [remember] when He showed them to you, when you met, as few in your eyes, and He made you [appear] as few in their eyes so that Allah might accomplish a matter already destined. And to Allah are [all] matters returned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mccv{%
O you who have believed, when you encounter a company [from the enemy forces], stand firm and remember Allah much that you may be successful.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mccvi{%
And obey Allah and His Messenger, and do not dispute and [thus] lose courage and [then] your strength would depart; and be patient. Indeed, Allah is with the patient.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mccvii{%
And do not be like those who came forth from their homes insolently and to be seen by people and avert [them] from the way of Allah. And Allah is encompassing of what they do.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mccviii{%
And [remember] when Satan made their deeds pleasing to them and said, ``No one can overcome you today from among the people, and indeed, I am your protector." But when the two armies sighted each other, he turned on his heels and said, ``Indeed, I am disassociated from you. Indeed, I see what you do not see; indeed I fear Allah. And Allah is severe in penalty."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mccix{%
[Remember] when the hypocrites and those in whose hearts was disease said, ``Their religion has deluded those [Muslims]." But whoever relies upon Allah - then indeed, Allah is Exalted in Might and Wise.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mccx{%
And if you could but see when the angels take the souls of those who disbelieved... They are striking their faces and their backs and [saying], ``Taste the punishment of the Burning Fire.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mccxi{%
That is for what your hands have put forth [of evil] and because Allah is not ever unjust to His servants."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mccxii{%
[Theirs is] like the custom of the people of Pharaoh and of those before them. They disbelieved in the signs of Allah, so Allah seized them for their sins. Indeed, Allah is Powerful and severe in penalty.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mccxiii{%
That is because Allah would not change a favor which He had bestowed upon a people until they change what is within themselves. And indeed, Allah is Hearing and Knowing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mccxiv{%
[Theirs is] like the custom of the people of Pharaoh and of those before them. They denied the signs of their Lord, so We destroyed them for their sins, and We drowned the people of Pharaoh. And all [of them] were wrongdoers.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxv{%
Indeed, the worst of living creatures in the sight of Allah are those who have disbelieved, and they will not [ever] believe -\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxvi{%
The ones with whom you made a treaty but then they break their pledge every time, and they do not fear Allah.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxvii{%
So if you, [O Muhammad], gain dominance over them in war, disperse by [means of] them those behind them that perhaps they will be reminded.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxviii{%
If you [have reason to] fear from a people betrayal, throw [their treaty] back to them, [putting you] on equal terms. Indeed, Allah does not like traitors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxix{%
And let not those who disbelieve think they will escape. Indeed, they will not cause failure [to Allah].\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxx{%
And prepare against them whatever you are able of power and of steeds of war by which you may terrify the enemy of Allah and your enemy and others besides them whom you do not know [but] whom Allah knows. And whatever you spend in the cause of Allah will be fully repaid to you, and you will not be wronged.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxxi{%
And if they incline to peace, then incline to it [also] and rely upon Allah. Indeed, it is He who is the Hearing, the Knowing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxxii{%
But if they intend to deceive you - then sufficient for you is Allah. It is He who supported you with His help and with the believers\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxxiii{%
And brought together their hearts. If you had spent all that is in the earth, you could not have brought their hearts together; but Allah brought them together. Indeed, He is Exalted in Might and Wise.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxxiv{%
O Prophet, sufficient for you is Allah and for whoever follows you of the believers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccxxv{%
O Prophet, urge the believers to battle. If there are among you twenty [who are] steadfast, they will overcome two hundred. And if there are among you one hundred [who are] steadfast, they will overcome a thousand of those who have disbelieved because they are a people who do not understand.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccxxvi{%
Now, Allah has lightened [the hardship] for you, and He knows that among you is weakness. So if there are from you one hundred [who are] steadfast, they will overcome two hundred. And if there are among you a thousand, they will overcome two thousand by permission of Allah. And Allah is with the steadfast.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mccxxvii{%
It is not for a prophet to have captives [of war] until he inflicts a massacre [upon Allah 's enemies] in the land. Some Muslims desire the commodities of this world, but Allah desires [for you] the Hereafter. And Allah is Exalted in Might and Wise.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccxxviii{%
If not for a decree from Allah that preceded, you would have been touched for what you took by a great punishment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccxxix{%
So consume what you have taken of war booty [as being] lawful and good, and fear Allah. Indeed, Allah is Forgiving and Merciful.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mccxxx{%
O Prophet, say to whoever is in your hands of the captives, ``If Allah knows [any] good in your hearts, He will give you [something] better than what was taken from you, and He will forgive you; and Allah is Forgiving and Merciful."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mccxxxi{%
But if they intend to betray you - then they have already betrayed Allah before, and He empowered [you] over them. And Allah is Knowing and Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mccxxxii{%
Indeed, those who have believed and emigrated and fought with their wealth and lives in the cause of Allah and those who gave shelter and aided - they are allies of one another. But those who believed and did not emigrate - for you there is no guardianship of them until they emigrate. And if they seek help of you for the religion, then you must help, except against a people between yourselves and whom is a treaty. And Allah is Seeing of what you do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mccxxxiii{%
And those who disbelieved are allies of one another. If you do not do so, there will be fitnah on earth and great corruption.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mccxxxiv{%
But those who have believed and emigrated and fought in the cause of Allah and those who gave shelter and aided - it is they who are the believers, truly. For them is forgiveness and noble provision.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mccxxxv{%
And those who believed after [the initial emigration] and emigrated and fought with you - they are of you. But those of [blood] relationship are more entitled [to inheritance] in the decree of Allah. Indeed, Allah is Knowing of all things.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mccxxxvi{%
\basmalahen [This is a declaration of] disassociation, from Allah and His Messenger, to those with whom you had made a treaty among the polytheists.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccxxxvii{%
So travel freely, [O disbelievers], throughout the land [during] four months but know that you cannot cause failure to Allah and that Allah will disgrace the disbelievers.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccxxxviii{%
And [it is] an announcement from Allah and His Messenger to the people on the day of the greater pilgrimage that Allah is disassociated from the disbelievers, and [so is] His Messenger. So if you repent, that is best for you; but if you turn away - then know that you will not cause failure to Allah. And give tidings to those who disbelieve of a painful punishment.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccxxxix{%
Excepted are those with whom you made a treaty among the polytheists and then they have not been deficient toward you in anything or supported anyone against you; so complete for them their treaty until their term [has ended]. Indeed, Allah loves the righteous [who fear Him].\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccxl{%
And when the sacred months have passed, then kill the polytheists wherever you find them and capture them and besiege them and sit in wait for them at every place of ambush. But if they should repent, establish prayer, and give zakah, let them [go] on their way. Indeed, Allah is Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccxli{%
And if any one of the polytheists seeks your protection, then grant him protection so that he may hear the words of Allah. Then deliver him to his place of safety. That is because they are a people who do not know.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccxlii{%
How can there be for the polytheists a treaty in the sight of Allah and with His Messenger, except for those with whom you made a treaty at al-Masjid al-Haram? So as long as they are upright toward you, be upright toward them. Indeed, Allah loves the righteous [who fear Him].\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccxliii{%
How [can there be a treaty] while, if they gain dominance over you, they do not observe concerning you any pact of kinship or covenant of protection? They satisfy you with their mouths, but their hearts refuse [compliance], and most of them are defiantly disobedient.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccxliv{%
They have exchanged the signs of Allah for a small price and averted [people] from His way. Indeed, it was evil that they were doing.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccxlv{%
They do not observe toward a believer any pact of kinship or covenant of protection. And it is they who are the transgressors.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccxlvi{%
But if they repent, establish prayer, and give zakah, then they are your brothers in religion; and We detail the verses for a people who know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccxlvii{%
And if they break their oaths after their treaty and defame your religion, then fight the leaders of disbelief, for indeed, there are no oaths [sacred] to them; [fight them that] they might cease.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccxlviii{%
Would you not fight a people who broke their oaths and determined to expel the Messenger, and they had begun [the attack upon] you the first time? Do you fear them? But Allah has more right that you should fear Him, if you are [truly] believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccxlix{%
Fight them; Allah will punish them by your hands and will disgrace them and give you victory over them and satisfy the breasts of a believing people\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccl{%
And remove the fury in the believers' hearts. And Allah turns in forgiveness to whom He wills; and Allah is Knowing and Wise.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccli{%
Do you think that you will be left [as you are] while Allah has not yet made evident those among you who strive [for His cause] and do not take other than Allah, His Messenger and the believers as intimates? And Allah is Acquainted with what you do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcclii{%
It is not for the polytheists to maintain the mosques of Allah [while] witnessing against themselves with disbelief. [For] those, their deeds have become worthless, and in the Fire they will abide eternally.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccliii{%
The mosques of Allah are only to be maintained by those who believe in Allah and the Last Day and establish prayer and give zakah and do not fear except Allah, for it is expected that those will be of the [rightly] guided.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccliv{%
Have you made the providing of water for the pilgrim and the maintenance of al-Masjid al-Haram equal to [the deeds of] one who believes in Allah and the Last Day and strives in the cause of Allah? They are not equal in the sight of Allah. And Allah does not guide the wrongdoing people.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcclv{%
The ones who have believed, emigrated and striven in the cause of Allah with their wealth and their lives are greater in rank in the sight of Allah. And it is those who are the attainers [of success].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcclvi{%
Their Lord gives them good tidings of mercy from Him and approval and of gardens for them wherein is enduring pleasure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcclvii{%
[They will be] abiding therein forever. Indeed, Allah has with Him a great reward.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcclviii{%
O you who have believed, do not take your fathers or your brothers as allies if they have preferred disbelief over belief. And whoever does so among you - then it is those who are the wrongdoers.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcclix{%
Say, [O Muhammad], ``If your fathers, your sons, your brothers, your wives, your relatives, wealth which you have obtained, commerce wherein you fear decline, and dwellings with which you are pleased are more beloved to you than Allah and His Messenger and jihad in His cause, then wait until Allah executes His command. And Allah does not guide the defiantly disobedient people."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcclx{%
Allah has already given you victory in many regions and [even] on the day of Hunayn, when your great number pleased you, but it did not avail you at all, and the earth was confining for you with its vastness; then you turned back, fleeing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcclxi{%
Then Allah sent down His tranquillity upon His Messenger and upon the believers and sent down soldiers angels whom you did not see and punished those who disbelieved. And that is the recompense of the disbelievers.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcclxii{%
Then Allah will accept repentance after that for whom He wills; and Allah is Forgiving and Merciful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcclxiii{%
O you who have believed, indeed the polytheists are unclean, so let them not approach al-Masjid al-Haram after this, their [final] year. And if you fear privation, Allah will enrich you from His bounty if He wills. Indeed, Allah is Knowing and Wise.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcclxiv{%
Fight those who do not believe in Allah or in the Last Day and who do not consider unlawful what Allah and His Messenger have made unlawful and who do not adopt the religion of truth from those who were given the Scripture - [fight] until they give the jizyah willingly while they are humbled.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcclxv{%
The Jews say, ``Ezra is the son of Allah ``; and the Christians say, ``The Messiah is the son of Allah." That is their statement from their mouths; they imitate the saying of those who disbelieved [before them]. May Allah destroy them; how are they deluded?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcclxvi{%
They have taken their scholars and monks as lords besides Allah, and [also] the Messiah, the son of Mary. And they were not commanded except to worship one God; there is no deity except Him. Exalted is He above whatever they associate with Him.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcclxvii{%
They want to extinguish the light of Allah with their mouths, but Allah refuses except to perfect His light, although the disbelievers dislike it.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcclxviii{%
It is He who has sent His Messenger with guidance and the religion of truth to manifest it over all religion, although they who associate others with Allah dislike it.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcclxix{%
O you who have believed, indeed many of the scholars and the monks devour the wealth of people unjustly and avert [them] from the way of Allah. And those who hoard gold and silver and spend it not in the way of Allah - give them tidings of a painful punishment.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcclxx{%
The Day when it will be heated in the fire of Hell and seared therewith will be their foreheads, their flanks, and their backs, [it will be said], ``This is what you hoarded for yourselves, so taste what you used to hoard."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcclxxi{%
Indeed, the number of months with Allah is twelve [lunar] months in the register of Allah [from] the day He created the heavens and the earth; of these, four are sacred. That is the correct religion, so do not wrong yourselves during them. And fight against the disbelievers collectively as they fight against you collectively. And know that Allah is with the righteous [who fear Him].\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcclxxii{%
Indeed, the postponing [of restriction within sacred months] is an increase in disbelief by which those who have disbelieved are led [further] astray. They make it lawful one year and unlawful another year to correspond to the number made unlawful by Allah and [thus] make lawful what Allah has made unlawful. Made pleasing to them is the evil of their deeds; and Allah does not guide the disbelieving people.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcclxxiii{%
O you who have believed, what is [the matter] with you that, when you are told to go forth in the cause of Allah, you adhere heavily to the earth? Are you satisfied with the life of this world rather than the Hereafter? But what is the enjoyment of worldly life compared to the Hereafter except a [very] little.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcclxxiv{%
If you do not go forth, He will punish you with a painful punishment and will replace you with another people, and you will not harm Him at all. And Allah is over all things competent.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcclxxv{%
If you do not aid the Prophet - Allah has already aided him when those who disbelieved had driven him out [of Makkah] as one of two, when they were in the cave and he said to his companion, ``Do not grieve; indeed Allah is with us." And Allah sent down his tranquillity upon him and supported him with angels you did not see and made the word of those who disbelieved the lowest, while the word of Allah - that is the highest. And Allah is Exalted in Might and Wise.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcclxxvi{%
Go forth, whether light or heavy, and strive with your wealth and your lives in the cause of Allah. That is better for you, if you only knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcclxxvii{%
Had it been an easy gain and a moderate trip, the hypocrites would have followed you, but distant to them was the journey. And they will swear by Allah, ``If we were able, we would have gone forth with you," destroying themselves [through false oaths], and Allah knows that indeed they are liars.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcclxxviii{%
May Allah pardon you, [O Muhammad]; why did you give them permission [to remain behind]? [You should not have] until it was evident to you who were truthful and you knew [who were] the liars.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcclxxix{%
Those who believe in Allah and the Last Day would not ask permission of you to be excused from striving with their wealth and their lives. And Allah is Knowing of those who fear Him.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcclxxx{%
Only those would ask permission of you who do not believe in Allah and the Last Day and whose hearts have doubted, and they, in their doubt, are hesitating.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcclxxxi{%
And if they had intended to go forth, they would have prepared for it [some] preparation. But Allah disliked their being sent, so He kept them back, and they were told, ``Remain [behind] with those who remain."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcclxxxii{%
Had they gone forth with you, they would not have increased you except in confusion, and they would have been active among you, seeking [to cause] you fitnah. And among you are avid listeners to them. And Allah is Knowing of the wrongdoers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcclxxxiii{%
They had already desired dissension before and had upset matters for you until the truth came and the ordinance of Allah appeared, while they were averse.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcclxxxiv{%
And among them is he who says, ``Permit me [to remain at home] and do not put me to trial." Unquestionably, into trial they have fallen. And indeed, Hell will encompass the disbelievers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcclxxxv{%
If good befalls you, it distresses them; but if disaster strikes you, they say, ``We took our matter [in hand] before," and turn away while they are rejoicing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcclxxxvi{%
Say, ``Never will we be struck except by what Allah has decreed for us; He is our protector." And upon Allah let the believers rely.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcclxxxvii{%
Say, ``Do you await for us except one of the two best things while we await for you that Allah will afflict you with punishment from Himself or at our hands? So wait; indeed we, along with you, are waiting."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcclxxxviii{%
Say, ``Spend willingly or unwillingly; never will it be accepted from you. Indeed, you have been a defiantly disobedient people."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcclxxxix{%
And what prevents their expenditures from being accepted from them but that they have disbelieved in Allah and in His Messenger and that they come not to prayer except while they are lazy and that they do not spend except while they are unwilling.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mccxc{%
So let not their wealth or their children impress you. Allah only intends to punish them through them in worldly life and that their souls should depart [at death] while they are disbelievers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mccxci{%
And they swear by Allah that they are from among you while they are not from among you; but they are a people who are afraid.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mccxcii{%
If they could find a refuge or some caves or any place to enter [and hide], they would turn to it while they run heedlessly.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mccxciii{%
And among them are some who criticize you concerning the [distribution of] charities. If they are given from them, they approve; but if they are not given from them, at once they become angry.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mccxciv{%
If only they had been satisfied with what Allah and His Messenger gave them and said, ``Sufficient for us is Allah; Allah will give us of His bounty, and [so will] His Messenger; indeed, we are desirous toward Allah," [it would have been better for them].\qt@no{59}}%
\qt@newcmd\qurantrans@en@mccxcv{%
Zakah expenditures are only for the poor and for the needy and for those employed to collect [zakah] and for bringing hearts together [for Islam] and for freeing captives [or slaves] and for those in debt and for the cause of Allah and for the [stranded] traveler - an obligation [imposed] by Allah. And Allah is Knowing and Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mccxcvi{%
And among them are those who abuse the Prophet and say, ``He is an ear." Say, ``[It is] an ear of goodness for you that believes in Allah and believes the believers and [is] a mercy to those who believe among you." And those who abuse the Messenger of Allah - for them is a painful punishment.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mccxcvii{%
They swear by Allah to you [Muslims] to satisfy you. But Allah and His Messenger are more worthy for them to satisfy, if they should be believers.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mccxcviii{%
Do they not know that whoever opposes Allah and His Messenger - that for him is the fire of Hell, wherein he will abide eternally? That is the great disgrace.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mccxcix{%
They hypocrites are apprehensive lest a surah be revealed about them, informing them of what is in their hearts. Say, ``Mock [as you wish]; indeed, Allah will expose that which you fear."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mccc{%
And if you ask them, they will surely say, ``We were only conversing and playing." Say, ``Is it Allah and His verses and His Messenger that you were mocking?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mccci{%
Make no excuse; you have disbelieved after your belief. If We pardon one faction of you - We will punish another faction because they were criminals.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcccii{%
The hypocrite men and hypocrite women are of one another. They enjoin what is wrong and forbid what is right and close their hands. They have forgotten Allah, so He has forgotten them [accordingly]. Indeed, the hypocrites - it is they who are the defiantly disobedient.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mccciii{%
Allah has promised the hypocrite men and hypocrite women and the disbelievers the fire of Hell, wherein they will abide eternally. It is sufficient for them. And Allah has cursed them, and for them is an enduring punishment.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mccciv{%
[You disbelievers are] like those before you; they were stronger than you in power and more abundant in wealth and children. They enjoyed their portion [of worldly enjoyment], and you have enjoyed your portion as those before you enjoyed their portion, and you have engaged [in vanities] like that in which they engaged. [It is] those whose deeds have become worthless in this world and in the Hereafter, and it is they who are the losers.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcccv{%
Has there not reached them the news of those before them - the people of Noah and [the tribes of] 'Aad and Thamud and the people of Abraham and the companions of Madyan and the towns overturned? Their messengers came to them with clear proofs. And Allah would never have wronged them, but they were wronging themselves.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcccvi{%
The believing men and believing women are allies of one another. They enjoin what is right and forbid what is wrong and establish prayer and give zakah and obey Allah and His Messenger. Those - Allah will have mercy upon them. Indeed, Allah is Exalted in Might and Wise.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcccvii{%
Allah has promised the believing men and believing women gardens beneath which rivers flow, wherein they abide eternally, and pleasant dwellings in gardens of perpetual residence; but approval from Allah is greater. It is that which is the great attainment.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcccviii{%
O Prophet, fight against the disbelievers and the hypocrites and be harsh upon them. And their refuge is Hell, and wretched is the destination.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcccix{%
They swear by Allah that they did not say [anything against the Prophet] while they had said the word of disbelief and disbelieved after their [pretense of] Islam and planned that which they were not to attain. And they were not resentful except [for the fact] that Allah and His Messenger had enriched them of His bounty. So if they repent, it is better for them; but if they turn away, Allah will punish them with a painful punishment in this world and the Hereafter. And there will not be for them on earth any protector or helper.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcccx{%
And among them are those who made a covenant with Allah, [saying], ``If He should give us from His bounty, we will surely spend in charity, and we will surely be among the righteous."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcccxi{%
But when he gave them from His bounty, they were stingy with it and turned away while they refused.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcccxii{%
So He penalized them with hypocrisy in their hearts until the Day they will meet Him - because they failed Allah in what they promised Him and because they [habitually] used to lie.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcccxiii{%
Did they not know that Allah knows their secrets and their private conversations and that Allah is the Knower of the unseen?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcccxiv{%
Those who criticize the contributors among the believers concerning [their] charities and [criticize] the ones who find nothing [to spend] except their effort, so they ridicule them - Allah will ridicule them, and they will have a painful punishment.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcccxv{%
Ask forgiveness for them, [O Muhammad], or do not ask forgiveness for them. If you should ask forgiveness for them seventy times - never will Allah forgive them. That is because they disbelieved in Allah and His Messenger, and Allah does not guide the defiantly disobedient people.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcccxvi{%
Those who remained behind rejoiced in their staying [at home] after [the departure of] the Messenger of Allah and disliked to strive with their wealth and their lives in the cause of Allah and said, ``Do not go forth in the heat." Say, ``The fire of Hell is more intensive in heat" - if they would but understand.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcccxvii{%
So let them laugh a little and [then] weep much as recompense for what they used to earn.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcccxviii{%
If Allah should return you to a faction of them [after the expedition] and then they ask your permission to go out [to battle], say, ``You will not go out with me, ever, and you will never fight with me an enemy. Indeed, you were satisfied with sitting [at home] the first time, so sit [now] with those who stay behind."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcccxix{%
And do not pray [the funeral prayer, O Muhammad], over any of them who has died - ever - or stand at his grave. Indeed, they disbelieved in Allah and His Messenger and died while they were defiantly disobedient.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcccxx{%
And let not their wealth and their children impress you. Allah only intends to punish them through them in this world and that their souls should depart [at death] while they are disbelievers.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcccxxi{%
And when a surah was revealed [enjoining them] to believe in Allah and to fight with His Messenger, those of wealth among them asked your permission [to stay back] and said, ``Leave us to be with them who sit [at home]."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcccxxii{%
They were satisfied to be with those who stay behind, and their hearts were sealed over, so they do not understand.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcccxxiii{%
But the Messenger and those who believed with him fought with their wealth and their lives. Those will have [all that is] good, and it is those who are the successful.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcccxxiv{%
Allah has prepared for them gardens beneath which rivers flow, wherein they will abide eternally. That is the great attainment.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcccxxv{%
And those with excuses among the bedouins came to be permitted [to remain], and they who had lied to Allah and His Messenger sat [at home]. There will strike those who disbelieved among them a painful punishment.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcccxxvi{%
There is not upon the weak or upon the ill or upon those who do not find anything to spend any discomfort when they are sincere to Allah and His Messenger. There is not upon the doers of good any cause [for blame]. And Allah is Forgiving and Merciful.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcccxxvii{%
Nor [is there blame] upon those who, when they came to you that you might give them mounts, you said, ``I can find nothing for you to ride upon." They turned back while their eyes overflowed with tears out of grief that they could not find something to spend [for the cause of Allah].\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcccxxviii{%
The cause [for blame] is only upon those who ask permission of you while they are rich. They are satisfied to be with those who stay behind, and Allah has sealed over their hearts, so they do not know.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcccxxix{%
They will make excuses to you when you have returned to them. Say, ``Make no excuse - never will we believe you. Allah has already informed us of your news. And Allah will observe your deeds, and [so will] His Messenger; then you will be taken back to the Knower of the unseen and the witnessed, and He will inform you of what you used to do."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcccxxx{%
They will swear by Allah to you when you return to them that you would leave them alone. So leave them alone; indeed they are evil; and their refuge is Hell as recompense for what they had been earning.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcccxxxi{%
They swear to you so that you might be satisfied with them. But if you should be satisfied with them - indeed, Allah is not satisfied with a defiantly disobedient people.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcccxxxii{%
The bedouins are stronger in disbelief and hypocrisy and more likely not to know the limits of what [laws] Allah has revealed to His Messenger. And Allah is Knowing and Wise.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcccxxxiii{%
And among the bedouins are some who consider what they spend as a loss and await for you turns of misfortune. Upon them will be a misfortune of evil. And Allah is Hearing and Knowing.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcccxxxiv{%
But among the bedouins are some who believe in Allah and the Last Day and consider what they spend as means of nearness to Allah and of [obtaining] invocations of the Messenger. Unquestionably, it is a means of nearness for them. Allah will admit them to His mercy. Indeed, Allah is Forgiving and Merciful.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcccxxxv{%
And the first forerunners [in the faith] among the Muhajireen and the Ansar and those who followed them with good conduct - Allah is pleased with them and they are pleased with Him, and He has prepared for them gardens beneath which rivers flow, wherein they will abide forever. That is the great attainment.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcccxxxvi{%
And among those around you of the bedouins are hypocrites, and [also] from the people of Madinah. They have become accustomed to hypocrisy. You, [O Muhammad], do not know them, [but] We know them. We will punish them twice [in this world]; then they will be returned to a great punishment.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcccxxxvii{%
And [there are] others who have acknowledged their sins. They had mixed a righteous deed with another that was bad. Perhaps Allah will turn to them in forgiveness. Indeed, Allah is Forgiving and Merciful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcccxxxviii{%
Take, [O, Muhammad], from their wealth a charity by which you purify them and cause them increase, and invoke [Allah 's blessings] upon them. Indeed, your invocations are reassurance for them. And Allah is Hearing and Knowing.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcccxxxix{%
Do they not know that it is Allah who accepts repentance from His servants and receives charities and that it is Allah who is the Accepting of repentance, the Merciful?\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcccxl{%
And say, ``Do [as you will], for Allah will see your deeds, and [so, will] His Messenger and the believers. And you will be returned to the Knower of the unseen and the witnessed, and He will inform you of what you used to do."\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcccxli{%
And [there are] others deferred until the command of Allah - whether He will punish them or whether He will forgive them. And Allah is Knowing and Wise.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcccxlii{%
And [there are] those [hypocrites] who took for themselves a mosque for causing harm and disbelief and division among the believers and as a station for whoever had warred against Allah and His Messenger before. And they will surely swear, ``We intended only the best." And Allah testifies that indeed they are liars.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcccxliii{%
Do not stand [for prayer] within it - ever. A mosque founded on righteousness from the first day is more worthy for you to stand in. Within it are men who love to purify themselves; and Allah loves those who purify themselves.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcccxliv{%
Then is one who laid the foundation of his building on righteousness [with fear] from Allah and [seeking] His approval better or one who laid the foundation of his building on the edge of a bank about to collapse, so it collapsed with him into the fire of Hell? And Allah does not guide the wrongdoing people.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcccxlv{%
Their building which they built will not cease to be a [cause of] skepticism in their hearts until their hearts are stopped. And Allah is Knowing and Wise.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mcccxlvi{%
Indeed, Allah has purchased from the believers their lives and their properties [in exchange] for that they will have Paradise. They fight in the cause of Allah, so they kill and are killed. [It is] a true promise [binding] upon Him in the Torah and the Gospel and the Qur'an. And who is truer to his covenant than Allah? So rejoice in your transaction which you have contracted. And it is that which is the great attainment.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mcccxlvii{%
[Such believers are] the repentant, the worshippers, the praisers [of Allah], the travelers [for His cause], those who bow and prostrate [in prayer], those who enjoin what is right and forbid what is wrong, and those who observe the limits [set by] Allah. And give good tidings to the believers.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mcccxlviii{%
It is not for the Prophet and those who have believed to ask forgiveness for the polytheists, even if they were relatives, after it has become clear to them that they are companions of Hellfire.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mcccxlix{%
And the request of forgiveness of Abraham for his father was only because of a promise he had made to him. But when it became apparent to Abraham that his father was an enemy to Allah, he disassociated himself from him. Indeed was Abraham compassionate and patient.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mcccl{%
And Allah would not let a people stray after He has guided them until He makes clear to them what they should avoid. Indeed, Allah is Knowing of all things.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mcccli{%
Indeed, to Allah belongs the dominion of the heavens and the earth; He gives life and causes death. And you have not besides Allah any protector or any helper.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mccclii{%
Allah has already forgiven the Prophet and the Muhajireen and the Ansar who followed him in the hour of difficulty after the hearts of a party of them had almost inclined [to doubt], and then He forgave them. Indeed, He was to them Kind and Merciful.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mcccliii{%
And [He also forgave] the three who were left behind [and regretted their error] to the point that the earth closed in on them in spite of its vastness and their souls confined them and they were certain that there is no refuge from Allah except in Him. Then He turned to them so they could repent. Indeed, Allah is the Accepting of repentance, the Merciful.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mcccliv{%
O you who have believed, fear Allah and be with those who are true.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mccclv{%
It was not [proper] for the people of Madinah and those surrounding them of the bedouins that they remain behind after [the departure of] the Messenger of Allah or that they prefer themselves over his self. That is because they are not afflicted by thirst or fatigue or hunger in the cause of Allah, nor do they tread on any ground that enrages the disbelievers, nor do they inflict upon an enemy any infliction but that is registered for them as a righteous deed. Indeed, Allah does not allow to be lost the reward of the doers of good.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mccclvi{%
Nor do they spend an expenditure, small or large, or cross a valley but that it is registered for them that Allah may reward them for the best of what they were doing.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mccclvii{%
And it is not for the believers to go forth [to battle] all at once. For there should separate from every division of them a group [remaining] to obtain understanding in the religion and warn their people when they return to them that they might be cautious.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mccclviii{%
O you who have believed, fight those adjacent to you of the disbelievers and let them find in you harshness. And know that Allah is with the righteous.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mccclix{%
And whenever a surah is revealed, there are among the hypocrites those who say, ``Which of you has this increased faith?" As for those who believed, it has increased them in faith, while they are rejoicing.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mccclx{%
But as for those in whose hearts is disease, it has [only] increased them in evil [in addition] to their evil. And they will have died while they are disbelievers.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mccclxi{%
Do they not see that they are tried every year once or twice but then they do not repent nor do they remember?\qt@no{126}}%
\qt@newcmd\qurantrans@en@mccclxii{%
And whenever a surah is revealed, they look at each other, [saying], ``Does anyone see you?" and then they dismiss themselves. Allah has dismissed their hearts because they are a people who do not understand.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mccclxiii{%
There has certainly come to you a Messenger from among yourselves. Grievous to him is what you suffer; [he is] concerned over you and to the believers is kind and merciful.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mccclxiv{%
But if they turn away, [O Muhammad], say, ``Sufficient for me is Allah; there is no deity except Him. On Him I have relied, and He is the Lord of the Great Throne."\qt@no{129}}%
\qt@newcmd\qurantrans@en@mccclxv{%
\basmalahen Alif, Lam, Ra. These are the verses of the wise Book\qt@no{1}}%
\qt@newcmd\qurantrans@en@mccclxvi{%
Have the people been amazed that We revealed [revelation] to a man from among them, [saying], ``Warn mankind and give good tidings to those who believe that they will have a [firm] precedence of honor with their Lord"? [But] the disbelievers say, ``Indeed, this is an obvious magician."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mccclxvii{%
Indeed, your Lord is Allah, who created the heavens and the earth in six days and then established Himself above the Throne, arranging the matter [of His creation]. There is no intercessor except after His permission. That is Allah, your Lord, so worship Him. Then will you not remember?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mccclxviii{%
To Him is your return all together. [It is] the promise of Allah [which is] truth. Indeed, He begins the [process of] creation and then repeats it that He may reward those who have believed and done righteous deeds, in justice. But those who disbelieved will have a drink of scalding water and a painful punishment for what they used to deny.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mccclxix{%
It is He who made the sun a shining light and the moon a derived light and determined for it phases - that you may know the number of years and account [of time]. Allah has not created this except in truth. He details the signs for a people who know\qt@no{5}}%
\qt@newcmd\qurantrans@en@mccclxx{%
Indeed, in the alternation of the night and the day and [in] what Allah has created in the heavens and the earth are signs for a people who fear Allah\qt@no{6}}%
\qt@newcmd\qurantrans@en@mccclxxi{%
Indeed, those who do not expect the meeting with Us and are satisfied with the life of this world and feel secure therein and those who are heedless of Our signs\qt@no{7}}%
\qt@newcmd\qurantrans@en@mccclxxii{%
For those their refuge will be the Fire because of what they used to earn.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mccclxxiii{%
Indeed, those who have believed and done righteous deeds - their Lord will guide them because of their faith. Beneath them rivers will flow in the Gardens of Pleasure\qt@no{9}}%
\qt@newcmd\qurantrans@en@mccclxxiv{%
Their call therein will be, ``Exalted are You, O Allah," and their greeting therein will be, ``Peace." And the last of their call will be, ``Praise to Allah, Lord of the worlds!"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mccclxxv{%
And if Allah was to hasten for the people the evil [they invoke] as He hastens for them the good, their term would have been ended for them. But We leave the ones who do not expect the meeting with Us, in their transgression, wandering blindly\qt@no{11}}%
\qt@newcmd\qurantrans@en@mccclxxvi{%
And when affliction touches man, he calls upon Us, whether lying on his side or sitting or standing; but when We remove from him his affliction, he continues [in disobedience] as if he had never called upon Us to [remove] an affliction that touched him. Thus is made pleasing to the transgressors that which they have been doing\qt@no{12}}%
\qt@newcmd\qurantrans@en@mccclxxvii{%
And We had already destroyed generations before you when they wronged, and their messengers had come to them with clear proofs, but they were not to believe. Thus do We recompense the criminal people\qt@no{13}}%
\qt@newcmd\qurantrans@en@mccclxxviii{%
Then We made you successors in the land after them so that We may observe how you will do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mccclxxix{%
And when Our verses are recited to them as clear evidences, those who do not expect the meeting with Us say, ``Bring us a Qur'an other than this or change it." Say, [O Muhammad], ``It is not for me to change it on my own accord. I only follow what is revealed to me. Indeed I fear, if I should disobey my Lord, the punishment of a tremendous Day."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mccclxxx{%
Say, ``If Allah had willed, I would not have recited it to you, nor would He have made it known to you, for I had remained among you a lifetime before it. Then will you not reason?"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mccclxxxi{%
So who is more unjust than he who invents a lie about Allah or denies His signs? Indeed, the criminals will not succeed\qt@no{17}}%
\qt@newcmd\qurantrans@en@mccclxxxii{%
And they worship other than Allah that which neither harms them nor benefits them, and they say, ``These are our intercessors with Allah `` Say, ``Do you inform Allah of something He does not know in the heavens or on the earth?" Exalted is He and high above what they associate with Him\qt@no{18}}%
\qt@newcmd\qurantrans@en@mccclxxxiii{%
And mankind was not but one community [united in religion], but [then] they differed. And if not for a word that preceded from your Lord, it would have been judged between them [immediately] concerning that over which they differ.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mccclxxxiv{%
And they say, ``Why is a sign not sent down to him from his Lord?" So say, ``The unseen is only for Allah [to administer], so wait; indeed, I am with you among those who wait."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mccclxxxv{%
And when We give the people a taste of mercy after adversity has touched them, at once they conspire against Our verses. Say, ``Allah is swifter in strategy." Indeed, Our messengers record that which you conspire\qt@no{21}}%
\qt@newcmd\qurantrans@en@mccclxxxvi{%
It is He who enables you to travel on land and sea until, when you are in ships and they sail with them by a good wind and they rejoice therein, there comes a storm wind and the waves come upon them from everywhere and they assume that they are surrounded, supplicating Allah, sincere to Him in religion, ``If You should save us from this, we will surely be among the thankful."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mccclxxxvii{%
But when He saves them, at once they commit injustice upon the earth without right. O mankind, your injustice is only against yourselves, [being merely] the enjoyment of worldly life. Then to Us is your return, and We will inform you of what you used to do.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mccclxxxviii{%
The example of [this] worldly life is but like rain which We have sent down from the sky that the plants of the earth absorb - [those] from which men and livestock eat - until, when the earth has taken on its adornment and is beautified and its people suppose that they have capability over it, there comes to it Our command by night or by day, and We make it as a harvest, as if it had not flourished yesterday. Thus do We explain in detail the signs for a people who give thought.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mccclxxxix{%
And Allah invites to the Home of Peace and guides whom He wills to a straight path\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcccxc{%
For them who have done good is the best [reward] and extra. No darkness will cover their faces, nor humiliation. Those are companions of Paradise; they will abide therein eternally\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcccxci{%
But they who have earned [blame for] evil doings - the recompense of an evil deed is its equivalent, and humiliation will cover them. They will have from Allah no protector. It will be as if their faces are covered with pieces of the night - so dark [are they]. Those are the companions of the Fire; they will abide therein eternally.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcccxcii{%
And [mention, O Muhammad], the Day We will gather them all together - then We will say to those who associated others with Allah, ``[Remain in] your place, you and your 'partners.' `` Then We will separate them, and their ``partners" will say, ``You did not used to worship us,\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcccxciii{%
And sufficient is Allah as a witness between us and you that we were of your worship unaware."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcccxciv{%
There, [on that Day], every soul will be put to trial for what it did previously, and they will be returned to Allah, their master, the Truth, and lost from them is whatever they used to invent.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcccxcv{%
Say, ``Who provides for you from the heaven and the earth? Or who controls hearing and sight and who brings the living out of the dead and brings the dead out of the living and who arranges [every] matter?" They will say, ``Allah," so say, ``Then will you not fear Him?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcccxcvi{%
For that is Allah, your Lord, the Truth. And what can be beyond truth except error? So how are you averted?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcccxcvii{%
Thus the word of your Lord has come into effect upon those who defiantly disobeyed - that they will not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcccxcviii{%
Say, ``Are there of your 'partners' any who begins creation and then repeats it?" Say, ``Allah begins creation and then repeats it, so how are you deluded?"\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcccxcix{%
Say, ``Are there of your 'partners' any who guides to the truth?" Say, ``Allah guides to the truth. So is He who guides to the truth more worthy to be followed or he who guides not unless he is guided? Then what is [wrong] with you - how do you judge?"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcd{%
And most of them follow not except assumption. Indeed, assumption avails not against the truth at all. Indeed, Allah is Knowing of what they do.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcdi{%
And it was not [possible] for this Qur'an to be produced by other than Allah, but [it is] a confirmation of what was before it and a detailed explanation of the [former] Scripture, about which there is no doubt, from the Lord of the worlds.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcdii{%
Or do they say [about the Prophet], ``He invented it?" Say, ``Then bring forth a surah like it and call upon [for assistance] whomever you can besides Allah, if you should be truthful."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcdiii{%
Rather, they have denied that which they encompass not in knowledge and whose interpretation has not yet come to them. Thus did those before them deny. Then observe how was the end of the wrongdoers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcdiv{%
And of them are those who believe in it, and of them are those who do not believe in it. And your Lord is most knowing of the corrupters\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcdv{%
And if they deny you, [O Muhammad], then say, ``For me are my deeds, and for you are your deeds. You are disassociated from what I do, and I am disassociated from what you do."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcdvi{%
And among them are those who listen to you. But can you cause the deaf to hear, although they will not use reason?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcdvii{%
And among them are those who look at you. But can you guide the blind although they will not [attempt to] see?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcdviii{%
Indeed, Allah does not wrong the people at all, but it is the people who are wronging themselves.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcdix{%
And on the Day when He will gather them, [it will be] as if they had not remained [in the world] but an hour of the day, [and] they will know each other. Those will have lost who denied the meeting with Allah and were not guided\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcdx{%
And whether We show you some of what We promise them, [O Muhammad], or We take you in death, to Us is their return; then, [either way], Allah is a witness concerning what they are doing\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcdxi{%
And for every nation is a messenger. So when their messenger comes, it will be judged between them in justice, and they will not be wronged\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcdxii{%
And they say, ``When is [the fulfillment of] this promise, if you should be truthful?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcdxiii{%
Say, ``I possess not for myself any harm or benefit except what Allah should will. For every nation is a [specified] term. When their time has come, then they will not remain behind an hour, nor will they precede [it]."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcdxiv{%
Say, ``Have you considered: if His punishment should come to you by night or by day - for which [aspect] of it would the criminals be impatient?"\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcdxv{%
Then is it that when it has [actually] occurred you will believe in it? Now? And you were [once] for it impatient\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcdxvi{%
Then it will be said to those who had wronged, ``Taste the punishment of eternity; are you being recompensed except for what you used to earn?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcdxvii{%
And they ask information of you, [O Muhammad], ``Is it true?" Say, ``Yes, by my Lord. Indeed, it is truth; and you will not cause failure [to Allah]."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcdxviii{%
And if each soul that wronged had everything on earth, it would offer it in ransom. And they will confide regret when they see the punishment; and they will be judged in justice, and they will not be wronged\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcdxix{%
Unquestionably, to Allah belongs whatever is in the heavens and the earth. Unquestionably, the promise of Allah is truth, but most of them do not know\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcdxx{%
He gives life and causes death, and to Him you will be returned\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcdxxi{%
O mankind, there has to come to you instruction from your Lord and healing for what is in the breasts and guidance and mercy for the believers.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcdxxii{%
Say, ``In the bounty of Allah and in His mercy - in that let them rejoice; it is better than what they accumulate."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcdxxiii{%
Say, ``Have you seen what Allah has sent down to you of provision of which you have made [some] lawful and [some] unlawful?" Say, ``Has Allah permitted you [to do so], or do you invent [something] about Allah?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcdxxiv{%
And what will be the supposition of those who invent falsehood about Allah on the Day of Resurrection? Indeed, Allah is full of bounty to the people, but most of them are not grateful."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcdxxv{%
And, [O Muhammad], you are not [engaged] in any matter or recite any of the Qur'an and you [people] do not do any deed except that We are witness over you when you are involved in it. And not absent from your Lord is any [part] of an atom's weight within the earth or within the heaven or [anything] smaller than that or greater but that it is in a clear register.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcdxxvi{%
Unquestionably, [for] the allies of Allah there will be no fear concerning them, nor will they grieve\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcdxxvii{%
Those who believed and were fearing Allah\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcdxxviii{%
For them are good tidings in the worldly life and in the Hereafter. No change is there in the words of Allah. That is what is the great attainment.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcdxxix{%
And let not their speech grieve you. Indeed, honor [due to power] belongs to Allah entirely. He is the Hearing, the Knowing.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcdxxx{%
Unquestionably, to Allah belongs whoever is in the heavens and whoever is on the earth. And those who invoke other than Allah do not [actually] follow [His] ``partners." They follow not except assumption, and they are not but falsifying\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcdxxxi{%
It is He who made for you the night to rest therein and the day, giving sight. Indeed in that are signs for a people who listen.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcdxxxii{%
They have said, ``Allah has taken a son." Exalted is He; He is the [one] Free of need. To Him belongs whatever is in the heavens and whatever is in the earth. You have no authority for this [claim]. Do you say about Allah that which you do not know?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcdxxxiii{%
Say, ``Indeed, those who invent falsehood about Allah will not succeed."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcdxxxiv{%
[For them is brief] enjoyment in this world; then to Us is their return; then We will make them taste the severe punishment because they used to disbelieve\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcdxxxv{%
And recite to them the news of Noah, when he said to his people, ``O my people, if my residence and my reminding of the signs of Allah has become burdensome upon you - then I have relied upon Allah. So resolve upon your plan and [call upon] your associates. Then let not your plan be obscure to you. Then carry it out upon me and do not give me respite.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcdxxxvi{%
And if you turn away [from my advice] then no payment have I asked of you. My reward is only from Allah, and I have been commanded to be of the Muslims."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcdxxxvii{%
And they denied him, so We saved him and those with him in the ship and made them successors, and We drowned those who denied Our signs. Then see how was the end of those who were warned.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcdxxxviii{%
Then We sent after him messengers to their peoples, and they came to them with clear proofs. But they were not to believe in that which they had denied before. Thus We seal over the hearts of the transgressors\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcdxxxix{%
Then We sent after them Moses and Aaron to Pharaoh and his establishment with Our signs, but they behaved arrogantly and were a criminal people\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcdxl{%
So when there came to them the truth from Us, they said, ``Indeed, this is obvious magic."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcdxli{%
Moses said, ``Do you say [thus] about the truth when it has come to you? Is this magic? But magicians will not succeed."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcdxlii{%
They said, ``Have you come to us to turn us away from that upon which we found our fathers and so that you two may have grandeur in the land? And we are not believers in you."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcdxliii{%
And Pharaoh said, ``Bring to me every learned magician."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcdxliv{%
So when the magicians came, Moses said to them, ``Throw down whatever you will throw."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcdxlv{%
And when they had thrown, Moses said, ``What you have brought is [only] magic. Indeed, Allah will expose its worthlessness. Indeed, Allah does not amend the work of corrupters.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcdxlvi{%
And Allah will establish the truth by His words, even if the criminals dislike it."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcdxlvii{%
But no one believed Moses, except [some] youths among his people, for fear of Pharaoh and his establishment that they would persecute them. And indeed, Pharaoh was haughty within the land, and indeed, he was of the transgressors\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcdxlviii{%
And Moses said, ``O my people, if you have believed in Allah, then rely upon Him, if you should be Muslims."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcdxlix{%
So they said, ``Upon Allah do we rely. Our Lord, make us not [objects of] trial for the wrongdoing people\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcdl{%
And save us by Your mercy from the disbelieving people."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcdli{%
And We inspired to Moses and his brother, ``Settle your people in Egypt in houses and make your houses [facing the] qiblah and establish prayer and give good tidings to the believers."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcdlii{%
And Moses said, ``Our Lord, indeed You have given Pharaoh and his establishment splendor and wealth in the worldly life, our Lord, that they may lead [men] astray from Your way. Our Lord, obliterate their wealth and harden their hearts so that they will not believe until they see the painful punishment."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcdliii{%
[Allah] said, ``Your supplication has been answered." So remain on a right course and follow not the way of those who do not know."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcdliv{%
And We took the Children of Israel across the sea, and Pharaoh and his soldiers pursued them in tyranny and enmity until, when drowning overtook him, he said, ``I believe that there is no deity except that in whom the Children of Israel believe, and I am of the Muslims."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcdlv{%
Now? And you had disobeyed [Him] before and were of the corrupters?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcdlvi{%
So today We will save you in body that you may be to those who succeed you a sign. And indeed, many among the people, of Our signs, are heedless\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcdlvii{%
And We had certainty settled the Children of Israel in an agreeable settlement and provided them with good things. And they did not differ until [after] knowledge had come to them. Indeed, your Lord will judge between them on the Day of Resurrection concerning that over which they used to differ\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcdlviii{%
So if you are in doubt, [O Muhammad], about that which We have revealed to you, then ask those who have been reading the Scripture before you. The truth has certainly come to you from your Lord, so never be among the doubters.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcdlix{%
And never be of those who deny the signs of Allah and [thus] be among the losers.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcdlx{%
Indeed, those upon whom the word of your Lord has come into effect will not believe,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcdlxi{%
Even if every sign should come to them, until they see the painful punishment.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcdlxii{%
Then has there not been a [single] city that believed so its faith benefited it except the people of Jonah? When they believed, We removed from them the punishment of disgrace in worldly life and gave them enjoyment for a time.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcdlxiii{%
And had your Lord willed, those on earth would have believed - all of them entirely. Then, [O Muhammad], would you compel the people in order that they become believers?\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcdlxiv{%
And it is not for a soul to believe except by permission of Allah, and He will place defilement upon those who will not use reason.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mcdlxv{%
Say, ``Observe what is in the heavens and earth." But of no avail will be signs or warners to a people who do not believe\qt@no{101}}%
\qt@newcmd\qurantrans@en@mcdlxvi{%
So do they wait except for like [what occurred in] the days of those who passed on before them? Say, ``Then wait; indeed, I am with you among those who wait."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mcdlxvii{%
Then We will save our messengers and those who have believed. Thus, it is an obligation upon Us that We save the believers\qt@no{103}}%
\qt@newcmd\qurantrans@en@mcdlxviii{%
Say, [O Muhammad], ``O people, if you are in doubt as to my religion - then I do not worship those which you worship besides Allah; but I worship Allah, who causes your death. And I have been commanded to be of the believers\qt@no{104}}%
\qt@newcmd\qurantrans@en@mcdlxix{%
And [commanded], 'Direct your face toward the religion, inclining to truth, and never be of those who associate others with Allah;\qt@no{105}}%
\qt@newcmd\qurantrans@en@mcdlxx{%
And do not invoke besides Allah that which neither benefits you nor harms you, for if you did, then indeed you would be of the wrongdoers.'"\qt@no{106}}%
\qt@newcmd\qurantrans@en@mcdlxxi{%
And if Allah should touch you with adversity, there is no remover of it except Him; and if He intends for you good, then there is no repeller of His bounty. He causes it to reach whom He wills of His servants. And He is the Forgiving, the Merciful\qt@no{107}}%
\qt@newcmd\qurantrans@en@mcdlxxii{%
Say, ``O mankind, the truth has come to you from your Lord, so whoever is guided is only guided for [the benefit of] his soul, and whoever goes astray only goes astray [in violation] against it. And I am not over you a manager."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mcdlxxiii{%
And follow what is revealed to you, [O Muhammad], and be patient until Allah will judge. And He is the best of judges.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mcdlxxiv{%
\basmalahen Alif, Lam, Ra. [This is] a Book whose verses are perfected and then presented in detail from [one who is] Wise and Acquainted.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcdlxxv{%
[Through a messenger, saying], ``Do not worship except Allah. Indeed, I am to you from Him a warner and a bringer of good tidings,"\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcdlxxvi{%
And [saying], ``Seek forgiveness of your Lord and repent to Him, [and] He will let you enjoy a good provision for a specified term and give every doer of favor his favor. But if you turn away, then indeed, I fear for you the punishment of a great Day.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcdlxxvii{%
To Allah is your return, and He is over all things competent."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcdlxxviii{%
Unquestionably, they the disbelievers turn away their breasts to hide themselves from Him. Unquestionably, [even] when they cover themselves in their clothing, Allah knows what they conceal and what they declare. Indeed, He is Knowing of that within the breasts.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcdlxxix{%
And there is no creature on earth but that upon Allah is its provision, and He knows its place of dwelling and place of storage. All is in a clear register.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcdlxxx{%
And it is He who created the heavens and the earth in six days - and His Throne had been upon water - that He might test you as to which of you is best in deed. But if you say, ``Indeed, you are resurrected after death," those who disbelieve will surely say, ``This is not but obvious magic."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcdlxxxi{%
And if We hold back from them the punishment for a limited time, they will surely say, ``What detains it?" Unquestionably, on the Day it comes to them, it will not be averted from them, and they will be enveloped by what they used to ridicule.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcdlxxxii{%
And if We give man a taste of mercy from Us and then We withdraw it from him, indeed, he is despairing and ungrateful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcdlxxxiii{%
But if We give him a taste of favor after hardship has touched him, he will surely say, ``Bad times have left me." Indeed, he is exultant and boastful -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcdlxxxiv{%
Except for those who are patient and do righteous deeds; those will have forgiveness and great reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcdlxxxv{%
Then would you possibly leave [out] some of what is revealed to you, or is your breast constrained by it because they say, ``Why has there not been sent down to him a treasure or come with him an angel?" But you are only a warner. And Allah is Disposer of all things.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcdlxxxvi{%
Or do they say, ``He invented it"? Say, ``Then bring ten surahs like it that have been invented and call upon [for assistance] whomever you can besides Allah, if you should be truthful."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcdlxxxvii{%
And if they do not respond to you - then know that the Qur'an was revealed with the knowledge of Allah and that there is no deity except Him. Then, would you [not] be Muslims?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcdlxxxviii{%
Whoever desires the life of this world and its adornments - We fully repay them for their deeds therein, and they therein will not be deprived.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcdlxxxix{%
Those are the ones for whom there is not in the Hereafter but the Fire. And lost is what they did therein, and worthless is what they used to do.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcdxc{%
So is one who [stands] upon a clear evidence from his Lord [like the aforementioned]? And a witness from Him follows it, and before it was the Scripture of Moses to lead and as mercy. Those [believers in the former revelations] believe in the Qur'an. But whoever disbelieves in it from the [various] factions - the Fire is his promised destination. So be not in doubt about it. Indeed, it is the truth from your Lord, but most of the people do not believe.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcdxci{%
And who is more unjust than he who invents a lie about Allah? Those will be presented before their Lord, and the witnesses will say, ``These are the ones who lied against their Lord." Unquestionably, the curse of Allah is upon the wrongdoers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcdxcii{%
Who averted [people] from the way of Allah and sought to make it [seem] deviant while they, concerning the Hereafter, were disbelievers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcdxciii{%
Those were not causing failure [to Allah] on earth, nor did they have besides Allah any protectors. For them the punishment will be multiplied. They were not able to hear, nor did they see.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcdxciv{%
Those are the ones who will have lost themselves, and lost from them is what they used to invent.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcdxcv{%
Assuredly, it is they in the Hereafter who will be the greatest losers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcdxcvi{%
Indeed, they who have believed and done righteous deeds and humbled themselves to their Lord - those are the companions of Paradise; they will abide eternally therein.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcdxcvii{%
The example of the two parties is like the blind and deaf, and the seeing and hearing. Are they equal in comparison? Then, will you not remember?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcdxcviii{%
And We had certainly sent Noah to his people, [saying], ``Indeed, I am to you a clear warner\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcdxcix{%
That you not worship except Allah. Indeed, I fear for you the punishment of a painful day."\qt@no{26}}%
\qt@newcmd\qurantrans@en@md{%
So the eminent among those who disbelieved from his people said, ``We do not see you but as a man like ourselves, and we do not see you followed except by those who are the lowest of us [and] at first suggestion. And we do not see in you over us any merit; rather, we think you are liars."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdi{%
He said, ``O my people have you considered: if I should be upon clear evidence from my Lord while He has given me mercy from Himself but it has been made unapparent to you, should we force it upon you while you are averse to it?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdii{%
And O my people, I ask not of you for it any wealth. My reward is not but from Allah. And I am not one to drive away those who have believed. Indeed, they will meet their Lord, but I see that you are a people behaving ignorantly.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdiii{%
And O my people, who would protect me from Allah if I drove them away? Then will you not be reminded?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdiv{%
And I do not tell you that I have the depositories [containing the provision] of Allah or that I know the unseen, nor do I tell you that I am an angel, nor do I say of those upon whom your eyes look down that Allah will never grant them any good. Allah is most knowing of what is within their souls. Indeed, I would then be among the wrongdoers."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdv{%
They said, ``O Noah, you have disputed us and been frequent in dispute of us. So bring us what you threaten us, if you should be of the truthful."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdvi{%
He said, ``Allah will only bring it to you if He wills, and you will not cause [Him] failure.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdvii{%
And my advice will not benefit you - although I wished to advise you - If Allah should intend to put you in error. He is your Lord, and to Him you will be returned."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdviii{%
Or do they say [about Prophet Muhammad], ``He invented it"? Say, ``If I have invented it, then upon me is [the consequence of] my crime; but I am innocent of what [crimes] you commit."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdix{%
And it was revealed to Noah that, ``No one will believe from your people except those who have already believed, so do not be distressed by what they have been doing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdx{%
And construct the ship under Our observation and Our inspiration and do not address Me concerning those who have wronged; indeed, they are [to be] drowned."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdxi{%
And he constructed the ship, and whenever an assembly of the eminent of his people passed by him, they ridiculed him. He said, ``If you ridicule us, then we will ridicule you just as you ridicule.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdxii{%
And you are going to know who will get a punishment that will disgrace him [on earth] and upon whom will descend an enduring punishment [in the Hereafter]."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdxiii{%
[So it was], until when Our command came and the oven overflowed, We said, ``Load upon the ship of each [creature] two mates and your family, except those about whom the word has preceded, and [include] whoever has believed." But none had believed with him, except a few.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdxiv{%
And [Noah] said, ``Embark therein; in the name of Allah is its course and its anchorage. Indeed, my Lord is Forgiving and Merciful."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdxv{%
And it sailed with them through waves like mountains, and Noah called to his son who was apart [from them], ``O my son, come aboard with us and be not with the disbelievers."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdxvi{%
[But] he said, ``I will take refuge on a mountain to protect me from the water." [Noah] said, ``There is no protector today from the decree of Allah, except for whom He gives mercy." And the waves came between them, and he was among the drowned.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdxvii{%
And it was said, ``O earth, swallow your water, and O sky, withhold [your rain]." And the water subsided, and the matter was accomplished, and the ship came to rest on the [mountain of] Judiyy. And it was said, ``Away with the wrongdoing people."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdxviii{%
And Noah called to his Lord and said, ``My Lord, indeed my son is of my family; and indeed, Your promise is true; and You are the most just of judges!"\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdxix{%
He said, ``O Noah, indeed he is not of your family; indeed, he is [one whose] work was other than righteous, so ask Me not for that about which you have no knowledge. Indeed, I advise you, lest you be among the ignorant."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdxx{%
[Noah] said, ``My Lord, I seek refuge in You from asking that of which I have no knowledge. And unless You forgive me and have mercy upon me, I will be among the losers."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdxxi{%
It was said, ``O Noah, disembark in security from Us and blessings upon you and upon nations [descending] from those with you. But other nations [of them] We will grant enjoyment; then there will touch them from Us a painful punishment."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdxxii{%
That is from the news of the unseen which We reveal to you, [O Muhammad]. You knew it not, neither you nor your people, before this. So be patient; indeed, the [best] outcome is for the righteous.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdxxiii{%
And to 'Aad [We sent] their brother Hud. He said, ``O my people, worship Allah; you have no deity other than Him. You are not but inventors [of falsehood].\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdxxiv{%
O my people, I do not ask you for it any reward. My reward is only from the one who created me. Then will you not reason?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdxxv{%
And O my people, ask forgiveness of your Lord and then repent to Him. He will send [rain from] the sky upon you in showers and increase you in strength [added] to your strength. And do not turn away, [being] criminals."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdxxvi{%
They said, ``O Hud, you have not brought us clear evidence, and we are not ones to leave our gods on your say-so. Nor are we believers in you.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdxxvii{%
We only say that some of our gods have possessed you with evil." He said, ``Indeed, I call Allah to witness, and witness [yourselves] that I am free from whatever you associate with Allah\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdxxviii{%
Other than Him. So plot against me all together; then do not give me respite.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdxxix{%
Indeed, I have relied upon Allah, my Lord and your Lord. There is no creature but that He holds its forelock. Indeed, my Lord is on a path [that is] straight."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdxxx{%
But if they turn away, [say], ``I have already conveyed that with which I was sent to you. My Lord will give succession to a people other than you, and you will not harm Him at all. Indeed my Lord is, over all things, Guardian."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdxxxi{%
And when Our command came, We saved Hud and those who believed with him, by mercy from Us; and We saved them from a harsh punishment.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdxxxii{%
And that was 'Aad, who rejected the signs of their Lord and disobeyed His messengers and followed the order of every obstinate tyrant.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdxxxiii{%
And they were [therefore] followed in this world with a curse and [as well] on the Day of Resurrection. Unquestionably, 'Aad denied their Lord; then away with 'Aad, the people of Hud.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdxxxiv{%
And to Thamud [We sent] their brother Salih. He said, ``O my people, worship Allah; you have no deity other than Him. He has produced you from the earth and settled you in it, so ask forgiveness of Him and then repent to Him. Indeed, my Lord is near and responsive."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdxxxv{%
They said, ``O Salih, you were among us a man of promise before this. Do you forbid us to worship what our fathers worshipped? And indeed we are, about that to which you invite us, in disquieting doubt."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdxxxvi{%
He said, ``O my people, have you considered: if I should be upon clear evidence from my Lord and He has given me mercy from Himself, who would protect me from Allah if I disobeyed Him? So you would not increase me except in loss.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdxxxvii{%
And O my people, this is the she-camel of Allah - [she is] to you a sign. So let her feed upon Allah 's earth and do not touch her with harm, or you will be taken by an impending punishment."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdxxxviii{%
But they hamstrung her, so he said, ``Enjoy yourselves in your homes for three days. That is a promise not to be denied."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdxxxix{%
So when Our command came, We saved Salih and those who believed with him, by mercy from Us, and [saved them] from the disgrace of that day. Indeed, it is your Lord who is the Powerful, the Exalted in Might.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdxl{%
And the shriek seized those who had wronged, and they became within their homes [corpses] fallen prone\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdxli{%
As if they had never prospered therein. Unquestionably, Thamud denied their Lord; then, away with Thamud.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdxlii{%
And certainly did Our messengers come to Abraham with good tidings; they said, ``Peace." He said, ``Peace," and did not delay in bringing [them] a roasted calf.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdxliii{%
But when he saw their hands not reaching for it, he distrusted them and felt from them apprehension. They said, ``Fear not. We have been sent to the people of Lot."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdxliv{%
And his Wife was standing, and she smiled. Then We gave her good tidings of Isaac and after Isaac, Jacob.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdxlv{%
She said, ``Woe to me! Shall I give birth while I am an old woman and this, my husband, is an old man? Indeed, this is an amazing thing!"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdxlvi{%
They said, ``Are you amazed at the decree of Allah? May the mercy of Allah and His blessings be upon you, people of the house. Indeed, He is Praiseworthy and Honorable."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdxlvii{%
And when the fright had left Abraham and the good tidings had reached him, he began to argue with Us concerning the people of Lot.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdxlviii{%
Indeed, Abraham was forbearing, grieving and [frequently] returning [to Allah].\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdxlix{%
[The angels said], ``O Abraham, give up this [plea]. Indeed, the command of your Lord has come, and indeed, there will reach them a punishment that cannot be repelled."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdl{%
And when Our messengers, [the angels], came to Lot, he was anguished for them and felt for them great discomfort and said, ``This is a trying day."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdli{%
And his people came hastening to him, and before [this] they had been doing evil deeds. He said, ``O my people, these are my daughters; they are purer for you. So fear Allah and do not disgrace me concerning my guests. Is there not among you a man of reason?"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdlii{%
They said, ``You have already known that we have not concerning your daughters any claim, and indeed, you know what we want."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdliii{%
He said, ``If only I had against you some power or could take refuge in a strong support."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdliv{%
The angels said, ``O Lot, indeed we are messengers of your Lord; [therefore], they will never reach you. So set out with your family during a portion of the night and let not any among you look back - except your wife; indeed, she will be struck by that which strikes them. Indeed, their appointment is [for] the morning. Is not the morning near?"\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdlv{%
So when Our command came, We made the highest part [of the city] its lowest and rained upon them stones of layered hard clay, [which were]\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdlvi{%
Marked from your Lord. And Allah 's punishment is not from the wrongdoers [very] far.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdlvii{%
And to Madyan [We sent] their brother Shu'ayb. He said, ``O my people, worship Allah; you have no deity other than Him. And do not decrease from the measure and the scale. Indeed, I see you in prosperity, but indeed, I fear for you the punishment of an all-encompassing Day.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdlviii{%
And O my people, give full measure and weight in justice and do not deprive the people of their due and do not commit abuse on the earth, spreading corruption.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdlix{%
What remains [lawful] from Allah is best for you, if you would be believers. But I am not a guardian over you."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdlx{%
They said, ``O Shu'ayb, does your prayer command you that we should leave what our fathers worship or not do with our wealth what we please? Indeed, you are the forbearing, the discerning!"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdlxi{%
He said, ``O my people, have you considered: if I am upon clear evidence from my Lord and He has provided me with a good provision from Him...? And I do not intend to differ from you in that which I have forbidden you; I only intend reform as much as I am able. And my success is not but through Allah. Upon him I have relied, and to Him I return.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdlxii{%
And O my people, let not [your] dissension from me cause you to be struck by that similar to what struck the people of Noah or the people of Hud or the people of Salih. And the people of Lot are not from you far away.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdlxiii{%
And ask forgiveness of your Lord and then repent to Him. Indeed, my Lord is Merciful and Affectionate."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdlxiv{%
They said, ``O Shu'ayb, we do not understand much of what you say, and indeed, we consider you among us as weak. And if not for your family, we would have stoned you [to death]; and you are not to us one respected."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdlxv{%
He said, ``O my people, is my family more respected for power by you than Allah? But you put Him behind your backs [in neglect]. Indeed, my Lord is encompassing of what you do.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdlxvi{%
And O my people, work according to your position; indeed, I am working. You are going to know to whom will come a punishment that will disgrace him and who is a liar. So watch; indeed, I am with you a watcher, [awaiting the outcome]."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdlxvii{%
And when Our command came, We saved Shu'ayb and those who believed with him, by mercy from Us. And the shriek seized those who had wronged, and they became within their homes [corpses] fallen prone\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdlxviii{%
As if they had never prospered therein. Then, away with Madyan as Thamud was taken away.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdlxix{%
And We did certainly send Moses with Our signs and a clear authority\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdlxx{%
To Pharaoh and his establishment, but they followed the command of Pharaoh, and the command of Pharaoh was not [at all] discerning.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdlxxi{%
He will precede his people on the Day of Resurrection and lead them into the Fire; and wretched is the place to which they are led.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdlxxii{%
And they were followed in this [world] with a curse and on the Day of Resurrection. And wretched is the gift which is given.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdlxxiii{%
That is from the news of the cities, which We relate to you; of them, some are [still] standing and some are [as] a harvest [mowed down].\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdlxxiv{%
And We did not wrong them, but they wronged themselves. And they were not availed at all by their gods which they invoked other than Allah when there came the command of your Lord. And they did not increase them in other than ruin.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdlxxv{%
And thus is the seizure of your Lord when He seizes the cities while they are committing wrong. Indeed, His seizure is painful and severe.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdlxxvi{%
Indeed in that is a sign for those who fear the punishment of the Hereafter. That is a Day for which the people will be collected, and that is a Day [which will be] witnessed.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdlxxvii{%
And We do not delay it except for a limited term.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdlxxviii{%
The Day it comes no soul will speak except by His permission. And among them will be the wretched and the prosperous.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdlxxix{%
As for those who were [destined to be] wretched, they will be in the Fire. For them therein is [violent] exhaling and inhaling.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdlxxx{%
[They will be] abiding therein as long as the heavens and the earth endure, except what your Lord should will. Indeed, your Lord is an effecter of what He intends.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdlxxxi{%
And as for those who were [destined to be] prosperous, they will be in Paradise, abiding therein as long as the heavens and the earth endure, except what your Lord should will - a bestowal uninterrupted.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdlxxxii{%
So do not be in doubt, [O Muhammad], as to what these [polytheists] are worshipping. They worship not except as their fathers worshipped before. And indeed, We will give them their share undiminished.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdlxxxiii{%
And We had certainly given Moses the Scripture, but it came under disagreement. And if not for a word that preceded from your Lord, it would have been judged between them. And indeed they are, concerning the Qur'an, in disquieting doubt.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdlxxxiv{%
And indeed, each [of the believers and disbelievers] - your Lord will fully compensate them for their deeds. Indeed, He is Acquainted with what they do.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdlxxxv{%
So remain on a right course as you have been commanded, [you] and those who have turned back with you [to Allah], and do not transgress. Indeed, He is Seeing of what you do.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mdlxxxvi{%
And do not incline toward those who do wrong, lest you be touched by the Fire, and you would not have other than Allah any protectors; then you would not be helped.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mdlxxxvii{%
And establish prayer at the two ends of the day and at the approach of the night. Indeed, good deeds do away with misdeeds. That is a reminder for those who remember.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mdlxxxviii{%
And be patient, for indeed, Allah does not allow to be lost the reward of those who do good.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mdlxxxix{%
So why were there not among the generations before you those of enduring discrimination forbidding corruption on earth - except a few of those We saved from among them? But those who wronged pursued what luxury they were given therein, and they were criminals.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mdxc{%
And your Lord would not have destroyed the cities unjustly while their people were reformers.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mdxci{%
And if your Lord had willed, He could have made mankind one community; but they will not cease to differ.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mdxcii{%
Except whom your Lord has given mercy, and for that He created them. But the word of your Lord is to be fulfilled that, ``I will surely fill Hell with jinn and men all together."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mdxciii{%
And each [story] We relate to you from the news of the messengers is that by which We make firm your heart. And there has come to you, in this, the truth and an instruction and a reminder for the believers.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mdxciv{%
And say to those who do not believe, ``Work according to your position; indeed, we are working.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mdxcv{%
And wait, indeed, we are waiting."\qt@no{122}}%
\qt@newcmd\qurantrans@en@mdxcvi{%
And to Allah belong the unseen [aspects] of the heavens and the earth and to Him will be returned the matter, all of it, so worship Him and rely upon Him. And your Lord is not unaware of that which you do.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mdxcvii{%
\basmalahen Alif, Lam, Ra. These are the verses of the clear Book.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdxcviii{%
Indeed, We have sent it down as an Arabic Qur'an that you might understand.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdxcix{%
We relate to you, [O Muhammad], the best of stories in what We have revealed to you of this Qur'an although you were, before it, among the unaware.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdc{%
[Of these stories mention] when Joseph said to his father, ``O my father, indeed I have seen [in a dream] eleven stars and the sun and the moon; I saw them prostrating to me."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdci{%
He said, ``O my son, do not relate your vision to your brothers or they will contrive against you a plan. Indeed Satan, to man, is a manifest enemy.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcii{%
And thus will your Lord choose you and teach you the interpretation of narratives and complete His favor upon you and upon the family of Jacob, as He completed it upon your fathers before, Abraham and Isaac. Indeed, your Lord is Knowing and Wise."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdciii{%
Certainly were there in Joseph and his brothers signs for those who ask,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdciv{%
When they said, ``Joseph and his brother are more beloved to our father than we, while we are a clan. Indeed, our father is in clear error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcv{%
Kill Joseph or cast him out to [another] land; the countenance of your father will [then] be only for you, and you will be after that a righteous people."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcvi{%
Said a speaker among them, ``Do not kill Joseph but throw him into the bottom of the well; some travelers will pick him up - if you would do [something]."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcvii{%
They said, ``O our father, why do you not entrust us with Joseph while indeed, we are to him sincere counselors?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcviii{%
Send him with us tomorrow that he may eat well and play. And indeed, we will be his guardians.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcix{%
[Jacob] said, ``Indeed, it saddens me that you should take him, and I fear that a wolf would eat him while you are of him unaware."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcx{%
They said, ``If a wolf should eat him while we are a [strong] clan, indeed, we would then be losers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcxi{%
So when they took him [out] and agreed to put him into the bottom of the well... But We inspired to him, ``You will surely inform them [someday] about this affair of theirs while they do not perceive [your identity]."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcxii{%
And they came to their father at night, weeping.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcxiii{%
They said, ``O our father, indeed we went racing each other and left Joseph with our possessions, and a wolf ate him. But you would not believe us, even if we were truthful."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcxiv{%
And they brought upon his shirt false blood. [Jacob] said, ``Rather, your souls have enticed you to something, so patience is most fitting. And Allah is the one sought for help against that which you describe."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcxv{%
And there came a company of travelers; then they sent their water drawer, and he let down his bucket. He said, ``Good news! Here is a boy." And they concealed him, [taking him] as merchandise; and Allah was knowing of what they did.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcxvi{%
And they sold him for a reduced price - a few dirhams - and they were, concerning him, of those content with little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcxvii{%
And the one from Egypt who bought him said to his wife, ``Make his residence comfortable. Perhaps he will benefit us, or we will adopt him as a son." And thus, We established Joseph in the land that We might teach him the interpretation of events. And Allah is predominant over His affair, but most of the people do not know.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcxviii{%
And when Joseph reached maturity, We gave him judgment and knowledge. And thus We reward the doers of good.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcxix{%
And she, in whose house he was, sought to seduce him. She closed the doors and said, ``Come, you." He said, ``[I seek] the refuge of Allah. Indeed, he is my master, who has made good my residence. Indeed, wrongdoers will not succeed."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcxx{%
And she certainly determined [to seduce] him, and he would have inclined to her had he not seen the proof of his Lord. And thus [it was] that We should avert from him evil and immorality. Indeed, he was of Our chosen servants.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcxxi{%
And they both raced to the door, and she tore his shirt from the back, and they found her husband at the door. She said, ``What is the recompense of one who intended evil for your wife but that he be imprisoned or a painful punishment?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcxxii{%
[Joseph] said, ``It was she who sought to seduce me." And a witness from her family testified. ``If his shirt is torn from the front, then she has told the truth, and he is of the liars.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcxxiii{%
But if his shirt is torn from the back, then she has lied, and he is of the truthful."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcxxiv{%
So when her husband saw his shirt torn from the back, he said, ``Indeed, it is of the women's plan. Indeed, your plan is great.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcxxv{%
Joseph, ignore this. And, [my wife], ask forgiveness for your sin. Indeed, you were of the sinful."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcxxvi{%
And women in the city said, ``The wife of al-'Azeez is seeking to seduce her slave boy; he has impassioned her with love. Indeed, we see her [to be] in clear error."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcxxvii{%
So when she heard of their scheming, she sent for them and prepared for them a banquet and gave each one of them a knife and said [to Joseph], ``Come out before them." And when they saw him, they greatly admired him and cut their hands and said, ``Perfect is Allah! This is not a man; this is none but a noble angel."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcxxviii{%
She said, ``That is the one about whom you blamed me. And I certainly sought to seduce him, but he firmly refused; and if he will not do what I order him, he will surely be imprisoned and will be of those debased."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcxxix{%
He said, ``My Lord, prison is more to my liking than that to which they invite me. And if You do not avert from me their plan, I might incline toward them and [thus] be of the ignorant."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcxxx{%
So his Lord responded to him and averted from him their plan. Indeed, He is the Hearing, the Knowing.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcxxxi{%
Then it appeared to them after they had seen the signs that al-'Azeez should surely imprison him for a time.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcxxxii{%
And there entered the prison with him two young men. One of them said, ``Indeed, I have seen myself [in a dream] pressing wine." The other said, ``Indeed, I have seen myself carrying upon my head [some] bread, from which the birds were eating. Inform us of its interpretation; indeed, we see you to be of those who do good."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcxxxiii{%
He said, ``You will not receive food that is provided to you except that I will inform you of its interpretation before it comes to you. That is from what my Lord has taught me. Indeed, I have left the religion of a people who do not believe in Allah, and they, in the Hereafter, are disbelievers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcxxxiv{%
And I have followed the religion of my fathers, Abraham, Isaac and Jacob. And it was not for us to associate anything with Allah. That is from the favor of Allah upon us and upon the people, but most of the people are not grateful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcxxxv{%
O [my] two companions of prison, are separate lords better or Allah, the One, the Prevailing?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcxxxvi{%
You worship not besides Him except [mere] names you have named them, you and your fathers, for which Allah has sent down no authority. Legislation is not but for Allah. He has commanded that you worship not except Him. That is the correct religion, but most of the people do not know.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcxxxvii{%
O two companions of prison, as for one of you, he will give drink to his master of wine; but as for the other, he will be crucified, and the birds will eat from his head. The matter has been decreed about which you both inquire."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcxxxviii{%
And he said to the one whom he knew would go free, ``Mention me before your master." But Satan made him forget the mention [to] his master, and Joseph remained in prison several years.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcxxxix{%
And [subsequently] the king said, ``Indeed, I have seen [in a dream] seven fat cows being eaten by seven [that were] lean, and seven green spikes [of grain] and others [that were] dry. O eminent ones, explain to me my vision, if you should interpret visions."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcxl{%
They said, ``[It is but] a mixture of false dreams, and we are not learned in the interpretation of dreams."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcxli{%
But the one who was freed and remembered after a time said, ``I will inform you of its interpretation, so send me forth."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcxlii{%
[He said], ``Joseph, O man of truth, explain to us about seven fat cows eaten by seven [that were] lean, and seven green spikes [of grain] and others [that were] dry - that I may return to the people; perhaps they will know [about you]."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcxliii{%
[Joseph] said, ``You will plant for seven years consecutively; and what you harvest leave in its spikes, except a little from which you will eat.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcxliv{%
Then will come after that seven difficult [years] which will consume what you saved for them, except a little from which you will store.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcxlv{%
Then will come after that a year in which the people will be given rain and in which they will press [olives and grapes]."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdcxlvi{%
And the king said, ``Bring him to me." But when the messenger came to him, [Joseph] said, ``Return to your master and ask him what is the case of the women who cut their hands. Indeed, my Lord is Knowing of their plan."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcxlvii{%
Said [the king to the women], ``What was your condition when you sought to seduce Joseph?" They said, ``Perfect is Allah! We know about him no evil." The wife of al-'Azeez said, ``Now the truth has become evident. It was I who sought to seduce him, and indeed, he is of the truthful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcxlviii{%
That is so al-'Azeez will know that I did not betray him in [his] absence and that Allah does not guide the plan of betrayers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdcxlix{%
And I do not acquit myself. Indeed, the soul is a persistent enjoiner of evil, except those upon which my Lord has mercy. Indeed, my Lord is Forgiving and Merciful."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdcl{%
And the king said, ``Bring him to me; I will appoint him exclusively for myself." And when he spoke to him, he said, ``Indeed, you are today established [in position] and trusted."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdcli{%
[Joseph] said, ``Appoint me over the storehouses of the land. Indeed, I will be a knowing guardian."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdclii{%
And thus We established Joseph in the land to settle therein wherever he willed. We touch with Our mercy whom We will, and We do not allow to be lost the reward of those who do good.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdcliii{%
And the reward of the Hereafter is better for those who believed and were fearing Allah.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdcliv{%
And the brothers of Joseph came [seeking food], and they entered upon him; and he recognized them, but he was to them unknown.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdclv{%
And when he had furnished them with their supplies, he said, ``Bring me a brother of yours from your father. Do not you see that I give full measure and that I am the best of accommodators?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdclvi{%
But if you do not bring him to me, no measure will there be [hereafter] for you from me, nor will you approach me."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdclvii{%
They said, ``We will attempt to dissuade his father from [keeping] him, and indeed, we will do [it]."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdclviii{%
And [Joseph] said to his servants, ``Put their merchandise into their saddlebags so they might recognize it when they have gone back to their people that perhaps they will [again] return."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdclix{%
So when they returned to their father, they said, ``O our father, [further] measure has been denied to us, so send with us our brother [that] we will be given measure. And indeed, we will be his guardians."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdclx{%
He said, ``Should I entrust you with him except [under coercion] as I entrusted you with his brother before? But Allah is the best guardian, and He is the most merciful of the merciful."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdclxi{%
And when they opened their baggage, they found their merchandise returned to them. They said, ``O our father, what [more] could we desire? This is our merchandise returned to us. And we will obtain supplies for our family and protect our brother and obtain an increase of a camel's load; that is an easy measurement."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdclxii{%
[Jacob] said, ``Never will I send him with you until you give me a promise by Allah that you will bring him [back] to me, unless you should be surrounded by enemies." And when they had given their promise, he said, ``Allah, over what we say, is Witness."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdclxiii{%
And he said, ``O my sons, do not enter from one gate but enter from different gates; and I cannot avail you against [the decree of] Allah at all. The decision is only for Allah; upon Him I have relied, and upon Him let those who would rely [indeed] rely."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdclxiv{%
And when they entered from where their father had ordered them, it did not avail them against Allah at all except [it was] a need within the soul of Jacob, which he satisfied. And indeed, he was a possessor of knowledge because of what We had taught him, but most of the people do not know.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdclxv{%
And when they entered upon Joseph, he took his brother to himself; he said, ``Indeed, I am your brother, so do not despair over what they used to do [to me]."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdclxvi{%
So when he had furnished them with their supplies, he put the [gold measuring] bowl into the bag of his brother. Then an announcer called out, ``O caravan, indeed you are thieves."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdclxvii{%
They said while approaching them, ``What is it you are missing?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdclxviii{%
They said, ``We are missing the measure of the king. And for he who produces it is [the reward of] a camel's load, and I am responsible for it."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdclxix{%
They said, ``By Allah, you have certainly known that we did not come to cause corruption in the land, and we have not been thieves."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdclxx{%
The accusers said, ``Then what would be its recompense if you should be liars?"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdclxxi{%
[The brothers] said, ``Its recompense is that he in whose bag it is found - he [himself] will be its recompense. Thus do we recompense the wrongdoers."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdclxxii{%
So he began [the search] with their bags before the bag of his brother; then he extracted it from the bag of his brother. Thus did We plan for Joseph. He could not have taken his brother within the religion of the king except that Allah willed. We raise in degrees whom We will, but over every possessor of knowledge is one [more] knowing.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdclxxiii{%
They said, ``If he steals - a brother of his has stolen before." But Joseph kept it within himself and did not reveal it to them. He said, ``You are worse in position, and Allah is most knowing of what you describe."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdclxxiv{%
They said, ``O 'Azeez, indeed he has a father [who is] an old man, so take one of us in place of him. Indeed, we see you as a doer of good."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdclxxv{%
He said, ``[I seek] the refuge of Allah [to prevent] that we take except him with whom we found our possession. Indeed, we would then be unjust."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdclxxvi{%
So when they had despaired of him, they secluded themselves in private consultation. The eldest of them said, ``Do you not know that your father has taken upon you an oath by Allah and [that] before you failed in [your duty to] Joseph? So I will never leave [this] land until my father permits me or Allah decides for me, and He is the best of judges.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdclxxvii{%
Return to your father and say, ``O our father, indeed your son has stolen, and we did not testify except to what we knew. And we were not witnesses of the unseen,\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdclxxviii{%
And ask the city in which we were and the caravan in which we came - and indeed, we are truthful,"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdclxxix{%
[Jacob] said, ``Rather, your souls have enticed you to something, so patience is most fitting. Perhaps Allah will bring them to me all together. Indeed it is He who is the Knowing, the Wise."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdclxxx{%
And he turned away from them and said, ``Oh, my sorrow over Joseph," and his eyes became white from grief, for he was [of that] a suppressor.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdclxxxi{%
They said, ``By Allah, you will not cease remembering Joseph until you become fatally ill or become of those who perish."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdclxxxii{%
He said, ``I only complain of my suffering and my grief to Allah, and I know from Allah that which you do not know.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdclxxxiii{%
O my sons, go and find out about Joseph and his brother and despair not of relief from Allah. Indeed, no one despairs of relief from Allah except the disbelieving people."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdclxxxiv{%
So when they entered upon Joseph, they said, ``O 'Azeez, adversity has touched us and our family, and we have come with goods poor in quality, but give us full measure and be charitable to us. Indeed, Allah rewards the charitable."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdclxxxv{%
He said, ``Do you know what you did with Joseph and his brother when you were ignorant?"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdclxxxvi{%
They said, ``Are you indeed Joseph?" He said ``I am Joseph, and this is my brother. Allah has certainly favored us. Indeed, he who fears Allah and is patient, then indeed, Allah does not allow to be lost the reward of those who do good."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdclxxxvii{%
They said, ``By Allah, certainly has Allah preferred you over us, and indeed, we have been sinners."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdclxxxviii{%
He said, ``No blame will there be upon you today. Allah will forgive you; and He is the most merciful of the merciful."\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdclxxxix{%
Take this, my shirt, and cast it over the face of my father; he will become seeing. And bring me your family, all together."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcxc{%
And when the caravan departed [from Egypt], their father said, ``Indeed, I find the smell of Joseph [and would say that he was alive] if you did not think me weakened in mind."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcxci{%
They said, ``By Allah, indeed you are in your [same] old error."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcxcii{%
And when the bearer of good tidings arrived, he cast it over his face, and he returned [once again] seeing. He said, ``Did I not tell you that I know from Allah that which you do not know?"\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcxciii{%
They said, ``O our father, ask for us forgiveness of our sins; indeed, we have been sinners."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mdcxciv{%
He said, ``I will ask forgiveness for you from my Lord. Indeed, it is He who is the Forgiving, the Merciful."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mdcxcv{%
And when they entered upon Joseph, he took his parents to himself and said, ``Enter Egypt, Allah willing, safe [and secure]."\qt@no{99}}%
\qt@newcmd\qurantrans@en@mdcxcvi{%
And he raised his parents upon the throne, and they bowed to him in prostration. And he said, ``O my father, this is the explanation of my vision of before. My Lord has made it reality. And He was certainly good to me when He took me out of prison and brought you [here] from bedouin life after Satan had induced [estrangement] between me and my brothers. Indeed, my Lord is Subtle in what He wills. Indeed, it is He who is the Knowing, the Wise.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mdcxcvii{%
My Lord, You have given me [something] of sovereignty and taught me of the interpretation of dreams. Creator of the heavens and earth, You are my protector in this world and in the Hereafter. Cause me to die a Muslim and join me with the righteous."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mdcxcviii{%
That is from the news of the unseen which We reveal, [O Muhammad], to you. And you were not with them when they put together their plan while they conspired.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mdcxcix{%
And most of the people, although you strive [for it], are not believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mdcc{%
And you do not ask of them for it any payment. It is not except a reminder to the worlds.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mdcci{%
And how many a sign within the heavens and earth do they pass over while they, therefrom, are turning away.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mdccii{%
And most of them believe not in Allah except while they associate others with Him.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mdcciii{%
Then do they feel secure that there will not come to them an overwhelming [aspect] of the punishment of Allah or that the Hour will not come upon them suddenly while they do not perceive?\qt@no{107}}%
\qt@newcmd\qurantrans@en@mdcciv{%
Say, ``This is my way; I invite to Allah with insight, I and those who follow me. And exalted is Allah; and I am not of those who associate others with Him."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mdccv{%
And We sent not before you [as messengers] except men to whom We revealed from among the people of cities. So have they not traveled through the earth and observed how was the end of those before them? And the home of the Hereafter is best for those who fear Allah; then will you not reason?\qt@no{109}}%
\qt@newcmd\qurantrans@en@mdccvi{%
[They continued] until, when the messengers despaired and were certain that they had been denied, there came to them Our victory, and whoever We willed was saved. And Our punishment cannot be repelled from the people who are criminals.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mdccvii{%
There was certainly in their stories a lesson for those of understanding. Never was the Qur'an a narration invented, but a confirmation of what was before it and a detailed explanation of all things and guidance and mercy for a people who believe.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mdccviii{%
\basmalahen Alif, Lam, Meem, Ra. These are the verses of the Book; and what has been revealed to you from your Lord is the truth, but most of the people do not believe.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccix{%
It is Allah who erected the heavens without pillars that you [can] see; then He established Himself above the Throne and made subject the sun and the moon, each running [its course] for a specified term. He arranges [each] matter; He details the signs that you may, of the meeting with your Lord, be certain.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccx{%
And it is He who spread the earth and placed therein firmly set mountains and rivers; and from all of the fruits He made therein two mates; He causes the night to cover the day. Indeed in that are signs for a people who give thought.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccxi{%
And within the land are neighboring plots and gardens of grapevines and crops and palm trees, [growing] several from a root or otherwise, watered with one water; but We make some of them exceed others in [quality of] fruit. Indeed in that are signs for a people who reason.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdccxii{%
And if you are astonished, [O Muhammad] - then astonishing is their saying, ``When we are dust, will we indeed be [brought] into a new creation?" Those are the ones who have disbelieved in their Lord, and those will have shackles upon their necks, and those are the companions of the Fire; they will abide therein eternally.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdccxiii{%
They impatiently urge you to bring about evil before good, while there has already occurred before them similar punishments [to what they demand]. And indeed, your Lord is full of forgiveness for the people despite their wrongdoing, and indeed, your Lord is severe in penalty.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdccxiv{%
And those who disbelieved say, ``Why has a sign not been sent down to him from his Lord?" You are only a warner, and for every people is a guide.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdccxv{%
Allah knows what every female carries and what the wombs lose [prematurely] or exceed. And everything with Him is by due measure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdccxvi{%
[He is] Knower of the unseen and the witnessed, the Grand, the Exalted.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdccxvii{%
It is the same [to Him] concerning you whether one conceals [his] speech or one publicizes it and whether one is hidden by night or conspicuous [among others] by day.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdccxviii{%
For each one are successive [angels] before and behind him who protect him by the decree of Allah. Indeed, Allah will not change the condition of a people until they change what is in themselves. And when Allah intends for a people ill, there is no repelling it. And there is not for them besides Him any patron.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdccxix{%
It is He who shows you lightening, [causing] fear and aspiration, and generates the heavy clouds.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdccxx{%
And the thunder exalts [Allah] with praise of Him - and the angels [as well] from fear of Him - and He sends thunderbolts and strikes therewith whom He wills while they dispute about Allah; and He is severe in assault.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdccxxi{%
To Him [alone] is the supplication of truth. And those they call upon besides Him do not respond to them with a thing, except as one who stretches his hands toward water [from afar, calling it] to reach his mouth, but it will not reach it [thus]. And the supplication of the disbelievers is not but in error [i.e. futility].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdccxxii{%
And to Allah prostrates whoever is within the heavens and the earth, willingly or by compulsion, and their shadows [as well] in the mornings and the afternoons.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdccxxiii{%
Say, ``Who is Lord of the heavens and earth?" Say, ``Allah." Say, ``Have you then taken besides Him allies not possessing [even] for themselves any benefit or any harm?" Say, ``Is the blind equivalent to the seeing? Or is darkness equivalent to light? Or have they attributed to Allah partners who created like His creation so that the creation [of each] seemed similar to them?" Say, ``Allah is the Creator of all things, and He is the One, the Prevailing."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdccxxiv{%
He sends down from the sky, rain, and valleys flow according to their capacity, and the torrent carries a rising foam. And from that [ore] which they heat in the fire, desiring adornments and utensils, is a foam like it. Thus Allah presents [the example of] truth and falsehood. As for the foam, it vanishes, [being] cast off; but as for that which benefits the people, it remains on the earth. Thus does Allah present examples.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdccxxv{%
For those who have responded to their Lord is the best [reward], but those who did not respond to Him - if they had all that is in the earth entirely and the like of it with it, they would [attempt to] ransom themselves thereby. Those will have the worst account, and their refuge is Hell, and wretched is the resting place.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdccxxvi{%
Then is he who knows that what has been revealed to you from your Lord is the truth like one who is blind? They will only be reminded who are people of understanding -\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdccxxvii{%
Those who fulfill the covenant of Allah and do not break the contract,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdccxxviii{%
And those who join that which Allah has ordered to be joined and fear their Lord and are afraid of the evil of [their] account,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdccxxix{%
And those who are patient, seeking the countenance of their Lord, and establish prayer and spend from what We have provided for them secretly and publicly and prevent evil with good - those will have the good consequence of [this] home -\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdccxxx{%
Gardens of perpetual residence; they will enter them with whoever were righteous among their fathers, their spouses and their descendants. And the angels will enter upon them from every gate, [saying],\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdccxxxi{%
``Peace be upon you for what you patiently endured. And excellent is the final home."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdccxxxii{%
But those who break the covenant of Allah after contracting it and sever that which Allah has ordered to be joined and spread corruption on earth - for them is the curse, and they will have the worst home.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdccxxxiii{%
Allah extends provision for whom He wills and restricts [it]. And they rejoice in the worldly life, while the worldly life is not, compared to the Hereafter, except [brief] enjoyment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdccxxxiv{%
And those who disbelieved say, ``Why has a sign not been sent down to him from his Lord?" Say, [O Muhammad], ``Indeed, Allah leaves astray whom He wills and guides to Himself whoever turns back [to Him] -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdccxxxv{%
Those who have believed and whose hearts are assured by the remembrance of Allah. Unquestionably, by the remembrance of Allah hearts are assured."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdccxxxvi{%
Those who have believed and done righteous deeds - a good state is theirs and a good return.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdccxxxvii{%
Thus have We sent you to a community before which [other] communities have passed on so you might recite to them that which We revealed to you, while they disbelieve in the Most Merciful. Say, ``He is my Lord; there is no deity except Him. Upon Him I rely, and to Him is my return."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdccxxxviii{%
And if there was any qur'an by which the mountains would be removed or the earth would be broken apart or the dead would be made to speak, [it would be this Qur'an], but to Allah belongs the affair entirely. Then have those who believed not accepted that had Allah willed, He would have guided the people, all of them? And those who disbelieve do not cease to be struck, for what they have done, by calamity - or it will descend near their home - until there comes the promise of Allah. Indeed, Allah does not fail in [His] promise.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdccxxxix{%
And already were [other] messengers ridiculed before you, and I extended the time of those who disbelieved; then I seized them, and how [terrible] was My penalty.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdccxl{%
Then is He who is a maintainer of every soul, [knowing] what it has earned, [like any other]? But to Allah they have attributed partners. Say, ``Name them. Or do you inform Him of that which He knows not upon the earth or of what is apparent of speech?" Rather, their [own] plan has been made attractive to those who disbelieve, and they have been averted from the way. And whomever Allah leaves astray - there will be for him no guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdccxli{%
For them will be punishment in the life of [this] world, and the punishment of the Hereafter is more severe. And they will not have from Allah any protector.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdccxlii{%
The example of Paradise, which the righteous have been promised, is [that] beneath it rivers flow. Its fruit is lasting, and its shade. That is the consequence for the righteous, and the consequence for the disbelievers is the Fire.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdccxliii{%
And [the believers among] those to whom We have given the [previous] Scripture rejoice at what has been revealed to you, [O Muhammad], but among the [opposing] factions are those who deny part of it. Say, ``I have only been commanded to worship Allah and not associate [anything] with Him. To Him I invite, and to Him is my return."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdccxliv{%
And thus We have revealed it as an Arabic legislation. And if you should follow their inclinations after what has come to you of knowledge, you would not have against Allah any ally or any protector.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdccxlv{%
And We have already sent messengers before you and assigned to them wives and descendants. And it was not for a messenger to come with a sign except by permission of Allah. For every term is a decree.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdccxlvi{%
Allah eliminates what He wills or confirms, and with Him is the Mother of the Book.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxlvii{%
And whether We show you part of what We promise them or take you in death, upon you is only the [duty of] notification, and upon Us is the account.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxlviii{%
Have they not seen that We set upon the land, reducing it from its borders? And Allah decides; there is no adjuster of His decision. And He is swift in account.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxlix{%
And those before them had plotted, but to Allah belongs the plan entirely. He knows what every soul earns, and the disbelievers will know for whom is the final home.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccl{%
And those who have disbelieved say, ``You are not a messenger." Say, [O Muhammad], ``Sufficient is Allah as Witness between me and you, and [the witness of] whoever has knowledge of the Scripture."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccli{%
\basmalahen Alif, Lam, Ra. [This is] a Book which We have revealed to you, [O Muhammad], that you might bring mankind out of darknesses into the light by permission of their Lord - to the path of the Exalted in Might, the Praiseworthy -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdcclii{%
Allah, to whom belongs whatever is in the heavens and whatever is on the earth. And woe to the disbelievers from a severe punishment\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdccliii{%
The ones who prefer the worldly life over the Hereafter and avert [people] from the way of Allah, seeking to make it (seem) deviant. Those are in extreme error.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdccliv{%
And We did not send any messenger except [speaking] in the language of his people to state clearly for them, and Allah sends astray [thereby] whom He wills and guides whom He wills. And He is the Exalted in Might, the Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcclv{%
And We certainly sent Moses with Our signs, [saying], ``Bring out your people from darknesses into the light and remind them of the days of Allah." Indeed in that are signs for everyone patient and grateful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcclvi{%
And [recall, O Children of Israel], when Moses said to His people, ``Remember the favor of Allah upon you when He saved you from the people of Pharaoh, who were afflicting you with the worst torment and were slaughtering your [newborn] sons and keeping your females alive. And in that was a great trial from your Lord.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcclvii{%
And [remember] when your Lord proclaimed, 'If you are grateful, I will surely increase you [in favor]; but if you deny, indeed, My punishment is severe.' ``\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcclviii{%
And Moses said, ``If you should disbelieve, you and whoever is on the earth entirely - indeed, Allah is Free of need and Praiseworthy."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcclix{%
Has there not reached you the news of those before you - the people of Noah and 'Aad and Thamud and those after them? No one knows them but Allah. Their messengers brought them clear proofs, but they returned their hands to their mouths and said, ``Indeed, we disbelieve in that with which you have been sent, and indeed we are, about that to which you invite us, in disquieting doubt."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcclx{%
Their messengers said, ``Can there be doubt about Allah, Creator of the heavens and earth? He invites you that He may forgive you of your sins, and He delays your death for a specified term." They said, ``You are not but men like us who wish to avert us from what our fathers were worshipping. So bring us a clear authority."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcclxi{%
Their messengers said to them, ``We are only men like you, but Allah confers favor upon whom He wills of His servants. It has never been for us to bring you evidence except by permission of Allah. And upon Allah let the believers rely.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcclxii{%
And why should we not rely upon Allah while He has guided us to our [good] ways. And we will surely be patient against whatever harm you should cause us. And upon Allah let those who would rely [indeed] rely."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcclxiii{%
And those who disbelieved said to their messengers, ``We will surely drive you out of our land, or you must return to our religion." So their Lord inspired to them, ``We will surely destroy the wrongdoers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcclxiv{%
And We will surely cause you to dwell in the land after them. That is for he who fears My position and fears My threat."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcclxv{%
And they requested victory from Allah, and disappointed, [therefore], was every obstinate tyrant.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcclxvi{%
Before him is Hell, and he will be given a drink of purulent water.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcclxvii{%
He will gulp it but will hardly [be able to] swallow it. And death will come to him from everywhere, but he is not to die. And before him is a massive punishment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcclxviii{%
The example of those who disbelieve in their Lord is [that] their deeds are like ashes which the wind blows forcefully on a stormy day; they are unable [to keep] from what they earned a [single] thing. That is what is extreme error.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcclxix{%
Have you not seen that Allah created the heavens and the earth in truth? If He wills, He can do away with you and produce a new creation.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcclxx{%
And that is not difficult for Allah.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcclxxi{%
And they will come out [for judgement] before Allah all together, and the weak will say to those who were arrogant, ``Indeed, we were your followers, so can you avail us anything against the punishment of Allah?" They will say, ``If Allah had guided us, we would have guided you. It is all the same for us whether we show intolerance or are patient: there is for us no place of escape."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcclxxii{%
And Satan will say when the matter has been concluded, ``Indeed, Allah had promised you the promise of truth. And I promised you, but I betrayed you. But I had no authority over you except that I invited you, and you responded to me. So do not blame me; but blame yourselves. I cannot be called to your aid, nor can you be called to my aid. Indeed, I deny your association of me [with Allah] before. Indeed, for the wrongdoers is a painful punishment."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcclxxiii{%
And those who believed and did righteous deeds will be admitted to gardens beneath which rivers flow, abiding eternally therein by permission of their Lord; and their greeting therein will be, ``Peace!"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcclxxiv{%
Have you not considered how Allah presents an example, [making] a good word like a good tree, whose root is firmly fixed and its branches [high] in the sky?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcclxxv{%
It produces its fruit all the time, by permission of its Lord. And Allah presents examples for the people that perhaps they will be reminded.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcclxxvi{%
And the example of a bad word is like a bad tree, uprooted from the surface of the earth, not having any stability.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcclxxvii{%
Allah keeps firm those who believe, with the firm word, in worldly life and in the Hereafter. And Allah sends astray the wrongdoers. And Allah does what He wills.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcclxxviii{%
Have you not considered those who exchanged the favor of Allah for disbelief and settled their people [in] the home of ruin?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcclxxix{%
[It is] Hell, which they will [enter to] burn, and wretched is the settlement.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcclxxx{%
And they have attributed to Allah equals to mislead [people] from His way. Say, ``Enjoy yourselves, for indeed, your destination is the Fire."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcclxxxi{%
[O Muhammad], tell My servants who have believed to establish prayer and spend from what We have provided them, secretly and publicly, before a Day comes in which there will be no exchange, nor any friendships.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcclxxxii{%
It is Allah who created the heavens and the earth and sent down rain from the sky and produced thereby some fruits as provision for you and subjected for you the ships to sail through the sea by His command and subjected for you the rivers.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcclxxxiii{%
And He subjected for you the sun and the moon, continuous [in orbit], and subjected for you the night and the day.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcclxxxiv{%
And He gave you from all you asked of Him. And if you should count the favor of Allah, you could not enumerate them. Indeed, mankind is [generally] most unjust and ungrateful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcclxxxv{%
And [mention, O Muhammad], when Abraham said, ``My Lord, make this city [Makkah] secure and keep me and my sons away from worshipping idols.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcclxxxvi{%
My Lord, indeed they have led astray many among the people. So whoever follows me - then he is of me; and whoever disobeys me - indeed, You are [yet] Forgiving and Merciful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcclxxxvii{%
Our Lord, I have settled some of my descendants in an uncultivated valley near Your sacred House, our Lord, that they may establish prayer. So make hearts among the people incline toward them and provide for them from the fruits that they might be grateful.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcclxxxviii{%
Our Lord, indeed You know what we conceal and what we declare, and nothing is hidden from Allah on the earth or in the heaven.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcclxxxix{%
Praise to Allah, who has granted to me in old age Ishmael and Isaac. Indeed, my Lord is the Hearer of supplication.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdccxc{%
My Lord, make me an establisher of prayer, and [many] from my descendants. Our Lord, and accept my supplication.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdccxci{%
Our Lord, forgive me and my parents and the believers the Day the account is established."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdccxcii{%
And never think that Allah is unaware of what the wrongdoers do. He only delays them for a Day when eyes will stare [in horror].\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdccxciii{%
Racing ahead, their heads raised up, their glance does not come back to them, and their hearts are void.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdccxciv{%
And, [O Muhammad], warn the people of a Day when the punishment will come to them and those who did wrong will say, ``Our Lord, delay us for a short term; we will answer Your call and follow the messengers." [But it will be said], ``Had you not sworn, before, that for you there would be no cessation?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdccxcv{%
And you lived among the dwellings of those who wronged themselves, and it had become clear to you how We dealt with them. And We presented for you [many] examples."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdccxcvi{%
And they had planned their plan, but with Allah is [recorded] their plan, even if their plan had been [sufficient] to do away with the mountains.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdccxcvii{%
So never think that Allah will fail in His promise to His messengers. Indeed, Allah is Exalted in Might and Owner of Retribution.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdccxcviii{%
[It will be] on the Day the earth will be replaced by another earth, and the heavens [as well], and all creatures will come out before Allah, the One, the Prevailing.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdccxcix{%
And you will see the criminals that Day bound together in shackles,\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccc{%
Their garments of liquid pitch and their faces covered by the Fire.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdccci{%
So that Allah will recompense every soul for what it earned. Indeed, Allah is swift in account.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccii{%
This [Qur'an] is notification for the people that they may be warned thereby and that they may know that He is but one God and that those of understanding will be reminded.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccciii{%
\basmalahen Alif, Lam, Ra. These are the verses of the Book and a clear Qur'an.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mdccciv{%
Perhaps those who disbelieve will wish that they had been Muslims.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mdcccv{%
Let them eat and enjoy themselves and be diverted by [false] hope, for they are going to know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mdcccvi{%
And We did not destroy any city but that for it was a known decree.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mdcccvii{%
No nation will precede its term, nor will they remain thereafter.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mdcccviii{%
And they say, ``O you upon whom the message has been sent down, indeed you are mad.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mdcccix{%
Why do you not bring us the angels, if you should be among the truthful?"\qt@no{7}}%
\qt@newcmd\qurantrans@en@mdcccx{%
We do not send down the angels except with truth; and the disbelievers would not then be reprieved.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mdcccxi{%
Indeed, it is We who sent down the Qur'an and indeed, We will be its guardian.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mdcccxii{%
And We had certainly sent [messengers] before you, [O Muhammad], among the sects of the former peoples.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mdcccxiii{%
And no messenger would come to them except that they ridiculed him.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mdcccxiv{%
Thus do We insert denial into the hearts of the criminals.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mdcccxv{%
They will not believe in it, while there has already occurred the precedent of the former peoples.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mdcccxvi{%
And [even] if We opened to them a gate from the heaven and they continued therein to ascend,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mdcccxvii{%
They would say, ``Our eyes have only been dazzled. Rather, we are a people affected by magic."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mdcccxviii{%
And We have placed within the heaven great stars and have beautified it for the observers.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mdcccxix{%
And We have protected it from every devil expelled [from the mercy of Allah]\qt@no{17}}%
\qt@newcmd\qurantrans@en@mdcccxx{%
Except one who steals a hearing and is pursued by a clear burning flame.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mdcccxxi{%
And the earth - We have spread it and cast therein firmly set mountains and caused to grow therein [something] of every well-balanced thing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mdcccxxii{%
And We have made for you therein means of living and [for] those for whom you are not providers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mdcccxxiii{%
And there is not a thing but that with Us are its depositories, and We do not send it down except according to a known measure.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mdcccxxiv{%
And We have sent the fertilizing winds and sent down water from the sky and given you drink from it. And you are not its retainers.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mdcccxxv{%
And indeed, it is We who give life and cause death, and We are the Inheritor.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mdcccxxvi{%
And We have already known the preceding [generations] among you, and We have already known the later [ones to come].\qt@no{24}}%
\qt@newcmd\qurantrans@en@mdcccxxvii{%
And indeed, your Lord will gather them; indeed, He is Wise and Knowing.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mdcccxxviii{%
And We did certainly create man out of clay from an altered black mud.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mdcccxxix{%
And the jinn We created before from scorching fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mdcccxxx{%
And [mention, O Muhammad], when your Lord said to the angels, ``I will create a human being out of clay from an altered black mud.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mdcccxxxi{%
And when I have proportioned him and breathed into him of My [created] soul, then fall down to him in prostration."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mdcccxxxii{%
So the angels prostrated - all of them entirely,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mdcccxxxiii{%
Except Iblees, he refused to be with those who prostrated.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mdcccxxxiv{%
[Allah] said, O Iblees, what is [the matter] with you that you are not with those who prostrate?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mdcccxxxv{%
He said, ``Never would I prostrate to a human whom You created out of clay from an altered black mud."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mdcccxxxvi{%
[Allah] said, ``Then get out of it, for indeed, you are expelled.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mdcccxxxvii{%
And indeed, upon you is the curse until the Day of Recompense."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mdcccxxxviii{%
He said, ``My Lord, then reprieve me until the Day they are resurrected."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mdcccxxxix{%
[Allah] said, ``So indeed, you are of those reprieved\qt@no{37}}%
\qt@newcmd\qurantrans@en@mdcccxl{%
Until the Day of the time well-known."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mdcccxli{%
[Iblees] said, ``My Lord, because You have put me in error, I will surely make [disobedience] attractive to them on earth, and I will mislead them all\qt@no{39}}%
\qt@newcmd\qurantrans@en@mdcccxlii{%
Except, among them, Your chosen servants."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mdcccxliii{%
[Allah] said, ``This is a path [of return] to Me [that is] straight.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mdcccxliv{%
Indeed, My servants - no authority will you have over them, except those who follow you of the deviators.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mdcccxlv{%
And indeed, Hell is the promised place for them all.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mdcccxlvi{%
It has seven gates; for every gate is of them a portion designated."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mdcccxlvii{%
Indeed, the righteous will be within gardens and springs.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mdcccxlviii{%
[Having been told], ``Enter it in peace, safe [and secure]."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mdcccxlix{%
And We will remove whatever is in their breasts of resentment, [so they will be] brothers, on thrones facing each other.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mdcccl{%
No fatigue will touch them therein, nor from it will they [ever] be removed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mdcccli{%
[O Muhammad], inform My servants that it is I who am the Forgiving, the Merciful.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mdccclii{%
And that it is My punishment which is the painful punishment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mdcccliii{%
And inform them about the guests of Abraham,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mdcccliv{%
When they entered upon him and said, ``Peace." [Abraham] said, ``Indeed, we are fearful of you."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mdccclv{%
[The angels] said, ``Fear not. Indeed, we give you good tidings of a learned boy."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mdccclvi{%
He said, ``Have you given me good tidings although old age has come upon me? Then of what [wonder] do you inform?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mdccclvii{%
They said, ``We have given you good tidings in truth, so do not be of the despairing."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mdccclviii{%
He said, ``And who despairs of the mercy of his Lord except for those astray?"\qt@no{56}}%
\qt@newcmd\qurantrans@en@mdccclix{%
[Abraham] said, ``Then what is your business [here], O messengers?"\qt@no{57}}%
\qt@newcmd\qurantrans@en@mdccclx{%
They said, ``Indeed, we have been sent to a people of criminals,\qt@no{58}}%
\qt@newcmd\qurantrans@en@mdccclxi{%
Except the family of Lot; indeed, we will save them all\qt@no{59}}%
\qt@newcmd\qurantrans@en@mdccclxii{%
Except his wife." Allah decreed that she is of those who remain behind.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mdccclxiii{%
And when the messengers came to the family of Lot,\qt@no{61}}%
\qt@newcmd\qurantrans@en@mdccclxiv{%
He said, ``Indeed, you are people unknown."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mdccclxv{%
They said, ``But we have come to you with that about which they were disputing,\qt@no{63}}%
\qt@newcmd\qurantrans@en@mdccclxvi{%
And we have come to you with truth, and indeed, we are truthful.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mdccclxvii{%
So set out with your family during a portion of the night and follow behind them and let not anyone among you look back and continue on to where you are commanded."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mdccclxviii{%
And We conveyed to him [the decree] of that matter: that those [sinners] would be eliminated by early morning.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mdccclxix{%
And the people of the city came rejoicing.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mdccclxx{%
[Lot] said, ``Indeed, these are my guests, so do not shame me.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mdccclxxi{%
And fear Allah and do not disgrace me."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mdccclxxii{%
They said, ``Have we not forbidden you from [protecting] people?"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mdccclxxiii{%
[Lot] said, ``These are my daughters - if you would be doers [of lawful marriage]."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mdccclxxiv{%
By your life, [O Muhammad], indeed they were, in their intoxication, wandering blindly.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mdccclxxv{%
So the shriek seized them at sunrise.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mdccclxxvi{%
And We made the highest part [of the city] its lowest and rained upon them stones of hard clay.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mdccclxxvii{%
Indeed in that are signs for those who discern.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mdccclxxviii{%
And indeed, those cities are [situated] on an established road.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mdccclxxix{%
Indeed in that is a sign for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mdccclxxx{%
And the companions of the thicket were [also] wrongdoers.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mdccclxxxi{%
So We took retribution from them, and indeed, both [cities] are on a clear highway.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mdccclxxxii{%
And certainly did the companions of Thamud deny the messengers.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mdccclxxxiii{%
And We gave them Our signs, but from them they were turning away.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mdccclxxxiv{%
And they used to carve from the mountains, houses, feeling secure.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mdccclxxxv{%
But the shriek seized them at early morning.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mdccclxxxvi{%
So nothing availed them [from] what they used to earn.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mdccclxxxvii{%
And We have not created the heavens and earth and that between them except in truth. And indeed, the Hour is coming; so forgive with gracious forgiveness.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mdccclxxxviii{%
Indeed, your Lord - He is the Knowing Creator.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mdccclxxxix{%
And We have certainly given you, [O Muhammad], seven of the often repeated [verses] and the great Qur'an.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mdcccxc{%
Do not extend your eyes toward that by which We have given enjoyment to [certain] categories of the disbelievers, and do not grieve over them. And lower your wing to the believers\qt@no{88}}%
\qt@newcmd\qurantrans@en@mdcccxci{%
And say, ``Indeed, I am the clear warner" -\qt@no{89}}%
\qt@newcmd\qurantrans@en@mdcccxcii{%
Just as We had revealed [scriptures] to the separators\qt@no{90}}%
\qt@newcmd\qurantrans@en@mdcccxciii{%
Who have made the Qur'an into portions.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mdcccxciv{%
So by your Lord, We will surely question them all\qt@no{92}}%
\qt@newcmd\qurantrans@en@mdcccxcv{%
About what they used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mdcccxcvi{%
Then declare what you are commanded and turn away from the polytheists.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mdcccxcvii{%
Indeed, We are sufficient for you against the mockers\qt@no{95}}%
\qt@newcmd\qurantrans@en@mdcccxcviii{%
Who make [equal] with Allah another deity. But they are going to know.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mdcccxcix{%
And We already know that your breast is constrained by what they say.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcm{%
So exalt [Allah] with praise of your Lord and be of those who prostrate [to Him].\qt@no{98}}%
\qt@newcmd\qurantrans@en@mcmi{%
And worship your Lord until there comes to you the certainty (death).\qt@no{99}}%
\qt@newcmd\qurantrans@en@mcmii{%
\basmalahen The command of Allah is coming, so be not impatient for it. Exalted is He and high above what they associate with Him.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mcmiii{%
He sends down the angels, with the inspiration of His command, upon whom He wills of His servants, [telling them], ``Warn that there is no deity except Me; so fear Me."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mcmiv{%
He created the heavens and earth in truth. High is He above what they associate with Him.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mcmv{%
He created man from a sperm-drop; then at once, he is a clear adversary.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mcmvi{%
And the grazing livestock He has created for you; in them is warmth and [numerous] benefits, and from them you eat.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mcmvii{%
And for you in them is [the enjoyment of] beauty when you bring them in [for the evening] and when you send them out [to pasture].\qt@no{6}}%
\qt@newcmd\qurantrans@en@mcmviii{%
And they carry your loads to a land you could not have reached except with difficulty to yourselves. Indeed, your Lord is Kind and Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mcmix{%
And [He created] the horses, mules and donkeys for you to ride and [as] adornment. And He creates that which you do not know.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mcmx{%
And upon Allah is the direction of the [right] way, and among the various paths are those deviating. And if He willed, He could have guided you all.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mcmxi{%
It is He who sends down rain from the sky; from it is drink and from it is foliage in which you pasture [animals].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mcmxii{%
He causes to grow for you thereby the crops, olives, palm trees, grapevines, and from all the fruits. Indeed in that is a sign for a people who give thought.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mcmxiii{%
And He has subjected for you the night and day and the sun and moon, and the stars are subjected by His command. Indeed in that are signs for a people who reason.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mcmxiv{%
And [He has subjected] whatever He multiplied for you on the earth of varying colors. Indeed in that is a sign for a people who remember.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mcmxv{%
And it is He who subjected the sea for you to eat from it tender meat and to extract from it ornaments which you wear. And you see the ships plowing through it, and [He subjected it] that you may seek of His bounty; and perhaps you will be grateful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mcmxvi{%
And He has cast into the earth firmly set mountains, lest it shift with you, and [made] rivers and roads, that you may be guided,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mcmxvii{%
And landmarks. And by the stars they are [also] guided.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mcmxviii{%
Then is He who creates like one who does not create? So will you not be reminded?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mcmxix{%
And if you should count the favors of Allah, you could not enumerate them. Indeed, Allah is Forgiving and Merciful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mcmxx{%
And Allah knows what you conceal and what you declare.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mcmxxi{%
And those they invoke other than Allah create nothing, and they [themselves] are created.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mcmxxii{%
They are, [in fact], dead, not alive, and they do not perceive when they will be resurrected.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mcmxxiii{%
Your god is one God. But those who do not believe in the Hereafter - their hearts are disapproving, and they are arrogant.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mcmxxiv{%
Assuredly, Allah knows what they conceal and what they declare. Indeed, He does not like the arrogant.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mcmxxv{%
And when it is said to them, ``What has your Lord sent down?" They say, ``Legends of the former peoples,"\qt@no{24}}%
\qt@newcmd\qurantrans@en@mcmxxvi{%
That they may bear their own burdens in full on the Day of Resurrection and some of the burdens of those whom they misguide without knowledge. Unquestionably, evil is that which they bear.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mcmxxvii{%
Those before them had already plotted, but Allah came at their building from the foundations, so the roof fell upon them from above them, and the punishment came to them from where they did not perceive.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mcmxxviii{%
Then on the Day of Resurrection He will disgrace them and say, ``Where are My 'partners' for whom you used to oppose [the believers]?" Those who were given knowledge will say, ``Indeed disgrace, this Day, and evil are upon the disbelievers" -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mcmxxix{%
The ones whom the angels take in death [while] wronging themselves, and [who] then offer submission, [saying], ``We were not doing any evil." But, yes! Indeed, Allah is Knowing of what you used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mcmxxx{%
So enter the gates of Hell to abide eternally therein, and how wretched is the residence of the arrogant.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mcmxxxi{%
And it will be said to those who feared Allah, ``What did your Lord send down?" They will say, ``[That which is] good." For those who do good in this world is good; and the home of the Hereafter is better. And how excellent is the home of the righteous -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mcmxxxii{%
Gardens of perpetual residence, which they will enter, beneath which rivers flow. They will have therein whatever they wish. Thus does Allah reward the righteous -\qt@no{31}}%
\qt@newcmd\qurantrans@en@mcmxxxiii{%
The ones whom the angels take in death, [being] good and pure; [the angels] will say, ``Peace be upon you. Enter Paradise for what you used to do."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mcmxxxiv{%
Do the disbelievers await [anything] except that the angels should come to them or there comes the command of your Lord? Thus did those do before them. And Allah wronged them not, but they had been wronging themselves.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mcmxxxv{%
So they were struck by the evil consequences of what they did and were enveloped by what they used to ridicule.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mcmxxxvi{%
And those who associate others with Allah say, ``If Allah had willed, we would not have worshipped anything other than Him, neither we nor our fathers, nor would we have forbidden anything through other than Him." Thus did those do before them. So is there upon the messengers except [the duty of] clear notification?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mcmxxxvii{%
And We certainly sent into every nation a messenger, [saying], ``Worship Allah and avoid Taghut." And among them were those whom Allah guided, and among them were those upon whom error was [deservedly] decreed. So proceed through the earth and observe how was the end of the deniers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mcmxxxviii{%
[Even] if you should strive for their guidance, [O Muhammad], indeed, Allah does not guide those He sends astray, and they will have no helpers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mcmxxxix{%
And they swear by Allah their strongest oaths [that] Allah will not resurrect one who dies. But yes - [it is] a true promise [binding] upon Him, but most of the people do not know.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mcmxl{%
[It is] so He will make clear to them [the truth of] that wherein they differ and so those who have disbelieved may know that they were liars.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mcmxli{%
Indeed, Our word to a thing when We intend it is but that We say to it, ``Be," and it is.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mcmxlii{%
And those who emigrated for [the cause of] Allah after they had been wronged - We will surely settle them in this world in a good place; but the reward of the Hereafter is greater, if only they could know.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mcmxliii{%
[They are] those who endured patiently and upon their Lord relied.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mcmxliv{%
And We sent not before you except men to whom We revealed [Our message]. So ask the people of the message if you do not know.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mcmxlv{%
[We sent them] with clear proofs and written ordinances. And We revealed to you the message that you may make clear to the people what was sent down to them and that they might give thought.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mcmxlvi{%
Then, do those who have planned evil deeds feel secure that Allah will not cause the earth to swallow them or that the punishment will not come upon them from where they do not perceive?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mcmxlvii{%
Or that He would not seize them during their [usual] activity, and they could not cause failure?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mcmxlviii{%
Or that He would not seize them gradually [in a state of dread]? But indeed, your Lord is Kind and Merciful.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mcmxlix{%
Have they not considered what things Allah has created? Their shadows incline to the right and to the left, prostrating to Allah, while they are humble.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mcml{%
And to Allah prostrates whatever is in the heavens and whatever is on the earth of creatures, and the angels [as well], and they are not arrogant.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mcmli{%
They fear their Lord above them, and they do what they are commanded.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mcmlii{%
And Allah has said, ``Do not take for yourselves two deities. He is but one God, so fear only Me."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mcmliii{%
And to Him belongs whatever is in the heavens and the earth, and to Him is [due] worship constantly. Then is it other than Allah that you fear?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mcmliv{%
And whatever you have of favor - it is from Allah. Then when adversity touches you, to Him you cry for help.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mcmlv{%
Then when He removes the adversity from you, at once a party of you associates others with their Lord\qt@no{54}}%
\qt@newcmd\qurantrans@en@mcmlvi{%
So they will deny what We have given them. Then enjoy yourselves, for you are going to know.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mcmlvii{%
And they assign to what they do not know a portion of that which We have provided them. By Allah, you will surely be questioned about what you used to invent.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mcmlviii{%
And they attribute to Allah daughters - exalted is He - and for them is what they desire.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mcmlix{%
And when one of them is informed of [the birth of] a female, his face becomes dark, and he suppresses grief.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mcmlx{%
He hides himself from the people because of the ill of which he has been informed. Should he keep it in humiliation or bury it in the ground? Unquestionably, evil is what they decide.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mcmlxi{%
For those who do not believe in the Hereafter is the description of evil; and for Allah is the highest attribute. And He is Exalted in Might, the Wise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mcmlxii{%
And if Allah were to impose blame on the people for their wrongdoing, He would not have left upon the earth any creature, but He defers them for a specified term. And when their term has come, they will not remain behind an hour, nor will they precede [it].\qt@no{61}}%
\qt@newcmd\qurantrans@en@mcmlxiii{%
And they attribute to Allah that which they dislike, and their tongues assert the lie that they will have the best [from Him]. Assuredly, they will have the Fire, and they will be [therein] neglected.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mcmlxiv{%
By Allah, We did certainly send [messengers] to nations before you, but Satan made their deeds attractive to them. And he is the disbelievers' ally today [as well], and they will have a painful punishment.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mcmlxv{%
And We have not revealed to you the Book, [O Muhammad], except for you to make clear to them that wherein they have differed and as guidance and mercy for a people who believe.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mcmlxvi{%
And Allah has sent down rain from the sky and given life thereby to the earth after its lifelessness. Indeed in that is a sign for a people who listen.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mcmlxvii{%
And indeed, for you in grazing livestock is a lesson. We give you drink from what is in their bellies - between excretion and blood - pure milk, palatable to drinkers.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mcmlxviii{%
And from the fruits of the palm trees and grapevines you take intoxicant and good provision. Indeed in that is a sign for a people who reason.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mcmlxix{%
And your Lord inspired to the bee, ``Take for yourself among the mountains, houses, and among the trees and [in] that which they construct.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mcmlxx{%
Then eat from all the fruits and follow the ways of your Lord laid down [for you]." There emerges from their bellies a drink, varying in colors, in which there is healing for people. Indeed in that is a sign for a people who give thought.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mcmlxxi{%
And Allah created you; then He will take you in death. And among you is he who is reversed to the most decrepit [old] age so that he will not know, after [having had] knowledge, a thing. Indeed, Allah is Knowing and Competent.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mcmlxxii{%
And Allah has favored some of you over others in provision. But those who were favored would not hand over their provision to those whom their right hands possess so they would be equal to them therein. Then is it the favor of Allah they reject?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mcmlxxiii{%
And Allah has made for you from yourselves mates and has made for you from your mates sons and grandchildren and has provided for you from the good things. Then in falsehood do they believe and in the favor of Allah they disbelieve?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mcmlxxiv{%
And they worship besides Allah that which does not possess for them [the power of] provision from the heavens and the earth at all, and [in fact], they are unable.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mcmlxxv{%
So do not assert similarities to Allah. Indeed, Allah knows and you do not know.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mcmlxxvi{%
Allah presents an example: a slave [who is] owned and unable to do a thing and he to whom We have provided from Us good provision, so he spends from it secretly and publicly. Can they be equal? Praise to Allah! But most of them do not know.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mcmlxxvii{%
And Allah presents an example of two men, one of them dumb and unable to do a thing, while he is a burden to his guardian. Wherever he directs him, he brings no good. Is he equal to one who commands justice, while he is on a straight path?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mcmlxxviii{%
And to Allah belongs the unseen [aspects] of the heavens and the earth. And the command for the Hour is not but as a glance of the eye or even nearer. Indeed, Allah is over all things competent.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mcmlxxix{%
And Allah has extracted you from the wombs of your mothers not knowing a thing, and He made for you hearing and vision and intellect that perhaps you would be grateful.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mcmlxxx{%
Do they not see the birds controlled in the atmosphere of the sky? None holds them up except Allah. Indeed in that are signs for a people who believe.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mcmlxxxi{%
And Allah has made for you from your homes a place of rest and made for you from the hides of the animals tents which you find light on your day of travel and your day of encampment; and from their wool, fur and hair is furnishing and enjoyment for a time.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mcmlxxxii{%
And Allah has made for you, from that which He has created, shadows and has made for you from the mountains, shelters and has made for you garments which protect you from the heat and garments which protect you from your [enemy in] battle. Thus does He complete His favor upon you that you might submit [to Him].\qt@no{81}}%
\qt@newcmd\qurantrans@en@mcmlxxxiii{%
But if they turn away, [O Muhammad] - then only upon you is [responsibility for] clear notification.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mcmlxxxiv{%
They recognize the favor of Allah; then they deny it. And most of them are disbelievers.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mcmlxxxv{%
And [mention] the Day when We will resurrect from every nation a witness. Then it will not be permitted to the disbelievers [to apologize or make excuses], nor will they be asked to appease [Allah].\qt@no{84}}%
\qt@newcmd\qurantrans@en@mcmlxxxvi{%
And when those who wronged see the punishment, it will not be lightened for them, nor will they be reprieved.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mcmlxxxvii{%
And when those who associated others with Allah see their ``partners," they will say," Our Lord, these are our partners [to You] whom we used to invoke besides You." But they will throw at them the statement, ``Indeed, you are liars."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mcmlxxxviii{%
And they will impart to Allah that Day [their] submission, and lost from them is what they used to invent.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mcmlxxxix{%
Those who disbelieved and averted [others] from the way of Allah - We will increase them in punishment over [their] punishment for what corruption they were causing.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mcmxc{%
And [mention] the Day when We will resurrect among every nation a witness over them from themselves. And We will bring you, [O Muhammad], as a witness over your nation. And We have sent down to you the Book as clarification for all things and as guidance and mercy and good tidings for the Muslims.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mcmxci{%
Indeed, Allah orders justice and good conduct and giving to relatives and forbids immorality and bad conduct and oppression. He admonishes you that perhaps you will be reminded.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mcmxcii{%
And fulfill the covenant of Allah when you have taken it, [O believers], and do not break oaths after their confirmation while you have made Allah, over you, a witness. Indeed, Allah knows what you do.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mcmxciii{%
And do not be like she who untwisted her spun thread after it was strong [by] taking your oaths as [means of] deceit between you because one community is more plentiful [in number or wealth] than another community. Allah only tries you thereby. And He will surely make clear to you on the Day of Resurrection that over which you used to differ.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mcmxciv{%
And if Allah had willed, He could have made you [of] one religion, but He causes to stray whom He wills and guides whom He wills. And you will surely be questioned about what you used to do.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mcmxcv{%
And do not take your oaths as [means of] deceit between you, lest a foot slip after it was [once] firm, and you would taste evil [in this world] for what [people] you diverted from the way of Allah, and you would have [in the Hereafter] a great punishment.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mcmxcvi{%
And do not exchange the covenant of Allah for a small price. Indeed, what is with Allah is best for you, if only you could know.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mcmxcvii{%
Whatever you have will end, but what Allah has is lasting. And We will surely give those who were patient their reward according to the best of what they used to do.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mcmxcviii{%
Whoever does righteousness, whether male or female, while he is a believer - We will surely cause him to live a good life, and We will surely give them their reward [in the Hereafter] according to the best of what they used to do.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mcmxcix{%
So when you recite the Qur'an, [first] seek refuge in Allah from Satan, the expelled [from His mercy].\qt@no{98}}%
\qt@newcmd\qurantrans@en@mm{%
Indeed, there is for him no authority over those who have believed and rely upon their Lord.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmi{%
His authority is only over those who take him as an ally and those who through him associate others with Allah.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmii{%
And when We substitute a verse in place of a verse - and Allah is most knowing of what He sends down - they say, ``You, [O Muhammad], are but an inventor [of lies]." But most of them do not know.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmiii{%
Say, [O Muhammad], ``The Pure Spirit has brought it down from your Lord in truth to make firm those who believe and as guidance and good tidings to the Muslims."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmiv{%
And We certainly know that they say, ``It is only a human being who teaches the Prophet." The tongue of the one they refer to is foreign, and this Qur'an is [in] a clear Arabic language.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmv{%
Indeed, those who do not believe in the verses of Allah - Allah will not guide them, and for them is a painful punishment.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmvi{%
They only invent falsehood who do not believe in the verses of Allah, and it is those who are the liars.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmvii{%
Whoever disbelieves in Allah after his belief... except for one who is forced [to renounce his religion] while his heart is secure in faith. But those who [willingly] open their breasts to disbelief, upon them is wrath from Allah, and for them is a great punishment;\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmviii{%
That is because they preferred the worldly life over the Hereafter and that Allah does not guide the disbelieving people.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmix{%
Those are the ones over whose hearts and hearing and vision Allah has sealed, and it is those who are the heedless.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmx{%
Assuredly, it is they, in the Hereafter, who will be the losers.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmxi{%
Then, indeed your Lord, to those who emigrated after they had been compelled [to renounce their religion] and thereafter fought [for the cause of Allah] and were patient - indeed, your Lord, after that, is Forgiving and Merciful\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmxii{%
On the Day when every soul will come disputing for itself, and every soul will be fully compensated for what it did, and they will not be wronged.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmxiii{%
And Allah presents an example: a city which was safe and secure, its provision coming to it in abundance from every location, but it denied the favors of Allah. So Allah made it taste the envelopment of hunger and fear for what they had been doing.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmxiv{%
And there had certainly come to them a Messenger from among themselves, but they denied him; so punishment overtook them while they were wrongdoers.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmxv{%
Then eat of what Allah has provided for you [which is] lawful and good. And be grateful for the favor of Allah, if it is [indeed] Him that you worship.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmxvi{%
He has only forbidden to you dead animals, blood, the flesh of swine, and that which has been dedicated to other than Allah. But whoever is forced [by necessity], neither desiring [it] nor transgressing [its limit] - then indeed, Allah is Forgiving and Merciful.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmxvii{%
And do not say about what your tongues assert of untruth, ``This is lawful and this is unlawful," to invent falsehood about Allah. Indeed, those who invent falsehood about Allah will not succeed.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmxviii{%
[It is but] a brief enjoyment, and they will have a painful punishment.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmxix{%
And to those who are Jews We have prohibited that which We related to you before. And We did not wrong them [thereby], but they were wronging themselves.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmxx{%
Then, indeed your Lord, to those who have done wrong out of ignorance and then repent after that and correct themselves - indeed, your Lord, thereafter, is Forgiving and Merciful.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmxxi{%
Indeed, Abraham was a [comprehensive] leader, devoutly obedient to Allah, inclining toward truth, and he was not of those who associate others with Allah.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmxxii{%
[He was] grateful for His favors. Allah chose him and guided him to a straight path.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmxxiii{%
And We gave him good in this world, and indeed, in the Hereafter he will be among the righteous.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmxxiv{%
Then We revealed to you, [O Muhammad], to follow the religion of Abraham, inclining toward truth; and he was not of those who associate with Allah.\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmxxv{%
The sabbath was only appointed for those who differed over it. And indeed, your Lord will judge between them on the Day of Resurrection concerning that over which they used to differ.\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmxxvi{%
Invite to the way of your Lord with wisdom and good instruction, and argue with them in a way that is best. Indeed, your Lord is most knowing of who has strayed from His way, and He is most knowing of who is [rightly] guided.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmxxvii{%
And if you punish [an enemy, O believers], punish with an equivalent of that with which you were harmed. But if you are patient - it is better for those who are patient.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmxxviii{%
And be patient, [O Muhammad], and your patience is not but through Allah. And do not grieve over them and do not be in distress over what they conspire.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmxxix{%
Indeed, Allah is with those who fear Him and those who are doers of good.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmxxx{%
\basmalahen Exalted is He who took His Servant by night from al-Masjid al-Haram to al-Masjid al-Aqsa, whose surroundings We have blessed, to show him of Our signs. Indeed, He is the Hearing, the Seeing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmxxxi{%
And We gave Moses the Scripture and made it a guidance for the Children of Israel that you not take other than Me as Disposer of affairs,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmxxxii{%
O descendants of those We carried [in the ship] with Noah. Indeed, he was a grateful servant.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmxxxiii{%
And We conveyed to the Children of Israel in the Scripture that, ``You will surely cause corruption on the earth twice, and you will surely reach [a degree of] great haughtiness.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmxxxiv{%
So when the [time of] promise came for the first of them, We sent against you servants of Ours - those of great military might, and they probed [even] into the homes, and it was a promise fulfilled.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmxxxv{%
Then We gave back to you a return victory over them. And We reinforced you with wealth and sons and made you more numerous in manpower\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmxxxvi{%
[And said], ``If you do good, you do good for yourselves; and if you do evil, [you do it] to yourselves." Then when the final promise came, [We sent your enemies] to sadden your faces and to enter the temple in Jerusalem, as they entered it the first time, and to destroy what they had taken over with [total] destruction.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmxxxvii{%
[Then Allah said], ``It is expected, [if you repent], that your Lord will have mercy upon you. But if you return [to sin], We will return [to punishment]. And We have made Hell, for the disbelievers, a prison-bed."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmxxxviii{%
Indeed, this Qur'an guides to that which is most suitable and gives good tidings to the believers who do righteous deeds that they will have a great reward.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmxxxix{%
And that those who do not believe in the Hereafter - We have prepared for them a painful punishment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmxl{%
And man supplicates for evil as he supplicates for good, and man is ever hasty.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmxli{%
And We have made the night and day two signs, and We erased the sign of the night and made the sign of the day visible that you may seek bounty from your Lord and may know the number of years and the account [of time]. And everything We have set out in detail.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmxlii{%
And [for] every person We have imposed his fate upon his neck, and We will produce for him on the Day of Resurrection a record which he will encounter spread open.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmxliii{%
[It will be said], ``Read your record. Sufficient is yourself against you this Day as accountant."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmxliv{%
Whoever is guided is only guided for [the benefit of] his soul. And whoever errs only errs against it. And no bearer of burdens will bear the burden of another. And never would We punish until We sent a messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmxlv{%
And when We intend to destroy a city, We command its affluent but they defiantly disobey therein; so the word comes into effect upon it, and We destroy it with [complete] destruction.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmxlvi{%
And how many have We destroyed from the generations after Noah. And sufficient is your Lord, concerning the sins of His servants, as Acquainted and Seeing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmxlvii{%
Whoever should desire the immediate - We hasten for him from it what We will to whom We intend. Then We have made for him Hell, which he will [enter to] burn, censured and banished.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmxlviii{%
But whoever desires the Hereafter and exerts the effort due to it while he is a believer - it is those whose effort is ever appreciated [by Allah].\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmxlix{%
To each [category] We extend - to these and to those - from the gift of your Lord. And never has the gift of your Lord been restricted.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mml{%
Look how We have favored [in provision] some of them over others. But the Hereafter is greater in degrees [of difference] and greater in distinction.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmli{%
Do not make [as equal] with Allah another deity and [thereby] become censured and forsaken.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmlii{%
And your Lord has decreed that you not worship except Him, and to parents, good treatment. Whether one or both of them reach old age [while] with you, say not to them [so much as], ``uff," and do not repel them but speak to them a noble word.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmliii{%
And lower to them the wing of humility out of mercy and say, ``My Lord, have mercy upon them as they brought me up [when I was] small."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmliv{%
Your Lord is most knowing of what is within yourselves. If you should be righteous [in intention] - then indeed He is ever, to the often returning [to Him], Forgiving.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmlv{%
And give the relative his right, and [also] the poor and the traveler, and do not spend wastefully.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmlvi{%
Indeed, the wasteful are brothers of the devils, and ever has Satan been to his Lord ungrateful.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmlvii{%
And if you [must] turn away from the needy awaiting mercy from your Lord which you expect, then speak to them a gentle word.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmlviii{%
And do not make your hand [as] chained to your neck or extend it completely and [thereby] become blamed and insolvent.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmlix{%
Indeed, your Lord extends provision for whom He wills and restricts [it]. Indeed He is ever, concerning His servants, Acquainted and Seeing.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmlx{%
And do not kill your children for fear of poverty. We provide for them and for you. Indeed, their killing is ever a great sin.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmlxi{%
And do not approach unlawful sexual intercourse. Indeed, it is ever an immorality and is evil as a way.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmlxii{%
And do not kill the soul which Allah has forbidden, except by right. And whoever is killed unjustly - We have given his heir authority, but let him not exceed limits in [the matter of] taking life. Indeed, he has been supported [by the law].\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmlxiii{%
And do not approach the property of an orphan, except in the way that is best, until he reaches maturity. And fulfill [every] commitment. Indeed, the commitment is ever [that about which one will be] questioned.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmlxiv{%
And give full measure when you measure, and weigh with an even balance. That is the best [way] and best in result.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmlxv{%
And do not pursue that of which you have no knowledge. Indeed, the hearing, the sight and the heart - about all those [one] will be questioned.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmlxvi{%
And do not walk upon the earth exultantly. Indeed, you will never tear the earth [apart], and you will never reach the mountains in height.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmlxvii{%
All that - its evil is ever, in the sight of your Lord, detested.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmlxviii{%
That is from what your Lord has revealed to you, [O Muhammad], of wisdom. And, [O mankind], do not make [as equal] with Allah another deity, lest you be thrown into Hell, blamed and banished.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmlxix{%
Then, has your Lord chosen you for [having] sons and taken from among the angels daughters? Indeed, you say a grave saying.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmlxx{%
And We have certainly diversified [the contents] in this Qur'an that mankind may be reminded, but it does not increase the disbelievers except in aversion.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmlxxi{%
Say, [O Muhammad], ``If there had been with Him [other] gods, as they say, then they [each] would have sought to the Owner of the Throne a way."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmlxxii{%
Exalted is He and high above what they say by great sublimity.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmlxxiii{%
The seven heavens and the earth and whatever is in them exalt Him. And there is not a thing except that it exalts [Allah] by His praise, but you do not understand their [way of] exalting. Indeed, He is ever Forbearing and Forgiving.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmlxxiv{%
And when you recite the Qur'an, We put between you and those who do not believe in the Hereafter a concealed partition.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmlxxv{%
And We have placed over their hearts coverings, lest they understand it, and in their ears deafness. And when you mention your Lord alone in the Qur'an, they turn back in aversion.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmlxxvi{%
We are most knowing of how they listen to it when they listen to you and [of] when they are in private conversation, when the wrongdoers say, ``You follow not but a man affected by magic."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmlxxvii{%
Look how they strike for you comparisons; but they have strayed, so they cannot [find] a way.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmlxxviii{%
And they say, ``When we are bones and crumbled particles, will we [truly] be resurrected as a new creation?"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmlxxix{%
Say, ``Be you stones or iron\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmlxxx{%
Or [any] creation of that which is great within your breasts." And they will say, ``Who will restore us?" Say, ``He who brought you forth the first time." Then they will nod their heads toward you and say, ``When is that?" Say, ``Perhaps it will be soon -\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmlxxxi{%
On the Day He will call you and you will respond with praise of Him and think that you had not remained [in the world] except for a little."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmlxxxii{%
And tell My servants to say that which is best. Indeed, Satan induces [dissension] among them. Indeed Satan is ever, to mankind, a clear enemy.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmlxxxiii{%
Your Lord is most knowing of you. If He wills, He will have mercy upon you; or if He wills, He will punish you. And We have not sent you, [O Muhammad], over them as a manager.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmlxxxiv{%
And your Lord is most knowing of whoever is in the heavens and the earth. And We have made some of the prophets exceed others [in various ways], and to David We gave the book [of Psalms].\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmlxxxv{%
Say, ``Invoke those you have claimed [as gods] besides Him, for they do not possess the [ability for] removal of adversity from you or [for its] transfer [to someone else]."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmlxxxvi{%
Those whom they invoke seek means of access to their Lord, [striving as to] which of them would be nearest, and they hope for His mercy and fear His punishment. Indeed, the punishment of your Lord is ever feared.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmlxxxvii{%
And there is no city but that We will destroy it before the Day of Resurrection or punish it with a severe punishment. That has ever been in the Register inscribed.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmlxxxviii{%
And nothing has prevented Us from sending signs except that the former peoples denied them. And We gave Thamud the she-camel as a visible sign, but they wronged her. And We send not the signs except as a warning.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmlxxxix{%
And [remember, O Muhammad], when We told you, ``Indeed, your Lord has encompassed the people." And We did not make the sight which We showed you except as a trial for the people, as was the accursed tree [mentioned] in the Qur'an. And We threaten them, but it increases them not except in great transgression.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmxc{%
And [mention] when We said to the angles, ``Prostrate to Adam," and they prostrated, except for Iblees. He said, ``Should I prostrate to one You created from clay?"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmxci{%
[Iblees] said, ``Do You see this one whom You have honored above me? If You delay me until the Day of Resurrection, I will surely destroy his descendants, except for a few."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmxcii{%
[Allah] said, ``Go, for whoever of them follows you, indeed Hell will be the recompense of you - an ample recompense.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmxciii{%
And incite [to senselessness] whoever you can among them with your voice and assault them with your horses and foot soldiers and become a partner in their wealth and their children and promise them." But Satan does not promise them except delusion.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmxciv{%
Indeed, over My [believing] servants there is for you no authority. And sufficient is your Lord as Disposer of affairs.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmxcv{%
It is your Lord who drives the ship for you through the sea that you may seek of His bounty. Indeed, He is ever, to you, Merciful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmxcvi{%
And when adversity touches you at sea, lost are [all] those you invoke except for Him. But when He delivers you to the land, you turn away [from Him]. And ever is man ungrateful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmxcvii{%
Then do you feel secure that [instead] He will not cause a part of the land to swallow you or send against you a storm of stones? Then you would not find for yourselves an advocate.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmxcviii{%
Or do you feel secure that He will not send you back into the sea another time and send upon you a hurricane of wind and drown you for what you denied? Then you would not find for yourselves against Us an avenger.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmxcix{%
And We have certainly honored the children of Adam and carried them on the land and sea and provided for them of the good things and preferred them over much of what We have created, with [definite] preference.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmc{%
[Mention, O Muhammad], the Day We will call forth every people with their record [of deeds]. Then whoever is given his record in his right hand - those will read their records, and injustice will not be done to them, [even] as much as a thread [inside the date seed].\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmci{%
And whoever is blind in this [life] will be blind in the Hereafter and more astray in way.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcii{%
And indeed, they were about to tempt you away from that which We revealed to you in order to [make] you invent about Us something else; and then they would have taken you as a friend.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmciii{%
And if We had not strengthened you, you would have almost inclined to them a little.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmciv{%
Then [if you had], We would have made you taste double [punishment in] life and double [after] death. Then you would not find for yourself against Us a helper.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcv{%
And indeed, they were about to drive you from the land to evict you therefrom. And then [when they do], they will not remain [there] after you, except for a little.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcvi{%
[That is Our] established way for those We had sent before you of Our messengers; and you will not find in Our way any alteration.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcvii{%
Establish prayer at the decline of the sun [from its meridian] until the darkness of the night and [also] the Qur'an of dawn. Indeed, the recitation of dawn is ever witnessed.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcviii{%
And from [part of] the night, pray with it as additional [worship] for you; it is expected that your Lord will resurrect you to a praised station.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcix{%
And say, ``My Lord, cause me to enter a sound entrance and to exit a sound exit and grant me from Yourself a supporting authority."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcx{%
And say, ``Truth has come, and falsehood has departed. Indeed is falsehood, [by nature], ever bound to depart."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcxi{%
And We send down of the Qur'an that which is healing and mercy for the believers, but it does not increase the wrongdoers except in loss.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcxii{%
And when We bestow favor upon the disbeliever, he turns away and distances himself; and when evil touches him, he is ever despairing.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcxiii{%
Say, ``Each works according to his manner, but your Lord is most knowing of who is best guided in way."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcxiv{%
And they ask you, [O Muhammad], about the soul. Say, ``The soul is of the affair of my Lord. And mankind have not been given of knowledge except a little."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcxv{%
And if We willed, We could surely do away with that which We revealed to you. Then you would not find for yourself concerning it an advocate against Us.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcxvi{%
Except [We have left it with you] as a mercy from your Lord. Indeed, His favor upon you has ever been great.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcxvii{%
Say, ``If mankind and the jinn gathered in order to produce the like of this Qur'an, they could not produce the like of it, even if they were to each other assistants."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcxviii{%
And We have certainly diversified for the people in this Qur'an from every [kind] of example, but most of the people refused [anything] except disbelief.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcxix{%
And they say, ``We will not believe you until you break open for us from the ground a spring.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcxx{%
Or [until] you have a garden of palm tress and grapes and make rivers gush forth within them in force [and abundance]\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcxxi{%
Or you make the heaven fall upon us in fragments as you have claimed or you bring Allah and the angels before [us]\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcxxii{%
Or you have a house of gold or you ascend into the sky. And [even then], we will not believe in your ascension until you bring down to us a book we may read." Say, ``Exalted is my Lord! Was I ever but a human messenger?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcxxiii{%
And what prevented the people from believing when guidance came to them except that they said, ``Has Allah sent a human messenger?"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcxxiv{%
Say, ``If there were upon the earth angels walking securely, We would have sent down to them from the heaven an angel [as a] messenger."\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcxxv{%
Say, ``Sufficient is Allah as Witness between me and you. Indeed he is ever, concerning His servants, Acquainted and Seeing."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcxxvi{%
And whoever Allah guides - he is the [rightly] guided; and whoever He sends astray - you will never find for them protectors besides Him, and We will gather them on the Day of Resurrection [fallen] on their faces - blind, dumb and deaf. Their refuge is Hell; every time it subsides We increase them in blazing fire.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcxxvii{%
That is their recompense because they disbelieved in Our verses and said, ``When we are bones and crumbled particles, will we [truly] be resurrected [in] a new creation?"\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcxxviii{%
Do they not see that Allah, who created the heavens and earth, is [the one] Able to create the likes of them? And He has appointed for them a term, about which there is no doubt. But the wrongdoers refuse [anything] except disbelief.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcxxix{%
Say [to them], ``If you possessed the depositories of the mercy of my Lord, then you would withhold out of fear of spending." And ever has man been stingy.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcxxx{%
And We had certainly given Moses nine evident signs, so ask the Children of Israel [about] when he came to them and Pharaoh said to him, ``Indeed I think, O Moses, that you are affected by magic."\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcxxxi{%
[Moses] said, ``You have already known that none has sent down these [signs] except the Lord of the heavens and the earth as evidence, and indeed I think, O Pharaoh, that you are destroyed."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcxxxii{%
So he intended to drive them from the land, but We drowned him and those with him all together.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcxxxiii{%
And We said after Pharaoh to the Children of Israel, ``Dwell in the land, and when there comes the promise of the Hereafter, We will bring you forth in [one] gathering."\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcxxxiv{%
And with the truth We have sent the Qur'an down, and with the truth it has descended. And We have not sent you, [O Muhammad], except as a bringer of good tidings and a warner.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcxxxv{%
And [it is] a Qur'an which We have separated [by intervals] that you might recite it to the people over a prolonged period. And We have sent it down progressively.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcxxxvi{%
Say, ``Believe in it or do not believe. Indeed, those who were given knowledge before it - when it is recited to them, they fall upon their faces in prostration,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcxxxvii{%
And they say, ``Exalted is our Lord! Indeed, the promise of our Lord has been fulfilled."\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcxxxviii{%
And they fall upon their faces weeping, and the Qur'an increases them in humble submission.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcxxxix{%
Say, ``Call upon Allah or call upon the Most Merciful. Whichever [name] you call - to Him belong the best names." And do not recite [too] loudly in your prayer or [too] quietly but seek between that an [intermediate] way.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcxl{%
And say, ``Praise to Allah, who has not taken a son and has had no partner in [His] dominion and has no [need of a] protector out of weakness; and glorify Him with [great] glorification."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcxli{%
\basmalahen [All] praise is [due] to Allah, who has sent down upon His Servant the Book and has not made therein any deviance.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcxlii{%
[He has made it] straight, to warn of severe punishment from Him and to give good tidings to the believers who do righteous deeds that they will have a good reward\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcxliii{%
In which they will remain forever\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcxliv{%
And to warn those who say, ``Allah has taken a son."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcxlv{%
They have no knowledge of it, nor had their fathers. Grave is the word that comes out of their mouths; they speak not except a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcxlvi{%
Then perhaps you would kill yourself through grief over them, [O Muhammad], if they do not believe in this message, [and] out of sorrow.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcxlvii{%
Indeed, We have made that which is on the earth adornment for it that We may test them [as to] which of them is best in deed.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcxlviii{%
And indeed, We will make that which is upon it [into] a barren ground.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcxlix{%
Or have you thought that the companions of the cave and the inscription were, among Our signs, a wonder?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcl{%
[Mention] when the youths retreated to the cave and said, ``Our Lord, grant us from Yourself mercy and prepare for us from our affair right guidance."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcli{%
So We cast [a cover of sleep] over their ears within the cave for a number of years.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmclii{%
Then We awakened them that We might show which of the two factions was most precise in calculating what [extent] they had remained in time.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcliii{%
It is We who relate to you, [O Muhammad], their story in truth. Indeed, they were youths who believed in their Lord, and We increased them in guidance.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcliv{%
And We made firm their hearts when they stood up and said, ``Our Lord is the Lord of the heavens and the earth. Never will we invoke besides Him any deity. We would have certainly spoken, then, an excessive transgression.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmclv{%
These, our people, have taken besides Him deities. Why do they not bring for [worship of] them a clear authority? And who is more unjust than one who invents about Allah a lie?"\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmclvi{%
[The youths said to one another], ``And when you have withdrawn from them and that which they worship other than Allah, retreat to the cave. Your Lord will spread out for you of His mercy and will prepare for you from your affair facility."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmclvii{%
And [had you been present], you would see the sun when it rose, inclining away from their cave on the right, and when it set, passing away from them on the left, while they were [laying] within an open space thereof. That was from the signs of Allah. He whom Allah guides is the [rightly] guided, but he whom He leaves astray - never will you find for him a protecting guide.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmclviii{%
And you would think them awake, while they were asleep. And We turned them to the right and to the left, while their dog stretched his forelegs at the entrance. If you had looked at them, you would have turned from them in flight and been filled by them with terror.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmclix{%
And similarly, We awakened them that they might question one another. Said a speaker from among them, ``How long have you remained [here]?" They said, ``We have remained a day or part of a day." They said, ``Your Lord is most knowing of how long you remained. So send one of you with this silver coin of yours to the city and let him look to which is the best of food and bring you provision from it and let him be cautious. And let no one be aware of you.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmclx{%
Indeed, if they come to know of you, they will stone you or return you to their religion. And never would you succeed, then - ever."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmclxi{%
And similarly, We caused them to be found that they [who found them] would know that the promise of Allah is truth and that of the Hour there is no doubt. [That was] when they disputed among themselves about their affair and [then] said, ``Construct over them a structure. Their Lord is most knowing about them." Said those who prevailed in the matter, ``We will surely take [for ourselves] over them a masjid."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmclxii{%
They will say there were three, the fourth of them being their dog; and they will say there were five, the sixth of them being their dog - guessing at the unseen; and they will say there were seven, and the eighth of them was their dog. Say, [O Muhammad], ``My Lord is most knowing of their number. None knows them except a few. So do not argue about them except with an obvious argument and do not inquire about them among [the speculators] from anyone."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmclxiii{%
And never say of anything, ``Indeed, I will do that tomorrow,"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmclxiv{%
Except [when adding], ``If Allah wills." And remember your Lord when you forget [it] and say, ``Perhaps my Lord will guide me to what is nearer than this to right conduct."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmclxv{%
And they remained in their cave for three hundred years and exceeded by nine.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmclxvi{%
Say, ``Allah is most knowing of how long they remained. He has [knowledge of] the unseen [aspects] of the heavens and the earth. How Seeing is He and how Hearing! They have not besides Him any protector, and He shares not His legislation with anyone."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmclxvii{%
And recite, [O Muhammad], what has been revealed to you of the Book of your Lord. There is no changer of His words, and never will you find in other than Him a refuge.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmclxviii{%
And keep yourself patient [by being] with those who call upon their Lord in the morning and the evening, seeking His countenance. And let not your eyes pass beyond them, desiring adornments of the worldly life, and do not obey one whose heart We have made heedless of Our remembrance and who follows his desire and whose affair is ever [in] neglect.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmclxix{%
And say, ``The truth is from your Lord, so whoever wills - let him believe; and whoever wills - let him disbelieve." Indeed, We have prepared for the wrongdoers a fire whose walls will surround them. And if they call for relief, they will be relieved with water like murky oil, which scalds [their] faces. Wretched is the drink, and evil is the resting place.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmclxx{%
Indeed, those who have believed and done righteous deeds - indeed, We will not allow to be lost the reward of any who did well in deeds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmclxxi{%
Those will have gardens of perpetual residence; beneath them rivers will flow. They will be adorned therein with bracelets of gold and will wear green garments of fine silk and brocade, reclining therein on adorned couches. Excellent is the reward, and good is the resting place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmclxxii{%
And present to them an example of two men: We granted to one of them two gardens of grapevines, and We bordered them with palm trees and placed between them [fields of] crops.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmclxxiii{%
Each of the two gardens produced its fruit and did not fall short thereof in anything. And We caused to gush forth within them a river.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmclxxiv{%
And he had fruit, so he said to his companion while he was conversing with him, ``I am greater than you in wealth and mightier in [numbers of] men."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmclxxv{%
And he entered his garden while he was unjust to himself. He said, ``I do not think that this will perish - ever.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmclxxvi{%
And I do not think the Hour will occur. And even if I should be brought back to my Lord, I will surely find better than this as a return."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmclxxvii{%
His companion said to him while he was conversing with him, ``Have you disbelieved in He who created you from dust and then from a sperm-drop and then proportioned you [as] a man?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmclxxviii{%
But as for me, He is Allah, my Lord, and I do not associate with my Lord anyone.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmclxxix{%
And why did you, when you entered your garden, not say, 'What Allah willed [has occurred]; there is no power except in Allah '? Although you see me less than you in wealth and children,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmclxxx{%
It may be that my Lord will give me [something] better than your garden and will send upon it a calamity from the sky, and it will become a smooth, dusty ground,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmclxxxi{%
Or its water will become sunken [into the earth], so you would never be able to seek it."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmclxxxii{%
And his fruits were encompassed [by ruin], so he began to turn his hands about [in dismay] over what he had spent on it, while it had collapsed upon its trellises, and said, ``Oh, I wish I had not associated with my Lord anyone."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmclxxxiii{%
And there was for him no company to aid him other than Allah, nor could he defend himself.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmclxxxiv{%
There the authority is [completely] for Allah, the Truth. He is best in reward and best in outcome.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmclxxxv{%
And present to them the example of the life of this world, [its being] like rain which We send down from the sky, and the vegetation of the earth mingles with it and [then] it becomes dry remnants, scattered by the winds. And Allah is ever, over all things, Perfect in Ability.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmclxxxvi{%
Wealth and children are [but] adornment of the worldly life. But the enduring good deeds are better to your Lord for reward and better for [one's] hope.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmclxxxvii{%
And [warn of] the Day when We will remove the mountains and you will see the earth prominent, and We will gather them and not leave behind from them anyone.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmclxxxviii{%
And they will be presented before your Lord in rows, [and He will say], ``You have certainly come to Us just as We created you the first time. But you claimed that We would never make for you an appointment."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmclxxxix{%
And the record [of deeds] will be placed [open], and you will see the criminals fearful of that within it, and they will say, ``Oh, woe to us! What is this book that leaves nothing small or great except that it has enumerated it?" And they will find what they did present [before them]. And your Lord does injustice to no one.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcxc{%
And [mention] when We said to the angels, ``Prostrate to Adam," and they prostrated, except for Iblees. He was of the jinn and departed from the command of his Lord. Then will you take him and his descendants as allies other than Me while they are enemies to you? Wretched it is for the wrongdoers as an exchange.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcxci{%
I did not make them witness to the creation of the heavens and the earth or to the creation of themselves, and I would not have taken the misguiders as assistants.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcxcii{%
And [warn of] the Day when He will say, ``Call 'My partners' whom you claimed," and they will invoke them, but they will not respond to them. And We will put between them [a valley of] destruction.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcxciii{%
And the criminals will see the Fire and will be certain that they are to fall therein. And they will not find from it a way elsewhere.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcxciv{%
And We have certainly diversified in this Qur'an for the people from every [kind of] example; but man has ever been, most of anything, [prone to] dispute.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcxcv{%
And nothing has prevented the people from believing when guidance came to them and from asking forgiveness of their Lord except that there [must] befall them the [accustomed] precedent of the former peoples or that the punishment should come [directly] before them.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcxcvi{%
And We send not the messengers except as bringers of good tidings and warners. And those who disbelieve dispute by [using] falsehood to [attempt to] invalidate thereby the truth and have taken My verses, and that of which they are warned, in ridicule.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcxcvii{%
And who is more unjust than one who is reminded of the verses of his Lord but turns away from them and forgets what his hands have put forth? Indeed, We have placed over their hearts coverings, lest they understand it, and in their ears deafness. And if you invite them to guidance - they will never be guided, then - ever.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcxcviii{%
And your Lord is the Forgiving, full of mercy. If He were to impose blame upon them for what they earned, He would have hastened for them the punishment. Rather, for them is an appointment from which they will never find an escape.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcxcix{%
And those cities - We destroyed them when they wronged, and We made for their destruction an appointed time.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcc{%
And [mention] when Moses said to his servant, ``I will not cease [traveling] until I reach the junction of the two seas or continue for a long period."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcci{%
But when they reached the junction between them, they forgot their fish, and it took its course into the sea, slipping away.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmccii{%
So when they had passed beyond it, [Moses] said to his boy, ``Bring us our morning meal. We have certainly suffered in this, our journey, [much] fatigue."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcciii{%
He said, ``Did you see when we retired to the rock? Indeed, I forgot [there] the fish. And none made me forget it except Satan - that I should mention it. And it took its course into the sea amazingly".\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcciv{%
[Moses] said, ``That is what we were seeking." So they returned, following their footprints.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmccv{%
And they found a servant from among Our servants to whom we had given mercy from us and had taught him from Us a [certain] knowledge.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmccvi{%
Moses said to him, ``May I follow you on [the condition] that you teach me from what you have been taught of sound judgement?"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmccvii{%
He said, ``Indeed, with me you will never be able to have patience.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmccviii{%
And how can you have patience for what you do not encompass in knowledge?"\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmccix{%
[Moses] said, ``You will find me, if Allah wills, patient, and I will not disobey you in [any] order."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmccx{%
He said, ``Then if you follow me, do not ask me about anything until I make to you about it mention."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmccxi{%
So they set out, until when they had embarked on the ship, al-Khidh r tore it open. [Moses] said, ``Have you torn it open to drown its people? You have certainly done a grave thing."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmccxii{%
[Al-Khidh r] said, ``Did I not say that with me you would never be able to have patience?"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmccxiii{%
[Moses] said, ``Do not blame me for what I forgot and do not cover me in my matter with difficulty."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmccxiv{%
So they set out, until when they met a boy, al-Khidh r killed him. [Moses] said, ``Have you killed a pure soul for other than [having killed] a soul? You have certainly done a deplorable thing."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmccxv{%
[Al-Khidh r] said, ``Did I not tell you that with me you would never be able to have patience?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmccxvi{%
[Moses] said, ``If I should ask you about anything after this, then do not keep me as a companion. You have obtained from me an excuse."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmccxvii{%
So they set out, until when they came to the people of a town, they asked its people for food, but they refused to offer them hospitality. And they found therein a wall about to collapse, so al-Khidh r restored it. [Moses] said, ``If you wished, you could have taken for it a payment."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmccxviii{%
[Al-Khidh r] said, ``This is parting between me and you. I will inform you of the interpretation of that about which you could not have patience.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmccxix{%
As for the ship, it belonged to poor people working at sea. So I intended to cause defect in it as there was after them a king who seized every [good] ship by force.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmccxx{%
And as for the boy, his parents were believers, and we feared that he would overburden them by transgression and disbelief.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmccxxi{%
So we intended that their Lord should substitute for them one better than him in purity and nearer to mercy.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmccxxii{%
And as for the wall, it belonged to two orphan boys in the city, and there was beneath it a treasure for them, and their father had been righteous. So your Lord intended that they reach maturity and extract their treasure, as a mercy from your Lord. And I did it not of my own accord. That is the interpretation of that about which you could not have patience."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmccxxiii{%
And they ask you, [O Muhammad], about Dhul-Qarnayn. Say, ``I will recite to you about him a report."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmccxxiv{%
Indeed We established him upon the earth, and We gave him to everything a way.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmccxxv{%
So he followed a way\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmccxxvi{%
Until, when he reached the setting of the sun, he found it [as if] setting in a spring of dark mud, and he found near it a people. Allah said, ``O Dhul-Qarnayn, either you punish [them] or else adopt among them [a way of] goodness."\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmccxxvii{%
He said, ``As for one who wrongs, we will punish him. Then he will be returned to his Lord, and He will punish him with a terrible punishment.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmccxxviii{%
But as for one who believes and does righteousness, he will have a reward of Paradise, and we will speak to him from our command with ease."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmccxxix{%
Then he followed a way\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmccxxx{%
Until, when he came to the rising of the sun, he found it rising on a people for whom We had not made against it any shield.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmccxxxi{%
Thus. And We had encompassed [all] that he had in knowledge.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmccxxxii{%
Then he followed a way\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmccxxxiii{%
Until, when he reached [a pass] between two mountains, he found beside them a people who could hardly understand [his] speech.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmccxxxiv{%
They said, ``O Dhul-Qarnayn, indeed Gog and Magog are [great] corrupters in the land. So may we assign for you an expenditure that you might make between us and them a barrier?"\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmccxxxv{%
He said, ``That in which my Lord has established me is better [than what you offer], but assist me with strength; I will make between you and them a dam.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmccxxxvi{%
Bring me sheets of iron" - until, when he had leveled [them] between the two mountain walls, he said, ``Blow [with bellows]," until when he had made it [like] fire, he said, ``Bring me, that I may pour over it molten copper."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmccxxxvii{%
So Gog and Magog were unable to pass over it, nor were they able [to effect] in it any penetration.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmccxxxviii{%
[Dhul-Qarnayn] said, ``This is a mercy from my Lord; but when the promise of my Lord comes, He will make it level, and ever is the promise of my Lord true."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmccxxxix{%
And We will leave them that day surging over each other, and [then] the Horn will be blown, and We will assemble them in [one] assembly.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmccxl{%
And We will present Hell that Day to the Disbelievers, on display -\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmccxli{%
Those whose eyes had been within a cover [removed] from My remembrance, and they were not able to hear.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmccxlii{%
Then do those who disbelieve think that they can take My servants instead of Me as allies? Indeed, We have prepared Hell for the disbelievers as a lodging.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmccxliii{%
Say, [O Muhammad], ``Shall we [believers] inform you of the greatest losers as to [their] deeds?\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmccxliv{%
[They are] those whose effort is lost in worldly life, while they think that they are doing well in work."\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmccxlv{%
Those are the ones who disbelieve in the verses of their Lord and in [their] meeting Him, so their deeds have become worthless; and We will not assign to them on the Day of Resurrection any importance.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmccxlvi{%
That is their recompense - Hell - for what they denied and [because] they took My signs and My messengers in ridicule.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmccxlvii{%
Indeed, those who have believed and done righteous deeds - they will have the Gardens of Paradise as a lodging,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmccxlviii{%
Wherein they abide eternally. They will not desire from it any transfer.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmccxlix{%
Say, ``If the sea were ink for [writing] the words of my Lord, the sea would be exhausted before the words of my Lord were exhausted, even if We brought the like of it as a supplement."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmccl{%
Say, ``I am only a man like you, to whom has been revealed that your god is one God. So whoever would hope for the meeting with his Lord - let him do righteous work and not associate in the worship of his Lord anyone."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmccli{%
\basmalahen Kaf, Ha, Ya, 'Ayn, Sad.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcclii{%
[This is] a mention of the mercy of your Lord to His servant Zechariah\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmccliii{%
When he called to his Lord a private supplication.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccliv{%
He said, ``My Lord, indeed my bones have weakened, and my head has filled with white, and never have I been in my supplication to You, my Lord, unhappy.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcclv{%
And indeed, I fear the successors after me, and my wife has been barren, so give me from Yourself an heir\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcclvi{%
Who will inherit me and inherit from the family of Jacob. And make him, my Lord, pleasing [to You]."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcclvii{%
[He was told], ``O Zechariah, indeed We give you good tidings of a boy whose name will be John. We have not assigned to any before [this] name."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcclviii{%
He said, ``My Lord, how will I have a boy when my wife has been barren and I have reached extreme old age?"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcclix{%
[An angel] said, ``Thus [it will be]; your Lord says, 'It is easy for Me, for I created you before, while you were nothing.' ``\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcclx{%
[Zechariah] said, ``My Lord, make for me a sign." He said, ``Your sign is that you will not speak to the people for three nights, [being] sound."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcclxi{%
So he came out to his people from the prayer chamber and signaled to them to exalt [Allah] in the morning and afternoon.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcclxii{%
[Allah] said, ``O John, take the Scripture with determination." And We gave him judgement [while yet] a boy\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcclxiii{%
And affection from Us and purity, and he was fearing of Allah\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcclxiv{%
And dutiful to his parents, and he was not a disobedient tyrant.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcclxv{%
And peace be upon him the day he was born and the day he dies and the day he is raised alive.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcclxvi{%
And mention, [O Muhammad], in the Book [the story of] Mary, when she withdrew from her family to a place toward the east.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcclxvii{%
And she took, in seclusion from them, a screen. Then We sent to her Our Angel, and he represented himself to her as a well-proportioned man.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcclxviii{%
She said, ``Indeed, I seek refuge in the Most Merciful from you, [so leave me], if you should be fearing of Allah."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcclxix{%
He said, ``I am only the messenger of your Lord to give you [news of] a pure boy."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcclxx{%
She said, ``How can I have a boy while no man has touched me and I have not been unchaste?"\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcclxxi{%
He said, ``Thus [it will be]; your Lord says, 'It is easy for Me, and We will make him a sign to the people and a mercy from Us. And it is a matter [already] decreed.' ``\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcclxxii{%
So she conceived him, and she withdrew with him to a remote place.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcclxxiii{%
And the pains of childbirth drove her to the trunk of a palm tree. She said, ``Oh, I wish I had died before this and was in oblivion, forgotten."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcclxxiv{%
But he called her from below her, ``Do not grieve; your Lord has provided beneath you a stream.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcclxxv{%
And shake toward you the trunk of the palm tree; it will drop upon you ripe, fresh dates.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcclxxvi{%
So eat and drink and be contented. And if you see from among humanity anyone, say, 'Indeed, I have vowed to the Most Merciful abstention, so I will not speak today to [any] man.' ``\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcclxxvii{%
Then she brought him to her people, carrying him. They said, ``O Mary, you have certainly done a thing unprecedented.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcclxxviii{%
O sister of Aaron, your father was not a man of evil, nor was your mother unchaste."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcclxxix{%
So she pointed to him. They said, ``How can we speak to one who is in the cradle a child?"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcclxxx{%
[Jesus] said, ``Indeed, I am the servant of Allah. He has given me the Scripture and made me a prophet.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcclxxxi{%
And He has made me blessed wherever I am and has enjoined upon me prayer and zakah as long as I remain alive\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcclxxxii{%
And [made me] dutiful to my mother, and He has not made me a wretched tyrant.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcclxxxiii{%
And peace is on me the day I was born and the day I will die and the day I am raised alive."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcclxxxiv{%
That is Jesus, the son of Mary - the word of truth about which they are in dispute.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcclxxxv{%
It is not [befitting] for Allah to take a son; exalted is He! When He decrees an affair, He only says to it, ``Be," and it is.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcclxxxvi{%
[Jesus said], ``And indeed, Allah is my Lord and your Lord, so worship Him. That is a straight path."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcclxxxvii{%
Then the factions differed [concerning Jesus] from among them, so woe to those who disbelieved - from the scene of a tremendous Day.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcclxxxviii{%
How [clearly] they will hear and see the Day they come to Us, but the wrongdoers today are in clear error.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcclxxxix{%
And warn them, [O Muhammad], of the Day of Regret, when the matter will be concluded; and [yet], they are in [a state of] heedlessness, and they do not believe.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccxc{%
Indeed, it is We who will inherit the earth and whoever is on it, and to Us they will be returned.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccxci{%
And mention in the Book [the story of] Abraham. Indeed, he was a man of truth and a prophet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmccxcii{%
[Mention] when he said to his father, ``O my father, why do you worship that which does not hear and does not see and will not benefit you at all?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmccxciii{%
O my father, indeed there has come to me of knowledge that which has not come to you, so follow me; I will guide you to an even path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmccxciv{%
O my father, do not worship Satan. Indeed Satan has ever been, to the Most Merciful, disobedient.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmccxcv{%
O my father, indeed I fear that there will touch you a punishment from the Most Merciful so you would be to Satan a companion [in Hellfire]."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmccxcvi{%
[His father] said, ``Have you no desire for my gods, O Abraham? If you do not desist, I will surely stone you, so avoid me a prolonged time."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmccxcvii{%
[Abraham] said, ``Peace will be upon you. I will ask forgiveness for you of my Lord. Indeed, He is ever gracious to me.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmccxcviii{%
And I will leave you and those you invoke other than Allah and will invoke my Lord. I expect that I will not be in invocation to my Lord unhappy."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmccxcix{%
So when he had left them and those they worshipped other than Allah, We gave him Isaac and Jacob, and each [of them] We made a prophet.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmccc{%
And We gave them of Our mercy, and we made for them a reputation of high honor.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmccci{%
And mention in the Book, Moses. Indeed, he was chosen, and he was a messenger and a prophet.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcccii{%
And We called him from the side of the mount at [his] right and brought him near, confiding [to him].\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmccciii{%
And We gave him out of Our mercy his brother Aaron as a prophet.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmccciv{%
And mention in the Book, Ishmael. Indeed, he was true to his promise, and he was a messenger and a prophet.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcccv{%
And he used to enjoin on his people prayer and zakah and was to his Lord pleasing.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcccvi{%
And mention in the Book, Idrees. Indeed, he was a man of truth and a prophet.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcccvii{%
And We raised him to a high station.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcccviii{%
Those were the ones upon whom Allah bestowed favor from among the prophets of the descendants of Adam and of those We carried [in the ship] with Noah, and of the descendants of Abraham and Israel, and of those whom We guided and chose. When the verses of the Most Merciful were recited to them, they fell in prostration and weeping.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcccix{%
But there came after them successors who neglected prayer and pursued desires; so they are going to meet evil -\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcccx{%
Except those who repent, believe and do righteousness; for those will enter Paradise and will not be wronged at all.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcccxi{%
[Therein are] gardens of perpetual residence which the Most Merciful has promised His servants in the unseen. Indeed, His promise has ever been coming.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcccxii{%
They will not hear therein any ill speech - only [greetings of] peace - and they will have their provision therein, morning and afternoon.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcccxiii{%
That is Paradise, which We give as inheritance to those of Our servants who were fearing of Allah.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcccxiv{%
[Gabriel said], ``And we [angels] descend not except by the order of your Lord. To Him belongs that before us and that behind us and what is in between. And never is your Lord forgetful -\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcccxv{%
Lord of the heavens and the earth and whatever is between them - so worship Him and have patience for His worship. Do you know of any similarity to Him?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcccxvi{%
And the disbeliever says, ``When I have died, am I going to be brought forth alive?"\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcccxvii{%
Does man not remember that We created him before, while he was nothing?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcccxviii{%
So by your Lord, We will surely gather them and the devils; then We will bring them to be present around Hell upon their knees.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcccxix{%
Then We will surely extract from every sect those of them who were worst against the Most Merciful in insolence.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcccxx{%
Then, surely it is We who are most knowing of those most worthy of burning therein.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcccxxi{%
And there is none of you except he will come to it. This is upon your Lord an inevitability decreed.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcccxxii{%
Then We will save those who feared Allah and leave the wrongdoers within it, on their knees.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcccxxiii{%
And when Our verses are recited to them as clear evidences, those who disbelieve say to those who believe, ``Which of [our] two parties is best in position and best in association?"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcccxxiv{%
And how many a generation have We destroyed before them who were better in possessions and [outward] appearance?\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcccxxv{%
Say, ``Whoever is in error - let the Most Merciful extend for him an extension [in wealth and time] until, when they see that which they were promised - either punishment [in this world] or the Hour [of resurrection] - they will come to know who is worst in position and weaker in soldiers."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcccxxvi{%
And Allah increases those who were guided, in guidance, and the enduring good deeds are better to your Lord for reward and better for recourse.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcccxxvii{%
Then, have you seen he who disbelieved in Our verses and said, ``I will surely be given wealth and children [in the next life]?"\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcccxxviii{%
Has he looked into the unseen, or has he taken from the Most Merciful a promise?\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcccxxix{%
No! We will record what he says and extend for him from the punishment extensively.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcccxxx{%
And We will inherit him [in] what he mentions, and he will come to Us alone.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcccxxxi{%
And they have taken besides Allah [false] deities that they would be for them [a source of] honor.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcccxxxii{%
No! Those ``gods" will deny their worship of them and will be against them opponents [on the Day of Judgement].\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcccxxxiii{%
Do you not see that We have sent the devils upon the disbelievers, inciting them to [evil] with [constant] incitement?\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcccxxxiv{%
So be not impatient over them. We only count out to them a [limited] number.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcccxxxv{%
On the Day We will gather the righteous to the Most Merciful as a delegation\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcccxxxvi{%
And will drive the criminals to Hell in thirst\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcccxxxvii{%
None will have [power of] intercession except he who had taken from the Most Merciful a covenant.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcccxxxviii{%
And they say, ``The Most Merciful has taken [for Himself] a son."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcccxxxix{%
You have done an atrocious thing.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcccxl{%
The heavens almost rupture therefrom and the earth splits open and the mountains collapse in devastation\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcccxli{%
That they attribute to the Most Merciful a son.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcccxlii{%
And it is not appropriate for the Most Merciful that He should take a son.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcccxliii{%
There is no one in the heavens and earth but that he comes to the Most Merciful as a servant.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcccxliv{%
He has enumerated them and counted them a [full] counting.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcccxlv{%
And all of them are coming to Him on the Day of Resurrection alone.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcccxlvi{%
Indeed, those who have believed and done righteous deeds - the Most Merciful will appoint for them affection.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcccxlvii{%
So, [O Muhammad], We have only made Qur'an easy in the Arabic language that you may give good tidings thereby to the righteous and warn thereby a hostile people.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcccxlviii{%
And how many have We destroyed before them of generations? Do you perceive of them anyone or hear from them a sound?\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcccxlix{%
\basmalahen Ta, Ha.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcccl{%
We have not sent down to you the Qur'an that you be distressed\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcccli{%
But only as a reminder for those who fear [Allah] -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmccclii{%
A revelation from He who created the earth and highest heavens,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcccliii{%
The Most Merciful [who is] above the Throne established.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcccliv{%
To Him belongs what is in the heavens and what is on the earth and what is between them and what is under the soil.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmccclv{%
And if you speak aloud - then indeed, He knows the secret and what is [even] more hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmccclvi{%
Allah - there is no deity except Him. To Him belong the best names.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmccclvii{%
And has the story of Moses reached you? -\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmccclviii{%
When he saw a fire and said to his family, ``Stay here; indeed, I have perceived a fire; perhaps I can bring you a torch or find at the fire some guidance."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmccclix{%
And when he came to it, he was called, ``O Moses,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmccclx{%
Indeed, I am your Lord, so remove your sandals. Indeed, you are in the sacred valley of Tuwa.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmccclxi{%
And I have chosen you, so listen to what is revealed [to you].\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmccclxii{%
Indeed, I am Allah. There is no deity except Me, so worship Me and establish prayer for My remembrance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmccclxiii{%
Indeed, the Hour is coming - I almost conceal it - so that every soul may be recompensed according to that for which it strives.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmccclxiv{%
So do not let one avert you from it who does not believe in it and follows his desire, for you [then] would perish.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmccclxv{%
And what is that in your right hand, O Moses?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmccclxvi{%
He said, ``It is my staff; I lean upon it, and I bring down leaves for my sheep and I have therein other uses."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmccclxvii{%
[Allah] said, ``Throw it down, O Moses."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmccclxviii{%
So he threw it down, and thereupon it was a snake, moving swiftly.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmccclxix{%
[Allah] said, ``Seize it and fear not; We will return it to its former condition.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmccclxx{%
And draw in your hand to your side; it will come out white without disease - another sign,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmccclxxi{%
That We may show you [some] of Our greater signs.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmccclxxii{%
Go to Pharaoh. Indeed, he has transgressed."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmccclxxiii{%
[Moses] said, ``My Lord, expand for me my breast [with assurance]\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmccclxxiv{%
And ease for me my task\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmccclxxv{%
And untie the knot from my tongue\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmccclxxvi{%
That they may understand my speech.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmccclxxvii{%
And appoint for me a minister from my family -\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmccclxxviii{%
Aaron, my brother.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmccclxxix{%
Increase through him my strength\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmccclxxx{%
And let him share my task\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmccclxxxi{%
That we may exalt You much\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmccclxxxii{%
And remember You much.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmccclxxxiii{%
Indeed, You are of us ever Seeing."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmccclxxxiv{%
[Allah] said, ``You have been granted your request, O Moses.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmccclxxxv{%
And We had already conferred favor upon you another time,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmccclxxxvi{%
When We inspired to your mother what We inspired,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmccclxxxvii{%
[Saying], 'Cast him into the chest and cast it into the river, and the river will throw it onto the bank; there will take him an enemy to Me and an enemy to him.' And I bestowed upon you love from Me that you would be brought up under My eye.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmccclxxxviii{%
[And We favored you] when your sister went and said, 'Shall I direct you to someone who will be responsible for him?' So We restored you to your mother that she might be content and not grieve. And you killed someone, but We saved you from retaliation and tried you with a [severe] trial. And you remained [some] years among the people of Madyan. Then you came [here] at the decreed time, O Moses.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmccclxxxix{%
And I produced you for Myself.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcccxc{%
Go, you and your brother, with My signs and do not slacken in My remembrance.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcccxci{%
Go, both of you, to Pharaoh. Indeed, he has transgressed.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcccxcii{%
And speak to him with gentle speech that perhaps he may be reminded or fear [Allah]."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcccxciii{%
They said, ``Our Lord, indeed we are afraid that he will hasten [punishment] against us or that he will transgress."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcccxciv{%
[Allah] said, ``Fear not. Indeed, I am with you both; I hear and I see.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcccxcv{%
So go to him and say, 'Indeed, we are messengers of your Lord, so send with us the Children of Israel and do not torment them. We have come to you with a sign from your Lord. And peace will be upon he who follows the guidance.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcccxcvi{%
Indeed, it has been revealed to us that the punishment will be upon whoever denies and turns away.' ``\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcccxcvii{%
[Pharaoh] said, ``So who is the Lord of you two, O Moses?"\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcccxcviii{%
He said, ``Our Lord is He who gave each thing its form and then guided [it]."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcccxcix{%
[Pharaoh] said, ``Then what is the case of the former generations?"\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcd{%
[Moses] said, ``The knowledge thereof is with my Lord in a record. My Lord neither errs nor forgets."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcdi{%
[It is He] who has made for you the earth as a bed [spread out] and inserted therein for you roadways and sent down from the sky, rain and produced thereby categories of various plants.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcdii{%
Eat [therefrom] and pasture your livestock. Indeed, in that are signs for those of intelligence.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcdiii{%
From the earth We created you, and into it We will return you, and from it We will extract you another time.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcdiv{%
And We certainly showed Pharaoh Our signs - all of them - but he denied and refused.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcdv{%
He said, ``Have you come to us to drive us out of our land with your magic, O Moses?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcdvi{%
Then we will surely bring you magic like it, so make between us and you an appointment, which we will not fail to keep and neither will you, in a place assigned."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcdvii{%
[Moses] said, ``Your appointment is on the day of the festival when the people assemble at mid-morning."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcdviii{%
So Pharaoh went away, put together his plan, and then came [to Moses].\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcdix{%
Moses said to the magicians summoned by Pharaoh, ``Woe to you! Do not invent a lie against Allah or He will exterminate you with a punishment; and he has failed who invents [such falsehood]."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcdx{%
So they disputed over their affair among themselves and concealed their private conversation.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcdxi{%
They said, ``Indeed, these are two magicians who want to drive you out of your land with their magic and do away with your most exemplary way.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcdxii{%
So resolve upon your plan and then come [forward] in line. And he has succeeded today who overcomes."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcdxiii{%
They said, ``O Moses, either you throw or we will be the first to throw."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcdxiv{%
He said, ``Rather, you throw." And suddenly their ropes and staffs seemed to him from their magic that they were moving [like snakes].\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcdxv{%
And he sensed within himself apprehension, did Moses.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcdxvi{%
Allah said, ``Fear not. Indeed, it is you who are superior.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcdxvii{%
And throw what is in your right hand; it will swallow up what they have crafted. What they have crafted is but the trick of a magician, and the magician will not succeed wherever he is."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcdxviii{%
So the magicians fell down in prostration. They said, ``We have believed in the Lord of Aaron and Moses."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcdxix{%
[Pharaoh] said, ``You believed him before I gave you permission. Indeed, he is your leader who has taught you magic. So I will surely cut off your hands and your feet on opposite sides, and I will crucify you on the trunks of palm trees, and you will surely know which of us is more severe in [giving] punishment and more enduring."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcdxx{%
They said, ``Never will we prefer you over what has come to us of clear proofs and [over] He who created us. So decree whatever you are to decree. You can only decree for this worldly life.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcdxxi{%
Indeed, we have believed in our Lord that He may forgive us our sins and what you compelled us [to do] of magic. And Allah is better and more enduring."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcdxxii{%
Indeed, whoever comes to his Lord as a criminal - indeed, for him is Hell; he will neither die therein nor live.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcdxxiii{%
But whoever comes to Him as a believer having done righteous deeds - for those will be the highest degrees [in position]:\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcdxxiv{%
Gardens of perpetual residence beneath which rivers flow, wherein they abide eternally. And that is the reward of one who purifies himself.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcdxxv{%
And We had inspired to Moses, ``Travel by night with My servants and strike for them a dry path through the sea; you will not fear being overtaken [by Pharaoh] nor be afraid [of drowning]."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcdxxvi{%
So Pharaoh pursued them with his soldiers, and there covered them from the sea that which covered them,\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmcdxxvii{%
And Pharaoh led his people astray and did not guide [them].\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmcdxxviii{%
O Children of Israel, We delivered you from your enemy, and We made an appointment with you at the right side of the mount, and We sent down to you manna and quails,\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmcdxxix{%
[Saying], ``Eat from the good things with which We have provided you and do not transgress [or oppress others] therein, lest My anger should descend upon you. And he upon whom My anger descends has certainly fallen."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmcdxxx{%
But indeed, I am the Perpetual Forgiver of whoever repents and believes and does righteousness and then continues in guidance.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmcdxxxi{%
[Allah] said, ``And what made you hasten from your people, O Moses?"\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmcdxxxii{%
He said, ``They are close upon my tracks, and I hastened to You, my Lord, that You be pleased."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmcdxxxiii{%
[Allah] said, ``But indeed, We have tried your people after you [departed], and the Samiri has led them astray."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmcdxxxiv{%
So Moses returned to his people, angry and grieved. He said, ``O my people, did your Lord not make you a good promise? Then, was the time [of its fulfillment] too long for you, or did you wish that wrath from your Lord descend upon you, so you broke your promise [of obedience] to me?"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmcdxxxv{%
They said, ``We did not break our promise to you by our will, but we were made to carry burdens from the ornaments of the people [of Pharaoh], so we threw them [into the fire], and thus did the Samiri throw."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmcdxxxvi{%
And he extracted for them [the statue of] a calf which had a lowing sound, and they said, ``This is your god and the god of Moses, but he forgot."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmcdxxxvii{%
Did they not see that it could not return to them any speech and that it did not possess for them any harm or benefit?\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmcdxxxviii{%
And Aaron had already told them before [the return of Moses], ``O my people, you are only being tested by it, and indeed, your Lord is the Most Merciful, so follow me and obey my order."\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmcdxxxix{%
They said, ``We will never cease being devoted to the calf until Moses returns to us."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmcdxl{%
[Moses] said, ``O Aaron, what prevented you, when you saw them going astray,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmcdxli{%
From following me? Then have you disobeyed my order?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmcdxlii{%
[Aaron] said, ``O son of my mother, do not seize [me] by my beard or by my head. Indeed, I feared that you would say, 'You caused division among the Children of Israel, and you did not observe [or await] my word.' ``\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmcdxliii{%
[Moses] said, ``And what is your case, O Samiri?"\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmcdxliv{%
He said, ``I saw what they did not see, so I took a handful [of dust] from the track of the messenger and threw it, and thus did my soul entice me."\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmcdxlv{%
[Moses] said, ``Then go. And indeed, it is [decreed] for you in [this] life to say, 'No contact.' And indeed, you have an appointment [in the Hereafter] you will not fail to keep. And look at your 'god' to which you remained devoted. We will surely burn it and blow it into the sea with a blast.\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmcdxlvi{%
Your god is only Allah, except for whom there is no deity. He has encompassed all things in knowledge."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmcdxlvii{%
Thus, [O Muhammad], We relate to you from the news of what has preceded. And We have certainly given you from Us the Qur'an.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmcdxlviii{%
Whoever turns away from it - then indeed, he will bear on the Day of Resurrection a burden,\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmcdxlix{%
[Abiding] eternally therein, and evil it is for them on the Day of Resurrection as a load -\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmcdl{%
The Day the Horn will be blown. And We will gather the criminals, that Day, blue-eyed.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmcdli{%
They will murmur among themselves, ``You remained not but ten [days in the world]."\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmcdlii{%
We are most knowing of what they say when the best of them in manner will say, ``You remained not but one day."\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmcdliii{%
And they ask you about the mountains, so say, ``My Lord will blow them away with a blast.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmcdliv{%
And He will leave the earth a level plain;\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmcdlv{%
You will not see therein a depression or an elevation."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmcdlvi{%
That Day, everyone will follow [the call of] the Caller [with] no deviation therefrom, and [all] voices will be stilled before the Most Merciful, so you will not hear except a whisper [of footsteps].\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmcdlvii{%
That Day, no intercession will benefit except [that of] one to whom the Most Merciful has given permission and has accepted his word.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmcdlviii{%
Allah knows what is [presently] before them and what will be after them, but they do not encompass it in knowledge.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmcdlix{%
And [all] faces will be humbled before the Ever-Living, the Sustainer of existence. And he will have failed who carries injustice.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmcdlx{%
But he who does of righteous deeds while he is a believer - he will neither fear injustice nor deprivation.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmcdlxi{%
And thus We have sent it down as an Arabic Qur'an and have diversified therein the warnings that perhaps they will avoid [sin] or it would cause them remembrance.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmcdlxii{%
So high [above all] is Allah, the Sovereign, the Truth. And, [O Muhammad], do not hasten with [recitation of] the Qur'an before its revelation is completed to you, and say, ``My Lord, increase me in knowledge."\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmcdlxiii{%
And We had already taken a promise from Adam before, but he forgot; and We found not in him determination.\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmcdlxiv{%
And [mention] when We said to the angels, ``Prostrate to Adam," and they prostrated, except Iblees; he refused.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmcdlxv{%
So We said, ``O Adam, indeed this is an enemy to you and to your wife. Then let him not remove you from Paradise so you would suffer.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmcdlxvi{%
Indeed, it is [promised] for you not to be hungry therein or be unclothed.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmcdlxvii{%
And indeed, you will not be thirsty therein or be hot from the sun."\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmcdlxviii{%
Then Satan whispered to him; he said, ``O Adam, shall I direct you to the tree of eternity and possession that will not deteriorate?"\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmcdlxix{%
And Adam and his wife ate of it, and their private parts became apparent to them, and they began to fasten over themselves from the leaves of Paradise. And Adam disobeyed his Lord and erred.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmcdlxx{%
Then his Lord chose him and turned to him in forgiveness and guided [him].\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmcdlxxi{%
[Allah] said, ``Descend from Paradise - all, [your descendants] being enemies to one another. And if there should come to you guidance from Me - then whoever follows My guidance will neither go astray [in the world] nor suffer [in the Hereafter].\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmcdlxxii{%
And whoever turns away from My remembrance - indeed, he will have a depressed life, and We will gather him on the Day of Resurrection blind."\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmcdlxxiii{%
He will say, ``My Lord, why have you raised me blind while I was [once] seeing?"\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmcdlxxiv{%
[Allah] will say, ``Thus did Our signs come to you, and you forgot them; and thus will you this Day be forgotten."\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmcdlxxv{%
And thus do We recompense he who transgressed and did not believe in the signs of his Lord. And the punishment of the Hereafter is more severe and more enduring.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmcdlxxvi{%
Then, has it not become clear to them how many generations We destroyed before them as they walk among their dwellings? Indeed in that are signs for those of intelligence.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmcdlxxvii{%
And if not for a word that preceded from your Lord, punishment would have been an obligation [due immediately], and [if not for] a specified term [decreed].\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmcdlxxviii{%
So be patient over what they say and exalt [Allah] with praise of your Lord before the rising of the sun and before its setting; and during periods of the night [exalt Him] and at the ends of the day, that you may be satisfied.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmcdlxxix{%
And do not extend your eyes toward that by which We have given enjoyment to [some] categories of them, [its being but] the splendor of worldly life by which We test them. And the provision of your Lord is better and more enduring.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmcdlxxx{%
And enjoin prayer upon your family [and people] and be steadfast therein. We ask you not for provision; We provide for you, and the [best] outcome is for [those of] righteousness.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmcdlxxxi{%
And they say, ``Why does he not bring us a sign from his Lord?" Has there not come to them evidence of what was in the former scriptures?\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmcdlxxxii{%
And if We had destroyed them with a punishment before him, they would have said, ``Our Lord, why did You not send to us a messenger so we could have followed Your verses before we were humiliated and disgraced?"\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiii{%
Say, ``Each [of us] is waiting; so wait. For you will know who are the companions of the sound path and who is guided."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmcdlxxxiv{%
\basmalahen [The time of] their account has approached for the people, while they are in heedlessness turning away.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcdlxxxv{%
No mention comes to them anew from their Lord except that they listen to it while they are at play\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvi{%
With their hearts distracted. And those who do wrong conceal their private conversation, [saying], ``Is this [Prophet] except a human being like you? So would you approach magic while you are aware [of it]?"\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcdlxxxvii{%
The Prophet said, ``My Lord knows whatever is said throughout the heaven and earth, and He is the Hearing, the Knowing."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcdlxxxviii{%
But they say, ``[The revelation is but] a mixture of false dreams; rather, he has invented it; rather, he is a poet. So let him bring us a sign just as the previous [messengers] were sent [with miracles]."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcdlxxxix{%
Not a [single] city which We destroyed believed before them, so will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcdxc{%
And We sent not before you, [O Muhammad], except men to whom We revealed [the message], so ask the people of the message if you do not know.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcdxci{%
And We did not make the prophets forms not eating food, nor were they immortal [on earth].\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcdxcii{%
Then We fulfilled for them the promise, and We saved them and whom We willed and destroyed the transgressors.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcdxciii{%
We have certainly sent down to you a Book in which is your mention. Then will you not reason?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcdxciv{%
And how many a city which was unjust have We shattered and produced after it another people.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcdxcv{%
And when its inhabitants perceived Our punishment, at once they fled from it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcdxcvi{%
[Some angels said], ``Do not flee but return to where you were given luxury and to your homes - perhaps you will be questioned."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcdxcvii{%
They said, ``O woe to us! Indeed, we were wrongdoers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcdxcviii{%
And that declaration of theirs did not cease until We made them [as] a harvest [mowed down], extinguished [like a fire].\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcdxcix{%
And We did not create the heaven and earth and that between them in play.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmd{%
Had We intended to take a diversion, We could have taken it from [what is] with Us - if [indeed] We were to do so.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdi{%
Rather, We dash the truth upon falsehood, and it destroys it, and thereupon it departs. And for you is destruction from that which you describe.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdii{%
To Him belongs whoever is in the heavens and the earth. And those near Him are not prevented by arrogance from His worship, nor do they tire.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdiii{%
They exalt [Him] night and day [and] do not slacken.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdiv{%
Or have men taken for themselves gods from the earth who resurrect [the dead]?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdv{%
Had there been within the heavens and earth gods besides Allah, they both would have been ruined. So exalted is Allah, Lord of the Throne, above what they describe.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdvi{%
He is not questioned about what He does, but they will be questioned.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdvii{%
Or have they taken gods besides Him? Say, [O Muhammad], ``Produce your proof. This [Qur'an] is the message for those with me and the message of those before me." But most of them do not know the truth, so they are turning away.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdviii{%
And We sent not before you any messenger except that We revealed to him that, ``There is no deity except Me, so worship Me."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdix{%
And they say, ``The Most Merciful has taken a son." Exalted is He! Rather, they are [but] honored servants.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdx{%
They cannot precede Him in word, and they act by His command.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdxi{%
He knows what is [presently] before them and what will be after them, and they cannot intercede except on behalf of one whom He approves. And they, from fear of Him, are apprehensive.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdxii{%
And whoever of them should say, ``Indeed, I am a god besides Him"- that one We would recompense with Hell. Thus do We recompense the wrongdoers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdxiii{%
Have those who disbelieved not considered that the heavens and the earth were a joined entity, and We separated them and made from water every living thing? Then will they not believe?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdxiv{%
And We placed within the earth firmly set mountains, lest it should shift with them, and We made therein [mountain] passes [as] roads that they might be guided.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdxv{%
And We made the sky a protected ceiling, but they, from its signs, are turning away.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdxvi{%
And it is He who created the night and the day and the sun and the moon; all [heavenly bodies] in an orbit are swimming.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdxvii{%
And We did not grant to any man before you eternity [on earth]; so if you die - would they be eternal?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdxviii{%
Every soul will taste death. And We test you with evil and with good as trial; and to Us you will be returned.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdxix{%
And when those who disbelieve see you, [O Muhammad], they take you not except in ridicule, [saying], ``Is this the one who insults your gods?" And they are, at the mention of the Most Merciful, disbelievers.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdxx{%
Man was created of haste. I will show you My signs, so do not impatiently urge Me.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdxxi{%
And they say, ``When is this promise, if you should be truthful?"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdxxii{%
If those who disbelieved but knew the time when they will not avert the Fire from their faces or from their backs and they will not be aided...\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdxxiii{%
Rather, it will come to them unexpectedly and bewilder them, and they will not be able to repel it, nor will they be reprieved.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdxxiv{%
And already were messengers ridiculed before you, but those who mocked them were enveloped by what they used to ridicule.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdxxv{%
Say, ``Who can protect you at night or by day from the Most Merciful?" But they are, from the remembrance of their Lord, turning away.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdxxvi{%
Or do they have gods to defend them other than Us? They are unable [even] to help themselves, nor can they be protected from Us.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdxxvii{%
But, [on the contrary], We have provided good things for these [disbelievers] and their fathers until life was prolonged for them. Then do they not see that We set upon the land, reducing it from its borders? So it is they who will overcome?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdxxviii{%
Say, ``I only warn you by revelation." But the deaf do not hear the call when they are warned.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdxxix{%
And if [as much as] a whiff of the punishment of your Lord should touch them, they would surely say, ``O woe to us! Indeed, we have been wrongdoers."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdxxx{%
And We place the scales of justice for the Day of Resurrection, so no soul will be treated unjustly at all. And if there is [even] the weight of a mustard seed, We will bring it forth. And sufficient are We as accountant.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdxxxi{%
And We had already given Moses and Aaron the criterion and a light and a reminder for the righteous\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdxxxii{%
Who fear their Lord unseen, while they are of the Hour apprehensive.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdxxxiii{%
And this [Qur'an] is a blessed message which We have sent down. Then are you with it unacquainted?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdxxxiv{%
And We had certainly given Abraham his sound judgement before, and We were of him well-Knowing\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdxxxv{%
When he said to his father and his people, ``What are these statues to which you are devoted?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdxxxvi{%
They said, ``We found our fathers worshippers of them."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdxxxvii{%
He said, ``You were certainly, you and your fathers, in manifest error."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdxxxviii{%
They said, ``Have you come to us with truth, or are you of those who jest?"\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdxxxix{%
He said, ``[No], rather, your Lord is the Lord of the heavens and the earth who created them, and I, to that, am of those who testify.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdxl{%
And [I swear] by Allah, I will surely plan against your idols after you have turned and gone away."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdxli{%
So he made them into fragments, except a large one among them, that they might return to it [and question].\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdxlii{%
They said, ``Who has done this to our gods? Indeed, he is of the wrongdoers."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdxliii{%
They said, ``We heard a young man mention them who is called Abraham."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdxliv{%
They said, ``Then bring him before the eyes of the people that they may testify."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdxlv{%
They said, ``Have you done this to our gods, O Abraham?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdxlvi{%
He said, ``Rather, this - the largest of them - did it, so ask them, if they should [be able to] speak."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdxlvii{%
So they returned to [blaming] themselves and said [to each other], ``Indeed, you are the wrongdoers."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdxlviii{%
Then they reversed themselves, [saying], ``You have already known that these do not speak!"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdxlix{%
He said, ``Then do you worship instead of Allah that which does not benefit you at all or harm you?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdl{%
Uff to you and to what you worship instead of Allah. Then will you not use reason?"\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdli{%
They said, ``Burn him and support your gods - if you are to act."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdlii{%
Allah said, ``O fire, be coolness and safety upon Abraham."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdliii{%
And they intended for him harm, but We made them the greatest losers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdliv{%
And We delivered him and Lot to the land which We had blessed for the worlds.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdlv{%
And We gave him Isaac and Jacob in addition, and all [of them] We made righteous.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdlvi{%
And We made them leaders guiding by Our command. And We inspired to them the doing of good deeds, establishment of prayer, and giving of zakah; and they were worshippers of Us.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdlvii{%
And to Lot We gave judgement and knowledge, and We saved him from the city that was committing wicked deeds. Indeed, they were a people of evil, defiantly disobedient.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdlviii{%
And We admitted him into Our mercy. Indeed, he was of the righteous.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdlix{%
And [mention] Noah, when he called [to Allah] before [that time], so We responded to him and saved him and his family from the great flood.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdlx{%
And We saved him from the people who denied Our signs. Indeed, they were a people of evil, so We drowned them, all together.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdlxi{%
And [mention] David and Solomon, when they judged concerning the field - when the sheep of a people overran it [at night], and We were witness to their judgement.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdlxii{%
And We gave understanding of the case to Solomon, and to each [of them] We gave judgement and knowledge. And We subjected the mountains to exalt [Us], along with David and [also] the birds. And We were doing [that].\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdlxiii{%
And We taught him the fashioning of coats of armor to protect you from your [enemy in] battle. So will you then be grateful?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdlxiv{%
And to Solomon [We subjected] the wind, blowing forcefully, proceeding by his command toward the land which We had blessed. And We are ever, of all things, Knowing.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdlxv{%
And of the devils were those who dived for him and did work other than that. And We were of them a guardian.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdlxvi{%
And [mention] Job, when he called to his Lord, ``Indeed, adversity has touched me, and you are the Most Merciful of the merciful."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdlxvii{%
So We responded to him and removed what afflicted him of adversity. And We gave him [back] his family and the like thereof with them as mercy from Us and a reminder for the worshippers [of Allah].\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdlxviii{%
And [mention] Ishmael and Idrees and Dhul-Kifl; all were of the patient.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdlxix{%
And We admitted them into Our mercy. Indeed, they were of the righteous.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdlxx{%
And [mention] the man of the fish, when he went off in anger and thought that We would not decree [anything] upon him. And he called out within the darknesses, ``There is no deity except You; exalted are You. Indeed, I have been of the wrongdoers."\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdlxxi{%
So We responded to him and saved him from the distress. And thus do We save the believers.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdlxxii{%
And [mention] Zechariah, when he called to his Lord, ``My Lord, do not leave me alone [with no heir], while you are the best of inheritors."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdlxxiii{%
So We responded to him, and We gave to him John, and amended for him his wife. Indeed, they used to hasten to good deeds and supplicate Us in hope and fear, and they were to Us humbly submissive.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdlxxiv{%
And [mention] the one who guarded her chastity, so We blew into her [garment] through Our angel [Gabriel], and We made her and her son a sign for the worlds.\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdlxxv{%
Indeed this, your religion, is one religion, and I am your Lord, so worship Me.\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdlxxvi{%
And [yet] they divided their affair among themselves, [but] all to Us will return.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdlxxvii{%
So whoever does righteous deeds while he is a believer - no denial will there be for his effort, and indeed We, of it, are recorders.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdlxxviii{%
And there is prohibition upon [the people of] a city which We have destroyed that they will [ever] return\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdlxxix{%
Until when [the dam of] Gog and Magog has been opened and they, from every elevation, descend\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdlxxx{%
And [when] the true promise has approached; then suddenly the eyes of those who disbelieved will be staring [in horror, while they say], ``O woe to us; we had been unmindful of this; rather, we were wrongdoers."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdlxxxi{%
Indeed, you [disbelievers] and what you worship other than Allah are the firewood of Hell. You will be coming to [enter] it.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdlxxxii{%
Had these [false deities] been [actual] gods, they would not have come to it, but all are eternal therein.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdlxxxiii{%
For them therein is heavy sighing, and they therein will not hear.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdlxxxiv{%
Indeed, those for whom the best [reward] has preceded from Us - they are from it far removed.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdlxxxv{%
They will not hear its sound, while they are, in that which their souls desire, abiding eternally.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdlxxxvi{%
They will not be grieved by the greatest terror, and the angels will meet them, [saying], ``This is your Day which you have been promised" -\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdlxxxvii{%
The Day when We will fold the heaven like the folding of a [written] sheet for the records. As We began the first creation, We will repeat it. [That is] a promise binding upon Us. Indeed, We will do it.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdlxxxviii{%
And We have already written in the book [of Psalms] after the [previous] mention that the land [of Paradise] is inherited by My righteous servants.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdlxxxix{%
Indeed, in this [Qur'an] is notification for a worshipping people.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdxc{%
And We have not sent you, [O Muhammad], except as a mercy to the worlds.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdxci{%
Say, ``It is only revealed to me that your god is but one God; so will you be Muslims [in submission to Him]?"\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdxcii{%
But if they turn away, then say, ``I have announced to [all of] you equally. And I know not whether near or far is that which you are promised.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdxciii{%
Indeed, He knows what is declared of speech, and He knows what you conceal.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdxciv{%
And I know not; perhaps it is a trial for you and enjoyment for a time."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdxcv{%
[The Prophet] has said, ``My Lord, judge [between us] in truth. And our Lord is the Most Merciful, the one whose help is sought against that which you describe."\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdxcvi{%
\basmalahen O mankind, fear your Lord. Indeed, the convulsion of the [final] Hour is a terrible thing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdxcvii{%
On the Day you see it every nursing mother will be distracted from that [child] she was nursing, and every pregnant woman will abort her pregnancy, and you will see the people [appearing] intoxicated while they are not intoxicated; but the punishment of Allah is severe.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdxcviii{%
And of the people is he who disputes about Allah without knowledge and follows every rebellious devil.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdxcix{%
It has been decreed for every devil that whoever turns to him - he will misguide him and will lead him to the punishment of the Blaze.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdc{%
O People, if you should be in doubt about the Resurrection, then [consider that] indeed, We created you from dust, then from a sperm-drop, then from a clinging clot, and then from a lump of flesh, formed and unformed - that We may show you. And We settle in the wombs whom We will for a specified term, then We bring you out as a child, and then [We develop you] that you may reach your [time of] maturity. And among you is he who is taken in [early] death, and among you is he who is returned to the most decrepit [old] age so that he knows, after [once having] knowledge, nothing. And you see the earth barren, but when We send down upon it rain, it quivers and swells and grows [something] of every beautiful kind.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdci{%
That is because Allah is the Truth and because He gives life to the dead and because He is over all things competent\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdcii{%
And [that they may know] that the Hour is coming - no doubt about it - and that Allah will resurrect those in the graves.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdciii{%
And of the people is he who disputes about Allah without knowledge or guidance or an enlightening book [from Him],\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdciv{%
Twisting his neck [in arrogance] to mislead [people] from the way of Allah. For him in the world is disgrace, and We will make him taste on the Day of Resurrection the punishment of the Burning Fire [while it is said],\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdcv{%
``That is for what your hands have put forth and because Allah is not ever unjust to [His] servants."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcvi{%
And of the people is he who worships Allah on an edge. If he is touched by good, he is reassured by it; but if he is struck by trial, he turns on his face [to the other direction]. He has lost [this] world and the Hereafter. That is what is the manifest loss.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdcvii{%
He invokes instead of Allah that which neither harms him nor benefits him. That is what is the extreme error.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdcviii{%
He invokes one whose harm is closer than his benefit - how wretched the protector and how wretched the associate.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcix{%
Indeed, Allah will admit those who believe and do righteous deeds to gardens beneath which rivers flow. Indeed, Allah does what He intends.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcx{%
Whoever should think that Allah will not support [Prophet Muhammad] in this world and the Hereafter - let him extend a rope to the ceiling, then cut off [his breath], and let him see: will his effort remove that which enrages [him]?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcxi{%
And thus have We sent the Qur'an down as verses of clear evidence and because Allah guides whom He intends.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxii{%
Indeed, those who have believed and those who were Jews and the Sabeans and the Christians and the Magians and those who associated with Allah - Allah will judge between them on the Day of Resurrection. Indeed Allah is, over all things, Witness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxiii{%
Do you not see that to Allah prostrates whoever is in the heavens and whoever is on the earth and the sun, the moon, the stars, the mountains, the trees, the moving creatures and many of the people? But upon many the punishment has been justified. And he whom Allah humiliates - for him there is no bestower of honor. Indeed, Allah does what He wills.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxiv{%
These are two adversaries who have disputed over their Lord. But those who disbelieved will have cut out for them garments of fire. Poured upon their heads will be scalding water\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxv{%
By which is melted that within their bellies and [their] skins.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxvi{%
And for [striking] them are maces of iron.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxvii{%
Every time they want to get out of Hellfire from anguish, they will be returned to it, and [it will be said], ``Taste the punishment of the Burning Fire!"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxviii{%
Indeed, Allah will admit those who believe and do righteous deeds to gardens beneath which rivers flow. They will be adorned therein with bracelets of gold and pearl, and their garments therein will be silk.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxix{%
And they had been guided [in worldly life] to good speech, and they were guided to the path of the Praiseworthy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxx{%
Indeed, those who have disbelieved and avert [people] from the way of Allah and [from] al-Masjid al-Haram, which We made for the people - equal are the resident therein and one from outside; and [also] whoever intends [a deed] therein of deviation [in religion] or wrongdoing - We will make him taste of a painful punishment.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxxi{%
And [mention, O Muhammad], when We designated for Abraham the site of the House, [saying], ``Do not associate anything with Me and purify My House for those who perform Tawaf and those who stand [in prayer] and those who bow and prostrate.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcxxii{%
And proclaim to the people the Hajj [pilgrimage]; they will come to you on foot and on every lean camel; they will come from every distant pass -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcxxiii{%
That they may witness benefits for themselves and mention the name of Allah on known days over what He has provided for them of [sacrificial] animals. So eat of them and feed the miserable and poor.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcxxiv{%
Then let them end their untidiness and fulfill their vows and perform Tawaf around the ancient House."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcxxv{%
That [has been commanded], and whoever honors the sacred ordinances of Allah - it is best for him in the sight of his Lord. And permitted to you are the grazing livestock, except what is recited to you. So avoid the uncleanliness of idols and avoid false statement,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcxxvi{%
Inclining [only] to Allah, not associating [anything] with Him. And he who associates with Allah - it is as though he had fallen from the sky and was snatched by the birds or the wind carried him down into a remote place.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcxxvii{%
That [is so]. And whoever honors the symbols of Allah - indeed, it is from the piety of hearts.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcxxviii{%
For you the animals marked for sacrifice are benefits for a specified term; then their place of sacrifice is at the ancient House.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcxxix{%
And for all religion We have appointed a rite [of sacrifice] that they may mention the name of Allah over what He has provided for them of [sacrificial] animals. For your god is one God, so to Him submit. And, [O Muhammad], give good tidings to the humble [before their Lord]\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcxxx{%
Who, when Allah is mentioned, their hearts are fearful, and [to] the patient over what has afflicted them, and the establishers of prayer and those who spend from what We have provided them.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcxxxi{%
And the camels and cattle We have appointed for you as among the symbols of Allah; for you therein is good. So mention the name of Allah upon them when lined up [for sacrifice]; and when they are [lifeless] on their sides, then eat from them and feed the needy and the beggar. Thus have We subjected them to you that you may be grateful.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcxxxii{%
Their meat will not reach Allah, nor will their blood, but what reaches Him is piety from you. Thus have We subjected them to you that you may glorify Allah for that [to] which He has guided you; and give good tidings to the doers of good.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcxxxiii{%
Indeed, Allah defends those who have believed. Indeed, Allah does not like everyone treacherous and ungrateful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcxxxiv{%
Permission [to fight] has been given to those who are being fought, because they were wronged. And indeed, Allah is competent to give them victory.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcxxxv{%
[They are] those who have been evicted from their homes without right - only because they say, ``Our Lord is Allah." And were it not that Allah checks the people, some by means of others, there would have been demolished monasteries, churches, synagogues, and mosques in which the name of Allah is much mentioned. And Allah will surely support those who support Him. Indeed, Allah is Powerful and Exalted in Might.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcxxxvi{%
[And they are] those who, if We give them authority in the land, establish prayer and give zakah and enjoin what is right and forbid what is wrong. And to Allah belongs the outcome of [all] matters.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcxxxvii{%
And if they deny you, [O Muhammad] - so, before them, did the people of Noah and 'Aad and Thamud deny [their prophets],\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcxxxviii{%
And the people of Abraham and the people of Lot\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcxxxix{%
And the inhabitants of Madyan. And Moses was denied, so I prolonged enjoyment for the disbelievers; then I seized them, and how [terrible] was My reproach.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcxl{%
And how many a city did We destroy while it was committing wrong - so it is [now] fallen into ruin - and [how many] an abandoned well and [how many] a lofty palace.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcxli{%
So have they not traveled through the earth and have hearts by which to reason and ears by which to hear? For indeed, it is not eyes that are blinded, but blinded are the hearts which are within the breasts.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcxlii{%
And they urge you to hasten the punishment. But Allah will never fail in His promise. And indeed, a day with your Lord is like a thousand years of those which you count.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcxliii{%
And for how many a city did I prolong enjoyment while it was committing wrong. Then I seized it, and to Me is the [final] destination.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcxliv{%
Say, ``O people, I am only to you a clear warner."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcxlv{%
And those who have believed and done righteous deeds - for them is forgiveness and noble provision.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcxlvi{%
But the ones who strove against Our verses, [seeking] to cause failure - those are the companions of Hellfire.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcxlvii{%
And We did not send before you any messenger or prophet except that when he spoke [or recited], Satan threw into it [some misunderstanding]. But Allah abolishes that which Satan throws in; then Allah makes precise His verses. And Allah is Knowing and Wise.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcxlviii{%
[That is] so He may make what Satan throws in a trial for those within whose hearts is disease and those hard of heart. And indeed, the wrongdoers are in extreme dissension.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcxlix{%
And so those who were given knowledge may know that it is the truth from your Lord and [therefore] believe in it, and their hearts humbly submit to it. And indeed is Allah the Guide of those who have believed to a straight path.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcl{%
But those who disbelieve will not cease to be in doubt of it until the Hour comes upon them unexpectedly or there comes to them the punishment of a barren Day.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcli{%
[All] sovereignty that Day is for Allah; He will judge between them. So they who believed and did righteous deeds will be in the Gardens of Pleasure.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdclii{%
And they who disbelieved and denied Our signs - for those there will be a humiliating punishment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcliii{%
And those who emigrated for the cause of Allah and then were killed or died - Allah will surely provide for them a good provision. And indeed, it is Allah who is the best of providers.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcliv{%
He will surely cause them to enter an entrance with which they will be pleased, and indeed, Allah is Knowing and Forbearing.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdclv{%
That [is so]. And whoever responds [to injustice] with the equivalent of that with which he was harmed and then is tyrannized - Allah will surely aid him. Indeed, Allah is Pardoning and Forgiving.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdclvi{%
That is because Allah causes the night to enter the day and causes the day to enter the night and because Allah is Hearing and Seeing.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdclvii{%
That is because Allah is the Truth, and that which they call upon other than Him is falsehood, and because Allah is the Most High, the Grand.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdclviii{%
Do you not see that Allah has sent down rain from the sky and the earth becomes green? Indeed, Allah is Subtle and Acquainted.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdclix{%
To Him belongs what is in the heavens and what is on the earth. And indeed, Allah is the Free of need, the Praiseworthy.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdclx{%
Do you not see that Allah has subjected to you whatever is on the earth and the ships which run through the sea by His command? And He restrains the sky from falling upon the earth, unless by His permission. Indeed Allah, to the people, is Kind and Merciful.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdclxi{%
And He is the one who gave you life; then He causes you to die and then will [again] give you life. Indeed, mankind is ungrateful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdclxii{%
For every religion We have appointed rites which they perform. So, [O Muhammad], let the disbelievers not contend with you over the matter but invite them to your Lord. Indeed, you are upon straight guidance.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdclxiii{%
And if they dispute with you, then say, ``Allah is most knowing of what you do.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdclxiv{%
Allah will judge between you on the Day of Resurrection concerning that over which you used to differ."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdclxv{%
Do you not know that Allah knows what is in the heaven and earth? Indeed, that is in a Record. Indeed that, for Allah, is easy.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdclxvi{%
And they worship besides Allah that for which He has not sent down authority and that of which they have no knowledge. And there will not be for the wrongdoers any helper.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdclxvii{%
And when Our verses are recited to them as clear evidences, you recognize in the faces of those who disbelieve disapproval. They are almost on the verge of assaulting those who recite to them Our verses. Say, ``Then shall I inform you of [what is] worse than that? [It is] the Fire which Allah has promised those who disbelieve, and wretched is the destination."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdclxviii{%
O people, an example is presented, so listen to it. Indeed, those you invoke besides Allah will never create [as much as] a fly, even if they gathered together for that purpose. And if the fly should steal away from them a [tiny] thing, they could not recover it from him. Weak are the pursuer and pursued.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdclxix{%
They have not appraised Allah with true appraisal. Indeed, Allah is Powerful and Exalted in Might.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdclxx{%
Allah chooses from the angels messengers and from the people. Indeed, Allah is Hearing and Seeing.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdclxxi{%
He knows what is [presently] before them and what will be after them. And to Allah will be returned [all] matters.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdclxxii{%
O you who have believed, bow and prostrate and worship your Lord and do good - that you may succeed.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdclxxiii{%
And strive for Allah with the striving due to Him. He has chosen you and has not placed upon you in the religion any difficulty. [It is] the religion of your father, Abraham. Allah named you ``Muslims" before [in former scriptures] and in this [revelation] that the Messenger may be a witness over you and you may be witnesses over the people. So establish prayer and give zakah and hold fast to Allah. He is your protector; and excellent is the protector, and excellent is the helper.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdclxxiv{%
\basmalahen Certainly will the believers have succeeded:\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdclxxv{%
They who are during their prayer humbly submissive\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdclxxvi{%
And they who turn away from ill speech\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdclxxvii{%
And they who are observant of zakah\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdclxxviii{%
And they who guard their private parts\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdclxxix{%
Except from their wives or those their right hands possess, for indeed, they will not be blamed -\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdclxxx{%
But whoever seeks beyond that, then those are the transgressors -\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdclxxxi{%
And they who are to their trusts and their promises attentive\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdclxxxii{%
And they who carefully maintain their prayers -\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdclxxxiii{%
Those are the inheritors\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdclxxxiv{%
Who will inherit al-Firdaus. They will abide therein eternally.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdclxxxv{%
And certainly did We create man from an extract of clay.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdclxxxvi{%
Then We placed him as a sperm-drop in a firm lodging.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdclxxxvii{%
Then We made the sperm-drop into a clinging clot, and We made the clot into a lump [of flesh], and We made [from] the lump, bones, and We covered the bones with flesh; then We developed him into another creation. So blessed is Allah, the best of creators.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdclxxxviii{%
Then indeed, after that you are to die.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdclxxxix{%
Then indeed you, on the Day of Resurrection, will be resurrected.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcxc{%
And We have created above you seven layered heavens, and never have We been of [Our] creation unaware.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcxci{%
And We have sent down rain from the sky in a measured amount and settled it in the earth. And indeed, We are Able to take it away.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcxcii{%
And We brought forth for you thereby gardens of palm trees and grapevines in which for you are abundant fruits and from which you eat.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcxciii{%
And [We brought forth] a tree issuing from Mount Sinai which produces oil and food for those who eat.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcxciv{%
And indeed, for you in livestock is a lesson. We give you drink from that which is in their bellies, and for you in them are numerous benefits, and from them you eat.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcxcv{%
And upon them and on ships you are carried.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcxcvi{%
And We had certainly sent Noah to his people, and he said, ``O my people, worship Allah; you have no deity other than Him; then will you not fear Him?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcxcvii{%
But the eminent among those who disbelieved from his people said, ``This is not but a man like yourselves who wishes to take precedence over you; and if Allah had willed [to send a messenger], He would have sent down angels. We have not heard of this among our forefathers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcxcviii{%
He is not but a man possessed with madness, so wait concerning him for a time."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcxcix{%
[Noah] said, ``My Lord, support me because they have denied me."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcc{%
So We inspired to him, ``Construct the ship under Our observation, and Our inspiration, and when Our command comes and the oven overflows, put into the ship from each [creature] two mates and your family, except those for whom the decree [of destruction] has proceeded. And do not address Me concerning those who have wronged; indeed, they are to be drowned.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcci{%
And when you have boarded the ship, you and those with you, then say, 'Praise to Allah who has saved us from the wrongdoing people.'\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccii{%
And say, 'My Lord, let me land at a blessed landing place, and You are the best to accommodate [us].' ``\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcciii{%
Indeed in that are signs, and indeed, We are ever testing [Our servants].\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcciv{%
Then We produced after them a generation of others.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccv{%
And We sent among them a messenger from themselves, [saying], ``Worship Allah; you have no deity other than Him; then will you not fear Him?"\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccvi{%
And the eminent among his people who disbelieved and denied the meeting of the Hereafter while We had given them luxury in the worldly life said, ``This is not but a man like yourselves. He eats of that from which you eat and drinks of what you drink.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccvii{%
And if you should obey a man like yourselves, indeed, you would then be losers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdccviii{%
Does he promise you that when you have died and become dust and bones that you will be brought forth [once more]?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdccix{%
How far, how far, is that which you are promised.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdccx{%
Life is not but our worldly life - we die and live, but we will not be resurrected.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdccxi{%
He is not but a man who has invented a lie about Allah, and we will not believe him."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdccxii{%
He said, ``My Lord, support me because they have denied me."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdccxiii{%
[Allah] said, ``After a little, they will surely become regretful."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdccxiv{%
So the shriek seized them in truth, and We made them as [plant] stubble. Then away with the wrongdoing people.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdccxv{%
Then We produced after them other generations.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdccxvi{%
No nation will precede its time [of termination], nor will they remain [thereafter].\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdccxvii{%
Then We sent Our messengers in succession. Every time there came to a nation its messenger, they denied him, so We made them follow one another [to destruction], and We made them narrations. So away with a people who do not believe.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdccxviii{%
Then We sent Moses and his brother Aaron with Our signs and a clear authority\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdccxix{%
To Pharaoh and his establishment, but they were arrogant and were a haughty people.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdccxx{%
They said, ``Should we believe two men like ourselves while their people are for us in servitude?"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdccxxi{%
So they denied them and were of those destroyed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdccxxii{%
And We certainly gave Moses the Scripture that perhaps they would be guided.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdccxxiii{%
And We made the son of Mary and his mother a sign and sheltered them within a high ground having level [areas] and flowing water.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdccxxiv{%
[Allah said], ``O messengers, eat from the good foods and work righteousness. Indeed, I, of what you do, am Knowing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdccxxv{%
And indeed this, your religion, is one religion, and I am your Lord, so fear Me."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdccxxvi{%
But the people divided their religion among them into sects - each faction, in what it has, rejoicing.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdccxxvii{%
So leave them in their confusion for a time.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdccxxviii{%
Do they think that what We extend to them of wealth and children\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdccxxix{%
Is [because] We hasten for them good things? Rather, they do not perceive.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdccxxx{%
Indeed, they who are apprehensive from fear of their Lord\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdccxxxi{%
And they who believe in the signs of their Lord\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdccxxxii{%
And they who do not associate anything with their Lord\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdccxxxiii{%
And they who give what they give while their hearts are fearful because they will be returning to their Lord -\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccxxxiv{%
It is those who hasten to good deeds, and they outstrip [others] therein.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdccxxxv{%
And We charge no soul except [with that within] its capacity, and with Us is a record which speaks with truth; and they will not be wronged.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdccxxxvi{%
But their hearts are covered with confusion over this, and they have [evil] deeds besides disbelief which they are doing,\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccxxxvii{%
Until when We seize their affluent ones with punishment, at once they are crying [to Allah] for help.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccxxxviii{%
Do not cry out today. Indeed, by Us you will not be helped.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmdccxxxix{%
My verses had already been recited to you, but you were turning back on your heels\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmdccxl{%
In arrogance regarding it, conversing by night, speaking evil.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmdccxli{%
Then have they not reflected over the Qur'an, or has there come to them that which had not come to their forefathers?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmdccxlii{%
Or did they not know their Messenger, so they are toward him disacknowledging?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmdccxliii{%
Or do they say, ``In him is madness?" Rather, he brought them the truth, but most of them, to the truth, are averse.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmdccxliv{%
But if the Truth had followed their inclinations, the heavens and the earth and whoever is in them would have been ruined. Rather, We have brought them their message, but they, from their message, are turning away.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmdccxlv{%
Or do you, [O Muhammad], ask them for payment? But the reward of your Lord is best, and He is the best of providers.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmdccxlvi{%
And indeed, you invite them to a straight path.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmdccxlvii{%
But indeed, those who do not believe in the Hereafter are deviating from the path.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmdccxlviii{%
And even if We gave them mercy and removed what was upon them of affliction, they would persist in their transgression, wandering blindly.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmdccxlix{%
And We had gripped them with suffering [as a warning], but they did not yield to their Lord, nor did they humbly supplicate, [and will continue thus]\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmdccl{%
Until when We have opened before them a door of severe punishment, immediately they will be therein in despair.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmdccli{%
And it is He who produced for you hearing and vision and hearts; little are you grateful.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmdcclii{%
And it is He who has multiplied you throughout the earth, and to Him you will be gathered.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmdccliii{%
And it is He who gives life and causes death, and His is the alternation of the night and the day. Then will you not reason?\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmdccliv{%
Rather, they say like what the former peoples said.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmdcclv{%
They said, ``When we have died and become dust and bones, are we indeed to be resurrected?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmdcclvi{%
We have been promised this, we and our forefathers, before; this is not but legends of the former peoples."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmdcclvii{%
Say, [O Muhammad], ``To whom belongs the earth and whoever is in it, if you should know?"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmdcclviii{%
They will say, ``To Allah." Say, ``Then will you not remember?"\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmdcclix{%
Say, ``Who is Lord of the seven heavens and Lord of the Great Throne?"\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmdcclx{%
They will say, ``[They belong] to Allah." Say, ``Then will you not fear Him?"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmdcclxi{%
Say, ``In whose hand is the realm of all things - and He protects while none can protect against Him - if you should know?"\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmdcclxii{%
They will say, ``[All belongs] to Allah." Say, ``Then how are you deluded?"\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmdcclxiii{%
Rather, We have brought them the truth, and indeed they are liars.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmdcclxiv{%
Allah has not taken any son, nor has there ever been with Him any deity. [If there had been], then each deity would have taken what it created, and some of them would have sought to overcome others. Exalted is Allah above what they describe [concerning Him].\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmdcclxv{%
[He is] Knower of the unseen and the witnessed, so high is He above what they associate [with Him].\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmdcclxvi{%
Say, [O Muhammad], ``My Lord, if You should show me that which they are promised,\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmdcclxvii{%
My Lord, then do not place me among the wrongdoing people."\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmdcclxviii{%
And indeed, We are able to show you what We have promised them.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmdcclxix{%
Repel, by [means of] what is best, [their] evil. We are most knowing of what they describe.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmdcclxx{%
And say, ``My Lord, I seek refuge in You from the incitements of the devils,\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmdcclxxi{%
And I seek refuge in You, my Lord, lest they be present with me."\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmdcclxxii{%
[For such is the state of the disbelievers], until, when death comes to one of them, he says, ``My Lord, send me back\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmdcclxxiii{%
That I might do righteousness in that which I left behind." No! It is only a word he is saying; and behind them is a barrier until the Day they are resurrected.\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmdcclxxiv{%
So when the Horn is blown, no relationship will there be among them that Day, nor will they ask about one another.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmdcclxxv{%
And those whose scales are heavy [with good deeds] - it is they who are the successful.\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmdcclxxvi{%
But those whose scales are light - those are the ones who have lost their souls, [being] in Hell, abiding eternally.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmdcclxxvii{%
The Fire will sear their faces, and they therein will have taut smiles.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmdcclxxviii{%
[It will be said]. ``Were not My verses recited to you and you used to deny them?"\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmdcclxxix{%
They will say, ``Our Lord, our wretchedness overcame us, and we were a people astray.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmdcclxxx{%
Our Lord, remove us from it, and if we were to return [to evil], we would indeed be wrongdoers."\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmdcclxxxi{%
He will say, ``Remain despised therein and do not speak to Me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmdcclxxxii{%
Indeed, there was a party of My servants who said, 'Our Lord, we have believed, so forgive us and have mercy upon us, and You are the best of the merciful.'\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiii{%
But you took them in mockery to the point that they made you forget My remembrance, and you used to laugh at them.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmdcclxxxiv{%
Indeed, I have rewarded them this Day for their patient endurance - that they are the attainers [of success]."\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmdcclxxxv{%
[Allah] will say, ``How long did you remain on earth in number of years?"\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvi{%
They will say, ``We remained a day or part of a day; ask those who enumerate."\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmdcclxxxvii{%
He will say, ``You stayed not but a little - if only you had known.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmdcclxxxviii{%
Then did you think that We created you uselessly and that to Us you would not be returned?"\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmdcclxxxix{%
So exalted is Allah, the Sovereign, the Truth; there is no deity except Him, Lord of the Noble Throne.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmdccxc{%
And whoever invokes besides Allah another deity for which he has no proof - then his account is only with his Lord. Indeed, the disbelievers will not succeed.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmdccxci{%
And, [O Muhammad], say, ``My Lord, forgive and have mercy, and You are the best of the merciful."\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmdccxcii{%
\basmalahen [This is] a surah which We have sent down and made [that within it] obligatory and revealed therein verses of clear evidence that you might remember.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccxciii{%
The [unmarried] woman or [unmarried] man found guilty of sexual intercourse - lash each one of them with a hundred lashes, and do not be taken by pity for them in the religion of Allah, if you should believe in Allah and the Last Day. And let a group of the believers witness their punishment.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccxciv{%
The fornicator does not marry except a [female] fornicator or polytheist, and none marries her except a fornicator or a polytheist, and that has been made unlawful to the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccxcv{%
And those who accuse chaste women and then do not produce four witnesses - lash them with eighty lashes and do not accept from them testimony ever after. And those are the defiantly disobedient,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccxcvi{%
Except for those who repent thereafter and reform, for indeed, Allah is Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccxcvii{%
And those who accuse their wives [of adultery] and have no witnesses except themselves - then the witness of one of them [shall be] four testimonies [swearing] by Allah that indeed, he is of the truthful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccxcviii{%
And the fifth [oath will be] that the curse of Allah be upon him if he should be among the liars.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccxcix{%
But it will prevent punishment from her if she gives four testimonies [swearing] by Allah that indeed, he is of the liars.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccc{%
And the fifth [oath will be] that the wrath of Allah be upon her if he was of the truthful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccci{%
And if not for the favor of Allah upon you and His mercy... and because Allah is Accepting of repentance and Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdcccii{%
Indeed, those who came with falsehood are a group among you. Do not think it bad for you; rather it is good for you. For every person among them is what [punishment] he has earned from the sin, and he who took upon himself the greater portion thereof - for him is a great punishment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccciii{%
Why, when you heard it, did not the believing men and believing women think good of one another and say, ``This is an obvious falsehood"?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccciv{%
Why did they [who slandered] not produce for it four witnesses? And when they do not produce the witnesses, then it is they, in the sight of Allah, who are the liars.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdcccv{%
And if it had not been for the favor of Allah upon you and His mercy in this world and the Hereafter, you would have been touched for that [lie] in which you were involved by a great punishment\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdcccvi{%
When you received it with your tongues and said with your mouths that of which you had no knowledge and thought it was insignificant while it was, in the sight of Allah, tremendous.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdcccvii{%
And why, when you heard it, did you not say, ``It is not for us to speak of this. Exalted are You, [O Allah]; this is a great slander"?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdcccviii{%
Allah warns you against returning to the likes of this [conduct], ever, if you should be believers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdcccix{%
And Allah makes clear to you the verses, and Allah is Knowing and Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdcccx{%
Indeed, those who like that immorality should be spread [or publicized] among those who have believed will have a painful punishment in this world and the Hereafter. And Allah knows and you do not know.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdcccxi{%
And if it had not been for the favor of Allah upon you and His mercy... and because Allah is Kind and Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdcccxii{%
O you who have believed, do not follow the footsteps of Satan. And whoever follows the footsteps of Satan - indeed, he enjoins immorality and wrongdoing. And if not for the favor of Allah upon you and His mercy, not one of you would have been pure, ever, but Allah purifies whom He wills, and Allah is Hearing and Knowing.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdcccxiii{%
And let not those of virtue among you and wealth swear not to give [aid] to their relatives and the needy and the emigrants for the cause of Allah, and let them pardon and overlook. Would you not like that Allah should forgive you? And Allah is Forgiving and Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdcccxiv{%
Indeed, those who [falsely] accuse chaste, unaware and believing women are cursed in this world and the Hereafter; and they will have a great punishment\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdcccxv{%
On a Day when their tongues, their hands and their feet will bear witness against them as to what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdcccxvi{%
That Day, Allah will pay them in full their deserved recompense, and they will know that it is Allah who is the perfect in justice.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdcccxvii{%
Evil words are for evil men, and evil men are [subjected] to evil words. And good words are for good men, and good men are [an object] of good words. Those [good people] are declared innocent of what the slanderers say. For them is forgiveness and noble provision.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdcccxviii{%
O you who have believed, do not enter houses other than your own houses until you ascertain welcome and greet their inhabitants. That is best for you; perhaps you will be reminded.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdcccxix{%
And if you do not find anyone therein, do not enter them until permission has been given you. And if it is said to you, ``Go back," then go back; it is purer for you. And Allah is Knowing of what you do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdcccxx{%
There is no blame upon you for entering houses not inhabited in which there is convenience for you. And Allah knows what you reveal and what you conceal.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdcccxxi{%
Tell the believing men to reduce [some] of their vision and guard their private parts. That is purer for them. Indeed, Allah is Acquainted with what they do.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdcccxxii{%
And tell the believing women to reduce [some] of their vision and guard their private parts and not expose their adornment except that which [necessarily] appears thereof and to wrap [a portion of] their headcovers over their chests and not expose their adornment except to their husbands, their fathers, their husbands' fathers, their sons, their husbands' sons, their brothers, their brothers' sons, their sisters' sons, their women, that which their right hands possess, or those male attendants having no physical desire, or children who are not yet aware of the private aspects of women. And let them not stamp their feet to make known what they conceal of their adornment. And turn to Allah in repentance, all of you, O believers, that you might succeed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdcccxxiii{%
And marry the unmarried among you and the righteous among your male slaves and female slaves. If they should be poor, Allah will enrich them from His bounty, and Allah is all-Encompassing and Knowing.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdcccxxiv{%
But let them who find not [the means for] marriage abstain [from sexual relations] until Allah enriches them from His bounty. And those who seek a contract [for eventual emancipation] from among whom your right hands possess - then make a contract with them if you know there is within them goodness and give them from the wealth of Allah which He has given you. And do not compel your slave girls to prostitution, if they desire chastity, to seek [thereby] the temporary interests of worldly life. And if someone should compel them, then indeed, Allah is [to them], after their compulsion, Forgiving and Merciful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdcccxxv{%
And We have certainly sent down to you distinct verses and examples from those who passed on before you and an admonition for those who fear Allah.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxxvi{%
Allah is the Light of the heavens and the earth. The example of His light is like a niche within which is a lamp, the lamp is within glass, the glass as if it were a pearly [white] star lit from [the oil of] a blessed olive tree, neither of the east nor of the west, whose oil would almost glow even if untouched by fire. Light upon light. Allah guides to His light whom He wills. And Allah presents examples for the people, and Allah is Knowing of all things.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxxvii{%
[Such niches are] in mosques which Allah has ordered to be raised and that His name be mentioned therein; exalting Him within them in the morning and the evenings\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxxviii{%
[Are] men whom neither commerce nor sale distracts from the remembrance of Allah and performance of prayer and giving of zakah. They fear a Day in which the hearts and eyes will [fearfully] turn about -\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxxix{%
That Allah may reward them [according to] the best of what they did and increase them from His bounty. And Allah gives provision to whom He wills without account.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxxx{%
But those who disbelieved - their deeds are like a mirage in a lowland which a thirsty one thinks is water until, when he comes to it, he finds it is nothing but finds Allah before Him, and He will pay him in full his due; and Allah is swift in account.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxxxi{%
Or [they are] like darknesses within an unfathomable sea which is covered by waves, upon which are waves, over which are clouds - darknesses, some of them upon others. When one puts out his hand [therein], he can hardly see it. And he to whom Allah has not granted light - for him there is no light.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxxxii{%
Do you not see that Allah is exalted by whomever is within the heavens and the earth and [by] the birds with wings spread [in flight]? Each [of them] has known his [means of] prayer and exalting [Him], and Allah is Knowing of what they do.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiii{%
And to Allah belongs the dominion of the heavens and the earth, and to Allah is the destination.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxxxiv{%
Do you not see that Allah drives clouds? Then He brings them together, then He makes them into a mass, and you see the rain emerge from within it. And He sends down from the sky, mountains [of clouds] within which is hail, and He strikes with it whom He wills and averts it from whom He wills. The flash of its lightening almost takes away the eyesight.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxxxv{%
Allah alternates the night and the day. Indeed in that is a lesson for those who have vision.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvi{%
Allah has created every [living] creature from water. And of them are those that move on their bellies, and of them are those that walk on two legs, and of them are those that walk on four. Allah creates what He wills. Indeed, Allah is over all things competent.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmdcccxxxvii{%
We have certainly sent down distinct verses. And Allah guides whom He wills to a straight path.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmdcccxxxviii{%
But the hypocrites say, ``We have believed in Allah and in the Messenger, and we obey"; then a party of them turns away after that. And those are not believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmdcccxxxix{%
And when they are called to [the words of] Allah and His Messenger to judge between them, at once a party of them turns aside [in refusal].\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmdcccxl{%
But if the right is theirs, they come to him in prompt obedience.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmdcccxli{%
Is there disease in their hearts? Or have they doubted? Or do they fear that Allah will be unjust to them, or His Messenger? Rather, it is they who are the wrongdoers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmdcccxlii{%
The only statement of the [true] believers when they are called to Allah and His Messenger to judge between them is that they say, ``We hear and we obey." And those are the successful.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmdcccxliii{%
And whoever obeys Allah and His Messenger and fears Allah and is conscious of Him - it is those who are the attainers.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmdcccxliv{%
And they swear by Allah their strongest oaths that if you ordered them, they would go forth [in Allah 's cause]. Say, ``Do not swear. [Such] obedience is known. Indeed, Allah is Acquainted with that which you do."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmdcccxlv{%
Say, ``Obey Allah and obey the Messenger; but if you turn away - then upon him is only that [duty] with which he has been charged, and upon you is that with which you have been charged. And if you obey him, you will be [rightly] guided. And there is not upon the Messenger except the [responsibility for] clear notification."\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmdcccxlvi{%
Allah has promised those who have believed among you and done righteous deeds that He will surely grant them succession [to authority] upon the earth just as He granted it to those before them and that He will surely establish for them [therein] their religion which He has preferred for them and that He will surely substitute for them, after their fear, security, [for] they worship Me, not associating anything with Me. But whoever disbelieves after that - then those are the defiantly disobedient.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmdcccxlvii{%
And establish prayer and give zakah and obey the Messenger - that you may receive mercy.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmdcccxlviii{%
Never think that the disbelievers are causing failure [to Allah] upon the earth. Their refuge will be the Fire - and how wretched the destination.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmdcccxlix{%
O you who have believed, let those whom your right hands possess and those who have not [yet] reached puberty among you ask permission of you [before entering] at three times: before the dawn prayer and when you put aside your clothing [for rest] at noon and after the night prayer. [These are] three times of privacy for you. There is no blame upon you nor upon them beyond these [periods], for they continually circulate among you - some of you, among others. Thus does Allah make clear to you the verses; and Allah is Knowing and Wise.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmdcccl{%
And when the children among you reach puberty, let them ask permission [at all times] as those before them have done. Thus does Allah make clear to you His verses; and Allah is Knowing and Wise.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmdcccli{%
And women of post-menstrual age who have no desire for marriage - there is no blame upon them for putting aside their outer garments [but] not displaying adornment. But to modestly refrain [from that] is better for them. And Allah is Hearing and Knowing.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmdccclii{%
There is not upon the blind [any] constraint nor upon the lame constraint nor upon the ill constraint nor upon yourselves when you eat from your [own] houses or the houses of your fathers or the houses of your mothers or the houses of your brothers or the houses of your sisters or the houses of your father's brothers or the houses of your father's sisters or the houses of your mother's brothers or the houses of your mother's sisters or [from houses] whose keys you possess or [from the house] of your friend. There is no blame upon you whether you eat together or separately. But when you enter houses, give greetings of peace upon each other - a greeting from Allah, blessed and good. Thus does Allah make clear to you the verses [of ordinance] that you may understand.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmdcccliii{%
The believers are only those who believe in Allah and His Messenger and, when they are [meeting] with him for a matter of common interest, do not depart until they have asked his permission. Indeed, those who ask your permission, [O Muhammad] - those are the ones who believe in Allah and His Messenger. So when they ask your permission for something of their affairs, then give permission to whom you will among them and ask forgiveness for them of Allah. Indeed, Allah is Forgiving and Merciful.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmdcccliv{%
Do not make [your] calling of the Messenger among yourselves as the call of one of you to another. Already Allah knows those of you who slip away, concealed by others. So let those beware who dissent from the Prophet's order, lest fitnah strike them or a painful punishment.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmdccclv{%
Unquestionably, to Allah belongs whatever is in the heavens and earth. Already He knows that upon which you [stand] and [knows] the Day when they will be returned to Him and He will inform them of what they have done. And Allah is Knowing of all things.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmdccclvi{%
\basmalahen Blessed is He who sent down the Criterion upon His Servant that he may be to the worlds a warner -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmdccclvii{%
He to whom belongs the dominion of the heavens and the earth and who has not taken a son and has not had a partner in dominion and has created each thing and determined it with [precise] determination.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmdccclviii{%
But they have taken besides Him gods which create nothing, while they are created, and possess not for themselves any harm or benefit and possess not [power to cause] death or life or resurrection.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmdccclix{%
And those who disbelieve say, ``This [Qur'an] is not except a falsehood he invented, and another people assisted him in it." But they have committed an injustice and a lie.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmdccclx{%
And they say, ``Legends of the former peoples which he has written down, and they are dictated to him morning and afternoon."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmdccclxi{%
Say, [O Muhammad], ``It has been revealed by He who knows [every] secret within the heavens and the earth. Indeed, He is ever Forgiving and Merciful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmdccclxii{%
And they say, ``What is this messenger that eats food and walks in the markets? Why was there not sent down to him an angel so he would be with him a warner?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmdccclxiii{%
Or [why is not] a treasure presented to him [from heaven], or does he [not] have a garden from which he eats?" And the wrongdoers say, ``You follow not but a man affected by magic."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmdccclxiv{%
Look how they strike for you comparisons; but they have strayed, so they cannot [find] a way.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmdccclxv{%
Blessed is He who, if He willed, could have made for you [something] better than that - gardens beneath which rivers flow - and could make for you palaces.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmdccclxvi{%
But they have denied the Hour, and We have prepared for those who deny the Hour a Blaze.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmdccclxvii{%
When the Hellfire sees them from a distant place, they will hear its fury and roaring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmdccclxviii{%
And when they are thrown into a narrow place therein bound in chains, they will cry out thereupon for destruction.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmdccclxix{%
[They will be told], ``Do not cry this Day for one destruction but cry for much destruction."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmdccclxx{%
Say, ``Is that better or the Garden of Eternity which is promised to the righteous? It will be for them a reward and destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmdccclxxi{%
For them therein is whatever they wish, [while] abiding eternally. It is ever upon your Lord a promise [worthy to be] requested.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmdccclxxii{%
And [mention] the Day He will gather them and that which they worship besides Allah and will say, ``Did you mislead these, My servants, or did they [themselves] stray from the way?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmdccclxxiii{%
They will say, ``Exalted are You! It was not for us to take besides You any allies. But You provided comforts for them and their fathers until they forgot the message and became a people ruined."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmdccclxxiv{%
So they will deny you, [disbelievers], in what you say, and you cannot avert [punishment] or [find] help. And whoever commits injustice among you - We will make him taste a great punishment.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmdccclxxv{%
And We did not send before you, [O Muhammad], any of the messengers except that they ate food and walked in the markets. And We have made some of you [people] as trial for others - will you have patience? And ever is your Lord, Seeing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmdccclxxvi{%
And those who do not expect the meeting with Us say, ``Why were not angels sent down to us, or [why] do we [not] see our Lord?" They have certainly become arrogant within themselves and [become] insolent with great insolence.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmdccclxxvii{%
The day they see the angels - no good tidings will there be that day for the criminals, and [the angels] will say, ``Prevented and inaccessible."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmdccclxxviii{%
And We will regard what they have done of deeds and make them as dust dispersed.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmdccclxxix{%
The companions of Paradise, that Day, are [in] a better settlement and better resting place.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmdccclxxx{%
And [mention] the Day when the heaven will split open with [emerging] clouds, and the angels will be sent down in successive descent.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmdccclxxxi{%
True sovereignty, that Day, is for the Most Merciful. And it will be upon the disbelievers a difficult Day.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmdccclxxxii{%
And the Day the wrongdoer will bite on his hands [in regret] he will say, ``Oh, I wish I had taken with the Messenger a way.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiii{%
Oh, woe to me! I wish I had not taken that one as a friend.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmdccclxxxiv{%
He led me away from the remembrance after it had come to me. And ever is Satan, to man, a deserter."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmdccclxxxv{%
And the Messenger has said, ``O my Lord, indeed my people have taken this Qur'an as [a thing] abandoned."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvi{%
And thus have We made for every prophet an enemy from among the criminals. But sufficient is your Lord as a guide and a helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmdccclxxxvii{%
And those who disbelieve say, ``Why was the Qur'an not revealed to him all at once?" Thus [it is] that We may strengthen thereby your heart. And We have spaced it distinctly.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmdccclxxxviii{%
And they do not come to you with an argument except that We bring you the truth and the best explanation.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmdccclxxxix{%
The ones who are gathered on their faces to Hell - those are the worst in position and farthest astray in [their] way.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmdcccxc{%
And We had certainly given Moses the Scripture and appointed with him his brother Aaron as an assistant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmdcccxci{%
And We said, ``Go both of you to the people who have denied Our signs." Then We destroyed them with [complete] destruction.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmdcccxcii{%
And the people of Noah - when they denied the messengers, We drowned them, and We made them for mankind a sign. And We have prepared for the wrongdoers a painful punishment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmdcccxciii{%
And [We destroyed] 'Aad and Thamud and the companions of the well and many generations between them.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmdcccxciv{%
And for each We presented examples [as warnings], and each We destroyed with [total] destruction.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmdcccxcv{%
And they have already come upon the town which was showered with a rain of evil. So have they not seen it? But they are not expecting resurrection.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmdcccxcvi{%
And when they see you, [O Muhammad], they take you not except in ridicule, [saying], ``Is this the one whom Allah has sent as a messenger?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmdcccxcvii{%
He almost would have misled us from our gods had we not been steadfast in [worship of] them." But they are going to know, when they see the punishment, who is farthest astray in [his] way.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmdcccxcviii{%
Have you seen the one who takes as his god his own desire? Then would you be responsible for him?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmdcccxcix{%
Or do you think that most of them hear or reason? They are not except like livestock. Rather, they are [even] more astray in [their] way.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcm{%
Have you not considered your Lord - how He extends the shadow, and if He willed, He could have made it stationary? Then We made the sun for it an indication.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmi{%
Then We hold it in hand for a brief grasp.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmii{%
And it is He who has made the night for you as clothing and sleep [a means for] rest and has made the day a resurrection.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmiii{%
And it is He who sends the winds as good tidings before His mercy, and We send down from the sky pure water\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmiv{%
That We may bring to life thereby a dead land and give it as drink to those We created of numerous livestock and men.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmv{%
And We have certainly distributed it among them that they might be reminded, but most of the people refuse except disbelief.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmvi{%
And if We had willed, We could have sent into every city a warner.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmvii{%
So do not obey the disbelievers, and strive against them with the Qur'an a great striving.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmviii{%
And it is He who has released [simultaneously] the two seas, one fresh and sweet and one salty and bitter, and He placed between them a barrier and prohibiting partition.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmix{%
And it is He who has created from water a human being and made him [a relative by] lineage and marriage. And ever is your Lord competent [concerning creation].\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmx{%
But they worship rather than Allah that which does not benefit them or harm them, and the disbeliever is ever, against his Lord, an assistant [to Satan].\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmxi{%
And We have not sent you, [O Muhammad], except as a bringer of good tidings and a warner.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmxii{%
Say, ``I do not ask of you for it any payment - only that whoever wills might take to his Lord a way."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxiii{%
And rely upon the Ever-Living who does not die, and exalt [Allah] with His praise. And sufficient is He to be, with the sins of His servants, Acquainted -\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxiv{%
He who created the heavens and the earth and what is between them in six days and then established Himself above the Throne - the Most Merciful, so ask about Him one well informed.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxv{%
And when it is said to them, ``Prostrate to the Most Merciful," they say, ``And what is the Most Merciful? Should we prostrate to that which you order us?" And it increases them in aversion.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxvi{%
Blessed is He who has placed in the sky great stars and placed therein a [burning] lamp and luminous moon.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxvii{%
And it is He who has made the night and the day in succession for whoever desires to remember or desires gratitude.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxviii{%
And the servants of the Most Merciful are those who walk upon the earth easily, and when the ignorant address them [harshly], they say [words of] peace,\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxix{%
And those who spend [part of] the night to their Lord prostrating and standing [in prayer]\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxx{%
And those who say, ``Our Lord, avert from us the punishment of Hell. Indeed, its punishment is ever adhering;\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxxi{%
Indeed, it is evil as a settlement and residence."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxxii{%
And [they are] those who, when they spend, do so not excessively or sparingly but are ever, between that, [justly] moderate\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmcmxxiii{%
And those who do not invoke with Allah another deity or kill the soul which Allah has forbidden [to be killed], except by right, and do not commit unlawful sexual intercourse. And whoever should do that will meet a penalty.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmcmxxiv{%
Multiplied for him is the punishment on the Day of Resurrection, and he will abide therein humiliated -\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmcmxxv{%
Except for those who repent, believe and do righteous work. For them Allah will replace their evil deeds with good. And ever is Allah Forgiving and Merciful.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmcmxxvi{%
And he who repents and does righteousness does indeed turn to Allah with [accepted] repentance.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmcmxxvii{%
And [they are] those who do not testify to falsehood, and when they pass near ill speech, they pass by with dignity.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmcmxxviii{%
And those who, when reminded of the verses of their Lord, do not fall upon them deaf and blind.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmcmxxix{%
And those who say, ``Our Lord, grant us from among our wives and offspring comfort to our eyes and make us an example for the righteous."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmcmxxx{%
Those will be awarded the Chamber for what they patiently endured, and they will be received therein with greetings and [words of] peace.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmcmxxxi{%
Abiding eternally therein. Good is the settlement and residence.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmcmxxxii{%
Say, ``What would my Lord care for you if not for your supplication?" For you [disbelievers] have denied, so your denial is going to be adherent.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmcmxxxiii{%
\basmalahen Ta, Seen, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmcmxxxiv{%
These are the verses of the clear Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmcmxxxv{%
Perhaps, [O Muhammad], you would kill yourself with grief that they will not be believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmcmxxxvi{%
If We willed, We could send down to them from the sky a sign for which their necks would remain humbled.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmcmxxxvii{%
And no revelation comes to them anew from the Most Merciful except that they turn away from it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmcmxxxviii{%
For they have already denied, but there will come to them the news of that which they used to ridicule.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmcmxxxix{%
Did they not look at the earth - how much We have produced therein from every noble kind?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmcmxl{%
Indeed in that is a sign, but most of them were not to be believers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmcmxli{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmcmxlii{%
And [mention] when your Lord called Moses, [saying], ``Go to the wrongdoing people -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmcmxliii{%
The people of Pharaoh. Will they not fear Allah?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmcmxliv{%
He said, ``My Lord, indeed I fear that they will deny me\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmcmxlv{%
And that my breast will tighten and my tongue will not be fluent, so send for Aaron.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmcmxlvi{%
And they have upon me a [claim due to] sin, so I fear that they will kill me."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmcmxlvii{%
[Allah] said, ``No. Go both of you with Our signs; indeed, We are with you, listening.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmcmxlviii{%
Go to Pharaoh and say, 'We are the messengers of the Lord of the worlds,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmcmxlix{%
[Commanded to say], ``Send with us the Children of Israel."'"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmcml{%
[Pharaoh] said, ``Did we not raise you among us as a child, and you remained among us for years of your life?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmcmli{%
And [then] you did your deed which you did, and you were of the ungrateful."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmcmlii{%
[Moses] said, ``I did it, then, while I was of those astray.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmcmliii{%
So I fled from you when I feared you. Then my Lord granted me wisdom and prophethood and appointed me [as one] of the messengers.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmcmliv{%
And is this a favor of which you remind me - that you have enslaved the Children of Israel?"\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmcmlv{%
Said Pharaoh, ``And what is the Lord of the worlds?"\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmcmlvi{%
[Moses] said, ``The Lord of the heavens and earth and that between them, if you should be convinced."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmcmlvii{%
[Pharaoh] said to those around him, ``Do you not hear?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmcmlviii{%
[Moses] said, ``Your Lord and the Lord of your first forefathers."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmcmlix{%
[Pharaoh] said, ``Indeed, your 'messenger' who has been sent to you is mad."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmcmlx{%
[Moses] said, ``Lord of the east and the west and that between them, if you were to reason."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmcmlxi{%
[Pharaoh] said, ``If you take a god other than me, I will surely place you among those imprisoned."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmcmlxii{%
[Moses] said, ``Even if I brought you proof manifest?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmcmlxiii{%
[Pharaoh] said, ``Then bring it, if you should be of the truthful."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmcmlxiv{%
So [Moses] threw his staff, and suddenly it was a serpent manifest.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmcmlxv{%
And he drew out his hand; thereupon it was white for the observers.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmcmlxvi{%
[Pharaoh] said to the eminent ones around him, ``Indeed, this is a learned magician.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmcmlxvii{%
He wants to drive you out of your land by his magic, so what do you advise?"\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmcmlxviii{%
They said, ``Postpone [the matter of] him and his brother and send among the cities gatherers\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmcmlxix{%
Who will bring you every learned, skilled magician."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmcmlxx{%
So the magicians were assembled for the appointment of a well-known day.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmcmlxxi{%
And it was said to the people, ``Will you congregate\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmcmlxxii{%
That we might follow the magicians if they are the predominant?"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmcmlxxiii{%
And when the magicians arrived, they said to Pharaoh, ``Is there indeed for us a reward if we are the predominant?"\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmcmlxxiv{%
He said, ``Yes, and indeed, you will then be of those near [to me]."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmcmlxxv{%
Moses said to them, ``Throw whatever you will throw."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmcmlxxvi{%
So they threw their ropes and their staffs and said, ``By the might of Pharaoh, indeed it is we who are predominant."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmcmlxxvii{%
Then Moses threw his staff, and at once it devoured what they falsified.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmcmlxxviii{%
So the magicians fell down in prostration [to Allah].\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmcmlxxix{%
They said, ``We have believed in the Lord of the worlds,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmcmlxxx{%
The Lord of Moses and Aaron."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmcmlxxxi{%
[Pharaoh] said, ``You believed Moses before I gave you permission. Indeed, he is your leader who has taught you magic, but you are going to know. I will surely cut off your hands and your feet on opposite sides, and I will surely crucify you all."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmcmlxxxii{%
They said, ``No harm. Indeed, to our Lord we will return.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiii{%
Indeed, we aspire that our Lord will forgive us our sins because we were the first of the believers."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmcmlxxxiv{%
And We inspired to Moses, ``Travel by night with My servants; indeed, you will be pursued."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmcmlxxxv{%
Then Pharaoh sent among the cities gatherers\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvi{%
[And said], ``Indeed, those are but a small band,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmcmlxxxvii{%
And indeed, they are enraging us,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmcmlxxxviii{%
And indeed, we are a cautious society... ``\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmcmlxxxix{%
So We removed them from gardens and springs\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmcmxc{%
And treasures and honorable station -\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmcmxci{%
Thus. And We caused to inherit it the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmcmxcii{%
So they pursued them at sunrise.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmcmxciii{%
And when the two companies saw one another, the companions of Moses said, ``Indeed, we are to be overtaken!"\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmcmxciv{%
[Moses] said, ``No! Indeed, with me is my Lord; He will guide me."\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmcmxcv{%
Then We inspired to Moses, ``Strike with your staff the sea," and it parted, and each portion was like a great towering mountain.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmcmxcvi{%
And We advanced thereto the pursuers.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmcmxcvii{%
And We saved Moses and those with him, all together.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmcmxcviii{%
Then We drowned the others.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmcmxcix{%
Indeed in that is a sign, but most of them were not to be believers.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmm{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmi{%
And recite to them the news of Abraham,\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmii{%
When he said to his father and his people, ``What do you worship?"\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmiii{%
They said, ``We worship idols and remain to them devoted."\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmiv{%
He said, ``Do they hear you when you supplicate?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmv{%
Or do they benefit you, or do they harm?"\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmvi{%
They said, ``But we found our fathers doing thus."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmvii{%
He said, ``Then do you see what you have been worshipping,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmviii{%
You and your ancient forefathers?\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmix{%
Indeed, they are enemies to me, except the Lord of the worlds,\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmx{%
Who created me, and He [it is who] guides me.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmxi{%
And it is He who feeds me and gives me drink.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmxii{%
And when I am ill, it is He who cures me\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmxiii{%
And who will cause me to die and then bring me to life\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmxiv{%
And who I aspire that He will forgive me my sin on the Day of Recompense."\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmxv{%
[And he said], ``My Lord, grant me authority and join me with the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmxvi{%
And grant me a reputation of honor among later generations.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmxvii{%
And place me among the inheritors of the Garden of Pleasure.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmxviii{%
And forgive my father. Indeed, he has been of those astray.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmxix{%
And do not disgrace me on the Day they are [all] resurrected -\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmxx{%
The Day when there will not benefit [anyone] wealth or children\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmxxi{%
But only one who comes to Allah with a sound heart."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmxxii{%
And Paradise will be brought near [that Day] to the righteous.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmxxiii{%
And Hellfire will be brought forth for the deviators,\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmxxiv{%
And it will be said to them, ``Where are those you used to worship\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmxxv{%
Other than Allah? Can they help you or help themselves?"\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmxxvi{%
So they will be overturned into Hellfire, they and the deviators\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmxxvii{%
And the soldiers of Iblees, all together.\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmxxviii{%
They will say while they dispute therein,\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmxxix{%
``By Allah, we were indeed in manifest error\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmxxx{%
When we equated you with the Lord of the worlds.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmxxxi{%
And no one misguided us except the criminals.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmxxxii{%
So now we have no intercessors\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmxxxiii{%
And not a devoted friend.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmxxxiv{%
Then if we only had a return [to the world] and could be of the believers... ``\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmxxxv{%
Indeed in that is a sign, but most of them were not to be believers.\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmxxxvi{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmxxxvii{%
The people of Noah denied the messengers\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmxxxviii{%
When their brother Noah said to them, ``Will you not fear Allah?\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmxxxix{%
Indeed, I am to you a trustworthy messenger.\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmxl{%
So fear Allah and obey me.\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmxli{%
And I do not ask you for it any payment. My payment is only from the Lord of the worlds.\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmxlii{%
So fear Allah and obey me."\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmxliii{%
They said, ``Should we believe you while you are followed by the lowest [class of people]?"\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmxliv{%
He said, ``And what is my knowledge of what they used to do?\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmxlv{%
Their account is only upon my Lord, if you [could] perceive.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmxlvi{%
And I am not one to drive away the believers.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmxlvii{%
I am only a clear warner."\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmxlviii{%
They said, ``If you do not desist, O Noah, you will surely be of those who are stoned."\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmxlix{%
He said, ``My Lord, indeed my people have denied me.\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmml{%
Then judge between me and them with decisive judgement and save me and those with me of the believers."\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmli{%
So We saved him and those with him in the laden ship.\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmlii{%
Then We drowned thereafter the remaining ones.\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmliii{%
Indeed in that is a sign, but most of them were not to be believers.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmliv{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmlv{%
'Aad denied the messengers\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmlvi{%
When their brother Hud said to them, ``Will you not fear Allah?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmlvii{%
Indeed, I am to you a trustworthy messenger.\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmlviii{%
So fear Allah and obey me.\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmlix{%
And I do not ask you for it any payment. My payment is only from the Lord of the worlds.\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmlx{%
Do you construct on every elevation a sign, amusing yourselves,\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmlxi{%
And take for yourselves palaces and fortresses that you might abide eternally?\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmlxii{%
And when you strike, you strike as tyrants.\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmlxiii{%
So fear Allah and obey me.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmlxiv{%
And fear He who provided you with that which you know,\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmlxv{%
Provided you with grazing livestock and children\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmlxvi{%
And gardens and springs.\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmlxvii{%
Indeed, I fear for you the punishment of a terrible day."\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmlxviii{%
They said, ``It is all the same to us whether you advise or are not of the advisors.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmlxix{%
This is not but the custom of the former peoples,\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmlxx{%
And we are not to be punished."\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmlxxi{%
And they denied him, so We destroyed them. Indeed in that is a sign, but most of them were not to be believers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmlxxii{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmlxxiii{%
Thamud denied the messengers\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmlxxiv{%
When their brother Salih said to them, ``Will you not fear Allah?\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmlxxv{%
Indeed, I am to you a trustworthy messenger.\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmlxxvi{%
So fear Allah and obey me.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmlxxvii{%
And I do not ask you for it any payment. My payment is only from the Lord of the worlds.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmlxxviii{%
Will you be left in what is here, secure [from death],\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmlxxix{%
Within gardens and springs\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmlxxx{%
And fields of crops and palm trees with softened fruit?\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmlxxxi{%
And you carve out of the mountains, homes, with skill.\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmlxxxii{%
So fear Allah and obey me.\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmlxxxiii{%
And do not obey the order of the transgressors,\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmlxxxiv{%
Who cause corruption in the land and do not amend."\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmlxxxv{%
They said, ``You are only of those affected by magic.\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmlxxxvi{%
You are but a man like ourselves, so bring a sign, if you should be of the truthful."\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmlxxxvii{%
He said, ``This is a she-camel. For her is a [time of] drink, and for you is a [time of] drink, [each] on a known day.\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmlxxxviii{%
And do not touch her with harm, lest you be seized by the punishment of a terrible day."\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmlxxxix{%
But they hamstrung her and so became regretful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmxc{%
And the punishment seized them. Indeed in that is a sign, but most of them were not to be believers.\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmxci{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmxcii{%
The people of Lot denied the messengers\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmxciii{%
When their brother Lot said to them, ``Will you not fear Allah?\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmxciv{%
Indeed, I am to you a trustworthy messenger.\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmxcv{%
So fear Allah and obey me.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmxcvi{%
And I do not ask you for it any payment. My payment is only from the Lord of the worlds.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmxcvii{%
Do you approach males among the worlds\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmxcviii{%
And leave what your Lord has created for you as mates? But you are a people transgressing."\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmxcix{%
They said, ``If you do not desist, O Lot, you will surely be of those evicted."\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmc{%
He said, ``Indeed, I am, toward your deed, of those who detest [it].\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmci{%
My Lord, save me and my family from [the consequence of] what they do."\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcii{%
So We saved him and his family, all,\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmciii{%
Except an old woman among those who remained behind.\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmciv{%
Then We destroyed the others.\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcv{%
And We rained upon them a rain [of stones], and evil was the rain of those who were warned.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcvi{%
Indeed in that is a sign, but most of them were not to be believers.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcvii{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcviii{%
The companions of the thicket denied the messengers\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcix{%
When Shu'ayb said to them, ``Will you not fear Allah?\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcx{%
Indeed, I am to you a trustworthy messenger.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcxi{%
So fear Allah and obey me.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcxii{%
And I do not ask you for it any payment. My payment is only from the Lord of the worlds.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcxiii{%
Give full measure and do not be of those who cause loss.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcxiv{%
And weigh with an even balance.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcxv{%
And do not deprive people of their due and do not commit abuse on earth, spreading corruption.\qt@no{183}}%
\qt@newcmd\qurantrans@en@mmmcxvi{%
And fear He who created you and the former creation."\qt@no{184}}%
\qt@newcmd\qurantrans@en@mmmcxvii{%
They said, ``You are only of those affected by magic.\qt@no{185}}%
\qt@newcmd\qurantrans@en@mmmcxviii{%
You are but a man like ourselves, and indeed, we think you are among the liars.\qt@no{186}}%
\qt@newcmd\qurantrans@en@mmmcxix{%
So cause to fall upon us fragments of the sky, if you should be of the truthful."\qt@no{187}}%
\qt@newcmd\qurantrans@en@mmmcxx{%
He said, ``My Lord is most knowing of what you do."\qt@no{188}}%
\qt@newcmd\qurantrans@en@mmmcxxi{%
And they denied him, so the punishment of the day of the black cloud seized them. Indeed, it was the punishment of a terrible day.\qt@no{189}}%
\qt@newcmd\qurantrans@en@mmmcxxii{%
Indeed in that is a sign, but most of them were not to be believers.\qt@no{190}}%
\qt@newcmd\qurantrans@en@mmmcxxiii{%
And indeed, your Lord - He is the Exalted in Might, the Merciful.\qt@no{191}}%
\qt@newcmd\qurantrans@en@mmmcxxiv{%
And indeed, the Qur'an is the revelation of the Lord of the worlds.\qt@no{192}}%
\qt@newcmd\qurantrans@en@mmmcxxv{%
The Trustworthy Spirit has brought it down\qt@no{193}}%
\qt@newcmd\qurantrans@en@mmmcxxvi{%
Upon your heart, [O Muhammad] - that you may be of the warners -\qt@no{194}}%
\qt@newcmd\qurantrans@en@mmmcxxvii{%
In a clear Arabic language.\qt@no{195}}%
\qt@newcmd\qurantrans@en@mmmcxxviii{%
And indeed, it is [mentioned] in the scriptures of former peoples.\qt@no{196}}%
\qt@newcmd\qurantrans@en@mmmcxxix{%
And has it not been a sign to them that it is recognized by the scholars of the Children of Israel?\qt@no{197}}%
\qt@newcmd\qurantrans@en@mmmcxxx{%
And even if We had revealed it to one among the foreigners\qt@no{198}}%
\qt@newcmd\qurantrans@en@mmmcxxxi{%
And he had recited it to them [perfectly], they would [still] not have been believers in it.\qt@no{199}}%
\qt@newcmd\qurantrans@en@mmmcxxxii{%
Thus have We inserted disbelief into the hearts of the criminals.\qt@no{200}}%
\qt@newcmd\qurantrans@en@mmmcxxxiii{%
They will not believe in it until they see the painful punishment.\qt@no{201}}%
\qt@newcmd\qurantrans@en@mmmcxxxiv{%
And it will come to them suddenly while they perceive [it] not.\qt@no{202}}%
\qt@newcmd\qurantrans@en@mmmcxxxv{%
And they will say, ``May we be reprieved?"\qt@no{203}}%
\qt@newcmd\qurantrans@en@mmmcxxxvi{%
So for Our punishment are they impatient?\qt@no{204}}%
\qt@newcmd\qurantrans@en@mmmcxxxvii{%
Then have you considered if We gave them enjoyment for years\qt@no{205}}%
\qt@newcmd\qurantrans@en@mmmcxxxviii{%
And then there came to them that which they were promised?\qt@no{206}}%
\qt@newcmd\qurantrans@en@mmmcxxxix{%
They would not be availed by the enjoyment with which they were provided.\qt@no{207}}%
\qt@newcmd\qurantrans@en@mmmcxl{%
And We did not destroy any city except that it had warners\qt@no{208}}%
\qt@newcmd\qurantrans@en@mmmcxli{%
As a reminder; and never have We been unjust.\qt@no{209}}%
\qt@newcmd\qurantrans@en@mmmcxlii{%
And the devils have not brought the revelation down.\qt@no{210}}%
\qt@newcmd\qurantrans@en@mmmcxliii{%
It is not allowable for them, nor would they be able.\qt@no{211}}%
\qt@newcmd\qurantrans@en@mmmcxliv{%
Indeed they, from [its] hearing, are removed.\qt@no{212}}%
\qt@newcmd\qurantrans@en@mmmcxlv{%
So do not invoke with Allah another deity and [thus] be among the punished.\qt@no{213}}%
\qt@newcmd\qurantrans@en@mmmcxlvi{%
And warn, [O Muhammad], your closest kindred.\qt@no{214}}%
\qt@newcmd\qurantrans@en@mmmcxlvii{%
And lower your wing to those who follow you of the believers.\qt@no{215}}%
\qt@newcmd\qurantrans@en@mmmcxlviii{%
And if they disobey you, then say, ``Indeed, I am disassociated from what you are doing."\qt@no{216}}%
\qt@newcmd\qurantrans@en@mmmcxlix{%
And rely upon the Exalted in Might, the Merciful,\qt@no{217}}%
\qt@newcmd\qurantrans@en@mmmcl{%
Who sees you when you arise\qt@no{218}}%
\qt@newcmd\qurantrans@en@mmmcli{%
And your movement among those who prostrate.\qt@no{219}}%
\qt@newcmd\qurantrans@en@mmmclii{%
Indeed, He is the Hearing, the Knowing.\qt@no{220}}%
\qt@newcmd\qurantrans@en@mmmcliii{%
Shall I inform you upon whom the devils descend?\qt@no{221}}%
\qt@newcmd\qurantrans@en@mmmcliv{%
They descend upon every sinful liar.\qt@no{222}}%
\qt@newcmd\qurantrans@en@mmmclv{%
They pass on what is heard, and most of them are liars.\qt@no{223}}%
\qt@newcmd\qurantrans@en@mmmclvi{%
And the poets - [only] the deviators follow them;\qt@no{224}}%
\qt@newcmd\qurantrans@en@mmmclvii{%
Do you not see that in every valley they roam\qt@no{225}}%
\qt@newcmd\qurantrans@en@mmmclviii{%
And that they say what they do not do? -\qt@no{226}}%
\qt@newcmd\qurantrans@en@mmmclix{%
Except those [poets] who believe and do righteous deeds and remember Allah often and defend [the Muslims] after they were wronged. And those who have wronged are going to know to what [kind of] return they will be returned.\qt@no{227}}%
\qt@newcmd\qurantrans@en@mmmclx{%
\basmalahen Ta, Seen. These are the verses of the Qur'an and a clear Book\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmclxi{%
As guidance and good tidings for the believers\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmclxii{%
Who establish prayer and give zakah, and of the Hereafter they are certain [in faith].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmclxiii{%
Indeed, for those who do not believe in the Hereafter, We have made pleasing to them their deeds, so they wander blindly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmclxiv{%
Those are the ones for whom there will be the worst of punishment, and in the Hereafter they are the greatest losers.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmclxv{%
And indeed, [O Muhammad], you receive the Qur'an from one Wise and Knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmclxvi{%
[Mention] when Moses said to his family, ``Indeed, I have perceived a fire. I will bring you from there information or will bring you a burning torch that you may warm yourselves."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmclxvii{%
But when he came to it, he was called, ``Blessed is whoever is at the fire and whoever is around it. And exalted is Allah, Lord of the worlds.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmclxviii{%
O Moses, indeed it is I - Allah, the Exalted in Might, the Wise."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmclxix{%
And [he was told], ``Throw down your staff." But when he saw it writhing as if it were a snake, he turned in flight and did not return. [Allah said], ``O Moses, fear not. Indeed, in My presence the messengers do not fear.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmclxx{%
Otherwise, he who wrongs, then substitutes good after evil - indeed, I am Forgiving and Merciful.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmclxxi{%
And put your hand into the opening of your garment [at the breast]; it will come out white without disease. [These are] among the nine signs [you will take] to Pharaoh and his people. Indeed, they have been a people defiantly disobedient."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmclxxii{%
But when there came to them Our visible signs, they said, ``This is obvious magic."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmclxxiii{%
And they rejected them, while their [inner] selves were convinced thereof, out of injustice and haughtiness. So see how was the end of the corrupters.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmclxxiv{%
And We had certainly given to David and Solomon knowledge, and they said, ``Praise [is due] to Allah, who has favored us over many of His believing servants."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmclxxv{%
And Solomon inherited David. He said, ``O people, we have been taught the language of birds, and we have been given from all things. Indeed, this is evident bounty."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmclxxvi{%
And gathered for Solomon were his soldiers of the jinn and men and birds, and they were [marching] in rows.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmclxxvii{%
Until, when they came upon the valley of the ants, an ant said, ``O ants, enter your dwellings that you not be crushed by Solomon and his soldiers while they perceive not."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmclxxviii{%
So [Solomon] smiled, amused at her speech, and said, ``My Lord, enable me to be grateful for Your favor which You have bestowed upon me and upon my parents and to do righteousness of which You approve. And admit me by Your mercy into [the ranks of] Your righteous servants."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmclxxix{%
And he took attendance of the birds and said, ``Why do I not see the hoopoe - or is he among the absent?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmclxxx{%
I will surely punish him with a severe punishment or slaughter him unless he brings me clear authorization."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmclxxxi{%
But the hoopoe stayed not long and said, ``I have encompassed [in knowledge] that which you have not encompassed, and I have come to you from Sheba with certain news.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmclxxxii{%
Indeed, I found [there] a woman ruling them, and she has been given of all things, and she has a great throne.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmclxxxiii{%
I found her and her people prostrating to the sun instead of Allah, and Satan has made their deeds pleasing to them and averted them from [His] way, so they are not guided,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmclxxxiv{%
[And] so they do not prostrate to Allah, who brings forth what is hidden within the heavens and the earth and knows what you conceal and what you declare -\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmclxxxv{%
Allah - there is no deity except Him, Lord of the Great Throne."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmclxxxvi{%
[Solomon] said, ``We will see whether you were truthful or were of the liars.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmclxxxvii{%
Take this letter of mine and deliver it to them. Then leave them and see what [answer] they will return."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmclxxxviii{%
She said, ``O eminent ones, indeed, to me has been delivered a noble letter.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmclxxxix{%
Indeed, it is from Solomon, and indeed, it reads: 'In the name of Allah, the Entirely Merciful, the Especially Merciful,\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcxc{%
Be not haughty with me but come to me in submission [as Muslims].' ``\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcxci{%
She said, ``O eminent ones, advise me in my affair. I would not decide a matter until you witness [for] me."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcxcii{%
They said, ``We are men of strength and of great military might, but the command is yours, so see what you will command."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcxciii{%
She said, ``Indeed kings - when they enter a city, they ruin it and render the honored of its people humbled. And thus do they do.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcxciv{%
But indeed, I will send to them a gift and see with what [reply] the messengers will return."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcxcv{%
So when they came to Solomon, he said, ``Do you provide me with wealth? But what Allah has given me is better than what He has given you. Rather, it is you who rejoice in your gift.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcxcvi{%
Return to them, for we will surely come to them with soldiers that they will be powerless to encounter, and we will surely expel them therefrom in humiliation, and they will be debased."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcxcvii{%
[Solomon] said, ``O assembly [of jinn], which of you will bring me her throne before they come to me in submission?"\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcxcviii{%
A powerful one from among the jinn said, ``I will bring it to you before you rise from your place, and indeed, I am for this [task] strong and trustworthy."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcxcix{%
Said one who had knowledge from the Scripture, ``I will bring it to you before your glance returns to you." And when [Solomon] saw it placed before him, he said, ``This is from the favor of my Lord to test me whether I will be grateful or ungrateful. And whoever is grateful - his gratitude is only for [the benefit of] himself. And whoever is ungrateful - then indeed, my Lord is Free of need and Generous."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcc{%
He said, ``Disguise for her her throne; we will see whether she will be guided [to truth] or will be of those who is not guided."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcci{%
So when she arrived, it was said [to her], ``Is your throne like this?" She said, ``[It is] as though it was it." [Solomon said], ``And we were given knowledge before her, and we have been Muslims [in submission to Allah].\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccii{%
And that which she was worshipping other than Allah had averted her [from submission to Him]. Indeed, she was from a disbelieving people."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcciii{%
She was told, ``Enter the palace." But when she saw it, she thought it was a body of water and uncovered her shins [to wade through]. He said, ``Indeed, it is a palace [whose floor is] made smooth with glass." She said, ``My Lord, indeed I have wronged myself, and I submit with Solomon to Allah, Lord of the worlds."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcciv{%
And We had certainly sent to Thamud their brother Salih, [saying], ``Worship Allah," and at once they were two parties conflicting.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccv{%
He said, ``O my people, why are you impatient for evil instead of good? Why do you not seek forgiveness of Allah that you may receive mercy?"\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccvi{%
They said, ``We consider you a bad omen, you and those with you." He said, ``Your omen is with Allah. Rather, you are a people being tested."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccvii{%
And there were in the city nine family heads causing corruption in the land and not amending [its affairs].\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccviii{%
They said, ``Take a mutual oath by Allah that we will kill him by night, he and his family. Then we will say to his executor, 'We did not witness the destruction of his family, and indeed, we are truthful.' ``\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmccix{%
And they planned a plan, and We planned a plan, while they perceived not.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccx{%
Then look how was the outcome of their plan - that We destroyed them and their people, all.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccxi{%
So those are their houses, desolate because of the wrong they had done. Indeed in that is a sign for people who know.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmccxii{%
And We saved those who believed and used to fear Allah.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmccxiii{%
And [mention] Lot, when he said to his people, ``Do you commit immorality while you are seeing?\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmccxiv{%
Do you indeed approach men with desire instead of women? Rather, you are a people behaving ignorantly."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmccxv{%
But the answer of his people was not except that they said, ``Expel the family of Lot from your city. Indeed, they are people who keep themselves pure."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmccxvi{%
So We saved him and his family, except for his wife; We destined her to be of those who remained behind.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmccxvii{%
And We rained upon them a rain [of stones], and evil was the rain of those who were warned.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmccxviii{%
Say, [O Muhammad], ``Praise be to Allah, and peace upon His servants whom He has chosen. Is Allah better or what they associate with Him?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmccxix{%
[More precisely], is He [not best] who created the heavens and the earth and sent down for you rain from the sky, causing to grow thereby gardens of joyful beauty which you could not [otherwise] have grown the trees thereof? Is there a deity with Allah? [No], but they are a people who ascribe equals [to Him].\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmccxx{%
Is He [not best] who made the earth a stable ground and placed within it rivers and made for it firmly set mountains and placed between the two seas a barrier? Is there a deity with Allah? [No], but most of them do not know.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmccxxi{%
Is He [not best] who responds to the desperate one when he calls upon Him and removes evil and makes you inheritors of the earth? Is there a deity with Allah? Little do you remember.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmccxxii{%
Is He [not best] who guides you through the darknesses of the land and sea and who sends the winds as good tidings before His mercy? Is there a deity with Allah? High is Allah above whatever they associate with Him.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmccxxiii{%
Is He [not best] who begins creation and then repeats it and who provides for you from the heaven and earth? Is there a deity with Allah? Say, ``Produce your proof, if you should be truthful."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmccxxiv{%
Say, ``None in the heavens and earth knows the unseen except Allah, and they do not perceive when they will be resurrected."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmccxxv{%
Rather, their knowledge is arrested concerning the Hereafter. Rather, they are in doubt about it. Rather, they are, concerning it, blind.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmccxxvi{%
And those who disbelieve say, ``When we have become dust as well as our forefathers, will we indeed be brought out [of the graves]?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmccxxvii{%
We have been promised this, we and our forefathers, before. This is not but legends of the former peoples."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmccxxviii{%
Say, [O Muhammad], ``Travel through the land and observe how was the end of the criminals."\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmccxxix{%
And grieve not over them or be in distress from what they conspire.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmccxxx{%
And they say, ``When is [the fulfillment of] this promise, if you should be truthful?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmccxxxi{%
Say, ``Perhaps it is close behind you - some of that for which you are impatient.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmccxxxii{%
And indeed, your Lord is full of bounty for the people, but most of them do not show gratitude."\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmccxxxiii{%
And indeed, your Lord knows what their breasts conceal and what they declare.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmccxxxiv{%
And there is nothing concealed within the heaven and the earth except that it is in a clear Register.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmccxxxv{%
Indeed, this Qur'an relates to the Children of Israel most of that over which they disagree.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmccxxxvi{%
And indeed, it is guidance and mercy for the believers.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmccxxxvii{%
Indeed, your Lord will judge between them by His [wise] judgement. And He is the Exalted in Might, the Knowing.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmccxxxviii{%
So rely upon Allah; indeed, you are upon the clear truth.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmccxxxix{%
Indeed, you will not make the dead hear, nor will you make the deaf hear the call when they have turned their backs retreating.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmccxl{%
And you cannot guide the blind away from their error. You will only make hear those who believe in Our verses so they are Muslims [submitting to Allah].\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmccxli{%
And when the word befalls them, We will bring forth for them a creature from the earth speaking to them, [saying] that the people were, of Our verses, not certain [in faith].\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmccxlii{%
And [warn of] the Day when We will gather from every nation a company of those who deny Our signs, and they will be [driven] in rows\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmccxliii{%
Until, when they arrive [at the place of Judgement], He will say, ``Did you deny My signs while you encompassed them not in knowledge, or what [was it that] you were doing?"\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmccxliv{%
And the decree will befall them for the wrong they did, and they will not [be able to] speak.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmccxlv{%
Do they not see that We made the night that they may rest therein and the day giving sight? Indeed in that are signs for a people who believe.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmccxlvi{%
And [warn of] the Day the Horn will be blown, and whoever is in the heavens and whoever is on the earth will be terrified except whom Allah wills. And all will come to Him humbled.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmccxlvii{%
And you see the mountains, thinking them rigid, while they will pass as the passing of clouds. [It is] the work of Allah, who perfected all things. Indeed, He is Acquainted with that which you do.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmccxlviii{%
Whoever comes [at Judgement] with a good deed will have better than it, and they, from the terror of that Day, will be safe.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmccxlix{%
And whoever comes with an evil deed - their faces will be overturned into the Fire, [and it will be said], ``Are you recompensed except for what you used to do?"\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmccl{%
[Say, O Muhammad], ``I have only been commanded to worship the Lord of this city, who made it sacred and to whom [belongs] all things. And I am commanded to be of the Muslims [those who submit to Allah]\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmccli{%
And to recite the Qur'an." And whoever is guided is only guided for [the benefit of] himself; and whoever strays - say, ``I am only [one] of the warners."\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmcclii{%
And say, ``[All] praise is [due] to Allah. He will show you His signs, and you will recognize them. And your Lord is not unaware of what you do."\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmccliii{%
\basmalahen Ta, Seen, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmccliv{%
These are the verses of the clear Book.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcclv{%
We recite to you from the news of Moses and Pharaoh in truth for a people who believe.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcclvi{%
Indeed, Pharaoh exalted himself in the land and made its people into factions, oppressing a sector among them, slaughtering their [newborn] sons and keeping their females alive. Indeed, he was of the corrupters.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcclvii{%
And We wanted to confer favor upon those who were oppressed in the land and make them leaders and make them inheritors\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcclviii{%
And establish them in the land and show Pharaoh and [his minister] Haman and their soldiers through them that which they had feared.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcclix{%
And We inspired to the mother of Moses, ``Suckle him; but when you fear for him, cast him into the river and do not fear and do not grieve. Indeed, We will return him to you and will make him [one] of the messengers."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcclx{%
And the family of Pharaoh picked him up [out of the river] so that he would become to them an enemy and a [cause of] grief. Indeed, Pharaoh and Haman and their soldiers were deliberate sinners.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcclxi{%
And the wife of Pharaoh said, ``[He will be] a comfort of the eye for me and for you. Do not kill him; perhaps he may benefit us, or we may adopt him as a son." And they perceived not.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcclxii{%
And the heart of Moses' mother became empty [of all else]. She was about to disclose [the matter concerning] him had We not bound fast her heart that she would be of the believers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcclxiii{%
And she said to his sister, ``Follow him"; so she watched him from a distance while they perceived not.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcclxiv{%
And We had prevented from him [all] wet nurses before, so she said, ``Shall I direct you to a household that will be responsible for him for you while they are to him [for his upbringing] sincere?"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcclxv{%
So We restored him to his mother that she might be content and not grieve and that she would know that the promise of Allah is true. But most of the people do not know.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcclxvi{%
And when he attained his full strength and was [mentally] mature, We bestowed upon him judgement and knowledge. And thus do We reward the doers of good.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcclxvii{%
And he entered the city at a time of inattention by its people and found therein two men fighting: one from his faction and one from among his enemy. And the one from his faction called for help to him against the one from his enemy, so Moses struck him and [unintentionally] killed him. [Moses] said, ``This is from the work of Satan. Indeed, he is a manifest, misleading enemy."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcclxviii{%
He said, ``My Lord, indeed I have wronged myself, so forgive me," and He forgave him. Indeed, He is the Forgiving, the Merciful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcclxix{%
He said, ``My Lord, for the favor You bestowed upon me, I will never be an assistant to the criminals."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcclxx{%
And he became inside the city fearful and anticipating [exposure], when suddenly the one who sought his help the previous day cried out to him [once again]. Moses said to him, ``Indeed, you are an evident, [persistent] deviator."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcclxxi{%
And when he wanted to strike the one who was an enemy to both of them, he said, ``O Moses, do you intend to kill me as you killed someone yesterday? You only want to be a tyrant in the land and do not want to be of the amenders."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcclxxii{%
And a man came from the farthest end of the city, running. He said, ``O Moses, indeed the eminent ones are conferring over you [intending] to kill you, so leave [the city]; indeed, I am to you of the sincere advisors."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcclxxiii{%
So he left it, fearful and anticipating [apprehension]. He said, ``My Lord, save me from the wrongdoing people."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcclxxiv{%
And when he directed himself toward Madyan, he said, ``Perhaps my Lord will guide me to the sound way."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcclxxv{%
And when he came to the well of Madyan, he found there a crowd of people watering [their flocks], and he found aside from them two women driving back [their flocks]. He said, ``What is your circumstance?" They said, ``We do not water until the shepherds dispatch [their flocks]; and our father is an old man."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcclxxvi{%
So he watered [their flocks] for them; then he went back to the shade and said, ``My Lord, indeed I am, for whatever good You would send down to me, in need."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcclxxvii{%
Then one of the two women came to him walking with shyness. She said, ``Indeed, my father invites you that he may reward you for having watered for us." So when he came to him and related to him the story, he said, ``Fear not. You have escaped from the wrongdoing people."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcclxxviii{%
One of the women said, ``O my father, hire him. Indeed, the best one you can hire is the strong and the trustworthy."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcclxxix{%
He said, ``Indeed, I wish to wed you one of these, my two daughters, on [the condition] that you serve me for eight years; but if you complete ten, it will be [as a favor] from you. And I do not wish to put you in difficulty. You will find me, if Allah wills, from among the righteous."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcclxxx{%
[Moses] said, ``That is [established] between me and you. Whichever of the two terms I complete - there is no injustice to me, and Allah, over what we say, is Witness."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcclxxxi{%
And when Moses had completed the term and was traveling with his family, he perceived from the direction of the mount a fire. He said to his family, ``Stay here; indeed, I have perceived a fire. Perhaps I will bring you from there [some] information or burning wood from the fire that you may warm yourselves."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcclxxxii{%
But when he came to it, he was called from the right side of the valley in a blessed spot - from the tree, ``O Moses, indeed I am Allah, Lord of the worlds."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiii{%
And [he was told], ``Throw down your staff." But when he saw it writhing as if it was a snake, he turned in flight and did not return. [Allah said], ``O Moses, approach and fear not. Indeed, you are of the secure.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcclxxxiv{%
Insert your hand into the opening of your garment; it will come out white, without disease. And draw in your arm close to you [as prevention] from fear, for those are two proofs from your Lord to Pharaoh and his establishment. Indeed, they have been a people defiantly disobedient."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcclxxxv{%
He said, ``My Lord, indeed, I killed from among them someone, and I fear they will kill me.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvi{%
And my brother Aaron is more fluent than me in tongue, so send him with me as support, verifying me. Indeed, I fear that they will deny me."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcclxxxvii{%
[Allah] said, ``We will strengthen your arm through your brother and grant you both supremacy so they will not reach you. [It will be] through Our signs; you and those who follow you will be the predominant."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcclxxxviii{%
But when Moses came to them with Our signs as clear evidences, they said, ``This is not except invented magic, and we have not heard of this [religion] among our forefathers."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcclxxxix{%
And Moses said, ``My Lord is more knowing [than we or you] of who has come with guidance from Him and to whom will be succession in the home. Indeed, wrongdoers do not succeed."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccxc{%
And Pharaoh said, ``O eminent ones, I have not known you to have a god other than me. Then ignite for me, O Haman, [a fire] upon the clay and make for me a tower that I may look at the God of Moses. And indeed, I do think he is among the liars."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccxci{%
And he was arrogant, he and his soldiers, in the land, without right, and they thought that they would not be returned to Us.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccxcii{%
So We took him and his soldiers and threw them into the sea. So see how was the end of the wrongdoers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccxciii{%
And We made them leaders inviting to the Fire, and on the Day of Resurrection they will not be helped.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccxciv{%
And We caused to overtake them in this world a curse, and on the Day of Resurrection they will be of the despised.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccxcv{%
And We gave Moses the Scripture, after We had destroyed the former generations, as enlightenment for the people and guidance and mercy that they might be reminded.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccxcvi{%
And you, [O Muhammad], were not on the western side [of the mount] when We revealed to Moses the command, and you were not among the witnesses [to that].\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccxcvii{%
But We produced [many] generations [after Moses], and prolonged was their duration. And you were not a resident among the people of Madyan, reciting to them Our verses, but We were senders [of this message].\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccxcviii{%
And you were not at the side of the mount when We called [Moses] but [were sent] as a mercy from your Lord to warn a people to whom no warner had come before you that they might be reminded.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccxcix{%
And if not that a disaster should strike them for what their hands put forth [of sins] and they would say, ``Our Lord, why did You not send us a messenger so we could have followed Your verses and been among the believers?"...\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccc{%
But when the truth came to them from Us, they said, ``Why was he not given like that which was given to Moses?" Did they not disbelieve in that which was given to Moses before? They said, ``[They are but] two works of magic supporting each other, and indeed we are, in both, disbelievers."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccci{%
Say, ``Then bring a scripture from Allah which is more guiding than either of them that I may follow it, if you should be truthful."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccii{%
But if they do not respond to you - then know that they only follow their [own] desires. And who is more astray than one who follows his desire without guidance from Allah? Indeed, Allah does not guide the wrongdoing people.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmccciii{%
And We have [repeatedly] conveyed to them the Qur'an that they might be reminded.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmccciv{%
Those to whom We gave the Scripture before it - they are believers in it.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccv{%
And when it is recited to them, they say, ``We have believed in it; indeed, it is the truth from our Lord. Indeed we were, [even] before it, Muslims [submitting to Allah]."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccvi{%
Those will be given their reward twice for what they patiently endured and [because] they avert evil through good, and from what We have provided them they spend.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccvii{%
And when they hear ill speech, they turn away from it and say, ``For us are our deeds, and for you are your deeds. Peace will be upon you; we seek not the ignorant."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccviii{%
Indeed, [O Muhammad], you do not guide whom you like, but Allah guides whom He wills. And He is most knowing of the [rightly] guided.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccix{%
And they say, ``If we were to follow the guidance with you, we would be swept from our land." Have we not established for them a safe sanctuary to which are brought the fruits of all things as provision from Us? But most of them do not know.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccx{%
And how many a city have We destroyed that was insolent in its [way of] living, and those are their dwellings which have not been inhabited after them except briefly. And it is We who were the inheritors.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxi{%
And never would your Lord have destroyed the cities until He had sent to their mother a messenger reciting to them Our verses. And We would not destroy the cities except while their people were wrongdoers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcccxii{%
And whatever thing you [people] have been given - it is [only for] the enjoyment of worldly life and its adornment. And what is with Allah is better and more lasting; so will you not use reason?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcccxiii{%
Then is he whom We have promised a good promise which he will obtain like he for whom We provided enjoyment of worldly life [but] then he is, on the Day of Resurrection, among those presented [for punishment in Hell]?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcccxiv{%
And [warn of] the Day He will call them and say, ``Where are My 'partners' which you used to claim?"\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcccxv{%
Those upon whom the word will have come into effect will say, ``Our Lord, these are the ones we led to error. We led them to error just as we were in error. We declare our disassociation [from them] to You. They did not used to worship us."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcccxvi{%
And it will be said, ``Invoke your 'partners' `` and they will invoke them; but they will not respond to them, and they will see the punishment. If only they had followed guidance!\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcccxvii{%
And [mention] the Day He will call them and say, ``What did you answer the messengers?"\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcccxviii{%
But the information will be unapparent to them that Day, so they will not [be able to] ask one another.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcccxix{%
But as for one who had repented, believed, and done righteousness, it is promised by Allah that he will be among the successful.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcccxx{%
And your Lord creates what He wills and chooses; not for them was the choice. Exalted is Allah and high above what they associate with Him.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcccxxi{%
And your Lord knows what their breasts conceal and what they declare.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcccxxii{%
And He is Allah; there is no deity except Him. To Him is [due all] praise in the first [life] and the Hereafter. And His is the [final] decision, and to Him you will be returned.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmcccxxiii{%
Say, ``Have you considered: if Allah should make for you the night continuous until the Day of Resurrection, what deity other than Allah could bring you light? Then will you not hear?"\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmcccxxiv{%
Say, ``Have you considered: if Allah should make for you the day continuous until the Day of Resurrection, what deity other than Allah could bring you a night in which you may rest? Then will you not see?"\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmcccxxv{%
And out of His mercy He made for you the night and the day that you may rest therein and [by day] seek from His bounty and [that] perhaps you will be grateful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmcccxxvi{%
And [warn of] the Day He will call them and say, ``Where are my 'partners' which you used to claim?"\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmcccxxvii{%
And We will extract from every nation a witness and say, ``Produce your proof," and they will know that the truth belongs to Allah, and lost from them is that which they used to invent.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmcccxxviii{%
Indeed, Qarun was from the people of Moses, but he tyrannized them. And We gave him of treasures whose keys would burden a band of strong men; thereupon his people said to him, ``Do not exult. Indeed, Allah does not like the exultant.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmcccxxix{%
But seek, through that which Allah has given you, the home of the Hereafter; and [yet], do not forget your share of the world. And do good as Allah has done good to you. And desire not corruption in the land. Indeed, Allah does not like corrupters."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmcccxxx{%
He said, ``I was only given it because of knowledge I have." Did he not know that Allah had destroyed before him of generations those who were greater than him in power and greater in accumulation [of wealth]? But the criminals, about their sins, will not be asked.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmcccxxxi{%
So he came out before his people in his adornment. Those who desired the worldly life said, ``Oh, would that we had like what was given to Qarun. Indeed, he is one of great fortune."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmcccxxxii{%
But those who had been given knowledge said, ``Woe to you! The reward of Allah is better for he who believes and does righteousness. And none are granted it except the patient."\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiii{%
And We caused the earth to swallow him and his home. And there was for him no company to aid him other than Allah, nor was he of those who [could] defend themselves.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmcccxxxiv{%
And those who had wished for his position the previous day began to say, ``Oh, how Allah extends provision to whom He wills of His servants and restricts it! If not that Allah had conferred favor on us, He would have caused it to swallow us. Oh, how the disbelievers do not succeed!"\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmcccxxxv{%
That home of the Hereafter We assign to those who do not desire exaltedness upon the earth or corruption. And the [best] outcome is for the righteous.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvi{%
Whoever comes [on the Day of Judgement] with a good deed will have better than it; and whoever comes with an evil deed - then those who did evil deeds will not be recompensed except [as much as] what they used to do.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmcccxxxvii{%
Indeed, [O Muhammad], He who imposed upon you the Qur'an will take you back to a place of return. Say, ``My Lord is most knowing of who brings guidance and who is in clear error."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmcccxxxviii{%
And you were not expecting that the Book would be conveyed to you, but [it is] a mercy from your Lord. So do not be an assistant to the disbelievers.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmcccxxxix{%
And never let them avert you from the verses of Allah after they have been revealed to you. And invite [people] to your Lord. And never be of those who associate others with Allah.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmcccxl{%
And do not invoke with Allah another deity. There is no deity except Him. Everything will be destroyed except His Face. His is the judgement, and to Him you will be returned.\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmcccxli{%
\basmalahen Alif, Lam, Meem\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcccxlii{%
Do the people think that they will be left to say, ``We believe" and they will not be tried?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcccxliii{%
But We have certainly tried those before them, and Allah will surely make evident those who are truthful, and He will surely make evident the liars.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcccxliv{%
Or do those who do evil deeds think they can outrun Us? Evil is what they judge.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcccxlv{%
Whoever should hope for the meeting with Allah - indeed, the term decreed by Allah is coming. And He is the Hearing, the Knowing.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcccxlvi{%
And whoever strives only strives for [the benefit of] himself. Indeed, Allah is free from need of the worlds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcccxlvii{%
And those who believe and do righteous deeds - We will surely remove from them their misdeeds and will surely reward them according to the best of what they used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcccxlviii{%
And We have enjoined upon man goodness to parents. But if they endeavor to make you associate with Me that of which you have no knowledge, do not obey them. To Me is your return, and I will inform you about what you used to do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcccxlix{%
And those who believe and do righteous deeds - We will surely admit them among the righteous [into Paradise].\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcccl{%
And of the people are some who say, ``We believe in Allah," but when one [of them] is harmed for [the cause of] Allah, they consider the trial of the people as [if it were] the punishment of Allah. But if victory comes from your Lord, they say, ``Indeed, We were with you." Is not Allah most knowing of what is within the breasts of all creatures?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcccli{%
And Allah will surely make evident those who believe, and He will surely make evident the hypocrites.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmccclii{%
And those who disbelieve say to those who believe, ``Follow our way, and we will carry your sins." But they will not carry anything of their sins. Indeed, they are liars.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcccliii{%
But they will surely carry their [own] burdens and [other] burdens along with their burdens, and they will surely be questioned on the Day of Resurrection about what they used to invent.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcccliv{%
And We certainly sent Noah to his people, and he remained among them a thousand years minus fifty years, and the flood seized them while they were wrongdoers.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmccclv{%
But We saved him and the companions of the ship, and We made it a sign for the worlds.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmccclvi{%
And [We sent] Abraham, when he said to his people, ``Worship Allah and fear Him. That is best for you, if you should know.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmccclvii{%
You only worship, besides Allah, idols, and you produce a falsehood. Indeed, those you worship besides Allah do not possess for you [the power of] provision. So seek from Allah provision and worship Him and be grateful to Him. To Him you will be returned."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmccclviii{%
And if you [people] deny [the message] - already nations before you have denied. And there is not upon the Messenger except [the duty of] clear notification.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmccclix{%
Have they not considered how Allah begins creation and then repeats it? Indeed that, for Allah, is easy.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmccclx{%
Say, [O Muhammad], ``Travel through the land and observe how He began creation. Then Allah will produce the final creation. Indeed Allah, over all things, is competent."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmccclxi{%
He punishes whom He wills and has mercy upon whom He wills, and to Him you will be returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmccclxii{%
And you will not cause failure [to Allah] upon the earth or in the heaven. And you have not other than Allah any protector or any helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmccclxiii{%
And the ones who disbelieve in the signs of Allah and the meeting with Him - those have despaired of My mercy, and they will have a painful punishment.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmccclxiv{%
And the answer of Abraham's people was not but that they said, ``Kill him or burn him," but Allah saved him from the fire. Indeed in that are signs for a people who believe.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmccclxv{%
And [Abraham] said, ``You have only taken, other than Allah, idols as [a bond of] affection among you in worldly life. Then on the Day of Resurrection you will deny one another and curse one another, and your refuge will be the Fire, and you will not have any helpers."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmccclxvi{%
And Lot believed him. [Abraham] said, ``Indeed, I will emigrate to [the service of] my Lord. Indeed, He is the Exalted in Might, the Wise."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmccclxvii{%
And We gave to Him Isaac and Jacob and placed in his descendants prophethood and scripture. And We gave him his reward in this world, and indeed, he is in the Hereafter among the righteous.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmccclxviii{%
And [mention] Lot, when he said to his people, ``Indeed, you commit such immorality as no one has preceded you with from among the worlds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmccclxix{%
Indeed, you approach men and obstruct the road and commit in your meetings [every] evil." And the answer of his people was not but they said, ``Bring us the punishment of Allah, if you should be of the truthful."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmccclxx{%
He said, ``My Lord, support me against the corrupting people."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmccclxxi{%
And when Our messengers came to Abraham with the good tidings, they said, ``Indeed, we will destroy the people of that Lot's city. Indeed, its people have been wrongdoers."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmccclxxii{%
[Abraham] said, ``Indeed, within it is Lot." They said, ``We are more knowing of who is within it. We will surely save him and his family, except his wife. She is to be of those who remain behind."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmccclxxiii{%
And when Our messengers came to Lot, he was distressed for them and felt for them great discomfort. They said, ``Fear not, nor grieve. Indeed, we will save you and your family, except your wife; she is to be of those who remain behind.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmccclxxiv{%
Indeed, we will bring down on the people of this city punishment from the sky because they have been defiantly disobedient."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmccclxxv{%
And We have certainly left of it a sign as clear evidence for a people who use reason.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmccclxxvi{%
And to Madyan [We sent] their brother Shu'ayb, and he said, ``O my people, worship Allah and expect the Last Day and do not commit abuse on the earth, spreading corruption."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmccclxxvii{%
But they denied him, so the earthquake seized them, and they became within their home [corpses] fallen prone.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmccclxxviii{%
And [We destroyed] 'Aad and Thamud, and it has become clear to you from their [ruined] dwellings. And Satan had made pleasing to them their deeds and averted them from the path, and they were endowed with perception.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmccclxxix{%
And [We destroyed] Qarun and Pharaoh and Haman. And Moses had already come to them with clear evidences, and they were arrogant in the land, but they were not outrunners [of Our punishment].\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmccclxxx{%
So each We seized for his sin; and among them were those upon whom We sent a storm of stones, and among them were those who were seized by the blast [from the sky], and among them were those whom We caused the earth to swallow, and among them were those whom We drowned. And Allah would not have wronged them, but it was they who were wronging themselves.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmccclxxxi{%
The example of those who take allies other than Allah is like that of the spider who takes a home. And indeed, the weakest of homes is the home of the spider, if they only knew.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmccclxxxii{%
Indeed, Allah knows whatever thing they call upon other than Him. And He is the Exalted in Might, the Wise.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiii{%
And these examples We present to the people, but none will understand them except those of knowledge.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmccclxxxiv{%
Allah created the heavens and the earth in truth. Indeed in that is a sign for the believers.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmccclxxxv{%
Recite, [O Muhammad], what has been revealed to you of the Book and establish prayer. Indeed, prayer prohibits immorality and wrongdoing, and the remembrance of Allah is greater. And Allah knows that which you do.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvi{%
And do not argue with the People of the Scripture except in a way that is best, except for those who commit injustice among them, and say, ``We believe in that which has been revealed to us and revealed to you. And our God and your God is one; and we are Muslims [in submission] to Him."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmccclxxxvii{%
And thus We have sent down to you the Qur'an. And those to whom We [previously] gave the Scripture believe in it. And among these [people of Makkah] are those who believe in it. And none reject Our verses except the disbelievers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmccclxxxviii{%
And you did not recite before it any scripture, nor did you inscribe one with your right hand. Otherwise the falsifiers would have had [cause for] doubt.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmccclxxxix{%
Rather, the Qur'an is distinct verses [preserved] within the breasts of those who have been given knowledge. And none reject Our verses except the wrongdoers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcccxc{%
But they say, ``Why are not signs sent down to him from his Lord?" Say, ``The signs are only with Allah, and I am only a clear warner."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcccxci{%
And is it not sufficient for them that We revealed to you the Book which is recited to them? Indeed in that is a mercy and reminder for a people who believe.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcccxcii{%
Say, ``Sufficient is Allah between me and you as Witness. He knows what is in the heavens and earth. And they who have believed in falsehood and disbelieved in Allah - it is those who are the losers."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcccxciii{%
And they urge you to hasten the punishment. And if not for [the decree of] a specified term, punishment would have reached them. But it will surely come to them suddenly while they perceive not.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcccxciv{%
They urge you to hasten the punishment. And indeed, Hell will be encompassing of the disbelievers\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcccxcv{%
On the Day the punishment will cover them from above them and from below their feet and it is said, ``Taste [the result of] what you used to do."\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcccxcvi{%
O My servants who have believed, indeed My earth is spacious, so worship only Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcccxcvii{%
Every soul will taste death. Then to Us will you be returned.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcccxcviii{%
And those who have believed and done righteous deeds - We will surely assign to them of Paradise [elevated] chambers beneath which rivers flow, wherein they abide eternally. Excellent is the reward of the [righteous] workers\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcccxcix{%
Who have been patient and upon their Lord rely.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcd{%
And how many a creature carries not its [own] provision. Allah provides for it and for you. And He is the Hearing, the Knowing.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdi{%
If you asked them, ``Who created the heavens and earth and subjected the sun and the moon?" they would surely say, ``Allah." Then how are they deluded?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmcdii{%
Allah extends provision for whom He wills of His servants and restricts for him. Indeed Allah is, of all things, Knowing.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmcdiii{%
And if you asked them, ``Who sends down rain from the sky and gives life thereby to the earth after its lifelessness?" they would surely say `` Allah." Say, ``Praise to Allah ``; but most of them do not reason.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmcdiv{%
And this worldly life is not but diversion and amusement. And indeed, the home of the Hereafter - that is the [eternal] life, if only they knew.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmcdv{%
And when they board a ship, they supplicate Allah, sincere to Him in religion. But when He delivers them to the land, at once they associate others with Him\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmcdvi{%
So that they will deny what We have granted them, and they will enjoy themselves. But they are going to know.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmcdvii{%
Have they not seen that We made [Makkah] a safe sanctuary, while people are being taken away all around them? Then in falsehood do they believe, and in the favor of Allah they disbelieve?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmcdviii{%
And who is more unjust than one who invents a lie about Allah or denies the truth when it has come to him? Is there not in Hell a [sufficient] residence for the disbelievers?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmcdix{%
And those who strive for Us - We will surely guide them to Our ways. And indeed, Allah is with the doers of good.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmcdx{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdxi{%
The Byzantines have been defeated\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdxii{%
In the nearest land. But they, after their defeat, will overcome.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdxiii{%
Within three to nine years. To Allah belongs the command before and after. And that day the believers will rejoice\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdxiv{%
In the victory of Allah. He gives victory to whom He wills, and He is the Exalted in Might, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdxv{%
[It is] the promise of Allah. Allah does not fail in His promise, but most of the people do not know.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdxvi{%
They know what is apparent of the worldly life, but they, of the Hereafter, are unaware.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdxvii{%
Do they not contemplate within themselves? Allah has not created the heavens and the earth and what is between them except in truth and for a specified term. And indeed, many of the people, in [the matter of] the meeting with their Lord, are disbelievers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdxviii{%
Have they not traveled through the earth and observed how was the end of those before them? They were greater than them in power, and they plowed the earth and built it up more than they have built it up, and their messengers came to them with clear evidences. And Allah would not ever have wronged them, but they were wronging themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdxix{%
Then the end of those who did evil was the worst [consequence] because they denied the signs of Allah and used to ridicule them.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdxx{%
Allah begins creation; then He will repeat it; then to Him you will be returned.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdxxi{%
And the Day the Hour appears the criminals will be in despair.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdxxii{%
And there will not be for them among their [alleged] partners any intercessors, and they will [then] be disbelievers in their partners.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdxxiii{%
And the Day the Hour appears - that Day they will become separated.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdxxiv{%
And as for those who had believed and done righteous deeds, they will be in a garden [of Paradise], delighted.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdxxv{%
But as for those who disbelieved and denied Our verses and the meeting of the Hereafter, those will be brought into the punishment [to remain].\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdxxvi{%
So exalted is Allah when you reach the evening and when you reach the morning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdxxvii{%
And to Him is [due all] praise throughout the heavens and the earth. And [exalted is He] at night and when you are at noon.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdxxviii{%
He brings the living out of the dead and brings the dead out of the living and brings to life the earth after its lifelessness. And thus will you be brought out.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdxxix{%
And of His signs is that He created you from dust; then, suddenly you were human beings dispersing [throughout the earth].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxxx{%
And of His signs is that He created for you from yourselves mates that you may find tranquillity in them; and He placed between you affection and mercy. Indeed in that are signs for a people who give thought.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxxxi{%
And of His signs is the creation of the heavens and the earth and the diversity of your languages and your colors. Indeed in that are signs for those of knowledge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxxxii{%
And of His signs is your sleep by night and day and your seeking of His bounty. Indeed in that are signs for a people who listen.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiii{%
And of His signs is [that] He shows you the lightning [causing] fear and aspiration, and He sends down rain from the sky by which He brings to life the earth after its lifelessness. Indeed in that are signs for a people who use reason.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxxxiv{%
And of His signs is that the heaven and earth remain by His command. Then when He calls you with a [single] call from the earth, immediately you will come forth.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxxxv{%
And to Him belongs whoever is in the heavens and earth. All are to Him devoutly obedient.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvi{%
And it is He who begins creation; then He repeats it, and that is [even] easier for Him. To Him belongs the highest attribute in the heavens and earth. And He is the Exalted in Might, the Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxxxvii{%
He presents to you an example from yourselves. Do you have among those whom your right hands possess any partners in what We have provided for you so that you are equal therein [and] would fear them as your fear of one another [within a partnership]? Thus do We detail the verses for a people who use reason.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxxxviii{%
But those who wrong follow their [own] desires without knowledge. Then who can guide one whom Allah has sent astray? And for them there are no helpers.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxxxix{%
So direct your face toward the religion, inclining to truth. [Adhere to] the fitrah of Allah upon which He has created [all] people. No change should there be in the creation of Allah. That is the correct religion, but most of the people do not know.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmcdxl{%
[Adhere to it], turning in repentance to Him, and fear Him and establish prayer and do not be of those who associate others with Allah\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmcdxli{%
[Or] of those who have divided their religion and become sects, every faction rejoicing in what it has.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmcdxlii{%
And when adversity touches the people, they call upon their Lord, turning in repentance to Him. Then when He lets them taste mercy from Him, at once a party of them associate others with their Lord,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmcdxliii{%
So that they will deny what We have granted them. Then enjoy yourselves, for you are going to know.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmcdxliv{%
Or have We sent down to them an authority, and it speaks of what they were associating with Him?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmcdxlv{%
And when We let the people taste mercy, they rejoice therein, but if evil afflicts them for what their hands have put forth, immediately they despair.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmcdxlvi{%
Do they not see that Allah extends provision for whom He wills and restricts [it]? Indeed, in that are signs for a people who believe.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmcdxlvii{%
So give the relative his right, as well as the needy and the traveler. That is best for those who desire the countenance of Allah, and it is they who will be the successful.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmcdxlviii{%
And whatever you give for interest to increase within the wealth of people will not increase with Allah. But what you give in zakah, desiring the countenance of Allah - those are the multipliers.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmcdxlix{%
Allah is the one who created you, then provided for you, then will cause you to die, and then will give you life. Are there any of your ``partners" who does anything of that? Exalted is He and high above what they associate with Him.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmcdl{%
Corruption has appeared throughout the land and sea by [reason of] what the hands of people have earned so He may let them taste part of [the consequence of] what they have done that perhaps they will return [to righteousness].\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmcdli{%
Say, [O Muhammad], ``Travel through the land and observe how was the end of those before. Most of them were associators [of others with Allah].\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmcdlii{%
So direct your face toward the correct religion before a Day comes from Allah of which there is no repelling. That Day, they will be divided.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmcdliii{%
Whoever disbelieves - upon him is [the consequence of] his disbelief. And whoever does righteousness - they are for themselves preparing,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmcdliv{%
That He may reward those who have believed and done righteous deeds out of His bounty. Indeed, He does not like the disbelievers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmcdlv{%
And of His signs is that He sends the winds as bringers of good tidings and to let you taste His mercy and so the ships may sail at His command and so you may seek of His bounty, and perhaps you will be grateful.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmcdlvi{%
And We have already sent messengers before you to their peoples, and they came to them with clear evidences; then We took retribution from those who committed crimes, and incumbent upon Us was support of the believers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmcdlvii{%
It is Allah who sends the winds, and they stir the clouds and spread them in the sky however He wills, and He makes them fragments so you see the rain emerge from within them. And when He causes it to fall upon whom He wills of His servants, immediately they rejoice\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmcdlviii{%
Although they were, before it was sent down upon them - before that, in despair.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmcdlix{%
So observe the effects of the mercy of Allah - how He gives life to the earth after its lifelessness. Indeed, that [same one] will give life to the dead, and He is over all things competent.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmcdlx{%
But if We should send a [bad] wind and they saw [their crops] turned yellow, they would remain thereafter disbelievers.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmcdlxi{%
So indeed, you will not make the dead hear, nor will you make the deaf hear the call when they turn their backs, retreating.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmcdlxii{%
And you cannot guide the blind away from their error. You will only make hear those who believe in Our verses so they are Muslims [in submission to Allah].\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmcdlxiii{%
Allah is the one who created you from weakness, then made after weakness strength, then made after strength weakness and white hair. He creates what He wills, and He is the Knowing, the Competent.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmcdlxiv{%
And the Day the Hour appears the criminals will swear they had remained but an hour. Thus they were deluded.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmcdlxv{%
But those who were given knowledge and faith will say, ``You remained the extent of Allah 's decree until the Day of Resurrection, and this is the Day of Resurrection, but you did not used to know."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmcdlxvi{%
So that Day, their excuse will not benefit those who wronged, nor will they be asked to appease [Allah].\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmcdlxvii{%
And We have certainly presented to the people in this Qur'an from every [kind of] example. But, [O Muhammad], if you should bring them a sign, the disbelievers will surely say, ``You [believers] are but falsifiers."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmcdlxviii{%
Thus does Allah seal the hearts of those who do not know.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmcdlxix{%
So be patient. Indeed, the promise of Allah is truth. And let them not disquiet you who are not certain [in faith].\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmcdlxx{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcdlxxi{%
These are verses of the wise Book,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcdlxxii{%
As guidance and mercy for the doers of good\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiii{%
Who establish prayer and give zakah, and they, of the Hereafter, are certain [in faith].\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcdlxxiv{%
Those are on [right] guidance from their Lord, and it is those who are the successful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcdlxxv{%
And of the people is he who buys the amusement of speech to mislead [others] from the way of Allah without knowledge and who takes it in ridicule. Those will have a humiliating punishment.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvi{%
And when our verses are recited to him, he turns away arrogantly as if he had not heard them, as if there was in his ears deafness. So give him tidings of a painful punishment.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcdlxxvii{%
Indeed, those who believe and do righteous deeds - for them are the Gardens of Pleasure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcdlxxviii{%
Wherein they abide eternally; [it is] the promise of Allah [which is] truth. And He is the Exalted in Might, the Wise.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcdlxxix{%
He created the heavens without pillars that you see and has cast into the earth firmly set mountains, lest it should shift with you, and dispersed therein from every creature. And We sent down rain from the sky and made grow therein [plants] of every noble kind.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcdlxxx{%
This is the creation of Allah. So show Me what those other than Him have created. Rather, the wrongdoers are in clear error.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxi{%
And We had certainly given Luqman wisdom [and said], ``Be grateful to Allah." And whoever is grateful is grateful for [the benefit of] himself. And whoever denies [His favor] - then indeed, Allah is Free of need and Praiseworthy.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxii{%
And [mention, O Muhammad], when Luqman said to his son while he was instructing him, ``O my son, do not associate [anything] with Allah. Indeed, association [with him] is great injustice."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiii{%
And We have enjoined upon man [care] for his parents. His mother carried him, [increasing her] in weakness upon weakness, and his weaning is in two years. Be grateful to Me and to your parents; to Me is the [final] destination.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxiv{%
But if they endeavor to make you associate with Me that of which you have no knowledge, do not obey them but accompany them in [this] world with appropriate kindness and follow the way of those who turn back to Me [in repentance]. Then to Me will be your return, and I will inform you about what you used to do.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxv{%
[And Luqman said], ``O my son, indeed if wrong should be the weight of a mustard seed and should be within a rock or [anywhere] in the heavens or in the earth, Allah will bring it forth. Indeed, Allah is Subtle and Acquainted.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvi{%
O my son, establish prayer, enjoin what is right, forbid what is wrong, and be patient over what befalls you. Indeed, [all] that is of the matters [requiring] determination.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxvii{%
And do not turn your cheek [in contempt] toward people and do not walk through the earth exultantly. Indeed, Allah does not like everyone self-deluded and boastful.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxviii{%
And be moderate in your pace and lower your voice; indeed, the most disagreeable of sounds is the voice of donkeys."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcdlxxxix{%
Do you not see that Allah has made subject to you whatever is in the heavens and whatever is in the earth and amply bestowed upon you His favors, [both] apparent and unapparent? But of the people is he who disputes about Allah without knowledge or guidance or an enlightening Book [from Him].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcdxc{%
And when it is said to them, ``Follow what Allah has revealed," they say, ``Rather, we will follow that upon which we found our fathers." Even if Satan was inviting them to the punishment of the Blaze?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcdxci{%
And whoever submits his face to Allah while he is a doer of good - then he has grasped the most trustworthy handhold. And to Allah will be the outcome of [all] matters.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcdxcii{%
And whoever has disbelieved - let not his disbelief grieve you. To Us is their return, and We will inform them of what they did. Indeed, Allah is Knowing of that within the breasts.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcdxciii{%
We grant them enjoyment for a little; then We will force them to a massive punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcdxciv{%
And if you asked them, ``Who created the heavens and earth?" they would surely say, ``Allah." Say, ``[All] praise is [due] to Allah ``; but most of them do not know.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcdxcv{%
To Allah belongs whatever is in the heavens and earth. Indeed, Allah is the Free of need, the Praiseworthy.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcdxcvi{%
And if whatever trees upon the earth were pens and the sea [was ink], replenished thereafter by seven [more] seas, the words of Allah would not be exhausted. Indeed, Allah is Exalted in Might and Wise.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcdxcvii{%
Your creation and your resurrection will not be but as that of a single soul. Indeed, Allah is Hearing and Seeing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcdxcviii{%
Do you not see that Allah causes the night to enter the day and causes the day to enter the night and has subjected the sun and the moon, each running [its course] for a specified term, and that Allah, with whatever you do, is Acquainted?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmcdxcix{%
That is because Allah is the Truth, and that what they call upon other than Him is falsehood, and because Allah is the Most High, the Grand.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmd{%
Do you not see that ships sail through the sea by the favor of Allah that He may show you of His signs? Indeed in that are signs for everyone patient and grateful.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdi{%
And when waves come over them like canopies, they supplicate Allah, sincere to Him in religion. But when He delivers them to the land, there are [some] of them who are moderate [in faith]. And none rejects Our signs except everyone treacherous and ungrateful.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdii{%
O mankind, fear your Lord and fear a Day when no father will avail his son, nor will a son avail his father at all. Indeed, the promise of Allah is truth, so let not the worldly life delude you and be not deceived about Allah by the Deceiver.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdiii{%
Indeed, Allah [alone] has knowledge of the Hour and sends down the rain and knows what is in the wombs. And no soul perceives what it will earn tomorrow, and no soul perceives in what land it will die. Indeed, Allah is Knowing and Acquainted.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdiv{%
\basmalahen Alif, Lam, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdv{%
[This is] the revelation of the Book about which there is no doubt from the Lord of the worlds.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdvi{%
Or do they say, ``He invented it"? Rather, it is the truth from your Lord, [O Muhammad], that you may warn a people to whom no warner has come before you [so] perhaps they will be guided.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdvii{%
It is Allah who created the heavens and the earth and whatever is between them in six days; then He established Himself above the Throne. You have not besides Him any protector or any intercessor; so will you not be reminded?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdviii{%
He arranges [each] matter from the heaven to the earth; then it will ascend to Him in a Day, the extent of which is a thousand years of those which you count.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdix{%
That is the Knower of the unseen and the witnessed, the Exalted in Might, the Merciful,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdx{%
Who perfected everything which He created and began the creation of man from clay.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxi{%
Then He made his posterity out of the extract of a liquid disdained.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxii{%
Then He proportioned him and breathed into him from His [created] soul and made for you hearing and vision and hearts; little are you grateful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxiii{%
And they say, ``When we are lost within the earth, will we indeed be [recreated] in a new creation?" Rather, they are, in [the matter of] the meeting with their Lord, disbelievers.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxiv{%
Say, ``The angel of death will take you who has been entrusted with you. Then to your Lord you will be returned."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxv{%
If you could but see when the criminals are hanging their heads before their Lord, [saying], ``Our Lord, we have seen and heard, so return us [to the world]; we will work righteousness. Indeed, we are [now] certain."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxvi{%
And if We had willed, We could have given every soul its guidance, but the word from Me will come into effect [that] ``I will surely fill Hell with jinn and people all together.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxvii{%
So taste [punishment] because you forgot the meeting of this, your Day; indeed, We have [accordingly] forgotten you. And taste the punishment of eternity for what you used to do."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxviii{%
Only those believe in Our verses who, when they are reminded by them, fall down in prostration and exalt [Allah] with praise of their Lord, and they are not arrogant.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxix{%
They arise from [their] beds; they supplicate their Lord in fear and aspiration, and from what We have provided them, they spend.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdxx{%
And no soul knows what has been hidden for them of comfort for eyes as reward for what they used to do.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdxxi{%
Then is one who was a believer like one who was defiantly disobedient? They are not equal.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdxxii{%
As for those who believed and did righteous deeds, for them will be the Gardens of Refuge as accommodation for what they used to do.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdxxiii{%
But as for those who defiantly disobeyed, their refuge is the Fire. Every time they wish to emerge from it, they will be returned to it while it is said to them, ``Taste the punishment of the Fire which you used to deny."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdxxiv{%
And we will surely let them taste the nearer punishment short of the greater punishment that perhaps they will repent.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdxxv{%
And who is more unjust than one who is reminded of the verses of his Lord; then he turns away from them? Indeed We, from the criminals, will take retribution.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdxxvi{%
And We certainly gave Moses the Scripture, so do not be in doubt over his meeting. And we made the Torah guidance for the Children of Israel.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdxxvii{%
And We made from among them leaders guiding by Our command when they were patient and [when] they were certain of Our signs.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdxxviii{%
Indeed, your Lord will judge between them on the Day of Resurrection concerning that over which they used to differ.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdxxix{%
Has it not become clear to them how many generations We destroyed before them, [as] they walk among their dwellings? Indeed in that are signs; then do they not hear?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdxxx{%
Have they not seen that We drive the water [in clouds] to barren land and bring forth thereby crops from which their livestock eat and [they] themselves? Then do they not see?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdxxxi{%
And they say, ``When will be this conquest, if you should be truthful?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdxxxii{%
Say, [O Muhammad], ``On the Day of Conquest the belief of those who had disbelieved will not benefit them, nor will they be reprieved."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdxxxiii{%
So turn away from them and wait. Indeed, they are waiting.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdxxxiv{%
\basmalahen O Prophet, fear Allah and do not obey the disbelievers and the hypocrites. Indeed, Allah is ever Knowing and Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdxxxv{%
And follow that which is revealed to you from your Lord. Indeed Allah is ever, with what you do, Acquainted.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdxxxvi{%
And rely upon Allah; and sufficient is Allah as Disposer of affairs.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdxxxvii{%
Allah has not made for a man two hearts in his interior. And He has not made your wives whom you declare unlawful your mothers. And he has not made your adopted sons your [true] sons. That is [merely] your saying by your mouths, but Allah says the truth, and He guides to the [right] way.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdxxxviii{%
Call them by [the names of] their fathers; it is more just in the sight of Allah. But if you do not know their fathers - then they are [still] your brothers in religion and those entrusted to you. And there is no blame upon you for that in which you have erred but [only for] what your hearts intended. And ever is Allah Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdxxxix{%
The Prophet is more worthy of the believers than themselves, and his wives are [in the position of] their mothers. And those of [blood] relationship are more entitled [to inheritance] in the decree of Allah than the [other] believers and the emigrants, except that you may do to your close associates a kindness [through bequest]. That was in the Book inscribed.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdxl{%
And [mention, O Muhammad], when We took from the prophets their covenant and from you and from Noah and Abraham and Moses and Jesus, the son of Mary; and We took from them a solemn covenant.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdxli{%
That He may question the truthful about their truth. And He has prepared for the disbelievers a painful punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdxlii{%
O you who have believed, remember the favor of Allah upon you when armies came to [attack] you and We sent upon them a wind and armies [of angels] you did not see. And ever is Allah, of what you do, Seeing.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdxliii{%
[Remember] when they came at you from above you and from below you, and when eyes shifted [in fear], and hearts reached the throats and you assumed about Allah [various] assumptions.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdxliv{%
There the believers were tested and shaken with a severe shaking.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdxlv{%
And [remember] when the hypocrites and those in whose hearts is disease said, ``Allah and His Messenger did not promise us except delusion,"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdxlvi{%
And when a faction of them said, ``O people of Yathrib, there is no stability for you [here], so return [home]." And a party of them asked permission of the Prophet, saying, ``Indeed, our houses are unprotected," while they were not exposed. They did not intend except to flee.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdxlvii{%
And if they had been entered upon from all its [surrounding] regions and fitnah had been demanded of them, they would have done it and not hesitated over it except briefly.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdxlviii{%
And they had already promised Allah before not to turn their backs and flee. And ever is the promise to Allah [that about which one will be] questioned.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdxlix{%
Say, [O Muhammad], ``Never will fleeing benefit you if you should flee from death or killing; and then [if you did], you would not be given enjoyment [of life] except for a little."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdl{%
Say, ``Who is it that can protect you from Allah if He intends for you an ill or intends for you a mercy?" And they will not find for themselves besides Allah any protector or any helper.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdli{%
Already Allah knows the hinderers among you and those [hypocrites] who say to their brothers, ``Come to us," and do not go to battle, except for a few,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdlii{%
Indisposed toward you. And when fear comes, you see them looking at you, their eyes revolving like one being overcome by death. But when fear departs, they lash you with sharp tongues, indisposed toward [any] good. Those have not believed, so Allah has rendered their deeds worthless, and ever is that, for Allah, easy.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdliii{%
They think the companies have not [yet] withdrawn. And if the companies should come [again], they would wish they were in the desert among the bedouins, inquiring [from afar] about your news. And if they should be among you, they would not fight except for a little.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdliv{%
There has certainly been for you in the Messenger of Allah an excellent pattern for anyone whose hope is in Allah and the Last Day and [who] remembers Allah often.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdlv{%
And when the believers saw the companies, they said, ``This is what Allah and His Messenger had promised us, and Allah and His Messenger spoke the truth." And it increased them only in faith and acceptance.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdlvi{%
Among the believers are men true to what they promised Allah. Among them is he who has fulfilled his vow [to the death], and among them is he who awaits [his chance]. And they did not alter [the terms of their commitment] by any alteration -\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdlvii{%
That Allah may reward the truthful for their truth and punish the hypocrites if He wills or accept their repentance. Indeed, Allah is ever Forgiving and Merciful.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdlviii{%
And Allah repelled those who disbelieved, in their rage, not having obtained any good. And sufficient was Allah for the believers in battle, and ever is Allah Powerful and Exalted in Might.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdlix{%
And He brought down those who supported them among the People of the Scripture from their fortresses and cast terror into their hearts [so that] a party you killed, and you took captive a party.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdlx{%
And He caused you to inherit their land and their homes and their properties and a land which you have not trodden. And ever is Allah, over all things, competent.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdlxi{%
O Prophet, say to your wives, ``If you should desire the worldly life and its adornment, then come, I will provide for you and give you a gracious release.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdlxii{%
But if you should desire Allah and His Messenger and the home of the Hereafter - then indeed, Allah has prepared for the doers of good among you a great reward."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdlxiii{%
O wives of the Prophet, whoever of you should commit a clear immorality - for her the punishment would be doubled two fold, and ever is that, for Allah, easy.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdlxiv{%
And whoever of you devoutly obeys Allah and His Messenger and does righteousness - We will give her her reward twice; and We have prepared for her a noble provision.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdlxv{%
O wives of the Prophet, you are not like anyone among women. If you fear Allah, then do not be soft in speech [to men], lest he in whose heart is disease should covet, but speak with appropriate speech.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdlxvi{%
And abide in your houses and do not display yourselves as [was] the display of the former times of ignorance. And establish prayer and give zakah and obey Allah and His Messenger. Allah intends only to remove from you the impurity [of sin], O people of the [Prophet's] household, and to purify you with [extensive] purification.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdlxvii{%
And remember what is recited in your houses of the verses of Allah and wisdom. Indeed, Allah is ever Subtle and Acquainted [with all things].\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdlxviii{%
Indeed, the Muslim men and Muslim women, the believing men and believing women, the obedient men and obedient women, the truthful men and truthful women, the patient men and patient women, the humble men and humble women, the charitable men and charitable women, the fasting men and fasting women, the men who guard their private parts and the women who do so, and the men who remember Allah often and the women who do so - for them Allah has prepared forgiveness and a great reward.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdlxix{%
It is not for a believing man or a believing woman, when Allah and His Messenger have decided a matter, that they should [thereafter] have any choice about their affair. And whoever disobeys Allah and His Messenger has certainly strayed into clear error.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdlxx{%
And [remember, O Muhammad], when you said to the one on whom Allah bestowed favor and you bestowed favor, ``Keep your wife and fear Allah," while you concealed within yourself that which Allah is to disclose. And you feared the people, while Allah has more right that you fear Him. So when Zayd had no longer any need for her, We married her to you in order that there not be upon the believers any discomfort concerning the wives of their adopted sons when they no longer have need of them. And ever is the command of Allah accomplished.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdlxxi{%
There is not to be upon the Prophet any discomfort concerning that which Allah has imposed upon him. [This is] the established way of Allah with those [prophets] who have passed on before. And ever is the command of Allah a destiny decreed.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdlxxii{%
[Allah praises] those who convey the messages of Allah and fear Him and do not fear anyone but Allah. And sufficient is Allah as Accountant.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdlxxiii{%
Muhammad is not the father of [any] one of your men, but [he is] the Messenger of Allah and last of the prophets. And ever is Allah, of all things, Knowing.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdlxxiv{%
O you who have believed, remember Allah with much remembrance\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdlxxv{%
And exalt Him morning and afternoon.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdlxxvi{%
It is He who confers blessing upon you, and His angels [ask Him to do so] that He may bring you out from darknesses into the light. And ever is He, to the believers, Merciful.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdlxxvii{%
Their greeting the Day they meet Him will be, ``Peace." And He has prepared for them a noble reward.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdlxxviii{%
O Prophet, indeed We have sent you as a witness and a bringer of good tidings and a warner.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdlxxix{%
And one who invites to Allah, by His permission, and an illuminating lamp.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdlxxx{%
And give good tidings to the believers that they will have from Allah great bounty.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdlxxxi{%
And do not obey the disbelievers and the hypocrites but do not harm them, and rely upon Allah. And sufficient is Allah as Disposer of affairs.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdlxxxii{%
O You who have believed, when you marry believing women and then divorce them before you have touched them, then there is not for you any waiting period to count concerning them. So provide for them and give them a gracious release.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiii{%
O Prophet, indeed We have made lawful to you your wives to whom you have given their due compensation and those your right hand possesses from what Allah has returned to you [of captives] and the daughters of your paternal uncles and the daughters of your paternal aunts and the daughters of your maternal uncles and the daughters of your maternal aunts who emigrated with you and a believing woman if she gives herself to the Prophet [and] if the Prophet wishes to marry her, [this is] only for you, excluding the [other] believers. We certainly know what We have made obligatory upon them concerning their wives and those their right hands possess, [but this is for you] in order that there will be upon you no discomfort. And ever is Allah Forgiving and Merciful.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdlxxxiv{%
You, [O Muhammad], may put aside whom you will of them or take to yourself whom you will. And any that you desire of those [wives] from whom you had [temporarily] separated - there is no blame upon you [in returning her]. That is more suitable that they should be content and not grieve and that they should be satisfied with what you have given them - all of them. And Allah knows what is in your hearts. And ever is Allah Knowing and Forbearing.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdlxxxv{%
Not lawful to you, [O Muhammad], are [any additional] women after [this], nor [is it] for you to exchange them for [other] wives, even if their beauty were to please you, except what your right hand possesses. And ever is Allah, over all things, an Observer.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvi{%
O you who have believed, do not enter the houses of the Prophet except when you are permitted for a meal, without awaiting its readiness. But when you are invited, then enter; and when you have eaten, disperse without seeking to remain for conversation. Indeed, that [behavior] was troubling the Prophet, and he is shy of [dismissing] you. But Allah is not shy of the truth. And when you ask [his wives] for something, ask them from behind a partition. That is purer for your hearts and their hearts. And it is not [conceivable or lawful] for you to harm the Messenger of Allah or to marry his wives after him, ever. Indeed, that would be in the sight of Allah an enormity.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdlxxxvii{%
Whether you reveal a thing or conceal it, indeed Allah is ever, of all things, Knowing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdlxxxviii{%
There is no blame upon women concerning their fathers or their sons or their brothers or their brothers' sons or their sisters' sons or their women or those their right hands possess. And fear Allah. Indeed Allah is ever, over all things, Witness.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdlxxxix{%
Indeed, Allah confers blessing upon the Prophet, and His angels [ask Him to do so]. O you who have believed, ask [Allah to confer] blessing upon him and ask [Allah to grant him] peace.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdxc{%
Indeed, those who abuse Allah and His Messenger - Allah has cursed them in this world and the Hereafter and prepared for them a humiliating punishment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdxci{%
And those who harm believing men and believing women for [something] other than what they have earned have certainly born upon themselves a slander and manifest sin.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdxcii{%
O Prophet, tell your wives and your daughters and the women of the believers to bring down over themselves [part] of their outer garments. That is more suitable that they will be known and not be abused. And ever is Allah Forgiving and Merciful.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdxciii{%
If the hypocrites and those in whose hearts is disease and those who spread rumors in al-Madinah do not cease, We will surely incite you against them; then they will not remain your neighbors therein except for a little.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdxciv{%
Accursed wherever they are found, [being] seized and massacred completely.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdxcv{%
[This is] the established way of Allah with those who passed on before; and you will not find in the way of Allah any change.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdxcvi{%
People ask you concerning the Hour. Say," Knowledge of it is only with Allah. And what may make you perceive? Perhaps the Hour is near."\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdxcvii{%
Indeed, Allah has cursed the disbelievers and prepared for them a Blaze.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdxcviii{%
Abiding therein forever, they will not find a protector or a helper.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdxcix{%
The Day their faces will be turned about in the Fire, they will say, ``How we wish we had obeyed Allah and obeyed the Messenger."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdc{%
And they will say, ``Our Lord, indeed we obeyed our masters and our dignitaries, and they led us astray from the [right] way.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdci{%
Our Lord, give them double the punishment and curse them with a great curse."\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcii{%
O you who have believed, be not like those who abused Moses; then Allah cleared him of what they said. And he, in the sight of Allah, was distinguished.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdciii{%
O you who have believed, fear Allah and speak words of appropriate justice.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdciv{%
He will [then] amend for you your deeds and forgive you your sins. And whoever obeys Allah and His Messenger has certainly attained a great attainment.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcv{%
Indeed, we offered the Trust to the heavens and the earth and the mountains, and they declined to bear it and feared it; but man [undertook to] bear it. Indeed, he was unjust and ignorant.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcvi{%
[It was] so that Allah may punish the hypocrite men and hypocrite women and the men and women who associate others with Him and that Allah may accept repentance from the believing men and believing women. And ever is Allah Forgiving and Merciful.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcvii{%
\basmalahen [All] praise is [due] to Allah, to whom belongs whatever is in the heavens and whatever is in the earth, and to Him belongs [all] praise in the Hereafter. And He is the Wise, the Acquainted.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdcviii{%
He knows what penetrates into the earth and what emerges from it and what descends from the heaven and what ascends therein. And He is the Merciful, the Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdcix{%
But those who disbelieve say, ``The Hour will not come to us." Say, ``Yes, by my Lord, it will surely come to you. [Allah is] the Knower of the unseen." Not absent from Him is an atom's weight within the heavens or within the earth or [what is] smaller than that or greater, except that it is in a clear register -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdcx{%
That He may reward those who believe and do righteous deeds. Those will have forgiveness and noble provision.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdcxi{%
But those who strive against Our verses [seeking] to cause failure - for them will be a painful punishment of foul nature.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdcxii{%
And those who have been given knowledge see that what is revealed to you from your Lord is the truth, and it guides to the path of the Exalted in Might, the Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdcxiii{%
But those who disbelieve say, ``Shall we direct you to a man who will inform you [that] when you have disintegrated in complete disintegration, you will [then] be [recreated] in a new creation?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdcxiv{%
Has he invented about Allah a lie or is there in him madness?" Rather, they who do not believe in the Hereafter will be in the punishment and [are in] extreme error.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdcxv{%
Then, do they not look at what is before them and what is behind them of the heaven and earth? If We should will, We could cause the earth to swallow them or [could] let fall upon them fragments from the sky. Indeed in that is a sign for every servant turning back [to Allah].\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdcxvi{%
And We certainly gave David from Us bounty. [We said], ``O mountains, repeat [Our] praises with him, and the birds [as well]." And We made pliable for him iron,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdcxvii{%
[Commanding him], ``Make full coats of mail and calculate [precisely] the links, and work [all of you] righteousness. Indeed I, of what you do, am Seeing."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdcxviii{%
And to Solomon [We subjected] the wind - its morning [journey was that of] a month - and its afternoon [journey was that of] a month, and We made flow for him a spring of [liquid] copper. And among the jinn were those who worked for him by the permission of his Lord. And whoever deviated among them from Our command - We will make him taste of the punishment of the Blaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdcxix{%
They made for him what he willed of elevated chambers, statues, bowls like reservoirs, and stationary kettles. [We said], ``Work, O family of David, in gratitude." And few of My servants are grateful.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcxx{%
And when We decreed for Solomon death, nothing indicated to the jinn his death except a creature of the earth eating his staff. But when he fell, it became clear to the jinn that if they had known the unseen, they would not have remained in humiliating punishment.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdcxxi{%
There was for [the tribe of] Saba' in their dwelling place a sign: two [fields of] gardens on the right and on the left. [They were told], ``Eat from the provisions of your Lord and be grateful to Him. A good land [have you], and a forgiving Lord."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdcxxii{%
But they turned away [refusing], so We sent upon them the flood of the dam, and We replaced their two [fields of] gardens with gardens of bitter fruit, tamarisks and something of sparse lote trees.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcxxiii{%
[By] that We repaid them because they disbelieved. And do We [thus] repay except the ungrateful?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcxxiv{%
And We placed between them and the cities which We had blessed [many] visible cities. And We determined between them the [distances of] journey, [saying], ``Travel between them by night or day in safety."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcxxv{%
But [insolently] they said, ``Our Lord, lengthen the distance between our journeys," and wronged themselves, so We made them narrations and dispersed them in total dispersion. Indeed in that are signs for everyone patient and grateful.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcxxvi{%
And Iblees had already confirmed through them his assumption, so they followed him, except for a party of believers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcxxvii{%
And he had over them no authority except [it was decreed] that We might make evident who believes in the Hereafter from who is thereof in doubt. And your Lord, over all things, is Guardian.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcxxviii{%
Say, [O Muhammad], ``Invoke those you claim [as deities] besides Allah." They do not possess an atom's weight [of ability] in the heavens or on the earth, and they do not have therein any partnership [with Him], nor is there for Him from among them any assistant.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcxxix{%
And intercession does not benefit with Him except for one whom He permits. [And those wait] until, when terror is removed from their hearts, they will say [to one another], ``What has your Lord said?" They will say, ``The truth." And He is the Most High, the Grand.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcxxx{%
Say, ``Who provides for you from the heavens and the earth?" Say, ``Allah. And indeed, we or you are either upon guidance or in clear error."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcxxxi{%
Say, ``You will not be asked about what we committed, and we will not be asked about what you do."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcxxxii{%
Say, ``Our Lord will bring us together; then He will judge between us in truth. And He is the Knowing Judge."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiii{%
Say, ``Show me those whom you have attached to Him as partners. No! Rather, He [alone] is Allah, the Exalted in Might, the Wise."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcxxxiv{%
And We have not sent you except comprehensively to mankind as a bringer of good tidings and a warner. But most of the people do not know.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcxxxv{%
And they say, ``When is this promise, if you should be truthful?"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvi{%
Say, ``For you is the appointment of a Day [when] you will not remain thereafter an hour, nor will you precede [it]."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxxxvii{%
And those who disbelieve say, ``We will never believe in this Qur'an nor in that before it." But if you could see when the wrongdoers are made to stand before their Lord, refuting each other's words... Those who were oppressed will say to those who were arrogant, ``If not for you, we would have been believers."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxxxviii{%
Those who were arrogant will say to those who were oppressed, ``Did we avert you from guidance after it had come to you? Rather, you were criminals."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxxxix{%
Those who were oppressed will say to those who were arrogant, ``Rather, [it was your] conspiracy of night and day when you were ordering us to disbelieve in Allah and attribute to Him equals." But they will [all] confide regret when they see the punishment; and We will put shackles on the necks of those who disbelieved. Will they be recompensed except for what they used to do?\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxl{%
And We did not send into a city any warner except that its affluent said, ``Indeed we, in that with which you were sent, are disbelievers."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxli{%
And they said, ``We are more [than the believers] in wealth and children, and we are not to be punished."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxlii{%
Say, ``Indeed, my Lord extends provision for whom He wills and restricts [it], but most of the people do not know."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxliii{%
And it is not your wealth or your children that bring you nearer to Us in position, but it is [by being] one who has believed and done righteousness. For them there will be the double reward for what they did, and they will be in the upper chambers [of Paradise], safe [and secure].\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxliv{%
And the ones who strive against Our verses to cause [them] failure - those will be brought into the punishment [to remain].\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxlv{%
Say, ``Indeed, my Lord extends provision for whom He wills of His servants and restricts [it] for him. But whatever thing you spend [in His cause] - He will compensate it; and He is the best of providers."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcxlvi{%
And [mention] the Day when He will gather them all and then say to the angels, ``Did these [people] used to worship you?"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcxlvii{%
They will say, ``Exalted are You! You, [O Allah], are our benefactor not them. Rather, they used to worship the jinn; most of them were believers in them."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcxlviii{%
But today you do not hold for one another [the power of] benefit or harm, and We will say to those who wronged, ``Taste the punishment of the Fire, which you used to deny."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcxlix{%
And when our verses are recited to them as clear evidences, they say, ``This is not but a man who wishes to avert you from that which your fathers were worshipping." And they say, ``This is not except a lie invented." And those who disbelieve say of the truth when it has come to them, ``This is not but obvious magic."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcl{%
And We had not given them any scriptures which they could study, and We had not sent to them before you, [O Muhammad], any warner.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcli{%
And those before them denied, and the people of Makkah have not attained a tenth of what We had given them. But the former peoples denied My messengers, so how [terrible] was My reproach.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdclii{%
Say, ``I only advise you of one [thing] - that you stand for Allah, [seeking truth] in pairs and individually, and then give thought." There is not in your companion any madness. He is only a warner to you before a severe punishment.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcliii{%
Say, ``Whatever payment I might have asked of you - it is yours. My payment is only from Allah, and He is, over all things, Witness."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcliv{%
Say, ``Indeed, my Lord projects the truth. Knower of the unseen."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdclv{%
Say, ``The truth has come, and falsehood can neither begin [anything] nor repeat [it]."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdclvi{%
Say, ``If I should err, I would only err against myself. But if I am guided, it is by what my Lord reveals to me. Indeed, He is Hearing and near."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdclvii{%
And if you could see when they are terrified but there is no escape, and they will be seized from a place nearby.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdclviii{%
And they will [then] say, ``We believe in it!" But how for them will be the taking [of faith] from a place far away?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdclix{%
And they had already disbelieved in it before and would assault the unseen from a place far away.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdclx{%
And prevention will be placed between them and what they desire, as was done with their kind before. Indeed, they were in disquieting denial.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdclxi{%
\basmalahen [All] praise is [due] to Allah, Creator of the heavens and the earth, [who] made the angels messengers having wings, two or three or four. He increases in creation what He wills. Indeed, Allah is over all things competent.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdclxii{%
Whatever Allah grants to people of mercy - none can withhold it; and whatever He withholds - none can release it thereafter. And He is the Exalted in Might, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdclxiii{%
O mankind, remember the favor of Allah upon you. Is there any creator other than Allah who provides for you from the heaven and earth? There is no deity except Him, so how are you deluded?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdclxiv{%
And if they deny you, [O Muhammad] - already were messengers denied before you. And to Allah are returned [all] matters.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdclxv{%
O mankind, indeed the promise of Allah is truth, so let not the worldly life delude you and be not deceived about Allah by the Deceiver.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdclxvi{%
Indeed, Satan is an enemy to you; so take him as an enemy. He only invites his party to be among the companions of the Blaze.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdclxvii{%
Those who disbelieve will have a severe punishment, and those who believe and do righteous deeds will have forgiveness and great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdclxviii{%
Then is one to whom the evil of his deed has been made attractive so he considers it good [like one rightly guided]? For indeed, Allah sends astray whom He wills and guides whom He wills. So do not let yourself perish over them in regret. Indeed, Allah is Knowing of what they do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdclxix{%
And it is Allah who sends the winds, and they stir the clouds, and We drive them to a dead land and give life thereby to the earth after its lifelessness. Thus is the resurrection.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdclxx{%
Whoever desires honor [through power] - then to Allah belongs all honor. To Him ascends good speech, and righteous work raises it. But they who plot evil deeds will have a severe punishment, and the plotting of those - it will perish.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdclxxi{%
And Allah created you from dust, then from a sperm-drop; then He made you mates. And no female conceives nor does she give birth except with His knowledge. And no aged person is granted [additional] life nor is his lifespan lessened but that it is in a register. Indeed, that for Allah is easy.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdclxxii{%
And not alike are the two bodies of water. One is fresh and sweet, palatable for drinking, and one is salty and bitter. And from each you eat tender meat and extract ornaments which you wear, and you see the ships plowing through [them] that you might seek of His bounty; and perhaps you will be grateful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdclxxiii{%
He causes the night to enter the day, and He causes the day to enter the night and has subjected the sun and the moon - each running [its course] for a specified term. That is Allah, your Lord; to Him belongs sovereignty. And those whom you invoke other than Him do not possess [as much as] the membrane of a date seed.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdclxxiv{%
If you invoke them, they do not hear your supplication; and if they heard, they would not respond to you. And on the Day of Resurrection they will deny your association. And none can inform you like [one] Acquainted [with all matters].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdclxxv{%
O mankind, you are those in need of Allah, while Allah is the Free of need, the Praiseworthy.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdclxxvi{%
If He wills, He can do away with you and bring forth a new creation.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdclxxvii{%
And that is for Allah not difficult.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdclxxviii{%
And no bearer of burdens will bear the burden of another. And if a heavily laden soul calls [another] to [carry some of] its load, nothing of it will be carried, even if he should be a close relative. You can only warn those who fear their Lord unseen and have established prayer. And whoever purifies himself only purifies himself for [the benefit of] his soul. And to Allah is the [final] destination.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdclxxix{%
Not equal are the blind and the seeing,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdclxxx{%
Nor are the darknesses and the light,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdclxxxi{%
Nor are the shade and the heat,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdclxxxii{%
And not equal are the living and the dead. Indeed, Allah causes to hear whom He wills, but you cannot make hear those in the graves.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiii{%
You, [O Muhammad], are not but a warner.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdclxxxiv{%
Indeed, We have sent you with the truth as a bringer of good tidings and a warner. And there was no nation but that there had passed within it a warner.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdclxxxv{%
And if they deny you - then already have those before them denied. Their messengers came to them with clear proofs and written ordinances and with the enlightening Scripture.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvi{%
Then I seized the ones who disbelieved, and how [terrible] was My reproach.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdclxxxvii{%
Do you not see that Allah sends down rain from the sky, and We produce thereby fruits of varying colors? And in the mountains are tracts, white and red of varying shades and [some] extremely black.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdclxxxviii{%
And among people and moving creatures and grazing livestock are various colors similarly. Only those fear Allah, from among His servants, who have knowledge. Indeed, Allah is Exalted in Might and Forgiving.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdclxxxix{%
Indeed, those who recite the Book of Allah and establish prayer and spend [in His cause] out of what We have provided them, secretly and publicly, [can] expect a profit that will never perish -\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcxc{%
That He may give them in full their rewards and increase for them of His bounty. Indeed, He is Forgiving and Appreciative.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcxci{%
And that which We have revealed to you, [O Muhammad], of the Book is the truth, confirming what was before it. Indeed, Allah, of His servants, is Acquainted and Seeing.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcxcii{%
Then we caused to inherit the Book those We have chosen of Our servants; and among them is he who wrongs himself, and among them is he who is moderate, and among them is he who is foremost in good deeds by permission of Allah. That [inheritance] is what is the great bounty.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcxciii{%
[For them are] gardens of perpetual residence which they will enter. They will be adorned therein with bracelets of gold and pearls, and their garments therein will be silk.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcxciv{%
And they will say, ``Praise to Allah, who has removed from us [all] sorrow. Indeed, our Lord is Forgiving and Appreciative -\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcxcv{%
He who has settled us in the home of duration out of His bounty. There touches us not in it any fatigue, and there touches us not in it weariness [of mind]."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcxcvi{%
And for those who disbelieve will be the fire of Hell. [Death] is not decreed for them so they may die, nor will its torment be lightened for them. Thus do we recompense every ungrateful one.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcxcvii{%
And they will cry out therein, ``Our Lord, remove us; we will do righteousness - other than what we were doing!" But did We not grant you life enough for whoever would remember therein to remember, and the warner had come to you? So taste [the punishment], for there is not for the wrongdoers any helper.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcxcviii{%
Indeed, Allah is Knower of the unseen [aspects] of the heavens and earth. Indeed, He is Knowing of that within the breasts.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcxcix{%
It is He who has made you successors upon the earth. And whoever disbelieves - upon him will be [the consequence of] his disbelief. And the disbelief of the disbelievers does not increase them in the sight of their Lord except in hatred; and the disbelief of the disbelievers does not increase them except in loss.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcc{%
Say, ``Have you considered your 'partners' whom you invoke besides Allah? Show me what they have created from the earth, or have they partnership [with Him] in the heavens? Or have We given them a book so they are [standing] on evidence therefrom? [No], rather, the wrongdoers do not promise each other except delusion."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcci{%
Indeed, Allah holds the heavens and the earth, lest they cease. And if they should cease, no one could hold them [in place] after Him. Indeed, He is Forbearing and Forgiving.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccii{%
And they swore by Allah their strongest oaths that if a warner came to them, they would be more guided than [any] one of the [previous] nations. But when a warner came to them, it did not increase them except in aversion.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcciii{%
[Due to] arrogance in the land and plotting of evil; but the evil plot does not encompass except its own people. Then do they await except the way of the former peoples? But you will never find in the way of Allah any change, and you will never find in the way of Allah any alteration.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcciv{%
Have they not traveled through the land and observed how was the end of those before them? And they were greater than them in power. But Allah is not to be caused failure by anything in the heavens or on the earth. Indeed, He is ever Knowing and Competent.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccv{%
And if Allah were to impose blame on the people for what they have earned, He would not leave upon the earth any creature. But He defers them for a specified term. And when their time comes, then indeed Allah has ever been, of His servants, Seeing.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccvi{%
\basmalahen Ya, Seen.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccvii{%
By the wise Qur'an.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccviii{%
Indeed you, [O Muhammad], are from among the messengers,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccix{%
On a straight path.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccx{%
[This is] a revelation of the Exalted in Might, the Merciful,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxi{%
That you may warn a people whose forefathers were not warned, so they are unaware.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxii{%
Already the word has come into effect upon most of them, so they do not believe.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxiii{%
Indeed, We have put shackles on their necks, and they are to their chins, so they are with heads [kept] aloft.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxiv{%
And We have put before them a barrier and behind them a barrier and covered them, so they do not see.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxv{%
And it is all the same for them whether you warn them or do not warn them - they will not believe.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxvi{%
You can only warn one who follows the message and fears the Most Merciful unseen. So give him good tidings of forgiveness and noble reward.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccxvii{%
Indeed, it is We who bring the dead to life and record what they have put forth and what they left behind, and all things We have enumerated in a clear register.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccxviii{%
And present to them an example: the people of the city, when the messengers came to it -\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdccxix{%
When We sent to them two but they denied them, so We strengthened them with a third, and they said, ``Indeed, we are messengers to you."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccxx{%
They said, ``You are not but human beings like us, and the Most Merciful has not revealed a thing. You are only telling lies."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccxxi{%
They said, ``Our Lord knows that we are messengers to you,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdccxxii{%
And we are not responsible except for clear notification."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdccxxiii{%
They said, ``Indeed, we consider you a bad omen. If you do not desist, we will surely stone you, and there will surely touch you, from us, a painful punishment."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdccxxiv{%
They said, ``Your omen is with yourselves. Is it because you were reminded? Rather, you are a transgressing people."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdccxxv{%
And there came from the farthest end of the city a man, running. He said, ``O my people, follow the messengers.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdccxxvi{%
Follow those who do not ask of you [any] payment, and they are [rightly] guided.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdccxxvii{%
And why should I not worship He who created me and to whom you will be returned?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdccxxviii{%
Should I take other than Him [false] deities [while], if the Most Merciful intends for me some adversity, their intercession will not avail me at all, nor can they save me?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdccxxix{%
Indeed, I would then be in manifest error.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdccxxx{%
Indeed, I have believed in your Lord, so listen to me."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdccxxxi{%
It was said, ``Enter Paradise." He said, ``I wish my people could know\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdccxxxii{%
Of how my Lord has forgiven me and placed me among the honored."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiii{%
And We did not send down upon his people after him any soldiers from the heaven, nor would We have done so.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdccxxxiv{%
It was not but one shout, and immediately they were extinguished.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdccxxxv{%
How regretful for the servants. There did not come to them any messenger except that they used to ridicule him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvi{%
Have they not considered how many generations We destroyed before them - that they to them will not return?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdccxxxvii{%
And indeed, all of them will yet be brought present before Us.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdccxxxviii{%
And a sign for them is the dead earth. We have brought it to life and brought forth from it grain, and from it they eat.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdccxxxix{%
And We placed therein gardens of palm trees and grapevines and caused to burst forth therefrom some springs -\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdccxl{%
That they may eat of His fruit. And their hands have not produced it, so will they not be grateful?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdccxli{%
Exalted is He who created all pairs - from what the earth grows and from themselves and from that which they do not know.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdccxlii{%
And a sign for them is the night. We remove from it [the light of] day, so they are [left] in darkness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdccxliii{%
And the sun runs [on course] toward its stopping point. That is the determination of the Exalted in Might, the Knowing.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdccxliv{%
And the moon - We have determined for it phases, until it returns [appearing] like the old date stalk.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdccxlv{%
It is not allowable for the sun to reach the moon, nor does the night overtake the day, but each, in an orbit, is swimming.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdccxlvi{%
And a sign for them is that We carried their forefathers in a laden ship.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdccxlvii{%
And We created for them from the likes of it that which they ride.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdccxlviii{%
And if We should will, We could drown them; then no one responding to a cry would there be for them, nor would they be saved\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdccxlix{%
Except as a mercy from Us and provision for a time.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdccl{%
But when it is said to them, ``Beware of what is before you and what is behind you; perhaps you will receive mercy... ``\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdccli{%
And no sign comes to them from the signs of their Lord except that they are from it turning away.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcclii{%
And when it is said to them, ``Spend from that which Allah has provided for you," those who disbelieve say to those who believe, ``Should we feed one whom, if Allah had willed, He would have fed? You are not but in clear error."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdccliii{%
And they say, ``When is this promise, if you should be truthful?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdccliv{%
They do not await except one blast which will seize them while they are disputing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcclv{%
And they will not be able [to give] any instruction, nor to their people can they return.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcclvi{%
And the Horn will be blown; and at once from the graves to their Lord they will hasten.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcclvii{%
They will say, ``O woe to us! Who has raised us up from our sleeping place?" [The reply will be], ``This is what the Most Merciful had promised, and the messengers told the truth."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcclviii{%
It will not be but one blast, and at once they are all brought present before Us.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcclix{%
So today no soul will be wronged at all, and you will not be recompensed except for what you used to do.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcclx{%
Indeed the companions of Paradise, that Day, will be amused in [joyful] occupation -\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcclxi{%
They and their spouses - in shade, reclining on adorned couches.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcclxii{%
For them therein is fruit, and for them is whatever they request [or wish]\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcclxiii{%
[And] ``Peace," a word from a Merciful Lord.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcclxiv{%
[Then He will say], ``But stand apart today, you criminals.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcclxv{%
Did I not enjoin upon you, O children of Adam, that you not worship Satan - [for] indeed, he is to you a clear enemy -\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcclxvi{%
And that you worship [only] Me? This is a straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcclxvii{%
And he had already led astray from among you much of creation, so did you not use reason?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcclxviii{%
This is the Hellfire which you were promised.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdcclxix{%
[Enter to] burn therein today for what you used to deny."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcclxx{%
That Day, We will seal over their mouths, and their hands will speak to Us, and their feet will testify about what they used to earn.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcclxxi{%
And if We willed, We could have obliterated their eyes, and they would race to [find] the path, and how could they see?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdcclxxii{%
And if We willed, We could have deformed them, [paralyzing them] in their places so they would not be able to proceed, nor could they return.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiii{%
And he to whom We grant long life We reverse in creation; so will they not understand?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdcclxxiv{%
And We did not give Prophet Muhammad, knowledge of poetry, nor is it befitting for him. It is not but a message and a clear Qur'an\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdcclxxv{%
To warn whoever is alive and justify the word against the disbelievers.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvi{%
Do they not see that We have created for them from what Our hands have made, grazing livestock, and [then] they are their owners?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdcclxxvii{%
And We have tamed them for them, so some of them they ride, and some of them they eat.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdcclxxviii{%
And for them therein are [other] benefits and drinks, so will they not be grateful?\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdcclxxix{%
But they have taken besides Allah [false] deities that perhaps they would be helped.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdcclxxx{%
They are not able to help them, and they [themselves] are for them soldiers in attendance.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxi{%
So let not their speech grieve you. Indeed, We know what they conceal and what they declare.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxii{%
Does man not consider that We created him from a [mere] sperm-drop - then at once he is a clear adversary?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiii{%
And he presents for Us an example and forgets his [own] creation. He says, ``Who will give life to bones while they are disintegrated?"\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxiv{%
Say, ``He will give them life who produced them the first time; and He is, of all creation, Knowing."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxv{%
[It is] He who made for you from the green tree, fire, and then from it you ignite.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvi{%
Is not He who created the heavens and the earth Able to create the likes of them? Yes, [it is so]; and He is the Knowing Creator.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxvii{%
His command is only when He intends a thing that He says to it, ``Be," and it is.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxviii{%
So exalted is He in whose hand is the realm of all things, and to Him you will be returned.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdcclxxxix{%
\basmalahen By those [angels] lined up in rows\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmdccxc{%
And those who drive [the clouds]\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmdccxci{%
And those who recite the message,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmdccxcii{%
Indeed, your God is One,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmdccxciii{%
Lord of the heavens and the earth and that between them and Lord of the sunrises.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmdccxciv{%
Indeed, We have adorned the nearest heaven with an adornment of stars\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmdccxcv{%
And as protection against every rebellious devil\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmdccxcvi{%
[So] they may not listen to the exalted assembly [of angels] and are pelted from every side,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmdccxcvii{%
Repelled; and for them is a constant punishment,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmdccxcviii{%
Except one who snatches [some words] by theft, but they are pursued by a burning flame, piercing [in brightness].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmdccxcix{%
Then inquire of them, [O Muhammad], ``Are they a stronger [or more difficult] creation or those [others] We have created?" Indeed, We created men from sticky clay.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmdccc{%
But you wonder, while they mock,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmdccci{%
And when they are reminded, they remember not.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmdcccii{%
And when they see a sign, they ridicule\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmdccciii{%
And say, ``This is not but obvious magic.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmdccciv{%
When we have died and become dust and bones, are we indeed to be resurrected?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmdcccv{%
And our forefathers [as well]?"\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmdcccvi{%
Say, ``Yes, and you will be [rendered] contemptible."\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmdcccvii{%
It will be only one shout, and at once they will be observing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmdcccviii{%
They will say, ``O woe to us! This is the Day of Recompense."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmdcccix{%
[They will be told], ``This is the Day of Judgement which you used to deny."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmdcccx{%
[The angels will be ordered], ``Gather those who committed wrong, their kinds, and what they used to worship\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmdcccxi{%
Other than Allah, and guide them to the path of Hellfire\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmdcccxii{%
And stop them; indeed, they are to be questioned."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmdcccxiii{%
[They will be asked], ``What is [wrong] with you? Why do you not help each other?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmdcccxiv{%
But they, that Day, are in surrender.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmdcccxv{%
And they will approach one another blaming each other.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmdcccxvi{%
They will say, ``Indeed, you used to come at us from the right."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmdcccxvii{%
The oppressors will say, ``Rather, you [yourselves] were not believers,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmdcccxviii{%
And we had over you no authority, but you were a transgressing people.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmdcccxix{%
So the word of our Lord has come into effect upon us; indeed, we will taste [punishment].\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmdcccxx{%
And we led you to deviation; indeed, we were deviators."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmdcccxxi{%
So indeed they, that Day, will be sharing in the punishment.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmdcccxxii{%
Indeed, that is how We deal with the criminals.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiii{%
Indeed they, when it was said to them, ``There is no deity but Allah," were arrogant\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmdcccxxiv{%
And were saying, ``Are we to leave our gods for a mad poet?"\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmdcccxxv{%
Rather, the Prophet has come with the truth and confirmed the [previous] messengers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvi{%
Indeed, you [disbelievers] will be tasters of the painful punishment,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmdcccxxvii{%
And you will not be recompensed except for what you used to do -\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmdcccxxviii{%
But not the chosen servants of Allah.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmdcccxxix{%
Those will have a provision determined -\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmdcccxxx{%
Fruits; and they will be honored\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxi{%
In gardens of pleasure\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxii{%
On thrones facing one another.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiii{%
There will be circulated among them a cup [of wine] from a flowing spring,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxiv{%
White and delicious to the drinkers;\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxv{%
No bad effect is there in it, nor from it will they be intoxicated.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvi{%
And with them will be women limiting [their] glances, with large, [beautiful] eyes,\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxvii{%
As if they were [delicate] eggs, well-protected.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxviii{%
And they will approach one another, inquiring of each other.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmdcccxxxix{%
A speaker among them will say, ``Indeed, I had a companion [on earth]\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmdcccxl{%
Who would say, 'Are you indeed of those who believe\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmdcccxli{%
That when we have died and become dust and bones, we will indeed be recompensed?'"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmdcccxlii{%
He will say, ``Would you [care to] look?"\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmdcccxliii{%
And he will look and see him in the midst of the Hellfire.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmdcccxliv{%
He will say, ``By Allah, you almost ruined me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmdcccxlv{%
If not for the favor of my Lord, I would have been of those brought in [to Hell].\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvi{%
Then, are we not to die\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmdcccxlvii{%
Except for our first death, and we will not be punished?"\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmdcccxlviii{%
Indeed, this is the great attainment.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmdcccxlix{%
For the like of this let the workers [on earth] work.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmdcccl{%
Is Paradise a better accommodation or the tree of zaqqum?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmdcccli{%
Indeed, We have made it a torment for the wrongdoers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmdccclii{%
Indeed, it is a tree issuing from the bottom of the Hellfire,\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmdcccliii{%
Its emerging fruit as if it was heads of the devils.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmdcccliv{%
And indeed, they will eat from it and fill with it their bellies.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmdccclv{%
Then indeed, they will have after it a mixture of scalding water.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmdccclvi{%
Then indeed, their return will be to the Hellfire.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmdccclvii{%
Indeed they found their fathers astray.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmdccclviii{%
So they hastened [to follow] in their footsteps.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmdccclix{%
And there had already strayed before them most of the former peoples,\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmdccclx{%
And We had already sent among them warners.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmdccclxi{%
Then look how was the end of those who were warned -\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmdccclxii{%
But not the chosen servants of Allah.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmdccclxiii{%
And Noah had certainly called Us, and [We are] the best of responders.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmdccclxiv{%
And We saved him and his family from the great affliction.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmdccclxv{%
And We made his descendants those remaining [on the earth]\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmdccclxvi{%
And left for him [favorable mention] among later generations:\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmdccclxvii{%
``Peace upon Noah among the worlds."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmdccclxviii{%
Indeed, We thus reward the doers of good.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmdccclxix{%
Indeed, he was of Our believing servants.\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmdccclxx{%
Then We drowned the disbelievers.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmdccclxxi{%
And indeed, among his kind was Abraham,\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmdccclxxii{%
When he came to his Lord with a sound heart\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiii{%
[And] when he said to his father and his people, ``What do you worship?\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmdccclxxiv{%
Is it falsehood [as] gods other than Allah you desire?\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmdccclxxv{%
Then what is your thought about the Lord of the worlds?"\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvi{%
And he cast a look at the stars\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmdccclxxvii{%
And said, ``Indeed, I am [about to be] ill."\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmdccclxxviii{%
So they turned away from him, departing.\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmdccclxxix{%
Then he turned to their gods and said, ``Do you not eat?\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmdccclxxx{%
What is [wrong] with you that you do not speak?"\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxi{%
And he turned upon them a blow with [his] right hand.\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxii{%
Then the people came toward him, hastening.\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiii{%
He said, ``Do you worship that which you [yourselves] carve,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxiv{%
While Allah created you and that which you do?"\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxv{%
They said, ``Construct for him a furnace and throw him into the burning fire."\qt@no{97}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvi{%
And they intended for him a plan, but We made them the most debased.\qt@no{98}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxvii{%
And [then] he said, ``Indeed, I will go to [where I am ordered by] my Lord; He will guide me.\qt@no{99}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxviii{%
My Lord, grant me [a child] from among the righteous."\qt@no{100}}%
\qt@newcmd\qurantrans@en@mmmdccclxxxix{%
So We gave him good tidings of a forbearing boy.\qt@no{101}}%
\qt@newcmd\qurantrans@en@mmmdcccxc{%
And when he reached with him [the age of] exertion, he said, ``O my son, indeed I have seen in a dream that I [must] sacrifice you, so see what you think." He said, ``O my father, do as you are commanded. You will find me, if Allah wills, of the steadfast."\qt@no{102}}%
\qt@newcmd\qurantrans@en@mmmdcccxci{%
And when they had both submitted and he put him down upon his forehead,\qt@no{103}}%
\qt@newcmd\qurantrans@en@mmmdcccxcii{%
We called to him, ``O Abraham,\qt@no{104}}%
\qt@newcmd\qurantrans@en@mmmdcccxciii{%
You have fulfilled the vision." Indeed, We thus reward the doers of good.\qt@no{105}}%
\qt@newcmd\qurantrans@en@mmmdcccxciv{%
Indeed, this was the clear trial.\qt@no{106}}%
\qt@newcmd\qurantrans@en@mmmdcccxcv{%
And We ransomed him with a great sacrifice,\qt@no{107}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvi{%
And We left for him [favorable mention] among later generations:\qt@no{108}}%
\qt@newcmd\qurantrans@en@mmmdcccxcvii{%
``Peace upon Abraham."\qt@no{109}}%
\qt@newcmd\qurantrans@en@mmmdcccxcviii{%
Indeed, We thus reward the doers of good.\qt@no{110}}%
\qt@newcmd\qurantrans@en@mmmdcccxcix{%
Indeed, he was of Our believing servants.\qt@no{111}}%
\qt@newcmd\qurantrans@en@mmmcm{%
And We gave him good tidings of Isaac, a prophet from among the righteous.\qt@no{112}}%
\qt@newcmd\qurantrans@en@mmmcmi{%
And We blessed him and Isaac. But among their descendants is the doer of good and the clearly unjust to himself.\qt@no{113}}%
\qt@newcmd\qurantrans@en@mmmcmii{%
And We did certainly confer favor upon Moses and Aaron.\qt@no{114}}%
\qt@newcmd\qurantrans@en@mmmcmiii{%
And We saved them and their people from the great affliction,\qt@no{115}}%
\qt@newcmd\qurantrans@en@mmmcmiv{%
And We supported them so it was they who overcame.\qt@no{116}}%
\qt@newcmd\qurantrans@en@mmmcmv{%
And We gave them the explicit Scripture,\qt@no{117}}%
\qt@newcmd\qurantrans@en@mmmcmvi{%
And We guided them on the straight path.\qt@no{118}}%
\qt@newcmd\qurantrans@en@mmmcmvii{%
And We left for them [favorable mention] among later generations:\qt@no{119}}%
\qt@newcmd\qurantrans@en@mmmcmviii{%
``Peace upon Moses and Aaron."\qt@no{120}}%
\qt@newcmd\qurantrans@en@mmmcmix{%
Indeed, We thus reward the doers of good.\qt@no{121}}%
\qt@newcmd\qurantrans@en@mmmcmx{%
Indeed, they were of Our believing servants.\qt@no{122}}%
\qt@newcmd\qurantrans@en@mmmcmxi{%
And indeed, Elias was from among the messengers,\qt@no{123}}%
\qt@newcmd\qurantrans@en@mmmcmxii{%
When he said to his people, ``Will you not fear Allah?\qt@no{124}}%
\qt@newcmd\qurantrans@en@mmmcmxiii{%
Do you call upon Ba'l and leave the best of creators -\qt@no{125}}%
\qt@newcmd\qurantrans@en@mmmcmxiv{%
Allah, your Lord and the Lord of your first forefathers?"\qt@no{126}}%
\qt@newcmd\qurantrans@en@mmmcmxv{%
And they denied him, so indeed, they will be brought [for punishment],\qt@no{127}}%
\qt@newcmd\qurantrans@en@mmmcmxvi{%
Except the chosen servants of Allah.\qt@no{128}}%
\qt@newcmd\qurantrans@en@mmmcmxvii{%
And We left for him [favorable mention] among later generations:\qt@no{129}}%
\qt@newcmd\qurantrans@en@mmmcmxviii{%
``Peace upon Elias."\qt@no{130}}%
\qt@newcmd\qurantrans@en@mmmcmxix{%
Indeed, We thus reward the doers of good.\qt@no{131}}%
\qt@newcmd\qurantrans@en@mmmcmxx{%
Indeed, he was of Our believing servants.\qt@no{132}}%
\qt@newcmd\qurantrans@en@mmmcmxxi{%
And indeed, Lot was among the messengers.\qt@no{133}}%
\qt@newcmd\qurantrans@en@mmmcmxxii{%
[So mention] when We saved him and his family, all,\qt@no{134}}%
\qt@newcmd\qurantrans@en@mmmcmxxiii{%
Except his wife among those who remained [with the evildoers].\qt@no{135}}%
\qt@newcmd\qurantrans@en@mmmcmxxiv{%
Then We destroyed the others.\qt@no{136}}%
\qt@newcmd\qurantrans@en@mmmcmxxv{%
And indeed, you pass by them in the morning\qt@no{137}}%
\qt@newcmd\qurantrans@en@mmmcmxxvi{%
And at night. Then will you not use reason?\qt@no{138}}%
\qt@newcmd\qurantrans@en@mmmcmxxvii{%
And indeed, Jonah was among the messengers.\qt@no{139}}%
\qt@newcmd\qurantrans@en@mmmcmxxviii{%
[Mention] when he ran away to the laden ship.\qt@no{140}}%
\qt@newcmd\qurantrans@en@mmmcmxxix{%
And he drew lots and was among the losers.\qt@no{141}}%
\qt@newcmd\qurantrans@en@mmmcmxxx{%
Then the fish swallowed him, while he was blameworthy.\qt@no{142}}%
\qt@newcmd\qurantrans@en@mmmcmxxxi{%
And had he not been of those who exalt Allah,\qt@no{143}}%
\qt@newcmd\qurantrans@en@mmmcmxxxii{%
He would have remained inside its belly until the Day they are resurrected.\qt@no{144}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiii{%
But We threw him onto the open shore while he was ill.\qt@no{145}}%
\qt@newcmd\qurantrans@en@mmmcmxxxiv{%
And We caused to grow over him a gourd vine.\qt@no{146}}%
\qt@newcmd\qurantrans@en@mmmcmxxxv{%
And We sent him to [his people of] a hundred thousand or more.\qt@no{147}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvi{%
And they believed, so We gave them enjoyment [of life] for a time.\qt@no{148}}%
\qt@newcmd\qurantrans@en@mmmcmxxxvii{%
So inquire of them, [O Muhammad], ``Does your Lord have daughters while they have sons?\qt@no{149}}%
\qt@newcmd\qurantrans@en@mmmcmxxxviii{%
Or did We create the angels as females while they were witnesses?"\qt@no{150}}%
\qt@newcmd\qurantrans@en@mmmcmxxxix{%
Unquestionably, it is out of their [invented] falsehood that they say,\qt@no{151}}%
\qt@newcmd\qurantrans@en@mmmcmxl{%
`` Allah has begotten," and indeed, they are liars.\qt@no{152}}%
\qt@newcmd\qurantrans@en@mmmcmxli{%
Has He chosen daughters over sons?\qt@no{153}}%
\qt@newcmd\qurantrans@en@mmmcmxlii{%
What is [wrong] with you? How do you make judgement?\qt@no{154}}%
\qt@newcmd\qurantrans@en@mmmcmxliii{%
Then will you not be reminded?\qt@no{155}}%
\qt@newcmd\qurantrans@en@mmmcmxliv{%
Or do you have a clear authority?\qt@no{156}}%
\qt@newcmd\qurantrans@en@mmmcmxlv{%
Then produce your scripture, if you should be truthful.\qt@no{157}}%
\qt@newcmd\qurantrans@en@mmmcmxlvi{%
And they have claimed between Him and the jinn a lineage, but the jinn have already known that they [who made such claims] will be brought to [punishment].\qt@no{158}}%
\qt@newcmd\qurantrans@en@mmmcmxlvii{%
Exalted is Allah above what they describe,\qt@no{159}}%
\qt@newcmd\qurantrans@en@mmmcmxlviii{%
Except the chosen servants of Allah [who do not share in that sin].\qt@no{160}}%
\qt@newcmd\qurantrans@en@mmmcmxlix{%
So indeed, you [disbelievers] and whatever you worship,\qt@no{161}}%
\qt@newcmd\qurantrans@en@mmmcml{%
You cannot tempt [anyone] away from Him\qt@no{162}}%
\qt@newcmd\qurantrans@en@mmmcmli{%
Except he who is to [enter and] burn in the Hellfire.\qt@no{163}}%
\qt@newcmd\qurantrans@en@mmmcmlii{%
[The angels say], ``There is not among us any except that he has a known position.\qt@no{164}}%
\qt@newcmd\qurantrans@en@mmmcmliii{%
And indeed, we are those who line up [for prayer].\qt@no{165}}%
\qt@newcmd\qurantrans@en@mmmcmliv{%
And indeed, we are those who exalt Allah."\qt@no{166}}%
\qt@newcmd\qurantrans@en@mmmcmlv{%
And indeed, the disbelievers used to say,\qt@no{167}}%
\qt@newcmd\qurantrans@en@mmmcmlvi{%
``If we had a message from [those of] the former peoples,\qt@no{168}}%
\qt@newcmd\qurantrans@en@mmmcmlvii{%
We would have been the chosen servants of Allah."\qt@no{169}}%
\qt@newcmd\qurantrans@en@mmmcmlviii{%
But they disbelieved in it, so they are going to know.\qt@no{170}}%
\qt@newcmd\qurantrans@en@mmmcmlix{%
And Our word has already preceded for Our servants, the messengers,\qt@no{171}}%
\qt@newcmd\qurantrans@en@mmmcmlx{%
[That] indeed, they would be those given victory\qt@no{172}}%
\qt@newcmd\qurantrans@en@mmmcmlxi{%
And [that] indeed, Our soldiers will be those who overcome.\qt@no{173}}%
\qt@newcmd\qurantrans@en@mmmcmlxii{%
So, [O Muhammad], leave them for a time.\qt@no{174}}%
\qt@newcmd\qurantrans@en@mmmcmlxiii{%
And see [what will befall] them, for they are going to see.\qt@no{175}}%
\qt@newcmd\qurantrans@en@mmmcmlxiv{%
Then for Our punishment are they impatient?\qt@no{176}}%
\qt@newcmd\qurantrans@en@mmmcmlxv{%
But when it descends in their territory, then evil is the morning of those who were warned.\qt@no{177}}%
\qt@newcmd\qurantrans@en@mmmcmlxvi{%
And leave them for a time.\qt@no{178}}%
\qt@newcmd\qurantrans@en@mmmcmlxvii{%
And see, for they are going to see.\qt@no{179}}%
\qt@newcmd\qurantrans@en@mmmcmlxviii{%
Exalted is your Lord, the Lord of might, above what they describe.\qt@no{180}}%
\qt@newcmd\qurantrans@en@mmmcmlxix{%
And peace upon the messengers.\qt@no{181}}%
\qt@newcmd\qurantrans@en@mmmcmlxx{%
And praise to Allah, Lord of the worlds.\qt@no{182}}%
\qt@newcmd\qurantrans@en@mmmcmlxxi{%
\basmalahen Sad. By the Qur'an containing reminder...\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmcmlxxii{%
But those who disbelieve are in pride and dissension.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiii{%
How many a generation have We destroyed before them, and they [then] called out; but it was not a time for escape.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmcmlxxiv{%
And they wonder that there has come to them a warner from among themselves. And the disbelievers say, ``This is a magician and a liar.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmcmlxxv{%
Has he made the gods [only] one God? Indeed, this is a curious thing."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvi{%
And the eminent among them went forth, [saying], ``Continue, and be patient over [the defense of] your gods. Indeed, this is a thing intended.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmcmlxxvii{%
We have not heard of this in the latest religion. This is not but a fabrication.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmcmlxxviii{%
Has the message been revealed to him out of [all of] us?" Rather, they are in doubt about My message. Rather, they have not yet tasted My punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmcmlxxix{%
Or do they have the depositories of the mercy of your Lord, the Exalted in Might, the Bestower?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmcmlxxx{%
Or is theirs the dominion of the heavens and the earth and what is between them? Then let them ascend through [any] ways of access.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxi{%
[They are but] soldiers [who will be] defeated there among the companies [of disbelievers].\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxii{%
The people of Noah denied before them, and [the tribe of] 'Aad and Pharaoh, the owner of stakes,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiii{%
And [the tribe of] Thamud and the people of Lot and the companions of the thicket. Those are the companies.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxiv{%
Each of them denied the messengers, so My penalty was justified.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxv{%
And these [disbelievers] await not but one blast [of the Horn]; for it there will be no delay.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvi{%
And they say, ``Our Lord, hasten for us our share [of the punishment] before the Day of Account"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxvii{%
Be patient over what they say and remember Our servant, David, the possessor of strength; indeed, he was one who repeatedly turned back [to Allah].\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxviii{%
Indeed, We subjected the mountains [to praise] with him, exalting [Allah] in the [late] afternoon and [after] sunrise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmcmlxxxix{%
And the birds were assembled, all with him repeating [praises].\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmcmxc{%
And We strengthened his kingdom and gave him wisdom and discernment in speech.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmcmxci{%
And has there come to you the news of the adversaries, when they climbed over the wall of [his] prayer chamber -\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmcmxcii{%
When they entered upon David and he was alarmed by them? They said, ``Fear not. [We are] two adversaries, one of whom has wronged the other, so judge between us with truth and do not exceed [it] and guide us to the sound path.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmcmxciii{%
Indeed this, my brother, has ninety-nine ewes, and I have one ewe; so he said, 'Entrust her to me,' and he overpowered me in speech."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmcmxciv{%
[David] said, ``He has certainly wronged you in demanding your ewe [in addition] to his ewes. And indeed, many associates oppress one another, except for those who believe and do righteous deeds - and few are they." And David became certain that We had tried him, and he asked forgiveness of his Lord and fell down bowing [in prostration] and turned in repentance [to Allah].\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmcmxcv{%
So We forgave him that; and indeed, for him is nearness to Us and a good place of return.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmcmxcvi{%
[We said], ``O David, indeed We have made you a successor upon the earth, so judge between the people in truth and do not follow [your own] desire, as it will lead you astray from the way of Allah." Indeed, those who go astray from the way of Allah will have a severe punishment for having forgotten the Day of Account.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmcmxcvii{%
And We did not create the heaven and the earth and that between them aimlessly. That is the assumption of those who disbelieve, so woe to those who disbelieve from the Fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmcmxcviii{%
Or should we treat those who believe and do righteous deeds like corrupters in the land? Or should We treat those who fear Allah like the wicked?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmcmxcix{%
[This is] a blessed Book which We have revealed to you, [O Muhammad], that they might reflect upon its verses and that those of understanding would be reminded.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmm{%
And to David We gave Solomon. An excellent servant, indeed he was one repeatedly turning back [to Allah].\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmi{%
[Mention] when there were exhibited before him in the afternoon the poised [standing] racehorses.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmii{%
And he said, ``Indeed, I gave preference to the love of good [things] over the remembrance of my Lord until the sun disappeared into the curtain [of darkness]."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmiii{%
[He said], ``Return them to me," and set about striking [their] legs and necks.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmiv{%
And We certainly tried Solomon and placed on his throne a body; then he returned.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmv{%
He said, ``My Lord, forgive me and grant me a kingdom such as will not belong to anyone after me. Indeed, You are the Bestower."\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmvi{%
So We subjected to him the wind blowing by his command, gently, wherever he directed,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmvii{%
And [also] the devils [of jinn] - every builder and diver\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmviii{%
And others bound together in shackles.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmix{%
[We said], ``This is Our gift, so grant or withhold without account."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmx{%
And indeed, for him is nearness to Us and a good place of return.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxi{%
And remember Our servant Job, when he called to his Lord, ``Indeed, Satan has touched me with hardship and torment."\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmxii{%
[So he was told], ``Strike [the ground] with your foot; this is a [spring for] a cool bath and drink."\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmxiii{%
And We granted him his family and a like [number] with them as mercy from Us and a reminder for those of understanding.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmxiv{%
[We said], ``And take in your hand a bunch [of grass] and strike with it and do not break your oath." Indeed, We found him patient, an excellent servant. Indeed, he was one repeatedly turning back [to Allah].\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmxv{%
And remember Our servants, Abraham, Isaac and Jacob - those of strength and [religious] vision.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmxvi{%
Indeed, We chose them for an exclusive quality: remembrance of the home [of the Hereafter].\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmxvii{%
And indeed they are, to Us, among the chosen and outstanding.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmxviii{%
And remember Ishmael, Elisha and Dhul-Kifl, and all are among the outstanding.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmxix{%
This is a reminder. And indeed, for the righteous is a good place of return\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmxx{%
Gardens of perpetual residence, whose doors will be opened to them.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmxxi{%
Reclining within them, they will call therein for abundant fruit and drink.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmxxii{%
And with them will be women limiting [their] glances and of equal age.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmxxiii{%
This is what you, [the righteous], are promised for the Day of Account.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmxxiv{%
Indeed, this is Our provision; for it there is no depletion.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmxxv{%
This [is so]. But indeed, for the transgressors is an evil place of return -\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmxxvi{%
Hell, which they will [enter to] burn, and wretched is the resting place.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmxxvii{%
This - so let them taste it - is scalding water and [foul] purulence.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmxxviii{%
And other [punishments] of its type [in various] kinds.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmxxix{%
[Its inhabitants will say], ``This is a company bursting in with you. No welcome for them. Indeed, they will burn in the Fire."\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmxxx{%
They will say, ``Nor you! No welcome for you. You, [our leaders], brought this upon us, and wretched is the settlement."\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmxxxi{%
They will say, ``Our Lord, whoever brought this upon us - increase for him double punishment in the Fire."\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmxxxii{%
And they will say, ``Why do we not see men whom we used to count among the worst?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmxxxiii{%
Is it [because] we took them in ridicule, or has [our] vision turned away from them?"\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmxxxiv{%
Indeed, that is truth - the quarreling of the people of the Fire.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmxxxv{%
Say, [O Muhammad], ``I am only a warner, and there is not any deity except Allah, the One, the Prevailing.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmxxxvi{%
Lord of the heavens and the earth and whatever is between them, the Exalted in Might, the Perpetual Forgiver."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmxxxvii{%
Say, ``It is great news\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmxxxviii{%
From which you turn away.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmxxxix{%
I had no knowledge of the exalted assembly [of angels] when they were disputing [the creation of Adam].\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmxl{%
It has not been revealed to me except that I am a clear warner."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmxli{%
[So mention] when your Lord said to the angels, ``Indeed, I am going to create a human being from clay.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmxlii{%
So when I have proportioned him and breathed into him of My [created] soul, then fall down to him in prostration."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmxliii{%
So the angels prostrated - all of them entirely.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmxliv{%
Except Iblees; he was arrogant and became among the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmxlv{%
[Allah] said, ``O Iblees, what prevented you from prostrating to that which I created with My hands? Were you arrogant [then], or were you [already] among the haughty?"\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmxlvi{%
He said, ``I am better than him. You created me from fire and created him from clay."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmxlvii{%
[Allah] said, ``Then get out of Paradise, for indeed, you are expelled.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmxlviii{%
And indeed, upon you is My curse until the Day of Recompense."\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmxlix{%
He said, ``My Lord, then reprieve me until the Day they are resurrected."\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmml{%
[Allah] said, ``So indeed, you are of those reprieved\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmli{%
Until the Day of the time well-known."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmlii{%
[Iblees] said, ``By your might, I will surely mislead them all\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmliii{%
Except, among them, Your chosen servants."\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmliv{%
[Allah] said, ``The truth [is My oath], and the truth I say -\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmlv{%
[That] I will surely fill Hell with you and those of them that follow you all together."\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmlvi{%
Say, [O Muhammad], ``I do not ask you for the Qur'an any payment, and I am not of the pretentious\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmlvii{%
It is but a reminder to the worlds.\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmlviii{%
And you will surely know [the truth of] its information after a time."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmlix{%
\basmalahen The revelation of the Qur'an is from Allah, the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmlx{%
Indeed, We have sent down to you the Book, [O Muhammad], in truth. So worship Allah, [being] sincere to Him in religion.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmlxi{%
Unquestionably, for Allah is the pure religion. And those who take protectors besides Him [say], ``We only worship them that they may bring us nearer to Allah in position." Indeed, Allah will judge between them concerning that over which they differ. Indeed, Allah does not guide he who is a liar and [confirmed] disbeliever.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmlxii{%
If Allah had intended to take a son, He could have chosen from what He creates whatever He willed. Exalted is He; He is Allah, the One, the Prevailing.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmlxiii{%
He created the heavens and earth in truth. He wraps the night over the day and wraps the day over the night and has subjected the sun and the moon, each running [its course] for a specified term. Unquestionably, He is the Exalted in Might, the Perpetual Forgiver.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmlxiv{%
He created you from one soul. Then He made from it its mate, and He produced for you from the grazing livestock eight mates. He creates you in the wombs of your mothers, creation after creation, within three darknesses. That is Allah, your Lord; to Him belongs dominion. There is no deity except Him, so how are you averted?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmlxv{%
If you disbelieve - indeed, Allah is Free from need of you. And He does not approve for His servants disbelief. And if you are grateful, He approves it for you; and no bearer of burdens will bear the burden of another. Then to your Lord is your return, and He will inform you about what you used to do. Indeed, He is Knowing of that within the breasts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmlxvi{%
And when adversity touches man, he calls upon his Lord, turning to Him [alone]; then when He bestows on him a favor from Himself, he forgets Him whom he called upon before, and he attributes to Allah equals to mislead [people] from His way. Say, ``Enjoy your disbelief for a little; indeed, you are of the companions of the Fire."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmlxvii{%
Is one who is devoutly obedient during periods of the night, prostrating and standing [in prayer], fearing the Hereafter and hoping for the mercy of his Lord, [like one who does not]? Say, ``Are those who know equal to those who do not know?" Only they will remember [who are] people of understanding.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmlxviii{%
Say, ``O My servants who have believed, fear your Lord. For those who do good in this world is good, and the earth of Allah is spacious. Indeed, the patient will be given their reward without account."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmlxix{%
Say, [O Muhammad], ``Indeed, I have been commanded to worship Allah, [being] sincere to Him in religion.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmlxx{%
And I have been commanded to be the first [among you] of the Muslims."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmlxxi{%
Say, ``Indeed I fear, if I should disobey my Lord, the punishment of a tremendous Day."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmlxxii{%
Say, ``Allah [alone] do I worship, sincere to Him in my religion,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmlxxiii{%
So worship what you will besides Him." Say, ``Indeed, the losers are the ones who will lose themselves and their families on the Day of Resurrection. Unquestionably, that is the manifest loss."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmlxxiv{%
They will have canopies of fire above them and below them, canopies. By that Allah threatens His servants. O My servants, then fear Me.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmlxxv{%
But those who have avoided Taghut, lest they worship it, and turned back to Allah - for them are good tidings. So give good tidings to My servants\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmlxxvi{%
Who listen to speech and follow the best of it. Those are the ones Allah has guided, and those are people of understanding.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmlxxvii{%
Then, is one who has deserved the decree of punishment [to be guided]? Then, can you save one who is in the Fire?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmlxxviii{%
But those who have feared their Lord - for them are chambers, above them chambers built high, beneath which rivers flow. [This is] the promise of Allah. Allah does not fail in [His] promise.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmlxxix{%
Do you not see that Allah sends down rain from the sky and makes it flow as springs [and rivers] in the earth; then He produces thereby crops of varying colors; then they dry and you see them turned yellow; then He makes them [scattered] debris. Indeed in that is a reminder for those of understanding.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmlxxx{%
So is one whose breast Allah has expanded to [accept] Islam and he is upon a light from his Lord [like one whose heart rejects it]? Then woe to those whose hearts are hardened against the remembrance of Allah. Those are in manifest error.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmlxxxi{%
Allah has sent down the best statement: a consistent Book wherein is reiteration. The skins shiver therefrom of those who fear their Lord; then their skins and their hearts relax at the remembrance of Allah. That is the guidance of Allah by which He guides whom He wills. And one whom Allah leaves astray - for him there is no guide.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmlxxxii{%
Then is he who will shield with his face the worst of the punishment on the Day of Resurrection [like one secure from it]? And it will be said to the wrongdoers, ``Taste what you used to earn."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiii{%
Those before them denied, and punishment came upon them from where they did not perceive.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmlxxxiv{%
So Allah made them taste disgrace in worldly life. But the punishment of the Hereafter is greater, if they only knew.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmlxxxv{%
And We have certainly presented for the people in this Qur'an from every [kind of] example - that they might remember.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvi{%
[It is] an Arabic Qur'an, without any deviance that they might become righteous.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmlxxxvii{%
Allah presents an example: a slave owned by quarreling partners and another belonging exclusively to one man - are they equal in comparison? Praise be to Allah! But most of them do not know.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmlxxxviii{%
Indeed, you are to die, and indeed, they are to die.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmlxxxix{%
Then indeed you, on the Day of Resurrection, before your Lord, will dispute.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmxc{%
So who is more unjust than one who lies about Allah and denies the truth when it has come to him? Is there not in Hell a residence for the disbelievers?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmxci{%
And the one who has brought the truth and [they who] believed in it - those are the righteous.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmxcii{%
They will have whatever they desire with their Lord. That is the reward of the doers of good -\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmxciii{%
That Allah may remove from them the worst of what they did and reward them their due for the best of what they used to do.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmxciv{%
Is not Allah sufficient for His Servant [Prophet Muhammad]? And [yet], they threaten you with those [they worship] other than Him. And whoever Allah leaves astray - for him there is no guide.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmxcv{%
And whoever Allah guides - for him there is no misleader. Is not Allah Exalted in Might and Owner of Retribution?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmxcvi{%
And if you asked them, ``Who created the heavens and the earth?" they would surely say, ``Allah." Say, ``Then have you considered what you invoke besides Allah? If Allah intended me harm, are they removers of His harm; or if He intended me mercy, are they withholders of His mercy?" Say, ``Sufficient for me is Allah; upon Him [alone] rely the [wise] reliers."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmxcvii{%
Say, ``O my people, work according to your position, [for] indeed, I am working; and you are going to know\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmxcviii{%
To whom will come a torment disgracing him and on whom will descend an enduring punishment."\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmxcix{%
Indeed, We sent down to you the Book for the people in truth. So whoever is guided - it is for [the benefit of] his soul; and whoever goes astray only goes astray to its detriment. And you are not a manager over them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmc{%
Allah takes the souls at the time of their death, and those that do not die [He takes] during their sleep. Then He keeps those for which He has decreed death and releases the others for a specified term. Indeed in that are signs for a people who give thought.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmci{%
Or have they taken other than Allah as intercessors? Say, ``Even though they do not possess [power over] anything, nor do they reason?"\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcii{%
Say, ``To Allah belongs [the right to allow] intercession entirely. To Him belongs the dominion of the heavens and the earth. Then to Him you will be returned."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmciii{%
And when Allah is mentioned alone, the hearts of those who do not believe in the Hereafter shrink with aversion, but when those [worshipped] other than Him are mentioned, immediately they rejoice.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmciv{%
Say, ``O Allah, Creator of the heavens and the earth, Knower of the unseen and the witnessed, You will judge between your servants concerning that over which they used to differ."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcv{%
And if those who did wrong had all that is in the earth entirely and the like of it with it, they would [attempt to] ransom themselves thereby from the worst of the punishment on the Day of Resurrection. And there will appear to them from Allah that which they had not taken into account.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcvi{%
And there will appear to them the evils they had earned, and they will be enveloped by what they used to ridicule.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcvii{%
And when adversity touches man, he calls upon Us; then when We bestow on him a favor from Us, he says, ``I have only been given it because of [my] knowledge." Rather, it is a trial, but most of them do not know.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcviii{%
Those before them had already said it, but they were not availed by what they used to earn.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcix{%
And the evil consequences of what they earned struck them. And those who have wronged of these [people] will be afflicted by the evil consequences of what they earned; and they will not cause failure.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcx{%
Do they not know that Allah extends provision for whom He wills and restricts [it]? Indeed in that are signs for a people who believe.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcxi{%
Say, ``O My servants who have transgressed against themselves [by sinning], do not despair of the mercy of Allah. Indeed, Allah forgives all sins. Indeed, it is He who is the Forgiving, the Merciful."\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcxii{%
And return [in repentance] to your Lord and submit to Him before the punishment comes upon you; then you will not be helped.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcxiii{%
And follow the best of what was revealed to you from your Lord before the punishment comes upon you suddenly while you do not perceive,\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcxiv{%
Lest a soul should say, ``Oh [how great is] my regret over what I neglected in regard to Allah and that I was among the mockers."\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxv{%
Or [lest] it say, ``If only Allah had guided me, I would have been among the righteous."\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxvi{%
Or [lest] it say when it sees the punishment, ``If only I had another turn so I could be among the doers of good."\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxvii{%
But yes, there had come to you My verses, but you denied them and were arrogant, and you were among the disbelievers.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxviii{%
And on the Day of Resurrection you will see those who lied about Allah [with] their faces blackened. Is there not in Hell a residence for the arrogant?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxix{%
And Allah will save those who feared Him by their attainment; no evil will touch them, nor will they grieve.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxx{%
Allah is the Creator of all things, and He is, over all things, Disposer of affairs.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxxi{%
To Him belong the keys of the heavens and the earth. And they who disbelieve in the verses of Allah - it is those who are the losers.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxxii{%
Say, [O Muhammad], ``Is it other than Allah that you order me to worship, O ignorant ones?"\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxxiii{%
And it was already revealed to you and to those before you that if you should associate [anything] with Allah, your work would surely become worthless, and you would surely be among the losers."\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxxiv{%
Rather, worship [only] Allah and be among the grateful.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcxxv{%
They have not appraised Allah with true appraisal, while the earth entirely will be [within] His grip on the Day of Resurrection, and the heavens will be folded in His right hand. Exalted is He and high above what they associate with Him.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcxxvi{%
And the Horn will be blown, and whoever is in the heavens and whoever is on the earth will fall dead except whom Allah wills. Then it will be blown again, and at once they will be standing, looking on.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcxxvii{%
And the earth will shine with the light of its Lord, and the record [of deeds] will be placed, and the prophets and the witnesses will be brought, and it will be judged between them in truth, and they will not be wronged.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcxxviii{%
And every soul will be fully compensated [for] what it did; and He is most knowing of what they do.\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcxxix{%
And those who disbelieved will be driven to Hell in groups until, when they reach it, its gates are opened and its keepers will say, ``Did there not come to you messengers from yourselves, reciting to you the verses of your Lord and warning you of the meeting of this Day of yours?" They will say, ``Yes, but the word of punishment has come into effect upon the disbelievers.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcxxx{%
[To them] it will be said, ``Enter the gates of Hell to abide eternally therein, and wretched is the residence of the arrogant."\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcxxxi{%
But those who feared their Lord will be driven to Paradise in groups until, when they reach it while its gates have been opened and its keepers say, ``Peace be upon you; you have become pure; so enter it to abide eternally therein," [they will enter].\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcxxxii{%
And they will say, ``Praise to Allah, who has fulfilled for us His promise and made us inherit the earth [so] we may settle in Paradise wherever we will. And excellent is the reward of [righteous] workers."\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiii{%
And you will see the angels surrounding the Throne, exalting [Allah] with praise of their Lord. And it will be judged between them in truth, and it will be said, ``[All] praise to Allah, Lord of the worlds."\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcxxxiv{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcxxxv{%
The revelation of the Book is from Allah, the Exalted in Might, the Knowing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvi{%
The forgiver of sin, acceptor of repentance, severe in punishment, owner of abundance. There is no deity except Him; to Him is the destination.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcxxxvii{%
No one disputes concerning the signs of Allah except those who disbelieve, so be not deceived by their [uninhibited] movement throughout the land.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcxxxviii{%
The people of Noah denied before them and the [disbelieving] factions after them, and every nation intended [a plot] for their messenger to seize him, and they disputed by [using] falsehood to [attempt to] invalidate thereby the truth. So I seized them, and how [terrible] was My penalty.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcxxxix{%
And thus has the word of your Lord come into effect upon those who disbelieved that they are companions of the Fire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcxl{%
Those [angels] who carry the Throne and those around it exalt [Allah] with praise of their Lord and believe in Him and ask forgiveness for those who have believed, [saying], ``Our Lord, You have encompassed all things in mercy and knowledge, so forgive those who have repented and followed Your way and protect them from the punishment of Hellfire.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcxli{%
Our Lord, and admit them to gardens of perpetual residence which You have promised them and whoever was righteous among their fathers, their spouses and their offspring. Indeed, it is You who is the Exalted in Might, the Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcxlii{%
And protect them from the evil consequences [of their deeds]. And he whom You protect from evil consequences that Day - You will have given him mercy. And that is the great attainment."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcxliii{%
Indeed, those who disbelieve will be addressed, ``The hatred of Allah for you was [even] greater than your hatred of yourselves [this Day in Hell] when you were invited to faith, but you refused."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcxliv{%
They will say, ``Our Lord, You made us lifeless twice and gave us life twice, and we have confessed our sins. So is there to an exit any way?"\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcxlv{%
[They will be told], ``That is because, when Allah was called upon alone, you disbelieved; but if others were associated with Him, you believed. So the judgement is with Allah, the Most High, the Grand."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcxlvi{%
It is He who shows you His signs and sends down to you from the sky, provision. But none will remember except he who turns back [in repentance].\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcxlvii{%
So invoke Allah, [being] sincere to Him in religion, although the disbelievers dislike it.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcxlviii{%
[He is] the Exalted above [all] degrees, Owner of the Throne; He places the inspiration of His command upon whom He wills of His servants to warn of the Day of Meeting.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcxlix{%
The Day they come forth nothing concerning them will be concealed from Allah. To whom belongs [all] sovereignty this Day? To Allah, the One, the Prevailing.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcl{%
This Day every soul will be recompensed for what it earned. No injustice today! Indeed, Allah is swift in account.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcli{%
And warn them, [O Muhammad], of the Approaching Day, when hearts are at the throats, filled [with distress]. For the wrongdoers there will be no devoted friend and no intercessor [who is] obeyed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmclii{%
He knows that which deceives the eyes and what the breasts conceal.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcliii{%
And Allah judges with truth, while those they invoke besides Him judge not with anything. Indeed, Allah - He is the Hearing, the Seeing.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcliv{%
Have they not traveled through the land and observed how was the end of those who were before them? They were greater than them in strength and in impression on the land, but Allah seized them for their sins. And they had not from Allah any protector.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmclv{%
That was because their messengers were coming to them with clear proofs, but they disbelieved, so Allah seized them. Indeed, He is Powerful and severe in punishment.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmclvi{%
And We did certainly send Moses with Our signs and a clear authority\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmclvii{%
To Pharaoh, Haman and Qarun; but they said, ``[He is] a magician and a liar."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmclviii{%
And when he brought them the truth from Us, they said, ``Kill the sons of those who have believed with him and keep their women alive." But the plan of the disbelievers is not except in error.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmclix{%
And Pharaoh said, ``Let me kill Moses and let him call upon his Lord. Indeed, I fear that he will change your religion or that he will cause corruption in the land."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmclx{%
But Moses said, ``Indeed, I have sought refuge in my Lord and your Lord from every arrogant one who does not believe in the Day of Account."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmclxi{%
And a believing man from the family of Pharaoh who concealed his faith said, ``Do you kill a man [merely] because he says, 'My Lord is Allah' while he has brought you clear proofs from your Lord? And if he should be lying, then upon him is [the consequence of] his lie; but if he should be truthful, there will strike you some of what he promises you. Indeed, Allah does not guide one who is a transgressor and a liar.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmclxii{%
O my people, sovereignty is yours today, [your being] dominant in the land. But who would protect us from the punishment of Allah if it came to us?" Pharaoh said, ``I do not show you except what I see, and I do not guide you except to the way of right conduct."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmclxiii{%
And he who believed said, ``O my people, indeed I fear for you [a fate] like the day of the companies -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmclxiv{%
Like the custom of the people of Noah and of 'Aad and Thamud and those after them. And Allah wants no injustice for [His] servants.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmclxv{%
And O my people, indeed I fear for you the Day of Calling -\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmclxvi{%
The Day you will turn your backs fleeing; there is not for you from Allah any protector. And whoever Allah leaves astray - there is not for him any guide.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmclxvii{%
And Joseph had already come to you before with clear proofs, but you remained in doubt of that which he brought to you, until when he died, you said, 'Never will Allah send a messenger after him.' Thus does Allah leave astray he who is a transgressor and skeptic."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmclxviii{%
Those who dispute concerning the signs of Allah without an authority having come to them - great is hatred [of them] in the sight of Allah and in the sight of those who have believed. Thus does Allah seal over every heart [belonging to] an arrogant tyrant.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmclxix{%
And Pharaoh said, ``O Haman, construct for me a tower that I might reach the ways -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmclxx{%
The ways into the heavens - so that I may look at the deity of Moses; but indeed, I think he is a liar." And thus was made attractive to Pharaoh the evil of his deed, and he was averted from the [right] way. And the plan of Pharaoh was not except in ruin.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmclxxi{%
And he who believed said, ``O my people, follow me, I will guide you to the way of right conduct.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmclxxii{%
O my people, this worldly life is only [temporary] enjoyment, and indeed, the Hereafter - that is the home of [permanent] settlement.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmclxxiii{%
Whoever does an evil deed will not be recompensed except by the like thereof; but whoever does righteousness, whether male or female, while he is a believer - those will enter Paradise, being given provision therein without account.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmclxxiv{%
And O my people, how is it that I invite you to salvation while you invite me to the Fire?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmclxxv{%
You invite me to disbelieve in Allah and associate with Him that of which I have no knowledge, and I invite you to the Exalted in Might, the Perpetual Forgiver.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmclxxvi{%
Assuredly, that to which you invite me has no [response to a] supplication in this world or in the Hereafter; and indeed, our return is to Allah, and indeed, the transgressors will be companions of the Fire.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmclxxvii{%
And you will remember what I [now] say to you, and I entrust my affair to Allah. Indeed, Allah is Seeing of [His] servants."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmclxxviii{%
So Allah protected him from the evils they plotted, and the people of Pharaoh were enveloped by the worst of punishment -\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmclxxix{%
The Fire, they are exposed to it morning and evening. And the Day the Hour appears [it will be said], ``Make the people of Pharaoh enter the severest punishment."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmclxxx{%
And [mention] when they will argue within the Fire, and the weak will say to those who had been arrogant, ``Indeed, we were [only] your followers, so will you relieve us of a share of the Fire?"\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmclxxxi{%
Those who had been arrogant will say, ``Indeed, all [of us] are in it. Indeed, Allah has judged between the servants."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmclxxxii{%
And those in the Fire will say to the keepers of Hell, ``Supplicate your Lord to lighten for us a day from the punishment."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiii{%
They will say, ``Did there not come to you your messengers with clear proofs?" They will say, ``Yes." They will reply, ``Then supplicate [yourselves], but the supplication of the disbelievers is not except in error."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmclxxxiv{%
Indeed, We will support Our messengers and those who believe during the life of this world and on the Day when the witnesses will stand -\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmclxxxv{%
The Day their excuse will not benefit the wrongdoers, and they will have the curse, and they will have the worst home.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvi{%
And We had certainly given Moses guidance, and We caused the Children of Israel to inherit the Scripture\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmclxxxvii{%
As guidance and a reminder for those of understanding.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmclxxxviii{%
So be patient, [O Muhammad]. Indeed, the promise of Allah is truth. And ask forgiveness for your sin and exalt [Allah] with praise of your Lord in the evening and the morning.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmclxxxix{%
Indeed, those who dispute concerning the signs of Allah without [any] authority having come to them - there is not within their breasts except pride, [the extent of] which they cannot reach. So seek refuge in Allah. Indeed, it is He who is the Hearing, the Seeing.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcxc{%
The creation of the heavens and earth is greater than the creation of mankind, but most of the people do not know.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcxci{%
And not equal are the blind and the seeing, nor are those who believe and do righteous deeds and the evildoer. Little do you remember.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcxcii{%
Indeed, the Hour is coming - no doubt about it - but most of the people do not believe.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcxciii{%
And your Lord says, ``Call upon Me; I will respond to you." Indeed, those who disdain My worship will enter Hell [rendered] contemptible.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcxciv{%
It is Allah who made for you the night that you may rest therein and the day giving sight. Indeed, Allah is full of bounty to the people, but most of the people are not grateful.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcxcv{%
That is Allah, your Lord, Creator of all things; there is no deity except Him, so how are you deluded?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcxcvi{%
Thus were those [before you] deluded who were rejecting the signs of Allah.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcxcvii{%
It is Allah who made for you the earth a place of settlement and the sky a ceiling and formed you and perfected your forms and provided you with good things. That is Allah, your Lord; then blessed is Allah, Lord of the worlds.\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcxcviii{%
He is the Ever-Living; there is no deity except Him, so call upon Him, [being] sincere to Him in religion. [All] praise is [due] to Allah, Lord of the worlds.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcxcix{%
Say, [O Muhammad], ``Indeed, I have been forbidden to worship those you call upon besides Allah once the clear proofs have come to me from my Lord, and I have been commanded to submit to the Lord of the worlds."\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcc{%
It is He who created you from dust, then from a sperm-drop, then from a clinging clot; then He brings you out as a child; then [He develops you] that you reach your [time of] maturity, then [further] that you become elders. And among you is he who is taken in death before [that], so that you reach a specified term; and perhaps you will use reason.\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcci{%
He it is who gives life and causes death; and when He decrees a matter, He but says to it, ``Be," and it is.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmccii{%
Do you not consider those who dispute concerning the signs of Allah - how are they averted?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcciii{%
Those who deny the Book and that with which We sent Our messengers - they are going to know,\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcciv{%
When the shackles are around their necks and the chains; they will be dragged\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmccv{%
In boiling water; then in the Fire they will be filled [with flame].\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmccvi{%
Then it will be said to them, ``Where is that which you used to associate [with Him in worship]\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmccvii{%
Other than Allah?" They will say, ``They have departed from us; rather, we did not used to invoke previously anything." Thus does Allah put astray the disbelievers.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmccviii{%
[The angels will say], ``That was because you used to exult upon the earth without right and you used to behave insolently.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmccix{%
Enter the gates of Hell to abide eternally therein, and wretched is the residence of the arrogant."\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmccx{%
So be patient, [O Muhammad]; indeed, the promise of Allah is truth. And whether We show you some of what We have promised them or We take you in death, it is to Us they will be returned.\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmccxi{%
And We have already sent messengers before you. Among them are those [whose stories] We have related to you, and among them are those [whose stories] We have not related to you. And it was not for any messenger to bring a sign [or verse] except by permission of Allah. So when the command of Allah comes, it will be concluded in truth, and the falsifiers will thereupon lose [all].\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmccxii{%
It is Allah who made for you the grazing animals upon which you ride, and some of them you eat.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmccxiii{%
And for you therein are [other] benefits and that you may realize upon them a need which is in your breasts; and upon them and upon ships you are carried.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmccxiv{%
And He shows you His signs. So which of the signs of Allah do you deny?\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmccxv{%
Have they not traveled through the land and observed how was the end of those before them? They were more numerous than themselves and greater in strength and in impression on the land, but they were not availed by what they used to earn.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmccxvi{%
And when their messengers came to them with clear proofs, they [merely] rejoiced in what they had of knowledge, but they were enveloped by what they used to ridicule.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmccxvii{%
And when they saw Our punishment, they said," We believe in Allah alone and disbelieve in that which we used to associate with Him."\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmccxviii{%
But never did their faith benefit them once they saw Our punishment. [It is] the established way of Allah which has preceded among His servants. And the disbelievers thereupon lost [all].\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmccxix{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmccxx{%
[This is] a revelation from the Entirely Merciful, the Especially Merciful -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmccxxi{%
A Book whose verses have been detailed, an Arabic Qur'an for a people who know,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmccxxii{%
As a giver of good tidings and a warner; but most of them turn away, so they do not hear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmccxxiii{%
And they say, ``Our hearts are within coverings from that to which you invite us, and in our ears is deafness, and between us and you is a partition, so work; indeed, we are working."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmccxxiv{%
Say, O [Muhammad], ``I am only a man like you to whom it has been revealed that your god is but one God; so take a straight course to Him and seek His forgiveness." And woe to those who associate others with Allah -\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmccxxv{%
Those who do not give zakah, and in the Hereafter they are disbelievers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmccxxvi{%
Indeed, those who believe and do righteous deeds - for them is a reward uninterrupted.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmccxxvii{%
Say, ``Do you indeed disbelieve in He who created the earth in two days and attribute to Him equals? That is the Lord of the worlds."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmccxxviii{%
And He placed on the earth firmly set mountains over its surface, and He blessed it and determined therein its [creatures'] sustenance in four days without distinction - for [the information] of those who ask.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmccxxix{%
Then He directed Himself to the heaven while it was smoke and said to it and to the earth, ``Come [into being], willingly or by compulsion." They said, ``We have come willingly."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmccxxx{%
And He completed them as seven heavens within two days and inspired in each heaven its command. And We adorned the nearest heaven with lamps and as protection. That is the determination of the Exalted in Might, the Knowing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmccxxxi{%
But if they turn away, then say, ``I have warned you of a thunderbolt like the thunderbolt [that struck] 'Aad and Thamud.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmccxxxii{%
[That occurred] when the messengers had come to them before them and after them, [saying], ``Worship not except Allah." They said, ``If our Lord had willed, He would have sent down the angels, so indeed we, in that with which you have been sent, are disbelievers."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiii{%
As for 'Aad, they were arrogant upon the earth without right and said, ``Who is greater than us in strength?" Did they not consider that Allah who created them was greater than them in strength? But they were rejecting Our signs.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmccxxxiv{%
So We sent upon them a screaming wind during days of misfortune to make them taste the punishment of disgrace in the worldly life; but the punishment of the Hereafter is more disgracing, and they will not be helped.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmccxxxv{%
And as for Thamud, We guided them, but they preferred blindness over guidance, so the thunderbolt of humiliating punishment seized them for what they used to earn.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvi{%
And We saved those who believed and used to fear Allah.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxxxvii{%
And [mention, O Muhammad], the Day when the enemies of Allah will be gathered to the Fire while they are [driven] assembled in rows,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxxxviii{%
Until, when they reach it, their hearing and their eyes and their skins will testify against them of what they used to do.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxxxix{%
And they will say to their skins, ``Why have you testified against us?" They will say, ``We were made to speak by Allah, who has made everything speak; and He created you the first time, and to Him you are returned.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxl{%
And you were not covering yourselves, lest your hearing testify against you or your sight or your skins, but you assumed that Allah does not know much of what you do.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxli{%
And that was your assumption which you assumed about your Lord. It has brought you to ruin, and you have become among the losers."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxlii{%
So [even] if they are patient, the Fire is a residence for them; and if they ask to appease [Allah], they will not be of those who are allowed to appease.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxliii{%
And We appointed for them companions who made attractive to them what was before them and what was behind them [of sin], and the word has come into effect upon them among nations which had passed on before them of jinn and men. Indeed, they [all] were losers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxliv{%
And those who disbelieve say, ``Do not listen to this Qur'an and speak noisily during [the recitation of] it that perhaps you will overcome."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxlv{%
But We will surely cause those who disbelieve to taste a severe punishment, and We will surely recompense them for the worst of what they had been doing.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccxlvi{%
That is the recompense of the enemies of Allah - the Fire. For them therein is the home of eternity as recompense for what they, of Our verses, were rejecting.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccxlvii{%
And those who disbelieved will [then] say, ``Our Lord, show us those who misled us of the jinn and men [so] we may put them under our feet that they will be among the lowest."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccxlviii{%
Indeed, those who have said, ``Our Lord is Allah `` and then remained on a right course - the angels will descend upon them, [saying], ``Do not fear and do not grieve but receive good tidings of Paradise, which you were promised.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccxlix{%
We [angels] were your allies in worldly life and [are so] in the Hereafter. And you will have therein whatever your souls desire, and you will have therein whatever you request [or wish]\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccl{%
As accommodation from a [Lord who is] Forgiving and Merciful."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccli{%
And who is better in speech than one who invites to Allah and does righteousness and says, ``Indeed, I am of the Muslims."\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcclii{%
And not equal are the good deed and the bad. Repel [evil] by that [deed] which is better; and thereupon the one whom between you and him is enmity [will become] as though he was a devoted friend.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccliii{%
But none is granted it except those who are patient, and none is granted it except one having a great portion [of good].\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccliv{%
And if there comes to you from Satan an evil suggestion, then seek refuge in Allah. Indeed, He is the Hearing, the Knowing.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcclv{%
And of His signs are the night and day and the sun and moon. Do not prostrate to the sun or to the moon, but prostate to Allah, who created them, if it should be Him that you worship.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcclvi{%
But if they are arrogant - then those who are near your Lord exalt Him by night and by day, and they do not become weary.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcclvii{%
And of His signs is that you see the earth stilled, but when We send down upon it rain, it quivers and grows. Indeed, He who has given it life is the Giver of Life to the dead. Indeed, He is over all things competent.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcclviii{%
Indeed, those who inject deviation into Our verses are not concealed from Us. So, is he who is cast into the Fire better or he who comes secure on the Day of Resurrection? Do whatever you will; indeed, He is Seeing of what you do.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcclix{%
Indeed, those who disbelieve in the message after it has come to them... And indeed, it is a mighty Book.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcclx{%
Falsehood cannot approach it from before it or from behind it; [it is] a revelation from a [Lord who is] Wise and Praiseworthy.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcclxi{%
Nothing is said to you, [O Muhammad], except what was already said to the messengers before you. Indeed, your Lord is a possessor of forgiveness and a possessor of painful penalty.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcclxii{%
And if We had made it a non-Arabic Qur'an, they would have said, ``Why are its verses not explained in detail [in our language]? Is it a foreign [recitation] and an Arab [messenger]?" Say, ``It is, for those who believe, a guidance and cure." And those who do not believe - in their ears is deafness, and it is upon them blindness. Those are being called from a distant place.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcclxiii{%
And We had already given Moses the Scripture, but it came under disagreement. And if not for a word that preceded from your Lord, it would have been concluded between them. And indeed they are, concerning the Qur'an, in disquieting doubt.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcclxiv{%
Whoever does righteousness - it is for his [own] soul; and whoever does evil [does so] against it. And your Lord is not ever unjust to [His] servants.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcclxv{%
To him [alone] is attributed knowledge of the Hour. And fruits emerge not from their coverings nor does a female conceive or give birth except with His knowledge. And the Day He will call to them, ``Where are My 'partners'?" they will say, ``We announce to You that there is [no longer] among us any witness [to that]."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcclxvi{%
And lost from them will be those they were invoking before, and they will be certain that they have no place of escape.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcclxvii{%
Man is not weary of supplication for good [things], but if evil touches him, he is hopeless and despairing.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcclxviii{%
And if We let him taste mercy from Us after an adversity which has touched him, he will surely say, ``This is [due] to me, and I do not think the Hour will occur; and [even] if I should be returned to my Lord, indeed, for me there will be with Him the best." But We will surely inform those who disbelieved about what they did, and We will surely make them taste a massive punishment.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcclxix{%
And when We bestow favor upon man, he turns away and distances himself; but when evil touches him, then he is full of extensive supplication.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcclxx{%
Say, ``Have you considered: if the Qur'an is from Allah and you disbelieved in it, who would be more astray than one who is in extreme dissension?"\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcclxxi{%
We will show them Our signs in the horizons and within themselves until it becomes clear to them that it is the truth. But is it not sufficient concerning your Lord that He is, over all things, a Witness?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcclxxii{%
Unquestionably, they are in doubt about the meeting with their Lord. Unquestionably He is, of all things, encompassing.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiii{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcclxxiv{%
'Ayn, Seen, Qaf.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcclxxv{%
Thus has He revealed to you, [O Muhammad], and to those before you - Allah, the Exalted in Might, the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvi{%
To Him belongs whatever is in the heavens and whatever is in the earth, and He is the Most High, the Most Great.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcclxxvii{%
The heavens almost break from above them, and the angels exalt [Allah] with praise of their Lord and ask forgiveness for those on earth. Unquestionably, it is Allah who is the Forgiving, the Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcclxxviii{%
And those who take as allies other than Him - Allah is [yet] Guardian over them; and you, [O Muhammad], are not over them a manager.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcclxxix{%
And thus We have revealed to you an Arabic Qur'an that you may warn the Mother of Cities [Makkah] and those around it and warn of the Day of Assembly, about which there is no doubt. A party will be in Paradise and a party in the Blaze.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcclxxx{%
And if Allah willed, He could have made them [of] one religion, but He admits whom He wills into His mercy. And the wrongdoers have not any protector or helper.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxi{%
Or have they taken protectors [or allies] besides him? But Allah - He is the Protector, and He gives life to the dead, and He is over all things competent.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxii{%
And in anything over which you disagree - its ruling is [to be referred] to Allah. [Say], ``That is Allah, my Lord; upon Him I have relied, and to Him I turn back."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiii{%
[He is] Creator of the heavens and the earth. He has made for you from yourselves, mates, and among the cattle, mates; He multiplies you thereby. There is nothing like unto Him, and He is the Hearing, the Seeing.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxiv{%
To Him belong the keys of the heavens and the earth. He extends provision for whom He wills and restricts [it]. Indeed He is, of all things, Knowing.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxv{%
He has ordained for you of religion what He enjoined upon Noah and that which We have revealed to you, [O Muhammad], and what We enjoined upon Abraham and Moses and Jesus - to establish the religion and not be divided therein. Difficult for those who associate others with Allah is that to which you invite them. Allah chooses for Himself whom He wills and guides to Himself whoever turns back [to Him].\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvi{%
And they did not become divided until after knowledge had come to them - out of jealous animosity between themselves. And if not for a word that preceded from your Lord [postponing the penalty] until a specified time, it would have been concluded between them. And indeed, those who were granted inheritance of the Scripture after them are, concerning it, in disquieting doubt.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxvii{%
So to that [religion of Allah] invite, [O Muhammad], and remain on a right course as you are commanded and do not follow their inclinations but say, ``I have believed in what Allah has revealed of the Qur'an, and I have been commanded to do justice among you. Allah is our Lord and your Lord. For us are our deeds, and for you your deeds. There is no [need for] argument between us and you. Allah will bring us together, and to Him is the [final] destination."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxviii{%
And those who argue concerning Allah after He has been responded to - their argument is invalid with their Lord, and upon them is [His] wrath, and for them is a severe punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcclxxxix{%
It is Allah who has sent down the Book in truth and [also] the balance. And what will make you perceive? Perhaps the Hour is near.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmccxc{%
Those who do not believe in it are impatient for it, but those who believe are fearful of it and know that it is the truth. Unquestionably, those who dispute concerning the Hour are in extreme error.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmccxci{%
Allah is Subtle with His servants; He gives provisions to whom He wills. And He is the Powerful, the Exalted in Might.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmccxcii{%
Whoever desires the harvest of the Hereafter - We increase for him in his harvest. And whoever desires the harvest of this world - We give him thereof, but there is not for him in the Hereafter any share.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmccxciii{%
Or have they other deities who have ordained for them a religion to which Allah has not consented? But if not for the decisive word, it would have been concluded between them. And indeed, the wrongdoers will have a painful punishment.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmccxciv{%
You will see the wrongdoers fearful of what they have earned, and it will [certainly] befall them. And those who have believed and done righteous deeds will be in lush regions of the gardens [in Paradise] having whatever they will in the presence of their Lord. That is what is the great bounty.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmccxcv{%
It is that of which Allah gives good tidings to His servants who believe and do righteous deeds. Say, [O Muhammad], ``I do not ask you for this message any payment [but] only good will through kinship." And whoever commits a good deed - We will increase for him good therein. Indeed, Allah is Forgiving and Appreciative.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmccxcvi{%
Or do they say, ``He has invented about Allah a lie"? But if Allah willed, He could seal over your heart. And Allah eliminates falsehood and establishes the truth by His words. Indeed, He is Knowing of that within the breasts.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmccxcvii{%
And it is He who accepts repentance from his servants and pardons misdeeds, and He knows what you do.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmccxcviii{%
And He answers [the supplication of] those who have believed and done righteous deeds and increases [for] them from His bounty. But the disbelievers will have a severe punishment.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccxcix{%
And if Allah had extended [excessively] provision for His servants, they would have committed tyranny throughout the earth. But He sends [it] down in an amount which He wills. Indeed He is, of His servants, Acquainted and Seeing.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmccc{%
And it is He who sends down the rain after they had despaired and spreads His mercy. And He is the Protector, the Praiseworthy.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmccci{%
And of his signs is the creation of the heavens and earth and what He has dispersed throughout them of creatures. And He, for gathering them when He wills, is competent.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcccii{%
And whatever strikes you of disaster - it is for what your hands have earned; but He pardons much.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccciii{%
And you will not cause failure [to Allah] upon the earth. And you have not besides Allah any protector or helper.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccciv{%
And of His signs are the ships in the sea, like mountains.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcccv{%
If He willed, He could still the wind, and they would remain motionless on its surface. Indeed in that are signs for everyone patient and grateful.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcccvi{%
Or He could destroy them for what they earned; but He pardons much.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcccvii{%
And [that is so] those who dispute concerning Our signs may know that for them there is no place of escape.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcccviii{%
So whatever thing you have been given - it is but [for] enjoyment of the worldly life. But what is with Allah is better and more lasting for those who have believed and upon their Lord rely\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcccix{%
And those who avoid the major sins and immoralities, and when they are angry, they forgive,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcccx{%
And those who have responded to their lord and established prayer and whose affair is [determined by] consultation among themselves, and from what We have provided them, they spend.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcccxi{%
And those who, when tyranny strikes them, they defend themselves,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcccxii{%
And the retribution for an evil act is an evil one like it, but whoever pardons and makes reconciliation - his reward is [due] from Allah. Indeed, He does not like wrongdoers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcccxiii{%
And whoever avenges himself after having been wronged - those have not upon them any cause [for blame].\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcccxiv{%
The cause is only against the ones who wrong the people and tyrannize upon the earth without right. Those will have a painful punishment.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcccxv{%
And whoever is patient and forgives - indeed, that is of the matters [requiring] determination.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcccxvi{%
And he whom Allah sends astray - for him there is no protector beyond Him. And you will see the wrongdoers, when they see the punishment, saying, ``Is there for return [to the former world] any way?"\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcccxvii{%
And you will see them being exposed to the Fire, humbled from humiliation, looking from [behind] a covert glance. And those who had believed will say, ``Indeed, the [true] losers are the ones who lost themselves and their families on the Day of Resurrection. Unquestionably, the wrongdoers are in an enduring punishment."\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcccxviii{%
And there will not be for them any allies to aid them other than Allah. And whoever Allah sends astray - for him there is no way.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcccxix{%
Respond to your Lord before a Day comes from Allah of which there is no repelling. No refuge will you have that day, nor for you will there be any denial.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcccxx{%
But if they turn away - then We have not sent you, [O Muhammad], over them as a guardian; upon you is only [the duty of] notification. And indeed, when We let man taste mercy from us, he rejoices in it; but if evil afflicts him for what his hands have put forth, then indeed, man is ungrateful.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcccxxi{%
To Allah belongs the dominion of the heavens and the earth; He creates what he wills. He gives to whom He wills female [children], and He gives to whom He wills males.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcccxxii{%
Or He makes them [both] males and females, and He renders whom He wills barren. Indeed, He is Knowing and Competent.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiii{%
And it is not for any human being that Allah should speak to him except by revelation or from behind a partition or that He sends a messenger to reveal, by His permission, what He wills. Indeed, He is Most High and Wise.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcccxxiv{%
And thus We have revealed to you an inspiration of Our command. You did not know what is the Book or [what is] faith, but We have made it a light by which We guide whom We will of Our servants. And indeed, [O Muhammad], you guide to a straight path -\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcccxxv{%
The path of Allah, to whom belongs whatever is in the heavens and whatever is on the earth. Unquestionably, to Allah do [all] matters evolve.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvi{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcccxxvii{%
By the clear Book,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcccxxviii{%
Indeed, We have made it an Arabic Qur'an that you might understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcccxxix{%
And indeed it is, in the Mother of the Book with Us, exalted and full of wisdom.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcccxxx{%
Then should We turn the message away, disregarding you, because you are a transgressing people?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxi{%
And how many a prophet We sent among the former peoples,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxii{%
But there would not come to them a prophet except that they used to ridicule him.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiii{%
And We destroyed greater than them in [striking] power, and the example of the former peoples has preceded.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxiv{%
And if you should ask them, ``Who has created the heavens and the earth?" they would surely say, ``They were created by the Exalted in Might, the Knowing."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxv{%
[The one] who has made for you the earth a bed and made for you upon it roads that you might be guided\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvi{%
And who sends down rain from the sky in measured amounts, and We revive thereby a dead land - thus will you be brought forth -\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxvii{%
And who created the species, all of them, and has made for you of ships and animals those which you mount.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxviii{%
That you may settle yourselves upon their backs and then remember the favor of your Lord when you have settled upon them and say. ``Exalted is He who has subjected this to us, and we could not have [otherwise] subdued it.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcccxxxix{%
And indeed we, to our Lord, will [surely] return."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcccxl{%
But they have attributed to Him from His servants a portion. Indeed, man is clearly ungrateful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcccxli{%
Or has He taken, out of what He has created, daughters and chosen you for [having] sons?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcccxlii{%
And when one of them is given good tidings of that which he attributes to the Most Merciful in comparison, his face becomes dark, and he suppresses grief.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcccxliii{%
So is one brought up in ornaments while being during conflict unevident [attributed to Allah]?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcccxliv{%
And they have made the angels, who are servants of the Most Merciful, females. Did they witness their creation? Their testimony will be recorded, and they will be questioned.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcccxlv{%
And they said, ``If the Most Merciful had willed, we would not have worshipped them." They have of that no knowledge. They are not but falsifying.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvi{%
Or have We given them a book before the Qur'an to which they are adhering?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcccxlvii{%
Rather, they say, ``Indeed, we found our fathers upon a religion, and we are in their footsteps [rightly] guided."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcccxlviii{%
And similarly, We did not send before you any warner into a city except that its affluent said, ``Indeed, we found our fathers upon a religion, and we are, in their footsteps, following."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcccxlix{%
[Each warner] said, ``Even if I brought you better guidance than that [religion] upon which you found your fathers?" They said, ``Indeed we, in that with which you were sent, are disbelievers."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcccl{%
So we took retribution from them; then see how was the end of the deniers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcccli{%
And [mention, O Muhammad], when Abraham said to his father and his people, ``Indeed, I am disassociated from that which you worship\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmccclii{%
Except for He who created me; and indeed, He will guide me."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcccliii{%
And he made it a word remaining among his descendants that they might return [to it].\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcccliv{%
However, I gave enjoyment to these [people of Makkah] and their fathers until there came to them the truth and a clear Messenger.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmccclv{%
But when the truth came to them, they said, ``This is magic, and indeed we are, concerning it, disbelievers."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmccclvi{%
And they said, ``Why was this Qur'an not sent down upon a great man from [one of] the two cities?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmccclvii{%
Do they distribute the mercy of your Lord? It is We who have apportioned among them their livelihood in the life of this world and have raised some of them above others in degrees [of rank] that they may make use of one another for service. But the mercy of your Lord is better than whatever they accumulate.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmccclviii{%
And if it were not that the people would become one community [of disbelievers], We would have made for those who disbelieve in the Most Merciful - for their houses - ceilings and stairways of silver upon which to mount\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmccclix{%
And for their houses - doors and couches [of silver] upon which to recline\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmccclx{%
And gold ornament. But all that is not but the enjoyment of worldly life. And the Hereafter with your Lord is for the righteous.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmccclxi{%
And whoever is blinded from remembrance of the Most Merciful - We appoint for him a devil, and he is to him a companion.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmccclxii{%
And indeed, the devils avert them from the way [of guidance] while they think that they are [rightly] guided\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmccclxiii{%
Until, when he comes to Us [at Judgement], he says [to his companion], ``Oh, I wish there was between me and you the distance between the east and west - how wretched a companion."\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmccclxiv{%
And never will it benefit you that Day, when you have wronged, that you are [all] sharing in the punishment.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmccclxv{%
Then will you make the deaf hear, [O Muhammad], or guide the blind or he who is in clear error?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmccclxvi{%
And whether [or not] We take you away [in death], indeed, We will take retribution upon them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmccclxvii{%
Or whether [or not] We show you that which We have promised them, indeed, We are Perfect in Ability.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmccclxviii{%
So adhere to that which is revealed to you. Indeed, you are on a straight path.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmccclxix{%
And indeed, it is a remembrance for you and your people, and you [all] are going to be questioned.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmccclxx{%
And ask those We sent before you of Our messengers; have We made besides the Most Merciful deities to be worshipped?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmccclxxi{%
And certainly did We send Moses with Our signs to Pharaoh and his establishment, and he said, ``Indeed, I am the messenger of the Lord of the worlds."\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmccclxxii{%
But when he brought them Our signs, at once they laughed at them.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiii{%
And We showed them not a sign except that it was greater than its sister, and We seized them with affliction that perhaps they might return [to faith].\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmccclxxiv{%
And they said [to Moses], ``O magician, invoke for us your Lord by what He has promised you. Indeed, we will be guided."\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmccclxxv{%
But when We removed from them the affliction, at once they broke their word.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvi{%
And Pharaoh called out among his people; he said, ``O my people, does not the kingdom of Egypt belong to me, and these rivers flowing beneath me; then do you not see?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmccclxxvii{%
Or am I [not] better than this one who is insignificant and hardly makes himself clear?\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmccclxxviii{%
Then why have there not been placed upon him bracelets of gold or come with him the angels in conjunction?"\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmccclxxix{%
So he bluffed his people, and they obeyed him. Indeed, they were [themselves] a people defiantly disobedient [of Allah].\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmccclxxx{%
And when they angered Us, We took retribution from them and drowned them all.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxi{%
And We made them a precedent and an example for the later peoples.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxii{%
And when the son of Mary was presented as an example, immediately your people laughed aloud.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiii{%
And they said, ``Are your gods better, or is he?" They did not present the comparison except for [mere] argument. But, [in fact], they are a people prone to dispute.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxiv{%
Jesus was not but a servant upon whom We bestowed favor, and We made him an example for the Children of Israel.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxv{%
And if We willed, We could have made [instead] of you angels succeeding [one another] on the earth.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvi{%
And indeed, Jesus will be [a sign for] knowledge of the Hour, so be not in doubt of it, and follow Me. This is a straight path.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxvii{%
And never let Satan avert you. Indeed, he is to you a clear enemy.\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxviii{%
And when Jesus brought clear proofs, he said, ``I have come to you with wisdom and to make clear to you some of that over which you differ, so fear Allah and obey me.\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmccclxxxix{%
Indeed, Allah is my Lord and your Lord, so worship Him. This is a straight path."\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcccxc{%
But the denominations from among them differed [and separated], so woe to those who have wronged from the punishment of a painful Day.\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcccxci{%
Are they waiting except for the Hour to come upon them suddenly while they perceive not?\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcccxcii{%
Close friends, that Day, will be enemies to each other, except for the righteous\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcccxciii{%
[To whom Allah will say], ``O My servants, no fear will there be concerning you this Day, nor will you grieve,\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcccxciv{%
[You] who believed in Our verses and were Muslims.\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcccxcv{%
Enter Paradise, you and your kinds, delighted."\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvi{%
Circulated among them will be plates and vessels of gold. And therein is whatever the souls desire and [what] delights the eyes, and you will abide therein eternally.\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcccxcvii{%
And that is Paradise which you are made to inherit for what you used to do.\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcccxcviii{%
For you therein is much fruit from which you will eat.\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcccxcix{%
Indeed, the criminals will be in the punishment of Hell, abiding eternally.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcd{%
It will not be allowed to subside for them, and they, therein, are in despair.\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcdi{%
And We did not wrong them, but it was they who were the wrongdoers.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcdii{%
And they will call, ``O Malik, let your Lord put an end to us!" He will say, ``Indeed, you will remain."\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcdiii{%
We had certainly brought you the truth, but most of you, to the truth, were averse.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcdiv{%
Or have they devised [some] affair? But indeed, We are devising [a plan].\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmcdv{%
Or do they think that We hear not their secrets and their private conversations? Yes, [We do], and Our messengers are with them recording.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmcdvi{%
Say, [O Muhammad], ``If the Most Merciful had a son, then I would be the first of [his] worshippers."\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmcdvii{%
Exalted is the Lord of the heavens and the earth, Lord of the Throne, above what they describe.\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmcdviii{%
So leave them to converse vainly and amuse themselves until they meet their Day which they are promised.\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmcdix{%
And it is Allah who is [the only] deity in the heaven, and on the earth [the only] deity. And He is the Wise, the Knowing.\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmcdx{%
And blessed is He to whom belongs the dominion of the heavens and the earth and whatever is between them and with whom is knowledge of the Hour and to whom you will be returned.\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmcdxi{%
And those they invoke besides Him do not possess [power of] intercession; but only those who testify to the truth [can benefit], and they know.\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmcdxii{%
And if you asked them who created them, they would surely say, ``Allah." So how are they deluded?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmcdxiii{%
And [Allah acknowledges] his saying, ``O my Lord, indeed these are a people who do not believe."\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmcdxiv{%
So turn aside from them and say, ``Peace." But they are going to know.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmcdxv{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdxvi{%
By the clear Book,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdxvii{%
Indeed, We sent it down during a blessed night. Indeed, We were to warn [mankind].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdxviii{%
On that night is made distinct every precise matter -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdxix{%
[Every] matter [proceeding] from Us. Indeed, We were to send [a messenger]\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdxx{%
As mercy from your Lord. Indeed, He is the Hearing, the Knowing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdxxi{%
Lord of the heavens and the earth and that between them, if you would be certain.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdxxii{%
There is no deity except Him; He gives life and causes death. [He is] your Lord and the Lord of your first forefathers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiii{%
But they are in doubt, amusing themselves.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdxxiv{%
Then watch for the Day when the sky will bring a visible smoke.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdxxv{%
Covering the people; this is a painful torment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvi{%
[They will say], ``Our Lord, remove from us the torment; indeed, we are believers."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdxxvii{%
How will there be for them a reminder [at that time]? And there had come to them a clear Messenger.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdxxviii{%
Then they turned away from him and said, ``[He was] taught [and is] a madman."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdxxix{%
Indeed, We will remove the torment for a little. Indeed, you [disbelievers] will return [to disbelief].\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdxxx{%
The Day We will strike with the greatest assault, indeed, We will take retribution.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxi{%
And We had already tried before them the people of Pharaoh, and there came to them a noble messenger,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxii{%
[Saying], ``Render to me the servants of Allah. Indeed, I am to you a trustworthy messenger,"\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiii{%
And [saying], ``Be not haughty with Allah. Indeed, I have come to you with clear authority.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxiv{%
And indeed, I have sought refuge in my Lord and your Lord, lest you stone me.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxv{%
But if you do not believe me, then leave me alone."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvi{%
And [finally] he called to his Lord that these were a criminal people.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxvii{%
[Allah said], ``Then set out with My servants by night. Indeed, you are to be pursued.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxviii{%
And leave the sea in stillness. Indeed, they are an army to be drowned."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxxxix{%
How much they left behind of gardens and springs\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxl{%
And crops and noble sites\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcdxli{%
And comfort wherein they were amused.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcdxlii{%
Thus. And We caused to inherit it another people.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcdxliii{%
And the heaven and earth wept not for them, nor were they reprieved.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcdxliv{%
And We certainly saved the Children of Israel from the humiliating torment -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcdxlv{%
From Pharaoh. Indeed, he was a haughty one among the transgressors.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvi{%
And We certainly chose them by knowledge over [all] the worlds.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcdxlvii{%
And We gave them of signs that in which there was a clear trial.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcdxlviii{%
Indeed, these [disbelievers] are saying,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcdxlix{%
``There is not but our first death, and we will not be resurrected.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcdl{%
Then bring [back] our forefathers, if you should be truthful."\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcdli{%
Are they better or the people of Tubba' and those before them? We destroyed them, [for] indeed, they were criminals.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcdlii{%
And We did not create the heavens and earth and that between them in play.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcdliii{%
We did not create them except in truth, but most of them do not know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcdliv{%
Indeed, the Day of Judgement is the appointed time for them all -\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcdlv{%
The Day when no relation will avail a relation at all, nor will they be helped -\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcdlvi{%
Except those [believers] on whom Allah has mercy. Indeed, He is the Exalted in Might, the Merciful.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcdlvii{%
Indeed, the tree of zaqqum\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcdlviii{%
Is food for the sinful.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcdlix{%
Like murky oil, it boils within bellies\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcdlx{%
Like the boiling of scalding water.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcdlxi{%
[It will be commanded], ``Seize him and drag him into the midst of the Hellfire,\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcdlxii{%
Then pour over his head from the torment of scalding water."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiii{%
[It will be said], ``Taste! Indeed, you are the honored, the noble!\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcdlxiv{%
Indeed, this is what you used to dispute."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcdlxv{%
Indeed, the righteous will be in a secure place;\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvi{%
Within gardens and springs,\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcdlxvii{%
Wearing [garments of] fine silk and brocade, facing each other.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcdlxviii{%
Thus. And We will marry them to fair women with large, [beautiful] eyes.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcdlxix{%
They will call therein for every [kind of] fruit - safe and secure.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcdlxx{%
They will not taste death therein except the first death, and He will have protected them from the punishment of Hellfire\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxi{%
As bounty from your Lord. That is what is the great attainment.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxii{%
And indeed, We have eased the Qur'an in your tongue that they might be reminded.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiii{%
So watch, [O Muhammad]; indeed, they are watching [for your end].\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxiv{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxv{%
The revelation of the Book is from Allah, the Exalted in Might, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvi{%
Indeed, within the heavens and earth are signs for the believers.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxvii{%
And in the creation of yourselves and what He disperses of moving creatures are signs for people who are certain [in faith].\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxviii{%
And [in] the alternation of night and day and [in] what Allah sends down from the sky of provision and gives life thereby to the earth after its lifelessness and [in His] directing of the winds are signs for a people who reason.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxix{%
These are the verses of Allah which We recite to you in truth. Then in what statement after Allah and His verses will they believe?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxx{%
Woe to every sinful liar\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxi{%
Who hears the verses of Allah recited to him, then persists arrogantly as if he had not heard them. So give him tidings of a painful punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxii{%
And when he knows anything of Our verses, he takes them in ridicule. Those will have a humiliating punishment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiii{%
Before them is Hell, and what they had earned will not avail them at all nor what they had taken besides Allah as allies. And they will have a great punishment.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxiv{%
This [Qur'an] is guidance. And those who have disbelieved in the verses of their Lord will have a painful punishment of foul nature.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxv{%
It is Allah who subjected to you the sea so that ships may sail upon it by His command and that you may seek of His bounty; and perhaps you will be grateful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvi{%
And He has subjected to you whatever is in the heavens and whatever is on the earth - all from Him. Indeed in that are signs for a people who give thought.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxvii{%
Say, [O Muhammad], to those who have believed that they [should] forgive those who expect not the days of Allah so that He may recompense a people for what they used to earn.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxviii{%
Whoever does a good deed - it is for himself; and whoever does evil - it is against the self. Then to your Lord you will be returned.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcdlxxxix{%
And We did certainly give the Children of Israel the Scripture and judgement and prophethood, and We provided them with good things and preferred them over the worlds.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcdxc{%
And We gave them clear proofs of the matter [of religion]. And they did not differ except after knowledge had come to them - out of jealous animosity between themselves. Indeed, your Lord will judge between them on the Day of Resurrection concerning that over which they used to differ.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcdxci{%
Then We put you, [O Muhammad], on an ordained way concerning the matter [of religion]; so follow it and do not follow the inclinations of those who do not know.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcdxcii{%
Indeed, they will never avail you against Allah at all. And indeed, the wrongdoers are allies of one another; but Allah is the protector of the righteous.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcdxciii{%
This [Qur'an] is enlightenment for mankind and guidance and mercy for a people who are certain [in faith].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcdxciv{%
Or do those who commit evils think We will make them like those who have believed and done righteous deeds - [make them] equal in their life and their death? Evil is that which they judge.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcdxcv{%
And Allah created the heavens and earth in truth and so that every soul may be recompensed for what it has earned, and they will not be wronged.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvi{%
Have you seen he who has taken as his god his [own] desire, and Allah has sent him astray due to knowledge and has set a seal upon his hearing and his heart and put over his vision a veil? So who will guide him after Allah? Then will you not be reminded?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcdxcvii{%
And they say, ``There is not but our worldly life; we die and live, and nothing destroys us except time." And they have of that no knowledge; they are only assuming.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcdxcviii{%
And when Our verses are recited to them as clear evidences, their argument is only that they say, ``Bring [back] our forefathers, if you should be truthful."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcdxcix{%
Say, ``Allah causes you to live, then causes you to die; then He will assemble you for the Day of Resurrection, about which there is no doubt, but most of the people do not know."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmd{%
And to Allah belongs the dominion of the heavens and the earth. And the Day the Hour appears - that Day the falsifiers will lose.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdi{%
And you will see every nation kneeling [from fear]. Every nation will be called to its record [and told], ``Today you will be recompensed for what you used to do.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdii{%
This, Our record, speaks about you in truth. Indeed, We were having transcribed whatever you used to do."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdiii{%
So as for those who believed and did righteous deeds, their Lord will admit them into His mercy. That is what is the clear attainment.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdiv{%
But as for those who disbelieved, [it will be said], ``Were not Our verses recited to you, but you were arrogant and became a people of criminals?\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdv{%
And when it was said, 'Indeed, the promise of Allah is truth and the Hour [is coming] - no doubt about it,' you said, 'We know not what is the Hour. We assume only assumption, and we are not convinced.' ``\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdvi{%
And the evil consequences of what they did will appear to them, and they will be enveloped by what they used to ridicule.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdvii{%
And it will be said, ``Today We will forget you as you forgot the meeting of this Day of yours, and your refuge is the Fire, and for you there are no helpers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdviii{%
That is because you took the verses of Allah in ridicule, and worldly life deluded you." So that Day they will not be removed from it, nor will they be asked to appease [Allah].\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdix{%
Then, to Allah belongs [all] praise - Lord of the heavens and Lord of the earth, Lord of the worlds.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdx{%
And to Him belongs [all] grandeur within the heavens and the earth, and He is the Exalted in Might, the Wise.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdxi{%
\basmalahen Ha, Meem.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxii{%
The revelation of the Book is from Allah, the Exalted in Might, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxiii{%
We did not create the heavens and earth and what is between them except in truth and [for] a specified term. But those who disbelieve, from that of which they are warned, are turning away.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxiv{%
Say, [O Muhammad], ``Have you considered that which you invoke besides Allah? Show me what they have created of the earth; or did they have partnership in [creation of] the heavens? Bring me a scripture [revealed] before this or a [remaining] trace of knowledge, if you should be truthful."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdxv{%
And who is more astray than he who invokes besides Allah those who will not respond to him until the Day of Resurrection, and they, of their invocation, are unaware.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdxvi{%
And when the people are gathered [that Day], they [who were invoked] will be enemies to them, and they will be deniers of their worship.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxvii{%
And when Our verses are recited to them as clear evidences, those who disbelieve say of the truth when it has come to them, ``This is obvious magic."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxviii{%
Or do they say, ``He has invented it?" Say, ``If I have invented it, you will not possess for me [the power of protection] from Allah at all. He is most knowing of that in which you are involved. Sufficient is He as Witness between me and you, and He is the Forgiving the Merciful."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxix{%
Say, ``I am not something original among the messengers, nor do I know what will be done with me or with you. I only follow that which is revealed to me, and I am not but a clear warner."\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxx{%
Say, ``Have you considered: if the Qur'an was from Allah, and you disbelieved in it while a witness from the Children of Israel has testified to something similar and believed while you were arrogant...?" Indeed, Allah does not guide the wrongdoing people.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxxi{%
And those who disbelieve say of those who believe, ``If it had [truly] been good, they would not have preceded us to it." And when they are not guided by it, they will say, ``This is an ancient falsehood."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxxii{%
And before it was the scripture of Moses to lead and as a mercy. And this is a confirming Book in an Arabic tongue to warn those who have wronged and as good tidings to the doers of good.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxxiii{%
Indeed, those who have said, ``Our Lord is Allah," and then remained on a right course - there will be no fear concerning them, nor will they grieve.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxxiv{%
Those are the companions of Paradise, abiding eternally therein as reward for what they used to do.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxxv{%
And We have enjoined upon man, to his parents, good treatment. His mother carried him with hardship and gave birth to him with hardship, and his gestation and weaning [period] is thirty months. [He grows] until, when he reaches maturity and reaches [the age of] forty years, he says, ``My Lord, enable me to be grateful for Your favor which You have bestowed upon me and upon my parents and to work righteousness of which You will approve and make righteous for me my offspring. Indeed, I have repented to You, and indeed, I am of the Muslims."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxxvi{%
Those are the ones from whom We will accept the best of what they did and overlook their misdeeds, [their being] among the companions of Paradise. [That is] the promise of truth which they had been promised.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdxxvii{%
But one who says to his parents, ``Uff to you; do you promise me that I will be brought forth [from the earth] when generations before me have already passed on [into oblivion]?" while they call to Allah for help [and to their son], ``Woe to you! Believe! Indeed, the promise of Allah is truth." But he says, ``This is not but legends of the former people" -\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdxxviii{%
Those are the ones upon whom the word has come into effect, [who will be] among nations which had passed on before them of jinn and men. Indeed, they [all] were losers.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdxxix{%
And for all there are degrees [of reward and punishment] for what they have done, and [it is] so that He may fully compensate them for their deeds, and they will not be wronged.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdxxx{%
And the Day those who disbelieved are exposed to the Fire [it will be said], ``You exhausted your pleasures during your worldly life and enjoyed them, so this Day you will be awarded the punishment of [extreme] humiliation because you were arrogant upon the earth without right and because you were defiantly disobedient."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdxxxi{%
And mention, [O Muhammad], the brother of 'Aad, when he warned his people in the [region of] al-Ahqaf - and warners had already passed on before him and after him - [saying], ``Do not worship except Allah. Indeed, I fear for you the punishment of a terrible day."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdxxxii{%
They said, ``Have you come to delude us away from our gods? Then bring us what you promise us, if you should be of the truthful."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiii{%
He said, ``Knowledge [of its time] is only with Allah, and I convey to you that with which I was sent; but I see you [to be] a people behaving ignorantly."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdxxxiv{%
And when they saw it as a cloud approaching their valleys, they said, ``This is a cloud bringing us rain!" Rather, it is that for which you were impatient: a wind, within it a painful punishment,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdxxxv{%
Destroying everything by command of its Lord. And they became so that nothing was seen [of them] except their dwellings. Thus do We recompense the criminal people.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvi{%
And We had certainly established them in such as We have not established you, and We made for them hearing and vision and hearts. But their hearing and vision and hearts availed them not from anything [of the punishment] when they were [continually] rejecting the signs of Allah; and they were enveloped by what they used to ridicule.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdxxxvii{%
And We have already destroyed what surrounds you of [those] cities, and We have diversified the signs [or verses] that perhaps they might return [from disbelief].\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdxxxviii{%
Then why did those they took besides Allah as deities by which to approach [Him] not aid them? But they had strayed from them. And that was their falsehood and what they were inventing.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdxxxix{%
And [mention, O Muhammad], when We directed to you a few of the jinn, listening to the Qur'an. And when they attended it, they said, ``Listen quietly." And when it was concluded, they went back to their people as warners.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdxl{%
They said, ``O our people, indeed we have heard a [recited] Book revealed after Moses confirming what was before it which guides to the truth and to a straight path.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdxli{%
O our people, respond to the Messenger of Allah and believe in him; Allah will forgive for you your sins and protect you from a painful punishment.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdxlii{%
But he who does not respond to the Caller of Allah will not cause failure [to Him] upon earth, and he will not have besides Him any protectors. Those are in manifest error."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdxliii{%
Do they not see that Allah, who created the heavens and earth and did not fail in their creation, is able to give life to the dead? Yes. Indeed, He is over all things competent.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdxliv{%
And the Day those who disbelieved are exposed to the Fire [it will be said], ``Is this not the truth?" They will say, ``Yes, by our Lord." He will say, ``Then taste the punishment because you used to disbelieve."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdxlv{%
So be patient, [O Muhammad], as were those of determination among the messengers and do not be impatient for them. It will be - on the Day they see that which they are promised - as though they had not remained [in the world] except an hour of a day. [This is] notification. And will [any] be destroyed except the defiantly disobedient people?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdxlvi{%
\basmalahen Those who disbelieve and avert [people] from the way of Allah - He will waste their deeds.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdxlvii{%
And those who believe and do righteous deeds and believe in what has been sent down upon Muhammad - and it is the truth from their Lord - He will remove from them their misdeeds and amend their condition.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdxlviii{%
That is because those who disbelieve follow falsehood, and those who believe follow the truth from their Lord. Thus does Allah present to the people their comparisons.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdxlix{%
So when you meet those who disbelieve [in battle], strike [their] necks until, when you have inflicted slaughter upon them, then secure their bonds, and either [confer] favor afterwards or ransom [them] until the war lays down its burdens. That [is the command]. And if Allah had willed, He could have taken vengeance upon them [Himself], but [He ordered armed struggle] to test some of you by means of others. And those who are killed in the cause of Allah - never will He waste their deeds.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdl{%
He will guide them and amend their condition\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdli{%
And admit them to Paradise, which He has made known to them.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdlii{%
O you who have believed, if you support Allah, He will support you and plant firmly your feet.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdliii{%
But those who disbelieve - for them is misery, and He will waste their deeds.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdliv{%
That is because they disliked what Allah revealed, so He rendered worthless their deeds.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdlv{%
Have they not traveled through the land and seen how was the end of those before them? Allah destroyed [everything] over them, and for the disbelievers is something comparable.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdlvi{%
That is because Allah is the protector of those who have believed and because the disbelievers have no protector.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdlvii{%
Indeed, Allah will admit those who have believed and done righteous deeds to gardens beneath which rivers flow, but those who disbelieve enjoy themselves and eat as grazing livestock eat, and the Fire will be a residence for them.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdlviii{%
And how many a city was stronger than your city [Makkah] which drove you out? We destroyed them; and there was no helper for them.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdlix{%
So is he who is on clear evidence from his Lord like him to whom the evil of his work has been made attractive and they follow their [own] desires?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdlx{%
Is the description of Paradise, which the righteous are promised, wherein are rivers of water unaltered, rivers of milk the taste of which never changes, rivers of wine delicious to those who drink, and rivers of purified honey, in which they will have from all [kinds of] fruits and forgiveness from their Lord, like [that of] those who abide eternally in the Fire and are given to drink scalding water that will sever their intestines?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdlxi{%
And among them, [O Muhammad], are those who listen to you, until when they depart from you, they say to those who were given knowledge, ``What has he said just now?" Those are the ones of whom Allah has sealed over their hearts and who have followed their [own] desires.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdlxii{%
And those who are guided - He increases them in guidance and gives them their righteousness.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdlxiii{%
Then do they await except that the Hour should come upon them unexpectedly? But already there have come [some of] its indications. Then what good to them, when it has come, will be their remembrance?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdlxiv{%
So know, [O Muhammad], that there is no deity except Allah and ask forgiveness for your sin and for the believing men and believing women. And Allah knows of your movement and your resting place.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdlxv{%
Those who believe say, ``Why has a surah not been sent down? But when a precise surah is revealed and fighting is mentioned therein, you see those in whose hearts is hypocrisy looking at you with a look of one overcome by death. And more appropriate for them [would have been]\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdlxvi{%
Obedience and good words. And when the matter [of fighting] was determined, if they had been true to Allah, it would have been better for them.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdlxvii{%
So would you perhaps, if you turned away, cause corruption on earth and sever your [ties of] relationship?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdlxviii{%
Those [who do so] are the ones that Allah has cursed, so He deafened them and blinded their vision.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdlxix{%
Then do they not reflect upon the Qur'an, or are there locks upon [their] hearts?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdlxx{%
Indeed, those who reverted back [to disbelief] after guidance had become clear to them - Satan enticed them and prolonged hope for them.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdlxxi{%
That is because they said to those who disliked what Allah sent down, ``We will obey you in part of the matter." And Allah knows what they conceal.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdlxxii{%
Then how [will it be] when the angels take them in death, striking their faces and their backs?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiii{%
That is because they followed what angered Allah and disliked [what earns] His pleasure, so He rendered worthless their deeds.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdlxxiv{%
Or do those in whose hearts is disease think that Allah would never expose their [feelings of] hatred?\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdlxxv{%
And if We willed, We could show them to you, and you would know them by their mark; but you will surely know them by the tone of [their] speech. And Allah knows your deeds.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvi{%
And We will surely test you until We make evident those who strive among you [for the cause of Allah] and the patient, and We will test your affairs.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdlxxvii{%
Indeed, those who disbelieved and averted [people] from the path of Allah and opposed the Messenger after guidance had become clear to them - never will they harm Allah at all, and He will render worthless their deeds.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdlxxviii{%
O you who have believed, obey Allah and obey the Messenger and do not invalidate your deeds.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdlxxix{%
Indeed, those who disbelieved and averted [people] from the path of Allah and then died while they were disbelievers - never will Allah forgive them.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdlxxx{%
So do not weaken and call for peace while you are superior; and Allah is with you and will never deprive you of [the reward of] your deeds.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxi{%
[This] worldly life is only amusement and diversion. And if you believe and fear Allah, He will give you your rewards and not ask you for your properties.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxii{%
If He should ask you for them and press you, you would withhold, and He would expose your unwillingness.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiii{%
Here you are - those invited to spend in the cause of Allah - but among you are those who withhold [out of greed]. And whoever withholds only withholds [benefit] from himself; and Allah is the Free of need, while you are the needy. And if you turn away, He will replace you with another people; then they will not be the likes of you.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxiv{%
\basmalahen Indeed, We have given you, [O Muhammad], a clear conquest\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxv{%
That Allah may forgive for you what preceded of your sin and what will follow and complete His favor upon you and guide you to a straight path\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvi{%
And [that] Allah may aid you with a mighty victory.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxvii{%
It is He who sent down tranquillity into the hearts of the believers that they would increase in faith along with their [present] faith. And to Allah belong the soldiers of the heavens and the earth, and ever is Allah Knowing and Wise.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxviii{%
[And] that He may admit the believing men and the believing women to gardens beneath which rivers flow to abide therein eternally and remove from them their misdeeds - and ever is that, in the sight of Allah, a great attainment -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdlxxxix{%
And [that] He may punish the hypocrite men and hypocrite women, and the polytheist men and polytheist women - those who assume about Allah an assumption of evil nature. Upon them is a misfortune of evil nature; and Allah has become angry with them and has cursed them and prepared for them Hell, and evil it is as a destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdxc{%
And to Allah belong the soldiers of the heavens and the earth. And ever is Allah Exalted in Might and Wise.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdxci{%
Indeed, We have sent you as a witness and a bringer of good tidings and a warner\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdxcii{%
That you [people] may believe in Allah and His Messenger and honor him and respect the Prophet and exalt Allah morning and afternoon.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdxciii{%
Indeed, those who pledge allegiance to you, [O Muhammad] - they are actually pledging allegiance to Allah. The hand of Allah is over their hands. So he who breaks his word only breaks it to the detriment of himself. And he who fulfills that which he has promised Allah - He will give him a great reward.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdxciv{%
Those who remained behind of the bedouins will say to you, ``Our properties and our families occupied us, so ask forgiveness for us." They say with their tongues what is not within their hearts. Say, ``Then who could prevent Allah at all if He intended for you harm or intended for you benefit? Rather, ever is Allah, with what you do, Acquainted.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdxcv{%
But you thought that the Messenger and the believers would never return to their families, ever, and that was made pleasing in your hearts. And you assumed an assumption of evil and became a people ruined."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdxcvi{%
And whoever has not believed in Allah and His Messenger - then indeed, We have prepared for the disbelievers a Blaze.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdxcvii{%
And to Allah belongs the dominion of the heavens and the earth. He forgives whom He wills and punishes whom He wills. And ever is Allah Forgiving and Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdxcviii{%
Those who remained behind will say when you set out toward the war booty to take it, ``Let us follow you." They wish to change the words of Allah. Say, ``Never will you follow us. Thus did Allah say before." So they will say, ``Rather, you envy us." But [in fact] they were not understanding except a little.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdxcix{%
Say to those who remained behind of the bedouins, ``You will be called to [face] a people of great military might; you may fight them, or they will submit. So if you obey, Allah will give you a good reward; but if you turn away as you turned away before, He will punish you with a painful punishment."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdc{%
There is not upon the blind any guilt or upon the lame any guilt or upon the ill any guilt [for remaining behind]. And whoever obeys Allah and His Messenger - He will admit him to gardens beneath which rivers flow; but whoever turns away - He will punish him with a painful punishment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdci{%
Certainly was Allah pleased with the believers when they pledged allegiance to you, [O Muhammad], under the tree, and He knew what was in their hearts, so He sent down tranquillity upon them and rewarded them with an imminent conquest\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcii{%
And much war booty which they will take. And ever is Allah Exalted in Might and Wise.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdciii{%
Allah has promised you much booty that you will take [in the future] and has hastened for you this [victory] and withheld the hands of people from you - that it may be a sign for the believers and [that] He may guide you to a straight path.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdciv{%
And [He promises] other [victories] that you were [so far] unable to [realize] which Allah has already encompassed. And ever is Allah, over all things, competent.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcv{%
And if those [Makkans] who disbelieve had fought you, they would have turned their backs [in flight]. Then they would not find a protector or a helper.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcvi{%
[This is] the established way of Allah which has occurred before. And never will you find in the way of Allah any change.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcvii{%
And it is He who withheld their hands from you and your hands from them within [the area of] Makkah after He caused you to overcome them. And ever is Allah of what you do, Seeing.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcviii{%
They are the ones who disbelieved and obstructed you from al-Masjid al-Haram while the offering was prevented from reaching its place of sacrifice. And if not for believing men and believing women whom you did not know - that you might trample them and there would befall you because of them dishonor without [your] knowledge - [you would have been permitted to enter Makkah]. [This was so] that Allah might admit to His mercy whom He willed. If they had been apart [from them], We would have punished those who disbelieved among them with painful punishment\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcix{%
When those who disbelieved had put into their hearts chauvinism - the chauvinism of the time of ignorance. But Allah sent down His tranquillity upon His Messenger and upon the believers and imposed upon them the word of righteousness, and they were more deserving of it and worthy of it. And ever is Allah, of all things, Knowing.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcx{%
Certainly has Allah showed to His Messenger the vision in truth. You will surely enter al-Masjid al-Haram, if Allah wills, in safety, with your heads shaved and [hair] shortened, not fearing [anyone]. He knew what you did not know and has arranged before that a conquest near [at hand].\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcxi{%
It is He who sent His Messenger with guidance and the religion of truth to manifest it over all religion. And sufficient is Allah as Witness.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcxii{%
Muhammad is the Messenger of Allah; and those with him are forceful against the disbelievers, merciful among themselves. You see them bowing and prostrating [in prayer], seeking bounty from Allah and [His] pleasure. Their mark is on their faces from the trace of prostration. That is their description in the Torah. And their description in the Gospel is as a plant which produces its offshoots and strengthens them so they grow firm and stand upon their stalks, delighting the sowers - so that Allah may enrage by them the disbelievers. Allah has promised those who believe and do righteous deeds among them forgiveness and a great reward.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcxiii{%
\basmalahen O you who have believed, do not put [yourselves] before Allah and His Messenger but fear Allah. Indeed, Allah is Hearing and Knowing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxiv{%
O you who have believed, do not raise your voices above the voice of the Prophet or be loud to him in speech like the loudness of some of you to others, lest your deeds become worthless while you perceive not.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxv{%
Indeed, those who lower their voices before the Messenger of Allah - they are the ones whose hearts Allah has tested for righteousness. For them is forgiveness and great reward.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxvi{%
Indeed, those who call you, [O Muhammad], from behind the chambers - most of them do not use reason.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxvii{%
And if they had been patient until you [could] come out to them, it would have been better for them. But Allah is Forgiving and Merciful.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxviii{%
O you who have believed, if there comes to you a disobedient one with information, investigate, lest you harm a people out of ignorance and become, over what you have done, regretful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxix{%
And know that among you is the Messenger of Allah. If he were to obey you in much of the matter, you would be in difficulty, but Allah has endeared to you the faith and has made it pleasing in your hearts and has made hateful to you disbelief, defiance and disobedience. Those are the [rightly] guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxx{%
[It is] as bounty from Allah and favor. And Allah is Knowing and Wise.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxi{%
And if two factions among the believers should fight, then make settlement between the two. But if one of them oppresses the other, then fight against the one that oppresses until it returns to the ordinance of Allah. And if it returns, then make settlement between them in justice and act justly. Indeed, Allah loves those who act justly.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxxii{%
The believers are but brothers, so make settlement between your brothers. And fear Allah that you may receive mercy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiii{%
O you who have believed, let not a people ridicule [another] people; perhaps they may be better than them; nor let women ridicule [other] women; perhaps they may be better than them. And do not insult one another and do not call each other by [offensive] nicknames. Wretched is the name of disobedience after [one's] faith. And whoever does not repent - then it is those who are the wrongdoers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxxiv{%
O you who have believed, avoid much [negative] assumption. Indeed, some assumption is sin. And do not spy or backbite each other. Would one of you like to eat the flesh of his brother when dead? You would detest it. And fear Allah; indeed, Allah is Accepting of repentance and Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxxv{%
O mankind, indeed We have created you from male and female and made you peoples and tribes that you may know one another. Indeed, the most noble of you in the sight of Allah is the most righteous of you. Indeed, Allah is Knowing and Acquainted.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvi{%
The bedouins say, ``We have believed." Say, ``You have not [yet] believed; but say [instead], 'We have submitted,' for faith has not yet entered your hearts. And if you obey Allah and His Messenger, He will not deprive you from your deeds of anything. Indeed, Allah is Forgiving and Merciful."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxxvii{%
The believers are only the ones who have believed in Allah and His Messenger and then doubt not but strive with their properties and their lives in the cause of Allah. It is those who are the truthful.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxxviii{%
Say, ``Would you acquaint Allah with your religion while Allah knows whatever is in the heavens and whatever is on the earth, and Allah is Knowing of all things?"\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxxix{%
They consider it a favor to you that they have accepted Islam. Say, ``Do not consider your Islam a favor to me. Rather, Allah has conferred favor upon you that He has guided you to the faith, if you should be truthful."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxxx{%
Indeed, Allah knows the unseen [aspects] of the heavens and the earth. And Allah is Seeing of what you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxi{%
\basmalahen Qaf. By the honored Qur'an...\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxii{%
But they wonder that there has come to them a warner from among themselves, and the disbelievers say, ``This is an amazing thing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiii{%
When we have died and have become dust, [we will return to life]? That is a distant return."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxiv{%
We know what the earth diminishes of them, and with Us is a retaining record.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxv{%
But they denied the truth when it came to them, so they are in a confused condition.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvi{%
Have they not looked at the heaven above them - how We structured it and adorned it and [how] it has no rifts?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxvii{%
And the earth - We spread it out and cast therein firmly set mountains and made grow therein [something] of every beautiful kind,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxviii{%
Giving insight and a reminder for every servant who turns [to Allah].\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdcxxxix{%
And We have sent down blessed rain from the sky and made grow thereby gardens and grain from the harvest\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdcxl{%
And lofty palm trees having fruit arranged in layers -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdcxli{%
As provision for the servants, and We have given life thereby to a dead land. Thus is the resurrection.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdcxlii{%
The people of Noah denied before them, and the companions of the well and Thamud\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdcxliii{%
And 'Aad and Pharaoh and the brothers of Lot\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdcxliv{%
And the companions of the thicket and the people of Tubba'. All denied the messengers, so My threat was justly fulfilled.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxlv{%
Did We fail in the first creation? But they are in confusion over a new creation.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvi{%
And We have already created man and know what his soul whispers to him, and We are closer to him than [his] jugular vein\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxlvii{%
When the two receivers receive, seated on the right and on the left.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxlviii{%
Man does not utter any word except that with him is an observer prepared [to record].\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxlix{%
And the intoxication of death will bring the truth; that is what you were trying to avoid.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcl{%
And the Horn will be blown. That is the Day of [carrying out] the threat.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcli{%
And every soul will come, with it a driver and a witness.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdclii{%
[It will be said], ``You were certainly in unmindfulness of this, and We have removed from you your cover, so your sight, this Day, is sharp."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcliii{%
And his companion, [the angel], will say, ``This [record] is what is with me, prepared."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcliv{%
[Allah will say], ``Throw into Hell every obstinate disbeliever,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdclv{%
Preventer of good, aggressor, and doubter,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdclvi{%
Who made [as equal] with Allah another deity; then throw him into the severe punishment."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdclvii{%
His [devil] companion will say, ``Our Lord, I did not make him transgress, but he [himself] was in extreme error."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdclviii{%
[Allah] will say, ``Do not dispute before Me, while I had already presented to you the warning.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdclix{%
The word will not be changed with Me, and never will I be unjust to the servants."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdclx{%
On the Day We will say to Hell, ``Have you been filled?" and it will say, ``Are there some more,"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdclxi{%
And Paradise will be brought near to the righteous, not far,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdclxii{%
[It will be said], ``This is what you were promised - for every returner [to Allah] and keeper [of His covenant]\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdclxiii{%
Who feared the Most Merciful unseen and came with a heart returning [in repentance].\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdclxiv{%
Enter it in peace. This is the Day of Eternity."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdclxv{%
They will have whatever they wish therein, and with Us is more.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdclxvi{%
And how many a generation before them did We destroy who were greater than them in [striking] power and had explored throughout the lands. Is there any place of escape?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdclxvii{%
Indeed in that is a reminder for whoever has a heart or who listens while he is present [in mind].\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdclxviii{%
And We did certainly create the heavens and earth and what is between them in six days, and there touched Us no weariness.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdclxix{%
So be patient, [O Muhammad], over what they say and exalt [Allah] with praise of your Lord before the rising of the sun and before its setting,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdclxx{%
And [in part] of the night exalt Him and after prostration.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdclxxi{%
And listen on the Day when the Caller will call out from a place that is near -\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdclxxii{%
The Day they will hear the blast [of the Horn] in truth. That is the Day of Emergence [from the graves].\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiii{%
Indeed, it is We who give life and cause death, and to Us is the destination\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdclxxiv{%
On the Day the earth breaks away from them [and they emerge] rapidly; that is a gathering easy for Us.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdclxxv{%
We are most knowing of what they say, and you are not over them a tyrant. But remind by the Qur'an whoever fears My threat.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvi{%
\basmalahen By those [winds] scattering [dust] dispersing\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdclxxvii{%
And those [clouds] carrying a load [of water]\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdclxxviii{%
And those [ships] sailing with ease\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdclxxix{%
And those [angels] apportioning [each] matter,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdclxxx{%
Indeed, what you are promised is true.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxi{%
And indeed, the recompense is to occur.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxii{%
By the heaven containing pathways,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiii{%
Indeed, you are in differing speech.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxiv{%
Deluded away from the Qur'an is he who is deluded.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxv{%
Destroyed are the falsifiers\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvi{%
Who are within a flood [of confusion] and heedless.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxvii{%
They ask, ``When is the Day of Recompense?"\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxviii{%
[It is] the Day they will be tormented over the Fire\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdclxxxix{%
[And will be told], ``Taste your torment. This is that for which you were impatient."\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdcxc{%
Indeed, the righteous will be among gardens and springs,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdcxci{%
Accepting what their Lord has given them. Indeed, they were before that doers of good.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcxcii{%
They used to sleep but little of the night,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcxciii{%
And in the hours before dawn they would ask forgiveness,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdcxciv{%
And from their properties was [given] the right of the [needy] petitioner and the deprived.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcxcv{%
And on the earth are signs for the certain [in faith]\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvi{%
And in yourselves. Then will you not see?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcxcvii{%
And in the heaven is your provision and whatever you are promised.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcxcviii{%
Then by the Lord of the heaven and earth, indeed, it is truth - just as [sure as] it is that you are speaking.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcxcix{%
Has there reached you the story of the honored guests of Abraham? -\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcc{%
When they entered upon him and said, ``[We greet you with] peace." He answered, ``[And upon you] peace, [you are] a people unknown.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcci{%
Then he went to his family and came with a fat [roasted] calf\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccii{%
And placed it near them; he said, ``Will you not eat?"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcciii{%
And he felt from them apprehension. They said, ``Fear not," and gave him good tidings of a learned boy.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcciv{%
And his wife approached with a cry [of alarm] and struck her face and said, ``[I am] a barren old woman!"\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccv{%
They said, ``Thus has said your Lord; indeed, He is the Wise, the Knowing."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccvi{%
[Abraham] said, ``Then what is your business [here], O messengers?"\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccvii{%
They said, ``Indeed, we have been sent to a people of criminals\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccviii{%
To send down upon them stones of clay,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccix{%
Marked in the presence of your Lord for the transgressors."\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccx{%
So We brought out whoever was in the cities of the believers.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccxi{%
And We found not within them other than a [single] house of Muslims.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccxii{%
And We left therein a sign for those who fear the painful punishment.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccxiii{%
And in Moses [was a sign], when We sent him to Pharaoh with clear authority.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccxiv{%
But he turned away with his supporters and said," A magician or a madman."\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccxv{%
So We took him and his soldiers and cast them into the sea, and he was blameworthy.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccxvi{%
And in 'Aad [was a sign], when We sent against them the barren wind.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccxvii{%
It left nothing of what it came upon but that it made it like disintegrated ruins.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccxviii{%
And in Thamud, when it was said to them, ``Enjoy yourselves for a time."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdccxix{%
But they were insolent toward the command of their Lord, so the thunderbolt seized them while they were looking on.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdccxx{%
And they were unable to arise, nor could they defend themselves.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdccxxi{%
And [We destroyed] the people of Noah before; indeed, they were a people defiantly disobedient.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdccxxii{%
And the heaven We constructed with strength, and indeed, We are [its] expander.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiii{%
And the earth We have spread out, and excellent is the preparer.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdccxxiv{%
And of all things We created two mates; perhaps you will remember.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdccxxv{%
So flee to Allah. Indeed, I am to you from Him a clear warner.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvi{%
And do not make [as equal] with Allah another deity. Indeed, I am to you from Him a clear warner.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdccxxvii{%
Similarly, there came not to those before them any messenger except that they said, ``A magician or a madman."\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdccxxviii{%
Did they suggest it to them? Rather, they [themselves] are a transgressing people.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdccxxix{%
So leave them, [O Muhammad], for you are not to be blamed.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdccxxx{%
And remind, for indeed, the reminder benefits the believers.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxi{%
And I did not create the jinn and mankind except to worship Me.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxii{%
I do not want from them any provision, nor do I want them to feed Me.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiii{%
Indeed, it is Allah who is the [continual] Provider, the firm possessor of strength.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxiv{%
And indeed, for those who have wronged is a portion [of punishment] like the portion of their predecessors, so let them not impatiently urge Me.\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxv{%
And woe to those who have disbelieved from their Day which they are promised.\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvi{%
\basmalahen By the mount\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxvii{%
And [by] a Book inscribed\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxviii{%
In parchment spread open\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdccxxxix{%
And [by] the frequented House\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdccxl{%
And [by] the heaven raised high\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxli{%
And [by] the sea filled [with fire],\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxlii{%
Indeed, the punishment of your Lord will occur.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxliii{%
Of it there is no preventer.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxliv{%
On the Day the heaven will sway with circular motion\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxlv{%
And the mountains will pass on, departing -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvi{%
Then woe, that Day, to the deniers,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxlvii{%
Who are in [empty] discourse amusing themselves.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxlviii{%
The Day they are thrust toward the fire of Hell with a [violent] thrust, [its angels will say],\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxlix{%
``This is the Fire which you used to deny.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccl{%
Then is this magic, or do you not see?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccli{%
[Enter to] burn therein; then be patient or impatient - it is all the same for you. You are only being recompensed [for] what you used to do."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdcclii{%
Indeed, the righteous will be in gardens and pleasure,\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccliii{%
Enjoying what their Lord has given them, and their Lord protected them from the punishment of Hellfire.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccliv{%
[They will be told], ``Eat and drink in satisfaction for what you used to do."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdcclv{%
They will be reclining on thrones lined up, and We will marry them to fair women with large, [beautiful] eyes.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcclvi{%
And those who believed and whose descendants followed them in faith - We will join with them their descendants, and We will not deprive them of anything of their deeds. Every person, for what he earned, is retained.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcclvii{%
And We will provide them with fruit and meat from whatever they desire.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcclviii{%
They will exchange with one another a cup [of wine] wherein [results] no ill speech or commission of sin.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcclix{%
There will circulate among them [servant] boys [especially] for them, as if they were pearls well-protected.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcclx{%
And they will approach one another, inquiring of each other.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcclxi{%
They will say, ``Indeed, we were previously among our people fearful [of displeasing Allah].\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcclxii{%
So Allah conferred favor upon us and protected us from the punishment of the Scorching Fire.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiii{%
Indeed, we used to supplicate Him before. Indeed, it is He who is the Beneficent, the Merciful."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcclxiv{%
So remind [O Muhammad], for you are not, by the favor of your Lord, a soothsayer or a madman.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcclxv{%
Or do they say [of you], ``A poet for whom we await a misfortune of time?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvi{%
Say, ``Wait, for indeed I am, with you, among the waiters."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcclxvii{%
Or do their minds command them to [say] this, or are they a transgressing people?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcclxviii{%
Or do they say, ``He has made it up"? Rather, they do not believe.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcclxix{%
Then let them produce a statement like it, if they should be truthful.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcclxx{%
Or were they created by nothing, or were they the creators [of themselves]?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxi{%
Or did they create the heavens and the earth? Rather, they are not certain.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxii{%
Or have they the depositories [containing the provision] of your Lord? Or are they the controllers [of them]?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiii{%
Or have they a stairway [into the heaven] upon which they listen? Then let their listener produce a clear authority.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxiv{%
Or has He daughters while you have sons?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxv{%
Or do you, [O Muhammad], ask of them a payment, so they are by debt burdened down?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvi{%
Or have they [knowledge of] the unseen, so they write [it] down?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxvii{%
Or do they intend a plan? But those who disbelieve - they are the object of a plan.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxviii{%
Or have they a deity other than Allah? Exalted is Allah above whatever they associate with Him.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxix{%
And if they were to see a fragment from the sky falling, they would say, ``[It is merely] clouds heaped up."\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxx{%
So leave them until they meet their Day in which they will be struck insensible -\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxi{%
The Day their plan will not avail them at all, nor will they be helped.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxii{%
And indeed, for those who have wronged is a punishment before that, but most of them do not know.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiii{%
And be patient, [O Muhammad], for the decision of your Lord, for indeed, you are in Our eyes. And exalt [Allah] with praise of your Lord when you arise.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxiv{%
And in a part of the night exalt Him and after [the setting of] the stars.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxv{%
\basmalahen By the star when it descends,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvi{%
Your companion [Muhammad] has not strayed, nor has he erred,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxvii{%
Nor does he speak from [his own] inclination.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxviii{%
It is not but a revelation revealed,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcclxxxix{%
Taught to him by one intense in strength -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccxc{%
One of soundness. And he rose to [his] true form\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdccxci{%
While he was in the higher [part of the] horizon.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdccxcii{%
Then he approached and descended\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccxciii{%
And was at a distance of two bow lengths or nearer.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccxciv{%
And he revealed to His Servant what he revealed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccxcv{%
The heart did not lie [about] what it saw.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvi{%
So will you dispute with him over what he saw?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccxcvii{%
And he certainly saw him in another descent\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccxcviii{%
At the Lote Tree of the Utmost Boundary -\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccxcix{%
Near it is the Garden of Refuge -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccc{%
When there covered the Lote Tree that which covered [it].\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccci{%
The sight [of the Prophet] did not swerve, nor did it transgress [its limit].\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdcccii{%
He certainly saw of the greatest signs of his Lord.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccciii{%
So have you considered al-Lat and al-'Uzza?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccciv{%
And Manat, the third - the other one?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdcccv{%
Is the male for you and for Him the female?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdcccvi{%
That, then, is an unjust division.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdcccvii{%
They are not but [mere] names you have named them - you and your forefathers - for which Allah has sent down no authority. They follow not except assumption and what [their] souls desire, and there has already come to them from their Lord guidance.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdcccviii{%
Or is there for man whatever he wishes?\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdcccix{%
Rather, to Allah belongs the Hereafter and the first [life].\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdcccx{%
And how many angels there are in the heavens whose intercession will not avail at all except [only] after Allah has permitted [it] to whom He wills and approves.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdcccxi{%
Indeed, those who do not believe in the Hereafter name the angels female names,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdcccxii{%
And they have thereof no knowledge. They follow not except assumption, and indeed, assumption avails not against the truth at all.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiii{%
So turn away from whoever turns his back on Our message and desires not except the worldly life.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdcccxiv{%
That is their sum of knowledge. Indeed, your Lord is most knowing of who strays from His way, and He is most knowing of who is guided.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdcccxv{%
And to Allah belongs whatever is in the heavens and whatever is in the earth - that He may recompense those who do evil with [the penalty of] what they have done and recompense those who do good with the best [reward] -\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvi{%
Those who avoid the major sins and immoralities, only [committing] slight ones. Indeed, your Lord is vast in forgiveness. He was most knowing of you when He produced you from the earth and when you were fetuses in the wombs of your mothers. So do not claim yourselves to be pure; He is most knowing of who fears Him.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdcccxvii{%
Have you seen the one who turned away\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdcccxviii{%
And gave a little and [then] refrained?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdcccxix{%
Does he have knowledge of the unseen, so he sees?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdcccxx{%
Or has he not been informed of what was in the scriptures of Moses\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxi{%
And [of] Abraham, who fulfilled [his obligations] -\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxii{%
That no bearer of burdens will bear the burden of another\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiii{%
And that there is not for man except that [good] for which he strives\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxiv{%
And that his effort is going to be seen -\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxv{%
Then he will be recompensed for it with the fullest recompense\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvi{%
And that to your Lord is the finality\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxvii{%
And that it is He who makes [one] laugh and weep\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxviii{%
And that it is He who causes death and gives life\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxix{%
And that He creates the two mates - the male and female -\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxx{%
From a sperm-drop when it is emitted\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxi{%
And that [incumbent] upon Him is the next creation\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxii{%
And that it is He who enriches and suffices\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiii{%
And that it is He who is the Lord of Sirius\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxiv{%
And that He destroyed the first [people of] 'Aad\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxv{%
And Thamud - and He did not spare [them] -\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvi{%
And the people of Noah before. Indeed, it was they who were [even] more unjust and oppressing.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxvii{%
And the overturned towns He hurled down\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxviii{%
And covered them by that which He covered.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmdcccxxxix{%
Then which of the favors of your Lord do you doubt?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmdcccxl{%
This [Prophet] is a warner like the former warners.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmdcccxli{%
The Approaching Day has approached.\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlii{%
Of it, [from those] besides Allah, there is no remover.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliii{%
Then at this statement do you wonder?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmdcccxliv{%
And you laugh and do not weep\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlv{%
While you are proudly sporting?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvi{%
So prostrate to Allah and worship [Him].\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlvii{%
\basmalahen The Hour has come near, and the moon has split [in two].\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlviii{%
And if they see a miracle, they turn away and say, ``Passing magic."\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmdcccxlix{%
And they denied and followed their inclinations. But for every matter is a [time of] settlement.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmdcccl{%
And there has already come to them of information that in which there is deterrence -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmdcccli{%
Extensive wisdom - but warning does not avail [them].\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmdccclii{%
So leave them, [O Muhammad]. The Day the Caller calls to something forbidding,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmdcccliii{%
Their eyes humbled, they will emerge from the graves as if they were locusts spreading,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmdcccliv{%
Racing ahead toward the Caller. The disbelievers will say, ``This is a difficult Day."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmdccclv{%
The people of Noah denied before them, and they denied Our servant and said, ``A madman," and he was repelled.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmdccclvi{%
So he invoked his Lord, ``Indeed, I am overpowered, so help."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmdccclvii{%
Then We opened the gates of the heaven with rain pouring down\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmdccclviii{%
And caused the earth to burst with springs, and the waters met for a matter already predestined.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmdccclix{%
And We carried him on a [construction of] planks and nails,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmdccclx{%
Sailing under Our observation as reward for he who had been denied.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmdccclxi{%
And We left it as a sign, so is there any who will remember?\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmdccclxii{%
And how [severe] were My punishment and warning.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiii{%
And We have certainly made the Qur'an easy for remembrance, so is there any who will remember?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmdccclxiv{%
'Aad denied; and how [severe] were My punishment and warning.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmdccclxv{%
Indeed, We sent upon them a screaming wind on a day of continuous misfortune,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvi{%
Extracting the people as if they were trunks of palm trees uprooted.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmdccclxvii{%
And how [severe] were My punishment and warning.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmdccclxviii{%
And We have certainly made the Qur'an easy for remembrance, so is there any who will remember?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmdccclxix{%
Thamud denied the warning\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmdccclxx{%
And said, ``Is it one human being among us that we should follow? Indeed, we would then be in error and madness.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxi{%
Has the message been sent down upon him from among us? Rather, he is an insolent liar."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxii{%
They will know tomorrow who is the insolent liar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiii{%
Indeed, We are sending the she-camel as trial for them, so watch them and be patient.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxiv{%
And inform them that the water is shared between them, each [day of] drink attended [by turn].\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxv{%
But they called their companion, and he dared and hamstrung [her].\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvi{%
And how [severe] were My punishment and warning.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxvii{%
Indeed, We sent upon them one blast from the sky, and they became like the dry twig fragments of an [animal] pen.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxviii{%
And We have certainly made the Qur'an easy for remembrance, so is there any who will remember?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxix{%
The people of Lot denied the warning.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxx{%
Indeed, We sent upon them a storm of stones, except the family of Lot - We saved them before dawn\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxi{%
As favor from us. Thus do We reward he who is grateful.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxii{%
And he had already warned them of Our assault, but they disputed the warning.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiii{%
And they had demanded from him his guests, but We obliterated their eyes, [saying], ``Taste My punishment and warning."\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxiv{%
And there came upon them by morning an abiding punishment.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxv{%
So taste My punishment and warning.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvi{%
And We have certainly made the Qur'an easy for remembrance, so is there any who will remember?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxvii{%
And there certainly came to the people of Pharaoh warning.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxviii{%
They denied Our signs, all of them, so We seized them with a seizure of one Exalted in Might and Perfect in Ability.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmdccclxxxix{%
Are your disbelievers better than those [former ones], or have you immunity in the scripture?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmdcccxc{%
Or do they say, ``We are an assembly supporting [each other]"?\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmdcccxci{%
[Their] assembly will be defeated, and they will turn their backs [in retreat].\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcii{%
But the Hour is their appointment [for due punishment], and the Hour is more disastrous and more bitter.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciii{%
Indeed, the criminals are in error and madness.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmdcccxciv{%
The Day they are dragged into the Fire on their faces [it will be said], ``Taste the touch of Saqar."\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcv{%
Indeed, all things We created with predestination.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvi{%
And Our command is but one, like a glance of the eye.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcvii{%
And We have already destroyed your kinds, so is there any who will remember?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcviii{%
And everything they did is in written records.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmdcccxcix{%
And every small and great [thing] is inscribed.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcm{%
Indeed, the righteous will be among gardens and rivers,\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmi{%
In a seat of honor near a Sovereign, Perfect in Ability.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmii{%
\basmalahen The Most Merciful\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmiii{%
Taught the Qur'an,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmiv{%
Created man,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmv{%
[And] taught him eloquence.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmvi{%
The sun and the moon [move] by precise calculation,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmvii{%
And the stars and trees prostrate.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmviii{%
And the heaven He raised and imposed the balance\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmix{%
That you not transgress within the balance.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmx{%
And establish weight in justice and do not make deficient the balance.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmxi{%
And the earth He laid [out] for the creatures.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxii{%
Therein is fruit and palm trees having sheaths [of dates]\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxiii{%
And grain having husks and scented plants.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxiv{%
So which of the favors of your Lord would you deny?\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxv{%
He created man from clay like [that of] pottery.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxvi{%
And He created the jinn from a smokeless flame of fire.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxvii{%
So which of the favors of your Lord would you deny?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxviii{%
[He is] Lord of the two sunrises and Lord of the two sunsets.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxix{%
So which of the favors of your Lord would you deny?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxx{%
He released the two seas, meeting [side by side];\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxxi{%
Between them is a barrier [so] neither of them transgresses.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmcmxxii{%
So which of the favors of your Lord would you deny?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiii{%
From both of them emerge pearl and coral.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmcmxxiv{%
So which of the favors of your Lord would you deny?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmcmxxv{%
And to Him belong the ships [with sails] elevated in the sea like mountains.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvi{%
So which of the favors of your Lord would you deny?\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmcmxxvii{%
Everyone upon the earth will perish,\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmcmxxviii{%
And there will remain the Face of your Lord, Owner of Majesty and Honor.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmcmxxix{%
So which of the favors of your Lord would you deny?\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmcmxxx{%
Whoever is within the heavens and earth asks Him; every day He is bringing about a matter.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxi{%
So which of the favors of your Lord would you deny?\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxii{%
We will attend to you, O prominent beings.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiii{%
So which of the favors of your Lord would you deny?\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxiv{%
O company of jinn and mankind, if you are able to pass beyond the regions of the heavens and the earth, then pass. You will not pass except by authority [from Allah].\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxv{%
So which of the favors of your Lord would you deny?\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvi{%
There will be sent upon you a flame of fire and smoke, and you will not defend yourselves.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxvii{%
So which of the favors of your Lord would you deny?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxviii{%
And when the heaven is split open and becomes rose-colored like oil -\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmcmxxxix{%
So which of the favors of your Lord would you deny? -\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmcmxl{%
Then on that Day none will be asked about his sin among men or jinn.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmcmxli{%
So which of the favors of your Lord would you deny?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmcmxlii{%
The criminals will be known by their marks, and they will be seized by the forelocks and the feet.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmcmxliii{%
So which of the favors of your Lord would you deny?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmcmxliv{%
This is Hell, which the criminals deny.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmcmxlv{%
They will go around between it and scalding water, heated [to the utmost degree].\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvi{%
So which of the favors of your Lord would you deny?\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmcmxlvii{%
But for he who has feared the position of his Lord are two gardens -\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmcmxlviii{%
So which of the favors of your Lord would you deny? -\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmcmxlix{%
Having [spreading] branches.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmcml{%
So which of the favors of your Lord would you deny?\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmcmli{%
In both of them are two springs, flowing.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmcmlii{%
So which of the favors of your Lord would you deny?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmcmliii{%
In both of them are of every fruit, two kinds.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmcmliv{%
So which of the favors of your Lord would you deny?\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmcmlv{%
[They are] reclining on beds whose linings are of silk brocade, and the fruit of the two gardens is hanging low.\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmcmlvi{%
So which of the favors of your Lord would you deny?\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmcmlvii{%
In them are women limiting [their] glances, untouched before them by man or jinni -\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmcmlviii{%
So which of the favors of your Lord would you deny? -\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmcmlix{%
As if they were rubies and coral.\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmcmlx{%
So which of the favors of your Lord would you deny?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmcmlxi{%
Is the reward for good [anything] but good?\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmcmlxii{%
So which of the favors of your Lord would you deny?\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiii{%
And below them both [in excellence] are two [other] gardens -\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmcmlxiv{%
So which of the favors of your Lord would you deny? -\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmcmlxv{%
Dark green [in color].\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvi{%
So which of the favors of your Lord would you deny?\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmcmlxvii{%
In both of them are two springs, spouting.\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmcmlxviii{%
So which of the favors of your Lord would you deny?\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmcmlxix{%
In both of them are fruit and palm trees and pomegranates.\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmcmlxx{%
So which of the favors of your Lord would you deny?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxi{%
In them are good and beautiful women -\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxii{%
So which of the favors of your Lord would you deny? -\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiii{%
Fair ones reserved in pavilions -\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxiv{%
So which of the favors of your Lord would you deny? -\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxv{%
Untouched before them by man or jinni -\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvi{%
So which of the favors of your Lord would you deny? -\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxvii{%
Reclining on green cushions and beautiful fine carpets.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxviii{%
So which of the favors of your Lord would you deny?\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxix{%
Blessed is the name of your Lord, Owner of Majesty and Honor.\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxx{%
\basmalahen When the Occurrence occurs,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxi{%
There is, at its occurrence, no denial.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxii{%
It will bring down [some] and raise up [others].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiii{%
When the earth is shaken with convulsion\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxiv{%
And the mountains are broken down, crumbling\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxv{%
And become dust dispersing.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvi{%
And you become [of] three kinds:\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxvii{%
Then the companions of the right - what are the companions of the right?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxviii{%
And the companions of the left - what are the companions of the left?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmcmlxxxix{%
And the forerunners, the forerunners -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmcmxc{%
Those are the ones brought near [to Allah]\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmcmxci{%
In the Gardens of Pleasure,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmcmxcii{%
A [large] company of the former peoples\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmcmxciii{%
And a few of the later peoples,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmcmxciv{%
On thrones woven [with ornament],\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmcmxcv{%
Reclining on them, facing each other.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvi{%
There will circulate among them young boys made eternal\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmcmxcvii{%
With vessels, pitchers and a cup [of wine] from a flowing spring -\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmcmxcviii{%
No headache will they have therefrom, nor will they be intoxicated -\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmcmxcix{%
And fruit of what they select\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmm{%
And the meat of fowl, from whatever they desire.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmi{%
And [for them are] fair women with large, [beautiful] eyes,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmii{%
The likenesses of pearls well-protected,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmiii{%
As reward for what they used to do.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmiv{%
They will not hear therein ill speech or commission of sin -\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmv{%
Only a saying: ``Peace, peace."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmvi{%
The companions of the right - what are the companions of the right?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmvii{%
[They will be] among lote trees with thorns removed\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmviii{%
And [banana] trees layered [with fruit]\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmix{%
And shade extended\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmx{%
And water poured out\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmxi{%
And fruit, abundant [and varied],\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmxii{%
Neither limited [to season] nor forbidden,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmxiii{%
And [upon] beds raised high.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmxiv{%
Indeed, We have produced the women of Paradise in a [new] creation\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmxv{%
And made them virgins,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmxvi{%
Devoted [to their husbands] and of equal age,\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmxvii{%
For the companions of the right [who are]\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmxviii{%
A company of the former peoples\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmxix{%
And a company of the later peoples.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmxx{%
And the companions of the left - what are the companions of the left?\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmxxi{%
[They will be] in scorching fire and scalding water\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmxxii{%
And a shade of black smoke,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmxxiii{%
Neither cool nor beneficial.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmxxiv{%
Indeed they were, before that, indulging in affluence,\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmxxv{%
And they used to persist in the great violation,\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmxxvi{%
And they used to say, ``When we die and become dust and bones, are we indeed to be resurrected?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmxxvii{%
And our forefathers [as well]?"\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmxxviii{%
Say, [O Muhammad], ``Indeed, the former and the later peoples\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmxxix{%
Are to be gathered together for the appointment of a known Day."\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmxxx{%
Then indeed you, O those astray [who are] deniers,\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmxxxi{%
Will be eating from trees of zaqqum\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmxxxii{%
And filling with it your bellies\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiii{%
And drinking on top of it from scalding water\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmxxxiv{%
And will drink as the drinking of thirsty camels.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmxxxv{%
That is their accommodation on the Day of Recompense.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvi{%
We have created you, so why do you not believe?\qt@no{57}}%
\qt@newcmd\qurantrans@en@mmmmmxxxvii{%
Have you seen that which you emit?\qt@no{58}}%
\qt@newcmd\qurantrans@en@mmmmmxxxviii{%
Is it you who creates it, or are We the Creator?\qt@no{59}}%
\qt@newcmd\qurantrans@en@mmmmmxxxix{%
We have decreed death among you, and We are not to be outdone\qt@no{60}}%
\qt@newcmd\qurantrans@en@mmmmmxl{%
In that We will change your likenesses and produce you in that [form] which you do not know.\qt@no{61}}%
\qt@newcmd\qurantrans@en@mmmmmxli{%
And you have already known the first creation, so will you not remember?\qt@no{62}}%
\qt@newcmd\qurantrans@en@mmmmmxlii{%
And have you seen that [seed] which you sow?\qt@no{63}}%
\qt@newcmd\qurantrans@en@mmmmmxliii{%
Is it you who makes it grow, or are We the grower?\qt@no{64}}%
\qt@newcmd\qurantrans@en@mmmmmxliv{%
If We willed, We could make it [dry] debris, and you would remain in wonder,\qt@no{65}}%
\qt@newcmd\qurantrans@en@mmmmmxlv{%
[Saying], ``Indeed, we are [now] in debt;\qt@no{66}}%
\qt@newcmd\qurantrans@en@mmmmmxlvi{%
Rather, we have been deprived."\qt@no{67}}%
\qt@newcmd\qurantrans@en@mmmmmxlvii{%
And have you seen the water that you drink?\qt@no{68}}%
\qt@newcmd\qurantrans@en@mmmmmxlviii{%
Is it you who brought it down from the clouds, or is it We who bring it down?\qt@no{69}}%
\qt@newcmd\qurantrans@en@mmmmmxlix{%
If We willed, We could make it bitter, so why are you not grateful?\qt@no{70}}%
\qt@newcmd\qurantrans@en@mmmmml{%
And have you seen the fire that you ignite?\qt@no{71}}%
\qt@newcmd\qurantrans@en@mmmmmli{%
Is it you who produced its tree, or are We the producer?\qt@no{72}}%
\qt@newcmd\qurantrans@en@mmmmmlii{%
We have made it a reminder and provision for the travelers,\qt@no{73}}%
\qt@newcmd\qurantrans@en@mmmmmliii{%
So exalt the name of your Lord, the Most Great.\qt@no{74}}%
\qt@newcmd\qurantrans@en@mmmmmliv{%
Then I swear by the setting of the stars,\qt@no{75}}%
\qt@newcmd\qurantrans@en@mmmmmlv{%
And indeed, it is an oath - if you could know - [most] great.\qt@no{76}}%
\qt@newcmd\qurantrans@en@mmmmmlvi{%
Indeed, it is a noble Qur'an\qt@no{77}}%
\qt@newcmd\qurantrans@en@mmmmmlvii{%
In a Register well-protected;\qt@no{78}}%
\qt@newcmd\qurantrans@en@mmmmmlviii{%
None touch it except the purified.\qt@no{79}}%
\qt@newcmd\qurantrans@en@mmmmmlix{%
[It is] a revelation from the Lord of the worlds.\qt@no{80}}%
\qt@newcmd\qurantrans@en@mmmmmlx{%
Then is it to this statement that you are indifferent\qt@no{81}}%
\qt@newcmd\qurantrans@en@mmmmmlxi{%
And make [the thanks for] your provision that you deny [the Provider]?\qt@no{82}}%
\qt@newcmd\qurantrans@en@mmmmmlxii{%
Then why, when the soul at death reaches the throat\qt@no{83}}%
\qt@newcmd\qurantrans@en@mmmmmlxiii{%
And you are at that time looking on -\qt@no{84}}%
\qt@newcmd\qurantrans@en@mmmmmlxiv{%
And Our angels are nearer to him than you, but you do not see -\qt@no{85}}%
\qt@newcmd\qurantrans@en@mmmmmlxv{%
Then why do you not, if you are not to be recompensed,\qt@no{86}}%
\qt@newcmd\qurantrans@en@mmmmmlxvi{%
Bring it back, if you should be truthful?\qt@no{87}}%
\qt@newcmd\qurantrans@en@mmmmmlxvii{%
And if the deceased was of those brought near to Allah,\qt@no{88}}%
\qt@newcmd\qurantrans@en@mmmmmlxviii{%
Then [for him is] rest and bounty and a garden of pleasure.\qt@no{89}}%
\qt@newcmd\qurantrans@en@mmmmmlxix{%
And if he was of the companions of the right,\qt@no{90}}%
\qt@newcmd\qurantrans@en@mmmmmlxx{%
Then [the angels will say], ``Peace for you; [you are] from the companions of the right."\qt@no{91}}%
\qt@newcmd\qurantrans@en@mmmmmlxxi{%
But if he was of the deniers [who were] astray,\qt@no{92}}%
\qt@newcmd\qurantrans@en@mmmmmlxxii{%
Then [for him is] accommodation of scalding water\qt@no{93}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiii{%
And burning in Hellfire\qt@no{94}}%
\qt@newcmd\qurantrans@en@mmmmmlxxiv{%
Indeed, this is the true certainty,\qt@no{95}}%
\qt@newcmd\qurantrans@en@mmmmmlxxv{%
So exalt the name of your Lord, the Most Great.\qt@no{96}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvi{%
\basmalahen Whatever is in the heavens and earth exalts Allah, and He is the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmlxxvii{%
His is the dominion of the heavens and earth. He gives life and causes death, and He is over all things competent.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmlxxviii{%
He is the First and the Last, the Ascendant and the Intimate, and He is, of all things, Knowing.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmlxxix{%
It is He who created the heavens and earth in six days and then established Himself above the Throne. He knows what penetrates into the earth and what emerges from it and what descends from the heaven and what ascends therein; and He is with you wherever you are. And Allah, of what you do, is Seeing.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmlxxx{%
His is the dominion of the heavens and earth. And to Allah are returned [all] matters.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxi{%
He causes the night to enter the day and causes the day to enter the night, and he is Knowing of that within the breasts.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxii{%
Believe in Allah and His Messenger and spend out of that in which He has made you successors. For those who have believed among you and spent, there will be a great reward.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiii{%
And why do you not believe in Allah while the Messenger invites you to believe in your Lord and He has taken your covenant, if you should [truly] be believers?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxiv{%
It is He who sends down upon His Servant [Muhammad] verses of clear evidence that He may bring you out from darknesses into the light. And indeed, Allah is to you Kind and Merciful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxv{%
And why do you not spend in the cause of Allah while to Allah belongs the heritage of the heavens and the earth? Not equal among you are those who spent before the conquest [of Makkah] and fought [and those who did so after it]. Those are greater in degree than they who spent afterwards and fought. But to all Allah has promised the best [reward]. And Allah, with what you do, is Acquainted.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvi{%
Who is it that would loan Allah a goodly loan so He will multiply it for him and he will have a noble reward?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxvii{%
On the Day you see the believing men and believing women, their light proceeding before them and on their right, [it will be said], ``Your good tidings today are [of] gardens beneath which rivers flow, wherein you will abide eternally." That is what is the great attainment.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxviii{%
On the [same] Day the hypocrite men and hypocrite women will say to those who believed, ``Wait for us that we may acquire some of your light." It will be said, ``Go back behind you and seek light." And a wall will be placed between them with a door, its interior containing mercy, but on the outside of it is torment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmlxxxix{%
The hypocrites will call to the believers, ``Were we not with you?" They will say, ``Yes, but you afflicted yourselves and awaited [misfortune for us] and doubted, and wishful thinking deluded you until there came the command of Allah. And the Deceiver deceived you concerning Allah.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmxc{%
So today no ransom will be taken from you or from those who disbelieved. Your refuge is the Fire. It is most worthy of you, and wretched is the destination.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmxci{%
Has the time not come for those who have believed that their hearts should become humbly submissive at the remembrance of Allah and what has come down of the truth? And let them not be like those who were given the Scripture before, and a long period passed over them, so their hearts hardened; and many of them are defiantly disobedient.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmxcii{%
Know that Allah gives life to the earth after its lifelessness. We have made clear to you the signs; perhaps you will understand.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmxciii{%
Indeed, the men who practice charity and the women who practice charity and [they who] have loaned Allah a goodly loan - it will be multiplied for them, and they will have a noble reward.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmxciv{%
And those who have believed in Allah and His messengers - those are [in the ranks of] the supporters of truth and the martyrs, with their Lord. For them is their reward and their light. But those who have disbelieved and denied Our verses - those are the companions of Hellfire.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmxcv{%
Know that the life of this world is but amusement and diversion and adornment and boasting to one another and competition in increase of wealth and children - like the example of a rain whose [resulting] plant growth pleases the tillers; then it dries and you see it turned yellow; then it becomes [scattered] debris. And in the Hereafter is severe punishment and forgiveness from Allah and approval. And what is the worldly life except the enjoyment of delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmxcvi{%
Race toward forgiveness from your Lord and a Garden whose width is like the width of the heavens and earth, prepared for those who believed in Allah and His messengers. That is the bounty of Allah which He gives to whom He wills, and Allah is the possessor of great bounty.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmxcvii{%
No disaster strikes upon the earth or among yourselves except that it is in a register before We bring it into being - indeed that, for Allah, is easy -\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmxcviii{%
In order that you not despair over what has eluded you and not exult [in pride] over what He has given you. And Allah does not like everyone self-deluded and boastful -\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmxcix{%
[Those] who are stingy and enjoin upon people stinginess. And whoever turns away - then indeed, Allah is the Free of need, the Praiseworthy.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmc{%
We have already sent Our messengers with clear evidences and sent down with them the Scripture and the balance that the people may maintain [their affairs] in justice. And We sent down iron, wherein is great military might and benefits for the people, and so that Allah may make evident those who support Him and His messengers unseen. Indeed, Allah is Powerful and Exalted in Might.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmci{%
And We have already sent Noah and Abraham and placed in their descendants prophethood and scripture; and among them is he who is guided, but many of them are defiantly disobedient.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcii{%
Then We sent following their footsteps Our messengers and followed [them] with Jesus, the son of Mary, and gave him the Gospel. And We placed in the hearts of those who followed him compassion and mercy and monasticism, which they innovated; We did not prescribe it for them except [that they did so] seeking the approval of Allah. But they did not observe it with due observance. So We gave the ones who believed among them their reward, but many of them are defiantly disobedient.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmciii{%
O you who have believed, fear Allah and believe in His Messenger; He will [then] give you a double portion of His mercy and make for you a light by which you will walk and forgive you; and Allah is Forgiving and Merciful.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmciv{%
[This is] so that the People of the Scripture may know that they are not able [to obtain] anything from the bounty of Allah and that [all] bounty is in the hand of Allah; He gives it to whom He wills. And Allah is the possessor of great bounty.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcv{%
\basmalahen Certainly has Allah heard the speech of the one who argues with you, [O Muhammad], concerning her husband and directs her complaint to Allah. And Allah hears your dialogue; indeed, Allah is Hearing and Seeing.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcvi{%
Those who pronounce thihar among you [to separate] from their wives - they are not [consequently] their mothers. Their mothers are none but those who gave birth to them. And indeed, they are saying an objectionable statement and a falsehood. But indeed, Allah is Pardoning and Forgiving.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcvii{%
And those who pronounce thihar from their wives and then [wish to] go back on what they said - then [there must be] the freeing of a slave before they touch one another. That is what you are admonished thereby; and Allah is Acquainted with what you do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcviii{%
And he who does not find [a slave] - then a fast for two months consecutively before they touch one another; and he who is unable - then the feeding of sixty poor persons. That is for you to believe [completely] in Allah and His Messenger; and those are the limits [set by] Allah. And for the disbelievers is a painful punishment.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcix{%
Indeed, those who oppose Allah and His Messenger are abased as those before them were abased. And We have certainly sent down verses of clear evidence. And for the disbelievers is a humiliating punishment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcx{%
On the Day when Allah will resurrect them all and inform them of what they did. Allah had enumerated it, while they forgot it; and Allah is, over all things, Witness.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxi{%
Have you not considered that Allah knows what is in the heavens and what is on the earth? There is in no private conversation three but that He is the fourth of them, nor are there five but that He is the sixth of them - and no less than that and no more except that He is with them [in knowledge] wherever they are. Then He will inform them of what they did, on the Day of Resurrection. Indeed Allah is, of all things, Knowing.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxii{%
Have you not considered those who were forbidden from private conversation, then they return to that which they were forbidden and converse among themselves about sin and aggression and disobedience to the Messenger? And when they come to you, they greet you with that [word] by which Allah does not greet you and say among themselves, ``Why does Allah not punish us for what we say?" Sufficient for them is Hell, which they will [enter to] burn, and wretched is the destination.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxiii{%
O you who have believed, when you converse privately, do not converse about sin and aggression and disobedience to the Messenger but converse about righteousness and piety. And fear Allah, to whom you will be gathered.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxiv{%
Private conversation is only from Satan that he may grieve those who have believed, but he will not harm them at all except by permission of Allah. And upon Allah let the believers rely.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxv{%
O you who have believed, when you are told, ``Space yourselves" in assemblies, then make space; Allah will make space for you. And when you are told, ``Arise," then arise; Allah will raise those who have believed among you and those who were given knowledge, by degrees. And Allah is Acquainted with what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxvi{%
O you who have believed, when you [wish to] privately consult the Messenger, present before your consultation a charity. That is better for you and purer. But if you find not [the means] - then indeed, Allah is Forgiving and Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxvii{%
Have you feared to present before your consultation charities? Then when you do not and Allah has forgiven you, then [at least] establish prayer and give zakah and obey Allah and His Messenger. And Allah is Acquainted with what you do.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxviii{%
Have you not considered those who make allies of a people with whom Allah has become angry? They are neither of you nor of them, and they swear to untruth while they know [they are lying].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxix{%
Allah has prepared for them a severe punishment. Indeed, it was evil that they were doing.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxx{%
They took their [false] oaths as a cover, so they averted [people] from the way of Allah, and for them is a humiliating punishment.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxxi{%
Never will their wealth or their children avail them against Allah at all. Those are the companions of the Fire; they will abide therein eternally\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxxii{%
On the Day Allah will resurrect them all, and they will swear to Him as they swear to you and think that they are [standing] on something. Unquestionably, it is they who are the liars.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiii{%
Satan has overcome them and made them forget the remembrance of Allah. Those are the party of Satan. Unquestionably, the party of Satan - they will be the losers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxxiv{%
Indeed, the ones who oppose Allah and His Messenger - those will be among the most humbled.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxxv{%
Allah has written, ``I will surely overcome, I and My messengers." Indeed, Allah is Powerful and Exalted in Might.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvi{%
You will not find a people who believe in Allah and the Last Day having affection for those who oppose Allah and His Messenger, even if they were their fathers or their sons or their brothers or their kindred. Those - He has decreed within their hearts faith and supported them with spirit from Him. And We will admit them to gardens beneath which rivers flow, wherein they abide eternally. Allah is pleased with them, and they are pleased with Him - those are the party of Allah. Unquestionably, the party of Allah - they are the successful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxxvii{%
\basmalahen Whatever is in the heavens and whatever is on the earth exalts Allah, and He is the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxxviii{%
It is He who expelled the ones who disbelieved among the People of the Scripture from their homes at the first gathering. You did not think they would leave, and they thought that their fortresses would protect them from Allah; but [the decree of] Allah came upon them from where they had not expected, and He cast terror into their hearts [so] they destroyed their houses by their [own] hands and the hands of the believers. So take warning, O people of vision.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxxix{%
And if not that Allah had decreed for them evacuation, He would have punished them in [this] world, and for them in the Hereafter is the punishment of the Fire.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxxx{%
That is because they opposed Allah and His Messenger. And whoever opposes Allah - then indeed, Allah is severe in penalty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxi{%
Whatever you have cut down of [their] palm trees or left standing on their trunks - it was by permission of Allah and so He would disgrace the defiantly disobedient.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxii{%
And what Allah restored [of property] to His Messenger from them - you did not spur for it [in an expedition] any horses or camels, but Allah gives His messengers power over whom He wills, and Allah is over all things competent.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiii{%
And what Allah restored to His Messenger from the people of the towns - it is for Allah and for the Messenger and for [his] near relatives and orphans and the [stranded] traveler - so that it will not be a perpetual distribution among the rich from among you. And whatever the Messenger has given you - take; and what he has forbidden you - refrain from. And fear Allah; indeed, Allah is severe in penalty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxiv{%
For the poor emigrants who were expelled from their homes and their properties, seeking bounty from Allah and [His] approval and supporting Allah and His Messenger, [there is also a share]. Those are the truthful.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxv{%
And [also for] those who were settled in al-Madinah and [adopted] the faith before them. They love those who emigrated to them and find not any want in their breasts of what the emigrants were given but give [them] preference over themselves, even though they are in privation. And whoever is protected from the stinginess of his soul - it is those who will be the successful.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvi{%
And [there is a share for] those who came after them, saying, ``Our Lord, forgive us and our brothers who preceded us in faith and put not in our hearts [any] resentment toward those who have believed. Our Lord, indeed You are Kind and Merciful."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxvii{%
Have you not considered those who practice hypocrisy, saying to their brothers who have disbelieved among the People of the Scripture, ``If you are expelled, we will surely leave with you, and we will not obey, in regard to you, anyone - ever; and if you are fought, we will surely aid you." But Allah testifies that they are liars.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxviii{%
If they are expelled, they will not leave with them, and if they are fought, they will not aid them. And [even] if they should aid them, they will surely turn their backs; then [thereafter] they will not be aided.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcxxxix{%
You [believers] are more fearful within their breasts than Allah. That is because they are a people who do not understand.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcxl{%
They will not fight you all except within fortified cities or from behind walls. Their violence among themselves is severe. You think they are together, but their hearts are diverse. That is because they are a people who do not reason.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcxli{%
[Theirs is] like the example of those shortly before them: they tasted the bad consequence of their affair, and they will have a painful punishment.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcxlii{%
[The hypocrites are] like the example of Satan when he says to man, ``Disbelieve." But when he disbelieves, he says, ``Indeed, I am disassociated from you. Indeed, I fear Allah, Lord of the worlds."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcxliii{%
So the outcome for both of them is that they will be in the Fire, abiding eternally therein. And that is the recompense of the wrong-doers.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcxliv{%
O you who have believed, fear Allah. And let every soul look to what it has put forth for tomorrow - and fear Allah. Indeed, Allah is Acquainted with what you do.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcxlv{%
And be not like those who forgot Allah, so He made them forget themselves. Those are the defiantly disobedient.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvi{%
Not equal are the companions of the Fire and the companions of Paradise. The companions of Paradise - they are the attainers [of success].\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcxlvii{%
If We had sent down this Qur'an upon a mountain, you would have seen it humbled and coming apart from fear of Allah. And these examples We present to the people that perhaps they will give thought.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcxlviii{%
He is Allah, other than whom there is no deity, Knower of the unseen and the witnessed. He is the Entirely Merciful, the Especially Merciful.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcxlix{%
He is Allah, other than whom there is no deity, the Sovereign, the Pure, the Perfection, the Bestower of Faith, the Overseer, the Exalted in Might, the Compeller, the Superior. Exalted is Allah above whatever they associate with Him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcl{%
He is Allah, the Creator, the Inventor, the Fashioner; to Him belong the best names. Whatever is in the heavens and earth is exalting Him. And He is the Exalted in Might, the Wise.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcli{%
\basmalahen O you who have believed, do not take My enemies and your enemies as allies, extending to them affection while they have disbelieved in what came to you of the truth, having driven out the Prophet and yourselves [only] because you believe in Allah, your Lord. If you have come out for jihad in My cause and seeking means to My approval, [take them not as friends]. You confide to them affection, but I am most knowing of what you have concealed and what you have declared. And whoever does it among you has certainly strayed from the soundness of the way.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclii{%
If they gain dominance over you, they would be to you as enemies and extend against you their hands and their tongues with evil, and they wish you would disbelieve.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcliii{%
Never will your relatives or your children benefit you; the Day of Resurrection He will judge between you. And Allah, of what you do, is Seeing.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcliv{%
There has already been for you an excellent pattern in Abraham and those with him, when they said to their people, ``Indeed, we are disassociated from you and from whatever you worship other than Allah. We have denied you, and there has appeared between us and you animosity and hatred forever until you believe in Allah alone" except for the saying of Abraham to his father, ``I will surely ask forgiveness for you, but I have not [power to do] for you anything against Allah. Our Lord, upon You we have relied, and to You we have returned, and to You is the destination.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclv{%
Our Lord, make us not [objects of] torment for the disbelievers and forgive us, our Lord. Indeed, it is You who is the Exalted in Might, the Wise."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclvi{%
There has certainly been for you in them an excellent pattern for anyone whose hope is in Allah and the Last Day. And whoever turns away - then indeed, Allah is the Free of need, the Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclvii{%
Perhaps Allah will put, between you and those to whom you have been enemies among them, affection. And Allah is competent, and Allah is Forgiving and Merciful.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclviii{%
Allah does not forbid you from those who do not fight you because of religion and do not expel you from your homes - from being righteous toward them and acting justly toward them. Indeed, Allah loves those who act justly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclix{%
Allah only forbids you from those who fight you because of religion and expel you from your homes and aid in your expulsion - [forbids] that you make allies of them. And whoever makes allies of them, then it is those who are the wrongdoers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclx{%
O you who have believed, when the believing women come to you as emigrants, examine them. Allah is most knowing as to their faith. And if you know them to be believers, then do not return them to the disbelievers; they are not lawful [wives] for them, nor are they lawful [husbands] for them. But give the disbelievers what they have spent. And there is no blame upon you if you marry them when you have given them their due compensation. And hold not to marriage bonds with disbelieving women, but ask for what you have spent and let them ask for what they have spent. That is the judgement of Allah; He judges between you. And Allah is Knowing and Wise.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxi{%
And if you have lost any of your wives to the disbelievers and you subsequently obtain [something], then give those whose wives have gone the equivalent of what they had spent. And fear Allah, in whom you are believers.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxii{%
O Prophet, when the believing women come to you pledging to you that they will not associate anything with Allah, nor will they steal, nor will they commit unlawful sexual intercourse, nor will they kill their children, nor will they bring forth a slander they have invented between their arms and legs, nor will they disobey you in what is right - then accept their pledge and ask forgiveness for them of Allah. Indeed, Allah is Forgiving and Merciful.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxiii{%
O you who have believed, do not make allies of a people with whom Allah has become angry. They have despaired of [reward in] the Hereafter just as the disbelievers have despaired of [meeting] the inhabitants of the graves.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxiv{%
\basmalahen Whatever is in the heavens and whatever is on the earth exalts Allah, and He is the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxv{%
O you who have believed, why do you say what you do not do?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxvi{%
Great is hatred in the sight of Allah that you say what you do not do.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxvii{%
Indeed, Allah loves those who fight in His cause in a row as though they are a [single] structure joined firmly.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxviii{%
And [mention, O Muhammad], when Moses said to his people, ``O my people, why do you harm me while you certainly know that I am the messenger of Allah to you?" And when they deviated, Allah caused their hearts to deviate. And Allah does not guide the defiantly disobedient people.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxix{%
And [mention] when Jesus, the son of Mary, said, ``O children of Israel, indeed I am the messenger of Allah to you confirming what came before me of the Torah and bringing good tidings of a messenger to come after me, whose name is Ahmad." But when he came to them with clear evidences, they said, ``This is obvious magic."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxx{%
And who is more unjust than one who invents about Allah untruth while he is being invited to Islam. And Allah does not guide the wrongdoing people.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxi{%
They want to extinguish the light of Allah with their mouths, but Allah will perfect His light, although the disbelievers dislike it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxii{%
It is He who sent His Messenger with guidance and the religion of truth to manifest it over all religion, although those who associate others with Allah dislike it.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiii{%
O you who have believed, shall I guide you to a transaction that will save you from a painful punishment?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxiv{%
[It is that] you believe in Allah and His Messenger and strive in the cause of Allah with your wealth and your lives. That is best for you, if you should know.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxv{%
He will forgive for you your sins and admit you to gardens beneath which rivers flow and pleasant dwellings in gardens of perpetual residence. That is the great attainment.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvi{%
And [you will obtain] another [favor] that you love - victory from Allah and an imminent conquest; and give good tidings to the believers.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmclxxvii{%
O you who have believed, be supporters of Allah, as when Jesus, the son of Mary, said to the disciples, ``Who are my supporters for Allah?" The disciples said, ``We are supporters of Allah." And a faction of the Children of Israel believed and a faction disbelieved. So We supported those who believed against their enemy, and they became dominant.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmclxxviii{%
\basmalahen Whatever is in the heavens and whatever is on the earth is exalting Allah, the Sovereign, the Pure, the Exalted in Might, the Wise.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmclxxix{%
It is He who has sent among the unlettered a Messenger from themselves reciting to them His verses and purifying them and teaching them the Book and wisdom - although they were before in clear error -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmclxxx{%
And [to] others of them who have not yet joined them. And He is the Exalted in Might, the Wise.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxi{%
That is the bounty of Allah, which He gives to whom He wills, and Allah is the possessor of great bounty.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxii{%
The example of those who were entrusted with the Torah and then did not take it on is like that of a donkey who carries volumes [of books]. Wretched is the example of the people who deny the signs of Allah. And Allah does not guide the wrongdoing people.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiii{%
Say, ``O you who are Jews, if you claim that you are allies of Allah, excluding the [other] people, then wish for death, if you should be truthful."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxiv{%
But they will not wish for it, ever, because of what their hands have put forth. And Allah is Knowing of the wrongdoers.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxv{%
Say, ``Indeed, the death from which you flee - indeed, it will meet you. Then you will be returned to the Knower of the unseen and the witnessed, and He will inform you about what you used to do."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvi{%
O you who have believed, when [the adhan] is called for the prayer on the day of Jumu'ah [Friday], then proceed to the remembrance of Allah and leave trade. That is better for you, if you only knew.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxvii{%
And when the prayer has been concluded, disperse within the land and seek from the bounty of Allah, and remember Allah often that you may succeed.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxviii{%
But when they saw a transaction or a diversion, [O Muhammad], they rushed to it and left you standing. Say, ``What is with Allah is better than diversion and than a transaction, and Allah is the best of providers."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmclxxxix{%
\basmalahen When the hypocrites come to you, [O Muhammad], they say, ``We testify that you are the Messenger of Allah." And Allah knows that you are His Messenger, and Allah testifies that the hypocrites are liars.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcxc{%
They have taken their oaths as a cover, so they averted [people] from the way of Allah. Indeed, it was evil that they were doing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcxci{%
That is because they believed, and then they disbelieved; so their hearts were sealed over, and they do not understand.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcxcii{%
And when you see them, their forms please you, and if they speak, you listen to their speech. [They are] as if they were pieces of wood propped up - they think that every shout is against them. They are the enemy, so beware of them. May Allah destroy them; how are they deluded?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcxciii{%
And when it is said to them, ``Come, the Messenger of Allah will ask forgiveness for you," they turn their heads aside and you see them evading while they are arrogant.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcxciv{%
It is all the same for them whether you ask forgiveness for them or do not ask forgiveness for them; never will Allah forgive them. Indeed, Allah does not guide the defiantly disobedient people.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcxcv{%
They are the ones who say, ``Do not spend on those who are with the Messenger of Allah until they disband." And to Allah belongs the depositories of the heavens and the earth, but the hypocrites do not understand.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvi{%
They say, ``If we return to al-Madinah, the more honored [for power] will surely expel therefrom the more humble." And to Allah belongs [all] honor, and to His Messenger, and to the believers, but the hypocrites do not know.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcxcvii{%
O you who have believed, let not your wealth and your children divert you from remembrance of Allah. And whoever does that - then those are the losers.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcxcviii{%
And spend [in the way of Allah] from what We have provided you before death approaches one of you and he says, ``My Lord, if only You would delay me for a brief term so I would give charity and be among the righteous."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcxcix{%
But never will Allah delay a soul when its time has come. And Allah is Acquainted with what you do.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcc{%
\basmalahen Whatever is in the heavens and whatever is on the earth is exalting Allah. To Him belongs dominion, and to Him belongs [all] praise, and He is over all things competent.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcci{%
It is He who created you, and among you is the disbeliever, and among you is the believer. And Allah, of what you do, is Seeing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccii{%
He created the heavens and earth in truth and formed you and perfected your forms; and to Him is the [final] destination.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcciii{%
He knows what is within the heavens and earth and knows what you conceal and what you declare. And Allah is Knowing of that within the breasts.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcciv{%
Has there not come to you the news of those who disbelieved before? So they tasted the bad consequence of their affair, and they will have a painful punishment.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccv{%
That is because their messengers used to come to them with clear evidences, but they said, ``Shall human beings guide us?" and disbelieved and turned away. And Allah dispensed [with them]; and Allah is Free of need and Praiseworthy.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccvi{%
Those who disbelieve have claimed that they will never be resurrected. Say, ``Yes, by my Lord, you will surely be resurrected; then you will surely be informed of what you did. And that, for Allah, is easy."\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccvii{%
So believe in Allah and His Messenger and the Qur'an which We have sent down. And Allah is Acquainted with what you do.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccviii{%
The Day He will assemble you for the Day of Assembly - that is the Day of Deprivation. And whoever believes in Allah and does righteousness - He will remove from him his misdeeds and admit him to gardens beneath which rivers flow, wherein they will abide forever. That is the great attainment.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccix{%
But the ones who disbelieved and denied Our verses - those are the companions of the Fire, abiding eternally therein; and wretched is the destination.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccx{%
No disaster strikes except by permission of Allah. And whoever believes in Allah - He will guide his heart. And Allah is Knowing of all things.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxi{%
And obey Allah and obey the Messenger; but if you turn away - then upon Our Messenger is only [the duty of] clear notification.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxii{%
Allah - there is no deity except Him. And upon Allah let the believers rely.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccxiii{%
O you who have believed, indeed, among your wives and your children are enemies to you, so beware of them. But if you pardon and overlook and forgive - then indeed, Allah is Forgiving and Merciful.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmccxiv{%
Your wealth and your children are but a trial, and Allah has with Him a great reward.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmccxv{%
So fear Allah as much as you are able and listen and obey and spend [in the way of Allah]; it is better for your selves. And whoever is protected from the stinginess of his soul - it is those who will be the successful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmccxvi{%
If you loan Allah a goodly loan, He will multiply it for you and forgive you. And Allah is Most Appreciative and Forbearing.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmccxvii{%
Knower of the unseen and the witnessed, the Exalted in Might, the Wise.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxviii{%
\basmalahen O Prophet, when you [Muslims] divorce women, divorce them for [the commencement of] their waiting period and keep count of the waiting period, and fear Allah, your Lord. Do not turn them out of their [husbands'] houses, nor should they [themselves] leave [during that period] unless they are committing a clear immorality. And those are the limits [set by] Allah. And whoever transgresses the limits of Allah has certainly wronged himself. You know not; perhaps Allah will bring about after that a [different] matter.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxix{%
And when they have [nearly] fulfilled their term, either retain them according to acceptable terms or part with them according to acceptable terms. And bring to witness two just men from among you and establish the testimony for [the acceptance of] Allah. That is instructed to whoever should believe in Allah and the Last day. And whoever fears Allah - He will make for him a way out\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxx{%
And will provide for him from where he does not expect. And whoever relies upon Allah - then He is sufficient for him. Indeed, Allah will accomplish His purpose. Allah has already set for everything a [decreed] extent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxi{%
And those who no longer expect menstruation among your women - if you doubt, then their period is three months, and [also for] those who have not menstruated. And for those who are pregnant, their term is until they give birth. And whoever fears Allah - He will make for him of his matter ease.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxii{%
That is the command of Allah, which He has sent down to you; and whoever fears Allah - He will remove for him his misdeeds and make great for him his reward.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiii{%
Lodge them [in a section] of where you dwell out of your means and do not harm them in order to oppress them. And if they should be pregnant, then spend on them until they give birth. And if they breastfeed for you, then give them their payment and confer among yourselves in the acceptable way; but if you are in discord, then there may breastfeed for the father another woman.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxiv{%
Let a man of wealth spend from his wealth, and he whose provision is restricted - let him spend from what Allah has given him. Allah does not charge a soul except [according to] what He has given it. Allah will bring about, after hardship, ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxv{%
And how many a city was insolent toward the command of its Lord and His messengers, so We took it to severe account and punished it with a terrible punishment.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvi{%
And it tasted the bad consequence of its affair, and the outcome of its affair was loss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxvii{%
Allah has prepared for them a severe punishment; so fear Allah, O you of understanding who have believed. Allah has sent down to you the Qur'an.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxxviii{%
[He sent] a Messenger [Muhammad] reciting to you the distinct verses of Allah that He may bring out those who believe and do righteous deeds from darknesses into the light. And whoever believes in Allah and does righteousness - He will admit him into gardens beneath which rivers flow to abide therein forever. Allah will have perfected for him a provision.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxxix{%
It is Allah who has created seven heavens and of the earth, the like of them. [His] command descends among them so you may know that Allah is over all things competent and that Allah has encompassed all things in knowledge.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxxx{%
\basmalahen O Prophet, why do you prohibit [yourself from] what Allah has made lawful for you, seeking the approval of your wives? And Allah is Forgiving and Merciful.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxi{%
Allah has already ordained for you [Muslims] the dissolution of your oaths. And Allah is your protector, and He is the Knowing, the Wise.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxii{%
And [remember] when the Prophet confided to one of his wives a statement; and when she informed [another] of it and Allah showed it to him, he made known part of it and ignored a part. And when he informed her about it, she said, ``Who told you this?" He said, ``I was informed by the Knowing, the Acquainted."\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiii{%
If you two [wives] repent to Allah, [it is best], for your hearts have deviated. But if you cooperate against him - then indeed Allah is his protector, and Gabriel and the righteous of the believers and the angels, moreover, are [his] assistants.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxiv{%
Perhaps his Lord, if he divorced you [all], would substitute for him wives better than you - submitting [to Allah], believing, devoutly obedient, repentant, worshipping, and traveling - [ones] previously married and virgins.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxv{%
O you who have believed, protect yourselves and your families from a Fire whose fuel is people and stones, over which are [appointed] angels, harsh and severe; they do not disobey Allah in what He commands them but do what they are commanded.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvi{%
O you who have disbelieved, make no excuses that Day. You will only be recompensed for what you used to do.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxvii{%
O you who have believed, repent to Allah with sincere repentance. Perhaps your Lord will remove from you your misdeeds and admit you into gardens beneath which rivers flow [on] the Day when Allah will not disgrace the Prophet and those who believed with him. Their light will proceed before them and on their right; they will say, ``Our Lord, perfect for us our light and forgive us. Indeed, You are over all things competent."\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxviii{%
O Prophet, strive against the disbelievers and the hypocrites and be harsh upon them. And their refuge is Hell, and wretched is the destination.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccxxxix{%
Allah presents an example of those who disbelieved: the wife of Noah and the wife of Lot. They were under two of Our righteous servants but betrayed them, so those prophets did not avail them from Allah at all, and it was said, ``Enter the Fire with those who enter."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccxl{%
And Allah presents an example of those who believed: the wife of Pharaoh, when she said, ``My Lord, build for me near You a house in Paradise and save me from Pharaoh and his deeds and save me from the wrongdoing people."\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccxli{%
And [the example of] Mary, the daughter of 'Imran, who guarded her chastity, so We blew into [her garment] through Our angel, and she believed in the words of her Lord and His scriptures and was of the devoutly obedient.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccxlii{%
\basmalahen Blessed is He in whose hand is dominion, and He is over all things competent -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccxliii{%
[He] who created death and life to test you [as to] which of you is best in deed - and He is the Exalted in Might, the Forgiving -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccxliv{%
[And] who created seven heavens in layers. You do not see in the creation of the Most Merciful any inconsistency. So return [your] vision [to the sky]; do you see any breaks?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccxlv{%
Then return [your] vision twice again. [Your] vision will return to you humbled while it is fatigued.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvi{%
And We have certainly beautified the nearest heaven with stars and have made [from] them what is thrown at the devils and have prepared for them the punishment of the Blaze.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccxlvii{%
And for those who disbelieved in their Lord is the punishment of Hell, and wretched is the destination.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccxlviii{%
When they are thrown into it, they hear from it a [dreadful] inhaling while it boils up.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccxlix{%
It almost bursts with rage. Every time a company is thrown into it, its keepers ask them, ``Did there not come to you a warner?"\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccl{%
They will say," Yes, a warner had come to us, but we denied and said, 'Allah has not sent down anything. You are not but in great error.'"\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccli{%
And they will say, ``If only we had been listening or reasoning, we would not be among the companions of the Blaze."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclii{%
And they will admit their sin, so [it is] alienation for the companions of the Blaze.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccliii{%
Indeed, those who fear their Lord unseen will have forgiveness and great reward.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccliv{%
And conceal your speech or publicize it; indeed, He is Knowing of that within the breasts.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclv{%
Does He who created not know, while He is the Subtle, the Acquainted?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclvi{%
It is He who made the earth tame for you - so walk among its slopes and eat of His provision - and to Him is the resurrection.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclvii{%
Do you feel secure that He who [holds authority] in the heaven would not cause the earth to swallow you and suddenly it would sway?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclviii{%
Or do you feel secure that He who [holds authority] in the heaven would not send against you a storm of stones? Then you would know how [severe] was My warning.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclix{%
And already had those before them denied, and how [terrible] was My reproach.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcclx{%
Do they not see the birds above them with wings outspread and [sometimes] folded in? None holds them [aloft] except the Most Merciful. Indeed He is, of all things, Seeing.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcclxi{%
Or who is it that could be an army for you to aid you other than the Most Merciful? The disbelievers are not but in delusion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcclxii{%
Or who is it that could provide for you if He withheld His provision? But they have persisted in insolence and aversion.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiii{%
Then is one who walks fallen on his face better guided or one who walks erect on a straight path?\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcclxiv{%
Say, ``It is He who has produced you and made for you hearing and vision and hearts; little are you grateful."\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcclxv{%
Say, ``It is He who has multiplied you throughout the earth, and to Him you will be gathered."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvi{%
And they say, ``When is this promise, if you should be truthful?"\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcclxvii{%
Say, ``The knowledge is only with Allah, and I am only a clear warner."\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcclxviii{%
But when they see it approaching, the faces of those who disbelieve will be distressed, and it will be said, ``This is that for which you used to call."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcclxix{%
Say, [O Muhammad], ``Have you considered: whether Allah should cause my death and those with me or have mercy upon us, who can protect the disbelievers from a painful punishment?"\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcclxx{%
Say, ``He is the Most Merciful; we have believed in Him, and upon Him we have relied. And you will [come to] know who it is that is in clear error."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxi{%
Say, ``Have you considered: if your water was to become sunken [into the earth], then who could bring you flowing water?"\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxii{%
\basmalahen Nun. By the pen and what they inscribe,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiii{%
You are not, [O Muhammad], by the favor of your Lord, a madman.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxiv{%
And indeed, for you is a reward uninterrupted.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxv{%
And indeed, you are of a great moral character.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvi{%
So you will see and they will see\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxvii{%
Which of you is the afflicted [by a devil].\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxviii{%
Indeed, your Lord is most knowing of who has gone astray from His way, and He is most knowing of the [rightly] guided.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxix{%
Then do not obey the deniers.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxx{%
They wish that you would soften [in your position], so they would soften [toward you].\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxi{%
And do not obey every worthless habitual swearer\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxii{%
[And] scorner, going about with malicious gossip -\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiii{%
A preventer of good, transgressing and sinful,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxiv{%
Cruel, moreover, and an illegitimate pretender.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxv{%
Because he is a possessor of wealth and children,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvi{%
When Our verses are recited to him, he says, ``Legends of the former peoples."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxvii{%
We will brand him upon the snout.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxviii{%
Indeed, We have tried them as We tried the companions of the garden, when they swore to cut its fruit in the [early] morning\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcclxxxix{%
Without making exception.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmccxc{%
So there came upon the garden an affliction from your Lord while they were asleep.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmccxci{%
And it became as though reaped.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmccxcii{%
And they called one another at morning,\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmccxciii{%
[Saying], ``Go early to your crop if you would cut the fruit."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmccxciv{%
So they set out, while lowering their voices,\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmccxcv{%
[Saying], ``There will surely not enter it today upon you [any] poor person."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvi{%
And they went early in determination, [assuming themselves] able.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmccxcvii{%
But when they saw it, they said, ``Indeed, we are lost;\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmccxcviii{%
Rather, we have been deprived."\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmccxcix{%
The most moderate of them said, ``Did I not say to you, 'Why do you not exalt [Allah]?' ``\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccc{%
They said, ``Exalted is our Lord! Indeed, we were wrongdoers."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmccci{%
Then they approached one another, blaming each other.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccii{%
They said, ``O woe to us; indeed we were transgressors.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccciii{%
Perhaps our Lord will substitute for us [one] better than it. Indeed, we are toward our Lord desirous."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccciv{%
Such is the punishment [of this world]. And the punishment of the Hereafter is greater, if they only knew.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcccv{%
Indeed, for the righteous with their Lord are the Gardens of Pleasure.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcccvi{%
Then will We treat the Muslims like the criminals?\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcccvii{%
What is [the matter] with you? How do you judge?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcccviii{%
Or do you have a scripture in which you learn\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcccix{%
That indeed for you is whatever you choose?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcccx{%
Or do you have oaths [binding] upon Us, extending until the Day of Resurrection, that indeed for you is whatever you judge?\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcccxi{%
Ask them which of them, for that [claim], is responsible.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcccxii{%
Or do they have partners? Then let them bring their partners, if they should be truthful.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiii{%
The Day the shin will be uncovered and they are invited to prostration but the disbelievers will not be able,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcccxiv{%
Their eyes humbled, humiliation will cover them. And they used to be invited to prostration while they were sound.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcccxv{%
So leave Me, [O Muhammad], with [the matter of] whoever denies the Qur'an. We will progressively lead them [to punishment] from where they do not know.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvi{%
And I will give them time. Indeed, My plan is firm.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmcccxvii{%
Or do you ask of them a payment, so they are by debt burdened down?\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmcccxviii{%
Or have they [knowledge of] the unseen, so they write [it] down?\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmcccxix{%
Then be patient for the decision of your Lord, [O Muhammad], and be not like the companion of the fish when he called out while he was distressed.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmcccxx{%
If not that a favor from his Lord overtook him, he would have been thrown onto the naked shore while he was censured.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxi{%
And his Lord chose him and made him of the righteous.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxii{%
And indeed, those who disbelieve would almost make you slip with their eyes when they hear the message, and they say, ``Indeed, he is mad."\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiii{%
But it is not except a reminder to the worlds.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxiv{%
\basmalahen The Inevitable Reality -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxv{%
What is the Inevitable Reality?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvi{%
And what can make you know what is the Inevitable Reality?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxvii{%
Thamud and 'Aad denied the Striking Calamity.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxviii{%
So as for Thamud, they were destroyed by the overpowering [blast].\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxix{%
And as for 'Aad, they were destroyed by a screaming, violent wind\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxx{%
Which Allah imposed upon them for seven nights and eight days in succession, so you would see the people therein fallen as if they were hollow trunks of palm trees.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxi{%
Then do you see of them any remains?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxii{%
And there came Pharaoh and those before him and the overturned cities with sin.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiii{%
And they disobeyed the messenger of their Lord, so He seized them with a seizure exceeding [in severity].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxiv{%
Indeed, when the water overflowed, We carried your ancestors in the sailing ship\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxv{%
That We might make it for you a reminder and [that] a conscious ear would be conscious of it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvi{%
Then when the Horn is blown with one blast\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxvii{%
And the earth and the mountains are lifted and leveled with one blow -\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxviii{%
Then on that Day, the Resurrection will occur,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxxxix{%
And the heaven will split [open], for that Day it is infirm.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxl{%
And the angels are at its edges. And there will bear the Throne of your Lord above them, that Day, eight [of them].\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxli{%
That Day, you will be exhibited [for judgement]; not hidden among you is anything concealed.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlii{%
So as for he who is given his record in his right hand, he will say, ``Here, read my record!\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliii{%
Indeed, I was certain that I would be meeting my account."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxliv{%
So he will be in a pleasant life -\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlv{%
In an elevated garden,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvi{%
Its [fruit] to be picked hanging near.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlvii{%
[They will be told], ``Eat and drink in satisfaction for what you put forth in the days past."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlviii{%
But as for he who is given his record in his left hand, he will say, ``Oh, I wish I had not been given my record\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcccxlix{%
And had not known what is my account.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcccl{%
I wish my death had been the decisive one.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcccli{%
My wealth has not availed me.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmccclii{%
Gone from me is my authority."\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcccliii{%
[Allah will say], ``Seize him and shackle him.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcccliv{%
Then into Hellfire drive him.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmccclv{%
Then into a chain whose length is seventy cubits insert him."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmccclvi{%
Indeed, he did not used to believe in Allah, the Most Great,\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmccclvii{%
Nor did he encourage the feeding of the poor.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmccclviii{%
So there is not for him here this Day any devoted friend\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmccclix{%
Nor any food except from the discharge of wounds;\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmccclx{%
None will eat it except the sinners.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmccclxi{%
So I swear by what you see\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmccclxii{%
And what you do not see\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiii{%
[That] indeed, the Qur'an is the word of a noble Messenger.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmccclxiv{%
And it is not the word of a poet; little do you believe.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmccclxv{%
Nor the word of a soothsayer; little do you remember.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvi{%
[It is] a revelation from the Lord of the worlds.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmccclxvii{%
And if Muhammad had made up about Us some [false] sayings,\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmccclxviii{%
We would have seized him by the right hand;\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmccclxix{%
Then We would have cut from him the aorta.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmccclxx{%
And there is no one of you who could prevent [Us] from him.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxi{%
And indeed, the Qur'an is a reminder for the righteous.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxii{%
And indeed, We know that among you are deniers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiii{%
And indeed, it will be [a cause of] regret upon the disbelievers.\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxiv{%
And indeed, it is the truth of certainty.\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxv{%
So exalt the name of your Lord, the Most Great.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvi{%
\basmalahen A supplicant asked for a punishment bound to happen\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxvii{%
To the disbelievers; of it there is no preventer.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxviii{%
[It is] from Allah, owner of the ways of ascent.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxix{%
The angels and the Spirit will ascend to Him during a Day the extent of which is fifty thousand years.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxx{%
So be patient with gracious patience.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxi{%
Indeed, they see it [as] distant,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxii{%
But We see it [as] near.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiii{%
On the Day the sky will be like murky oil,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxiv{%
And the mountains will be like wool,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxv{%
And no friend will ask [anything of] a friend,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvi{%
They will be shown each other. The criminal will wish that he could be ransomed from the punishment of that Day by his children\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxvii{%
And his wife and his brother\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxviii{%
And his nearest kindred who shelter him\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmccclxxxix{%
And whoever is on earth entirely [so] then it could save him.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcccxc{%
No! Indeed, it is the Flame [of Hell],\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcccxci{%
A remover of exteriors.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcii{%
It invites he who turned his back [on truth] and went away [from obedience]\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciii{%
And collected [wealth] and hoarded.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcccxciv{%
Indeed, mankind was created anxious:\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcv{%
When evil touches him, impatient,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvi{%
And when good touches him, withholding [of it],\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcvii{%
Except the observers of prayer -\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcviii{%
Those who are constant in their prayer\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcccxcix{%
And those within whose wealth is a known right\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcd{%
For the petitioner and the deprived -\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdi{%
And those who believe in the Day of Recompense\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdii{%
And those who are fearful of the punishment of their Lord -\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdiii{%
Indeed, the punishment of their Lord is not that from which one is safe -\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdiv{%
And those who guard their private parts\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmcdv{%
Except from their wives or those their right hands possess, for indeed, they are not to be blamed -\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmcdvi{%
But whoever seeks beyond that, then they are the transgressors -\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmcdvii{%
And those who are to their trusts and promises attentive\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmcdviii{%
And those who are in their testimonies upright\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmcdix{%
And those who [carefully] maintain their prayer:\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmcdx{%
They will be in gardens, honored.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmcdxi{%
So what is [the matter] with those who disbelieve, hastening [from] before you, [O Muhammad],\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmcdxii{%
[To sit] on [your] right and [your] left in separate groups?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiii{%
Does every person among them aspire to enter a garden of pleasure?\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmcdxiv{%
No! Indeed, We have created them from that which they know.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmcdxv{%
So I swear by the Lord of [all] risings and settings that indeed We are able\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvi{%
To replace them with better than them; and We are not to be outdone.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmcdxvii{%
So leave them to converse vainly and amuse themselves until they meet their Day which they are promised -\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmcdxviii{%
The Day they will emerge from the graves rapidly as if they were, toward an erected idol, hastening.\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmcdxix{%
Their eyes humbled, humiliation will cover them. That is the Day which they had been promised.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmcdxx{%
\basmalahen Indeed, We sent Noah to his people, [saying], ``Warn your people before there comes to them a painful punishment."\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxi{%
He said, ``O my people, indeed I am to you a clear warner,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxii{%
[Saying], 'Worship Allah, fear Him and obey me.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiii{%
Allah will forgive you of your sins and delay you for a specified term. Indeed, the time [set by] Allah, when it comes, will not be delayed, if you only knew.' ``\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxiv{%
He said, ``My Lord, indeed I invited my people [to truth] night and day.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxv{%
But my invitation increased them not except in flight.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvi{%
And indeed, every time I invited them that You may forgive them, they put their fingers in their ears, covered themselves with their garments, persisted, and were arrogant with [great] arrogance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxvii{%
Then I invited them publicly.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxviii{%
Then I announced to them and [also] confided to them secretly\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxix{%
And said, 'Ask forgiveness of your Lord. Indeed, He is ever a Perpetual Forgiver.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxx{%
He will send [rain from] the sky upon you in [continuing] showers\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxi{%
And give you increase in wealth and children and provide for you gardens and provide for you rivers.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxii{%
What is [the matter] with you that you do not attribute to Allah [due] grandeur\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiii{%
While He has created you in stages?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxiv{%
Do you not consider how Allah has created seven heavens in layers\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxv{%
And made the moon therein a [reflected] light and made the sun a burning lamp?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvi{%
And Allah has caused you to grow from the earth a [progressive] growth.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxvii{%
Then He will return you into it and extract you [another] extraction.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxviii{%
And Allah has made for you the earth an expanse\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxxxix{%
That you may follow therein roads of passage.' ``\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxl{%
Noah said, ``My Lord, indeed they have disobeyed me and followed him whose wealth and children will not increase him except in loss.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdxli{%
And they conspired an immense conspiracy.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlii{%
And said, 'Never leave your gods and never leave Wadd or Suwa' or Yaghuth and Ya'uq and Nasr.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliii{%
And already they have misled many. And, [my Lord], do not increase the wrongdoers except in error."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdxliv{%
Because of their sins they were drowned and put into the Fire, and they found not for themselves besides Allah [any] helpers.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlv{%
And Noah said, ``My Lord, do not leave upon the earth from among the disbelievers an inhabitant.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvi{%
Indeed, if You leave them, they will mislead Your servants and not beget except [every] wicked one and [confirmed] disbeliever.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlvii{%
My Lord, forgive me and my parents and whoever enters my house a believer and the believing men and believing women. And do not increase the wrongdoers except in destruction."\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlviii{%
\basmalahen Say, [O Muhammad], ``It has been revealed to me that a group of the jinn listened and said, 'Indeed, we have heard an amazing Qur'an.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxlix{%
It guides to the right course, and we have believed in it. And we will never associate with our Lord anyone.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdl{%
And [it teaches] that exalted is the nobleness of our Lord; He has not taken a wife or a son\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdli{%
And that our foolish one has been saying about Allah an excessive transgression.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlii{%
And we had thought that mankind and the jinn would never speak about Allah a lie.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdliii{%
And there were men from mankind who sought refuge in men from the jinn, so they [only] increased them in burden.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdliv{%
And they had thought, as you thought, that Allah would never send anyone [as a messenger].\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlv{%
And we have sought [to reach] the heaven but found it filled with powerful guards and burning flames.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvi{%
And we used to sit therein in positions for hearing, but whoever listens now will find a burning flame lying in wait for him.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlvii{%
And we do not know [therefore] whether evil is intended for those on earth or whether their Lord intends for them a right course.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlviii{%
And among us are the righteous, and among us are [others] not so; we were [of] divided ways.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlix{%
And we have become certain that we will never cause failure to Allah upon earth, nor can we escape Him by flight.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlx{%
And when we heard the guidance, we believed in it. And whoever believes in his Lord will not fear deprivation or burden.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxi{%
And among us are Muslims [in submission to Allah], and among us are the unjust. And whoever has become Muslim - those have sought out the right course.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxii{%
But as for the unjust, they will be, for Hell, firewood.'\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiii{%
And [Allah revealed] that if they had remained straight on the way, We would have given them abundant provision\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxiv{%
So We might test them therein. And whoever turns away from the remembrance of his Lord He will put into arduous punishment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxv{%
And [He revealed] that the masjids are for Allah, so do not invoke with Allah anyone.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvi{%
And that when the Servant of Allah stood up supplicating Him, they almost became about him a compacted mass."\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxvii{%
Say, [O Muhammad], ``I only invoke my Lord and do not associate with Him anyone."\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxviii{%
Say, ``Indeed, I do not possess for you [the power of] harm or right direction."\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxix{%
Say, ``Indeed, there will never protect me from Allah anyone [if I should disobey], nor will I find in other than Him a refuge.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxx{%
But [I have for you] only notification from Allah, and His messages." And whoever disobeys Allah and His Messenger - then indeed, for him is the fire of Hell; they will abide therein forever.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxi{%
[The disbelievers continue] until, when they see that which they are promised, then they will know who is weaker in helpers and less in number.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxii{%
Say, ``I do not know if what you are promised is near or if my Lord will grant for it a [long] period."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiii{%
[He is] Knower of the unseen, and He does not disclose His [knowledge of the] unseen to anyone\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxiv{%
Except whom He has approved of messengers, and indeed, He sends before each messenger and behind him observers\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxv{%
That he may know that they have conveyed the messages of their Lord; and He has encompassed whatever is with them and has enumerated all things in number.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvi{%
\basmalahen O you who wraps himself [in clothing],\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxvii{%
Arise [to pray] the night, except for a little -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxviii{%
Half of it - or subtract from it a little\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxix{%
Or add to it, and recite the Qur'an with measured recitation.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxx{%
Indeed, We will cast upon you a heavy word.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxi{%
Indeed, the hours of the night are more effective for concurrence [of heart and tongue] and more suitable for words.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxii{%
Indeed, for you by day is prolonged occupation.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiii{%
And remember the name of your Lord and devote yourself to Him with [complete] devotion.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxiv{%
[He is] the Lord of the East and the West; there is no deity except Him, so take Him as Disposer of [your] affairs.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxv{%
And be patient over what they say and avoid them with gracious avoidance.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvi{%
And leave Me with [the matter of] the deniers, those of ease [in life], and allow them respite a little.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxvii{%
Indeed, with Us [for them] are shackles and burning fire\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxviii{%
And food that chokes and a painful punishment -\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcdlxxxix{%
On the Day the earth and the mountains will convulse and the mountains will become a heap of sand pouring down.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcdxc{%
Indeed, We have sent to you a Messenger as a witness upon you just as We sent to Pharaoh a messenger.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcdxci{%
But Pharaoh disobeyed the messenger, so We seized him with a ruinous seizure.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcii{%
Then how can you fear, if you disbelieve, a Day that will make the children white- haired?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciii{%
The heaven will break apart therefrom; ever is His promise fulfilled.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcdxciv{%
Indeed, this is a reminder, so whoever wills may take to his Lord a way.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcv{%
Indeed, your Lord knows, [O Muhammad], that you stand [in prayer] almost two thirds of the night or half of it or a third of it, and [so do] a group of those with you. And Allah determines [the extent of] the night and the day. He has known that you [Muslims] will not be able to do it and has turned to you in forgiveness, so recite what is easy [for you] of the Qur'an. He has known that there will be among you those who are ill and others traveling throughout the land seeking [something] of the bounty of Allah and others fighting for the cause of Allah. So recite what is easy from it and establish prayer and give zakah and loan Allah a goodly loan. And whatever good you put forward for yourselves - you will find it with Allah. It is better and greater in reward. And seek forgiveness of Allah. Indeed, Allah is Forgiving and Merciful.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvi{%
\basmalahen O you who covers himself [with a garment],\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcvii{%
Arise and warn\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcviii{%
And your Lord glorify\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcdxcix{%
And your clothing purify\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmd{%
And uncleanliness avoid\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdi{%
And do not confer favor to acquire more\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdii{%
But for your Lord be patient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdiii{%
And when the trumpet is blown,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdiv{%
That Day will be a difficult day\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdv{%
For the disbelievers - not easy.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdvi{%
Leave Me with the one I created alone\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdvii{%
And to whom I granted extensive wealth\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdviii{%
And children present [with him]\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdix{%
And spread [everything] before him, easing [his life].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdx{%
Then he desires that I should add more.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdxi{%
No! Indeed, he has been toward Our verses obstinate.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdxii{%
I will cover him with arduous torment.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdxiii{%
Indeed, he thought and deliberated.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdxiv{%
So may he be destroyed [for] how he deliberated.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdxv{%
Then may he be destroyed [for] how he deliberated.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdxvi{%
Then he considered [again];\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdxvii{%
Then he frowned and scowled;\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdxviii{%
Then he turned back and was arrogant\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdxix{%
And said, ``This is not but magic imitated [from others].\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdxx{%
This is not but the word of a human being."\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdxxi{%
I will drive him into Saqar.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdxxii{%
And what can make you know what is Saqar?\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiii{%
It lets nothing remain and leaves nothing [unburned],\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdxxiv{%
Blackening the skins.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdxxv{%
Over it are nineteen [angels].\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvi{%
And We have not made the keepers of the Fire except angels. And We have not made their number except as a trial for those who disbelieve - that those who were given the Scripture will be convinced and those who have believed will increase in faith and those who were given the Scripture and the believers will not doubt and that those in whose hearts is hypocrisy and the disbelievers will say, ``What does Allah intend by this as an example?" Thus does Allah leave astray whom He wills and guides whom He wills. And none knows the soldiers of your Lord except Him. And mention of the Fire is not but a reminder to humanity.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdxxvii{%
No! By the moon\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdxxviii{%
And [by] the night when it departs\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdxxix{%
And [by] the morning when it brightens,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdxxx{%
Indeed, the Fire is of the greatest [afflictions]\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxi{%
As a warning to humanity -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxii{%
To whoever wills among you to proceed or stay behind.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiii{%
Every soul, for what it has earned, will be retained\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxiv{%
Except the companions of the right,\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxv{%
[Who will be] in gardens, questioning each other\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvi{%
About the criminals,\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxvii{%
[And asking them], ``What put you into Saqar?"\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxviii{%
They will say, ``We were not of those who prayed,\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdxxxix{%
Nor did we used to feed the poor.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdxl{%
And we used to enter into vain discourse with those who engaged [in it],\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdxli{%
And we used to deny the Day of Recompense\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdxlii{%
Until there came to us the certainty."\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdxliii{%
So there will not benefit them the intercession of [any] intercessors.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdxliv{%
Then what is [the matter] with them that they are, from the reminder, turning away\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdxlv{%
As if they were alarmed donkeys\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvi{%
Fleeing from a lion?\qt@no{51}}%
\qt@newcmd\qurantrans@en@mmmmmdxlvii{%
Rather, every person among them desires that he would be given scriptures spread about.\qt@no{52}}%
\qt@newcmd\qurantrans@en@mmmmmdxlviii{%
No! But they do not fear the Hereafter.\qt@no{53}}%
\qt@newcmd\qurantrans@en@mmmmmdxlix{%
No! Indeed, the Qur'an is a reminder\qt@no{54}}%
\qt@newcmd\qurantrans@en@mmmmmdl{%
Then whoever wills will remember it.\qt@no{55}}%
\qt@newcmd\qurantrans@en@mmmmmdli{%
And they will not remember except that Allah wills. He is worthy of fear and adequate for [granting] forgiveness.\qt@no{56}}%
\qt@newcmd\qurantrans@en@mmmmmdlii{%
\basmalahen I swear by the Day of Resurrection\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdliii{%
And I swear by the reproaching soul [to the certainty of resurrection].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdliv{%
Does man think that We will not assemble his bones?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdlv{%
Yes. [We are] Able [even] to proportion his fingertips.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdlvi{%
But man desires to continue in sin.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdlvii{%
He asks, ``When is the Day of Resurrection?"\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdlviii{%
So when vision is dazzled\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdlix{%
And the moon darkens\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdlx{%
And the sun and the moon are joined,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdlxi{%
Man will say on that Day, ``Where is the [place of] escape?"\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdlxii{%
No! There is no refuge.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiii{%
To your Lord, that Day, is the [place of] permanence.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdlxiv{%
Man will be informed that Day of what he sent ahead and kept back.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdlxv{%
Rather, man, against himself, will be a witness,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvi{%
Even if he presents his excuses.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdlxvii{%
Move not your tongue with it, [O Muhammad], to hasten with recitation of the Qur'an.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdlxviii{%
Indeed, upon Us is its collection [in your heart] and [to make possible] its recitation.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdlxix{%
So when We have recited it [through Gabriel], then follow its recitation.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdlxx{%
Then upon Us is its clarification [to you].\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxi{%
No! But you love the immediate\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxii{%
And leave the Hereafter.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiii{%
[Some] faces, that Day, will be radiant,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxiv{%
Looking at their Lord.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxv{%
And [some] faces, that Day, will be contorted,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvi{%
Expecting that there will be done to them [something] backbreaking.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxvii{%
No! When the soul has reached the collar bones\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxviii{%
And it is said, ``Who will cure [him]?"\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxix{%
And the dying one is certain that it is the [time of] separation\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxx{%
And the leg is wound about the leg,\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxi{%
To your Lord, that Day, will be the procession.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxii{%
And the disbeliever had not believed, nor had he prayed.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiii{%
But [instead], he denied and turned away.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxiv{%
And then he went to his people, swaggering [in pride].\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxv{%
Woe to you, and woe!\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvi{%
Then woe to you, and woe!\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxvii{%
Does man think that he will be left neglected?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxviii{%
Had he not been a sperm from semen emitted?\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdlxxxix{%
Then he was a clinging clot, and [Allah] created [his form] and proportioned [him]\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdxc{%
And made of him two mates, the male and the female.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdxci{%
Is not that [Creator] Able to give life to the dead?\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdxcii{%
\basmalahen Has there [not] come upon man a period of time when he was not a thing [even] mentioned?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdxciii{%
Indeed, We created man from a sperm-drop mixture that We may try him; and We made him hearing and seeing.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdxciv{%
Indeed, We guided him to the way, be he grateful or be he ungrateful.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdxcv{%
Indeed, We have prepared for the disbelievers chains and shackles and a blaze.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvi{%
Indeed, the righteous will drink from a cup [of wine] whose mixture is of Kafur,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdxcvii{%
A spring of which the [righteous] servants of Allah will drink; they will make it gush forth in force [and abundance].\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdxcviii{%
They [are those who] fulfill [their] vows and fear a Day whose evil will be widespread.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdxcix{%
And they give food in spite of love for it to the needy, the orphan, and the captive,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdc{%
[Saying], ``We feed you only for the countenance of Allah. We wish not from you reward or gratitude.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdci{%
Indeed, We fear from our Lord a Day austere and distressful."\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcii{%
So Allah will protect them from the evil of that Day and give them radiance and happiness\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdciii{%
And will reward them for what they patiently endured [with] a garden [in Paradise] and silk [garments].\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdciv{%
[They will be] reclining therein on adorned couches. They will not see therein any [burning] sun or [freezing] cold.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcv{%
And near above them are its shades, and its [fruit] to be picked will be lowered in compliance.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcvi{%
And there will be circulated among them vessels of silver and cups having been [created] clear [as glass],\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcvii{%
Clear glasses [made] from silver of which they have determined the measure.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcviii{%
And they will be given to drink a cup [of wine] whose mixture is of ginger\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcix{%
[From] a fountain within Paradise named Salsabeel.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcx{%
There will circulate among them young boys made eternal. When you see them, you would think them [as beautiful as] scattered pearls.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxi{%
And when you look there [in Paradise], you will see pleasure and great dominion.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxii{%
Upon the inhabitants will be green garments of fine silk and brocade. And they will be adorned with bracelets of silver, and their Lord will give them a purifying drink.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiii{%
[And it will be said], ``Indeed, this is for you a reward, and your effort has been appreciated."\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxiv{%
Indeed, it is We who have sent down to you, [O Muhammad], the Qur'an progressively.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxv{%
So be patient for the decision of your Lord and do not obey from among them a sinner or ungrateful [disbeliever].\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvi{%
And mention the name of your Lord [in prayer] morning and evening\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxvii{%
And during the night prostrate to Him and exalt Him a long [part of the] night.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxviii{%
Indeed, these [disbelievers] love the immediate and leave behind them a grave Day.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcxix{%
We have created them and strengthened their forms, and when We will, We can change their likenesses with [complete] alteration.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcxx{%
Indeed, this is a reminder, so he who wills may take to his Lord a way.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxi{%
And you do not will except that Allah wills. Indeed, Allah is ever Knowing and Wise.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxii{%
He admits whom He wills into His mercy; but the wrongdoers - He has prepared for them a painful punishment.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiii{%
\basmalahen By those [winds] sent forth in gusts\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxiv{%
And the winds that blow violently\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxv{%
And [by] the winds that spread [clouds]\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvi{%
And those [angels] who bring criterion\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxvii{%
And those [angels] who deliver a message\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxviii{%
As justification or warning,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxix{%
Indeed, what you are promised is to occur.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxx{%
So when the stars are obliterated\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxi{%
And when the heaven is opened\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxii{%
And when the mountains are blown away\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiii{%
And when the messengers' time has come...\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxiv{%
For what Day was it postponed?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxv{%
For the Day of Judgement.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvi{%
And what can make you know what is the Day of Judgement?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxvii{%
Woe, that Day, to the deniers.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxviii{%
Did We not destroy the former peoples?\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcxxxix{%
Then We will follow them with the later ones.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxl{%
Thus do We deal with the criminals.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxli{%
Woe, that Day, to the deniers.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlii{%
Did We not create you from a liquid disdained?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliii{%
And We placed it in a firm lodging\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxliv{%
For a known extent.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlv{%
And We determined [it], and excellent [are We] to determine.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvi{%
Woe, that Day, to the deniers.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlvii{%
Have We not made the earth a container\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlviii{%
Of the living and the dead?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxlix{%
And We placed therein lofty, firmly set mountains and have given you to drink sweet water.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcl{%
Woe, that Day, to the deniers.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcli{%
[They will be told], ``Proceed to that which you used to deny.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdclii{%
Proceed to a shadow [of smoke] having three columns\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcliii{%
[But having] no cool shade and availing not against the flame."\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcliv{%
Indeed, it throws sparks [as huge] as a fortress,\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdclv{%
As if they were yellowish [black] camels.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdclvi{%
Woe, that Day, to the deniers.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdclvii{%
This is a Day they will not speak,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdclviii{%
Nor will it be permitted for them to make an excuse.\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdclix{%
Woe, that Day, to the deniers.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdclx{%
This is the Day of Judgement; We will have assembled you and the former peoples.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdclxi{%
So if you have a plan, then plan against Me.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdclxii{%
Woe, that Day, to the deniers.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiii{%
Indeed, the righteous will be among shades and springs\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdclxiv{%
And fruits from whatever they desire,\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdclxv{%
[Being told], ``Eat and drink in satisfaction for what you used to do."\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvi{%
Indeed, We thus reward the doers of good.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdclxvii{%
Woe, that Day, to the deniers.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdclxviii{%
[O disbelievers], eat and enjoy yourselves a little; indeed, you are criminals.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdclxix{%
Woe, that Day, to the deniers.\qt@no{47}}%
\qt@newcmd\qurantrans@en@mmmmmdclxx{%
And when it is said to them, ``Bow [in prayer]," they do not bow.\qt@no{48}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxi{%
Woe, that Day, to the deniers.\qt@no{49}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxii{%
Then in what statement after the Qur'an will they believe?\qt@no{50}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiii{%
\basmalahen About what are they asking one another?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxiv{%
About the great news -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxv{%
That over which they are in disagreement.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvi{%
No! They are going to know.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxvii{%
Then, no! They are going to know.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxviii{%
Have We not made the earth a resting place?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxix{%
And the mountains as stakes?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxx{%
And We created you in pairs\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxi{%
And made your sleep [a means for] rest\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxii{%
And made the night as clothing\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiii{%
And made the day for livelihood\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxiv{%
And constructed above you seven strong [heavens]\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxv{%
And made [therein] a burning lamp\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvi{%
And sent down, from the rain clouds, pouring water\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxvii{%
That We may bring forth thereby grain and vegetation\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxviii{%
And gardens of entwined growth.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdclxxxix{%
Indeed, the Day of Judgement is an appointed time -\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcxc{%
The Day the Horn is blown and you will come forth in multitudes\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcxci{%
And the heaven is opened and will become gateways\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcii{%
And the mountains are removed and will be [but] a mirage.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciii{%
Indeed, Hell has been lying in wait\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcxciv{%
For the transgressors, a place of return,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcv{%
In which they will remain for ages [unending].\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvi{%
They will not taste therein [any] coolness or drink\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcvii{%
Except scalding water and [foul] purulence -\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcviii{%
An appropriate recompense.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcxcix{%
Indeed, they were not expecting an account\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcc{%
And denied Our verses with [emphatic] denial.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcci{%
But all things We have enumerated in writing.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccii{%
``So taste [the penalty], and never will We increase you except in torment."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcciii{%
Indeed, for the righteous is attainment -\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdcciv{%
Gardens and grapevines\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccv{%
And full-breasted [companions] of equal age\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccvi{%
And a full cup.\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccvii{%
No ill speech will they hear therein or any falsehood -\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccviii{%
[As] reward from your Lord, [a generous] gift [made due by] account,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccix{%
[From] the Lord of the heavens and the earth and whatever is between them, the Most Merciful. They possess not from Him [authority for] speech.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccx{%
The Day that the Spirit and the angels will stand in rows, they will not speak except for one whom the Most Merciful permits, and he will say what is correct.\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxi{%
That is the True Day; so he who wills may take to his Lord a [way of] return.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxii{%
Indeed, We have warned you of a near punishment on the Day when a man will observe what his hands have put forth and the disbeliever will say, ``Oh, I wish that I were dust!"\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiii{%
\basmalahen By those [angels] who extract with violence\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccxiv{%
And [by] those who remove with ease\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccxv{%
And [by] those who glide [as if] swimming\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvi{%
And those who race each other in a race\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccxvii{%
And those who arrange [each] matter,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdccxviii{%
On the Day the blast [of the Horn] will convulse [creation],\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccxix{%
There will follow it the subsequent [one].\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccxx{%
Hearts, that Day, will tremble,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxi{%
Their eyes humbled.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxii{%
They are [presently] saying, ``Will we indeed be returned to [our] former state [of life]?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiii{%
Even if we should be decayed bones?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxiv{%
They say, ``That, then, would be a losing return."\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxv{%
Indeed, it will be but one shout,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvi{%
And suddenly they will be [alert] upon the earth's surface.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxvii{%
Has there reached you the story of Moses? -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxviii{%
When his Lord called to him in the sacred valley of Tuwa,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxix{%
``Go to Pharaoh. Indeed, he has transgressed.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxx{%
And say to him, 'Would you [be willing to] purify yourself\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxi{%
And let me guide you to your Lord so you would fear [Him]?'"\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxii{%
And he showed him the greatest sign,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiii{%
But Pharaoh denied and disobeyed.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxiv{%
Then he turned his back, striving.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxv{%
And he gathered [his people] and called out\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvi{%
And said, ``I am your most exalted lord."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxvii{%
So Allah seized him in exemplary punishment for the last and the first [transgression].\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxviii{%
Indeed in that is a warning for whoever would fear [Allah].\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccxxxix{%
Are you a more difficult creation or is the heaven? Allah constructed it.\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccxl{%
He raised its ceiling and proportioned it.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccxli{%
And He darkened its night and extracted its brightness.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlii{%
And after that He spread the earth.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliii{%
He extracted from it its water and its pasture,\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxliv{%
And the mountains He set firmly\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlv{%
As provision for you and your grazing livestock.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvi{%
But when there comes the greatest Overwhelming Calamity -\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlvii{%
The Day when man will remember that for which he strove,\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlviii{%
And Hellfire will be exposed for [all] those who see -\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxlix{%
So as for he who transgressed\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccl{%
And preferred the life of the world,\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccli{%
Then indeed, Hellfire will be [his] refuge.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdcclii{%
But as for he who feared the position of his Lord and prevented the soul from [unlawful] inclination,\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccliii{%
Then indeed, Paradise will be [his] refuge.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccliv{%
They ask you, [O Muhammad], about the Hour: when is its arrival?\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdcclv{%
In what [position] are you that you should mention it?\qt@no{43}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvi{%
To your Lord is its finality.\qt@no{44}}%
\qt@newcmd\qurantrans@en@mmmmmdcclvii{%
You are only a warner for those who fear it.\qt@no{45}}%
\qt@newcmd\qurantrans@en@mmmmmdcclviii{%
It will be, on the Day they see it, as though they had not remained [in the world] except for an afternoon or a morning thereof.\qt@no{46}}%
\qt@newcmd\qurantrans@en@mmmmmdcclix{%
\basmalahen The Prophet frowned and turned away\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcclx{%
Because there came to him the blind man, [interrupting].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxi{%
But what would make you perceive, [O Muhammad], that perhaps he might be purified\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxii{%
Or be reminded and the remembrance would benefit him?\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiii{%
As for he who thinks himself without need,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxiv{%
To him you give attention.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxv{%
And not upon you [is any blame] if he will not be purified.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvi{%
But as for he who came to you striving [for knowledge]\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxvii{%
While he fears [Allah],\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxviii{%
From him you are distracted.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxix{%
No! Indeed, these verses are a reminder;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxx{%
So whoever wills may remember it.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxi{%
[It is recorded] in honored sheets,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxii{%
Exalted and purified,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiii{%
[Carried] by the hands of messenger-angels,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxiv{%
Noble and dutiful.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxv{%
Cursed is man; how disbelieving is he.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvi{%
From what substance did He create him?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxvii{%
From a sperm-drop He created him and destined for him;\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxviii{%
Then He eased the way for him;\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxix{%
Then He causes his death and provides a grave for him.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxx{%
Then when He wills, He will resurrect him.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxi{%
No! Man has not yet accomplished what He commanded him.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxii{%
Then let mankind look at his food -\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiii{%
How We poured down water in torrents,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxiv{%
Then We broke open the earth, splitting [it with sprouts],\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxv{%
And caused to grow within it grain\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvi{%
And grapes and herbage\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxvii{%
And olive and palm trees\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxviii{%
And gardens of dense shrubbery\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdcclxxxix{%
And fruit and grass -\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccxc{%
[As] enjoyment for you and your grazing livestock.\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccxci{%
But when there comes the Deafening Blast\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcii{%
On the Day a man will flee from his brother\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciii{%
And his mother and his father\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccxciv{%
And his wife and his children,\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcv{%
For every man, that Day, will be a matter adequate for him.\qt@no{37}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvi{%
[Some] faces, that Day, will be bright -\qt@no{38}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcvii{%
Laughing, rejoicing at good news.\qt@no{39}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcviii{%
And [other] faces, that Day, will have upon them dust.\qt@no{40}}%
\qt@newcmd\qurantrans@en@mmmmmdccxcix{%
Blackness will cover them.\qt@no{41}}%
\qt@newcmd\qurantrans@en@mmmmmdccc{%
Those are the disbelievers, the wicked ones.\qt@no{42}}%
\qt@newcmd\qurantrans@en@mmmmmdccci{%
\basmalahen When the sun is wrapped up [in darkness]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccii{%
And when the stars fall, dispersing,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccciii{%
And when the mountains are removed\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccciv{%
And when full-term she-camels are neglected\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccv{%
And when the wild beasts are gathered\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvi{%
And when the seas are filled with flame\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccvii{%
And when the souls are paired\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccviii{%
And when the girl [who was] buried alive is asked\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccix{%
For what sin she was killed\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccx{%
And when the pages are made public\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxi{%
And when the sky is stripped away\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxii{%
And when Hellfire is set ablaze\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiii{%
And when Paradise is brought near,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxiv{%
A soul will [then] know what it has brought [with it].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxv{%
So I swear by the retreating stars -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvi{%
Those that run [their courses] and disappear -\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxvii{%
And by the night as it closes in\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxviii{%
And by the dawn when it breathes\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxix{%
[That] indeed, the Qur'an is a word [conveyed by] a noble messenger\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxx{%
[Who is] possessed of power and with the Owner of the Throne, secure [in position],\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxi{%
Obeyed there [in the heavens] and trustworthy.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxii{%
And your companion is not [at all] mad.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiii{%
And he has already seen Gabriel in the clear horizon.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxiv{%
And Muhammad is not a withholder of [knowledge of] the unseen.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxv{%
And the Qur'an is not the word of a devil, expelled [from the heavens].\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvi{%
So where are you going?\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxvii{%
It is not except a reminder to the worlds\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxviii{%
For whoever wills among you to take a right course.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxix{%
And you do not will except that Allah wills - Lord of the worlds.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxx{%
\basmalahen When the sky breaks apart\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxi{%
And when the stars fall, scattering,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxii{%
And when the seas are erupted\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiii{%
And when the [contents of] graves are scattered,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxiv{%
A soul will [then] know what it has put forth and kept back.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxv{%
O mankind, what has deceived you concerning your Lord, the Generous,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvi{%
Who created you, proportioned you, and balanced you?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxvii{%
In whatever form He willed has He assembled you.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxviii{%
No! But you deny the Recompense.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxxxix{%
And indeed, [appointed] over you are keepers,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxl{%
Noble and recording;\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxli{%
They know whatever you do.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlii{%
Indeed, the righteous will be in pleasure,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliii{%
And indeed, the wicked will be in Hellfire.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxliv{%
They will [enter to] burn therein on the Day of Recompense,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlv{%
And never therefrom will they be absent.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvi{%
And what can make you know what is the Day of Recompense?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlvii{%
Then, what can make you know what is the Day of Recompense?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlviii{%
It is the Day when a soul will not possess for another soul [power to do] a thing; and the command, that Day, is [entirely] with Allah.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxlix{%
\basmalahen Woe to those who give less [than due],\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdcccl{%
Who, when they take a measure from people, take in full.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdcccli{%
But if they give by measure or by weight to them, they cause loss.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclii{%
Do they not think that they will be resurrected\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliii{%
For a tremendous Day -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccliv{%
The Day when mankind will stand before the Lord of the worlds?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdccclv{%
No! Indeed, the record of the wicked is in sijjeen.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvi{%
And what can make you know what is sijjeen?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdccclvii{%
It is [their destination recorded in] a register inscribed.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdccclviii{%
Woe, that Day, to the deniers,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdccclix{%
Who deny the Day of Recompense.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdccclx{%
And none deny it except every sinful transgressor.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxi{%
When Our verses are recited to him, he says, ``Legends of the former peoples."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxii{%
No! Rather, the stain has covered their hearts of that which they were earning.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiii{%
No! Indeed, from their Lord, that Day, they will be partitioned.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxiv{%
Then indeed, they will [enter and] burn in Hellfire.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxv{%
Then it will be said [to them], ``This is what you used to deny."\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvi{%
No! Indeed, the record of the righteous is in 'illiyyun.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxvii{%
And what can make you know what is 'illiyyun?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxviii{%
It is [their destination recorded in] a register inscribed\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxix{%
Which is witnessed by those brought near [to Allah].\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxx{%
Indeed, the righteous will be in pleasure\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxi{%
On adorned couches, observing.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxii{%
You will recognize in their faces the radiance of pleasure.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiii{%
They will be given to drink [pure] wine [which was] sealed.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxiv{%
The last of it is musk. So for this let the competitors compete.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxv{%
And its mixture is of Tasneem,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvi{%
A spring from which those near [to Allah] drink.\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxvii{%
Indeed, those who committed crimes used to laugh at those who believed.\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxviii{%
And when they passed by them, they would exchange derisive glances.\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxix{%
And when they returned to their people, they would return jesting.\qt@no{31}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxx{%
And when they saw them, they would say, ``Indeed, those are truly lost."\qt@no{32}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxi{%
But they had not been sent as guardians over them.\qt@no{33}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxii{%
So Today those who believed are laughing at the disbelievers,\qt@no{34}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiii{%
On adorned couches, observing.\qt@no{35}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxiv{%
Have the disbelievers [not] been rewarded [this Day] for what they used to do?\qt@no{36}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxv{%
\basmalahen When the sky has split [open]\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvi{%
And has responded to its Lord and was obligated [to do so]\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxvii{%
And when the earth has been extended\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxviii{%
And has cast out that within it and relinquished [it]\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmdccclxxxix{%
And has responded to its Lord and was obligated [to do so] -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxc{%
O mankind, indeed you are laboring toward your Lord with [great] exertion and will meet it.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxci{%
Then as for he who is given his record in his right hand,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcii{%
He will be judged with an easy account\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciii{%
And return to his people in happiness.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxciv{%
But as for he who is given his record behind his back,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcv{%
He will cry out for destruction\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvi{%
And [enter to] burn in a Blaze.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcvii{%
Indeed, he had [once] been among his people in happiness;\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcviii{%
Indeed, he had thought he would never return [to Allah].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmdcccxcix{%
But yes! Indeed, his Lord was ever of him, Seeing.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcm{%
So I swear by the twilight glow\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmi{%
And [by] the night and what it envelops\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmii{%
And [by] the moon when it becomes full\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmiii{%
[That] you will surely experience state after state.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmiv{%
So what is [the matter] with them [that] they do not believe,\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmv{%
And when the Qur'an is recited to them, they do not prostrate [to Allah]?\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmvi{%
But those who have disbelieved deny,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmvii{%
And Allah is most knowing of what they keep within themselves.\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmviii{%
So give them tidings of a painful punishment,\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmix{%
Except for those who believe and do righteous deeds. For them is a reward uninterrupted.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmx{%
\basmalahen By the sky containing great stars\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxi{%
And [by] the promised Day\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxii{%
And [by] the witness and what is witnessed,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiii{%
Cursed were the companions of the trench\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxiv{%
[Containing] the fire full of fuel,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxv{%
When they were sitting near it\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvi{%
And they, to what they were doing against the believers, were witnesses.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxvii{%
And they resented them not except because they believed in Allah, the Exalted in Might, the Praiseworthy,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxviii{%
To whom belongs the dominion of the heavens and the earth. And Allah, over all things, is Witness.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxix{%
Indeed, those who have tortured the believing men and believing women and then have not repented will have the punishment of Hell, and they will have the punishment of the Burning Fire.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxx{%
Indeed, those who have believed and done righteous deeds will have gardens beneath which rivers flow. That is the great attainment.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxi{%
Indeed, the vengeance of your Lord is severe.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxii{%
Indeed, it is He who originates [creation] and repeats.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiii{%
And He is the Forgiving, the Affectionate,\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxiv{%
Honorable Owner of the Throne,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxv{%
Effecter of what He intends.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvi{%
Has there reached you the story of the soldiers -\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxvii{%
[Those of] Pharaoh and Thamud?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxviii{%
But they who disbelieve are in [persistent] denial,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxix{%
While Allah encompasses them from behind.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxx{%
But this is an honored Qur'an\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxi{%
[Inscribed] in a Preserved Slate.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxii{%
\basmalahen By the sky and the night comer -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiii{%
And what can make you know what is the night comer?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxiv{%
It is the piercing star -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxv{%
There is no soul but that it has over it a protector.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvi{%
So let man observe from what he was created.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxvii{%
He was created from a fluid, ejected,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxviii{%
Emerging from between the backbone and the ribs.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmxxxix{%
Indeed, Allah, to return him [to life], is Able.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmxl{%
The Day when secrets will be put on trial,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmxli{%
Then man will have no power or any helper.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlii{%
By the sky which returns [rain]\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliii{%
And [by] the earth which cracks open,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmxliv{%
Indeed, the Qur'an is a decisive statement,\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlv{%
And it is not amusement.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvi{%
Indeed, they are planning a plan,\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlvii{%
But I am planning a plan.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlviii{%
So allow time for the disbelievers. Leave them awhile.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmxlix{%
\basmalahen Exalt the name of your Lord, the Most High,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcml{%
Who created and proportioned\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmli{%
And who destined and [then] guided\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlii{%
And who brings out the pasture\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmliii{%
And [then] makes it black stubble.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmliv{%
We will make you recite, [O Muhammad], and you will not forget,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlv{%
Except what Allah should will. Indeed, He knows what is declared and what is hidden.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvi{%
And We will ease you toward ease.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlvii{%
So remind, if the reminder should benefit;\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlviii{%
He who fears [Allah] will be reminded.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlix{%
But the wretched one will avoid it -\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlx{%
[He] who will [enter and] burn in the greatest Fire,\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxi{%
Neither dying therein nor living.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxii{%
He has certainly succeeded who purifies himself\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiii{%
And mentions the name of his Lord and prays.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxiv{%
But you prefer the worldly life,\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxv{%
While the Hereafter is better and more enduring.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvi{%
Indeed, this is in the former scriptures,\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxvii{%
The scriptures of Abraham and Moses.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxviii{%
\basmalahen Has there reached you the report of the Overwhelming [event]?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxix{%
[Some] faces, that Day, will be humbled,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxx{%
Working [hard] and exhausted.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxi{%
They will [enter to] burn in an intensely hot Fire.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxii{%
They will be given drink from a boiling spring.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiii{%
For them there will be no food except from a poisonous, thorny plant\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxiv{%
Which neither nourishes nor avails against hunger.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxv{%
[Other] faces, that Day, will show pleasure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvi{%
With their effort [they are] satisfied\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxvii{%
In an elevated garden,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxviii{%
Wherein they will hear no unsuitable speech.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxix{%
Within it is a flowing spring.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxx{%
Within it are couches raised high\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxi{%
And cups put in place\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxii{%
And cushions lined up\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiii{%
And carpets spread around.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxiv{%
Then do they not look at the camels - how they are created?\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxv{%
And at the sky - how it is raised?\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvi{%
And at the mountains - how they are erected?\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxvii{%
And at the earth - how it is spread out?\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxviii{%
So remind, [O Muhammad]; you are only a reminder.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmcmlxxxix{%
You are not over them a controller.\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmcmxc{%
However, he who turns away and disbelieves -\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmcmxci{%
Then Allah will punish him with the greatest punishment.\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcii{%
Indeed, to Us is their return.\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciii{%
Then indeed, upon Us is their account.\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmcmxciv{%
\basmalahen By the dawn\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcv{%
And [by] ten nights\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvi{%
And [by] the even [number] and the odd\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcvii{%
And [by] the night when it passes,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcviii{%
Is there [not] in [all] that an oath [sufficient] for one of perception?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmcmxcix{%
Have you not considered how your Lord dealt with 'Aad -\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmm{%
[With] Iram - who had lofty pillars,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmi{%
The likes of whom had never been created in the land?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmii{%
And [with] Thamud, who carved out the rocks in the valley?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmiii{%
And [with] Pharaoh, owner of the stakes? -\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmiv{%
[All of] whom oppressed within the lands\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmv{%
And increased therein the corruption.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmvi{%
So your Lord poured upon them a scourge of punishment.\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmvii{%
Indeed, your Lord is in observation.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmviii{%
And as for man, when his Lord tries him and [thus] is generous to him and favors him, he says, ``My Lord has honored me."\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmix{%
But when He tries him and restricts his provision, he says, ``My Lord has humiliated me."\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmx{%
No! But you do not honor the orphan\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxi{%
And you do not encourage one another to feed the poor.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxii{%
And you consume inheritance, devouring [it] altogether,\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxiii{%
And you love wealth with immense love.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxiv{%
No! When the earth has been leveled - pounded and crushed -\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmxv{%
And your Lord has come and the angels, rank upon rank,\qt@no{22}}%
\qt@newcmd\qurantrans@en@mmmmmmxvi{%
And brought [within view], that Day, is Hell - that Day, man will remember, but what good to him will be the remembrance?\qt@no{23}}%
\qt@newcmd\qurantrans@en@mmmmmmxvii{%
He will say, ``Oh, I wish I had sent ahead [some good] for my life."\qt@no{24}}%
\qt@newcmd\qurantrans@en@mmmmmmxviii{%
So on that Day, none will punish [as severely] as His punishment,\qt@no{25}}%
\qt@newcmd\qurantrans@en@mmmmmmxix{%
And none will bind [as severely] as His binding [of the evildoers].\qt@no{26}}%
\qt@newcmd\qurantrans@en@mmmmmmxx{%
[To the righteous it will be said], ``O reassured soul,\qt@no{27}}%
\qt@newcmd\qurantrans@en@mmmmmmxxi{%
Return to your Lord, well-pleased and pleasing [to Him],\qt@no{28}}%
\qt@newcmd\qurantrans@en@mmmmmmxxii{%
And enter among My [righteous] servants\qt@no{29}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiii{%
And enter My Paradise."\qt@no{30}}%
\qt@newcmd\qurantrans@en@mmmmmmxxiv{%
\basmalahen I swear by this city, Makkah -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxxv{%
And you, [O Muhammad], are free of restriction in this city -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvi{%
And [by] the father and that which was born [of him],\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxxvii{%
We have certainly created man into hardship.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxxviii{%
Does he think that never will anyone overcome him?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxxix{%
He says, ``I have spent wealth in abundance."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxxx{%
Does he think that no one has seen him?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxi{%
Have We not made for him two eyes?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxii{%
And a tongue and two lips?\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiii{%
And have shown him the two ways?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxiv{%
But he has not broken through the difficult pass.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxv{%
And what can make you know what is [breaking through] the difficult pass?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvi{%
It is the freeing of a slave\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxvii{%
Or feeding on a day of severe hunger\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxviii{%
An orphan of near relationship\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmxxxix{%
Or a needy person in misery\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmxl{%
And then being among those who believed and advised one another to patience and advised one another to compassion.\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmxli{%
Those are the companions of the right.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmxlii{%
But they who disbelieved in Our signs - those are the companions of the left.\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmxliii{%
Over them will be fire closed in.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmxliv{%
\basmalahen By the sun and its brightness\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxlv{%
And [by] the moon when it follows it\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvi{%
And [by] the day when it displays it\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxlvii{%
And [by] the night when it covers it\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxlviii{%
And [by] the sky and He who constructed it\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxlix{%
And [by] the earth and He who spread it\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmml{%
And [by] the soul and He who proportioned it\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmli{%
And inspired it [with discernment of] its wickedness and its righteousness,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlii{%
He has succeeded who purifies it,\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmliii{%
And he has failed who instills it [with corruption].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmliv{%
Thamud denied [their prophet] by reason of their transgression,\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlv{%
When the most wretched of them was sent forth.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlvi{%
And the messenger of Allah [Salih] said to them, ``[Do not harm] the she-camel of Allah or [prevent her from] her drink."\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlvii{%
But they denied him and hamstrung her. So their Lord brought down upon them destruction for their sin and made it equal [upon all of them].\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlviii{%
And He does not fear the consequence thereof.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlix{%
\basmalahen By the night when it covers\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlx{%
And [by] the day when it appears\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxi{%
And [by] He who created the male and female,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxii{%
Indeed, your efforts are diverse.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiii{%
As for he who gives and fears Allah\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxiv{%
And believes in the best [reward],\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxv{%
We will ease him toward ease.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvi{%
But as for he who withholds and considers himself free of need\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxvii{%
And denies the best [reward],\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxviii{%
We will ease him toward difficulty.\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmlxix{%
And what will his wealth avail him when he falls?\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmlxx{%
Indeed, [incumbent] upon Us is guidance.\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxi{%
And indeed, to Us belongs the Hereafter and the first [life].\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxii{%
So I have warned you of a Fire which is blazing.\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiii{%
None will [enter to] burn therein except the most wretched one.\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxiv{%
Who had denied and turned away.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxv{%
But the righteous one will avoid it -\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvi{%
[He] who gives [from] his wealth to purify himself\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxvii{%
And not [giving] for anyone who has [done him] a favor to be rewarded\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxviii{%
But only seeking the countenance of his Lord, Most High.\qt@no{20}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxix{%
And he is going to be satisfied.\qt@no{21}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxx{%
\basmalahen By the morning brightness\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxi{%
And [by] the night when it covers with darkness,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxii{%
Your Lord has not taken leave of you, [O Muhammad], nor has He detested [you].\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiii{%
And the Hereafter is better for you than the first [life].\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxiv{%
And your Lord is going to give you, and you will be satisfied.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxv{%
Did He not find you an orphan and give [you] refuge?\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvi{%
And He found you lost and guided [you],\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxvii{%
And He found you poor and made [you] self-sufficient.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxviii{%
So as for the orphan, do not oppress [him].\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmlxxxix{%
And as for the petitioner, do not repel [him].\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmxc{%
But as for the favor of your Lord, report [it].\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmxci{%
\basmalahen Did We not expand for you, [O Muhammad], your breast?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmxcii{%
And We removed from you your burden\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmxciii{%
Which had weighed upon your back\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmxciv{%
And raised high for you your repute.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmxcv{%
For indeed, with hardship [will be] ease.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvi{%
Indeed, with hardship [will be] ease.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmxcvii{%
So when you have finished [your duties], then stand up [for worship].\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmxcviii{%
And to your Lord direct [your] longing.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmxcix{%
\basmalahen By the fig and the olive\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmc{%
And [by] Mount Sinai\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmci{%
And [by] this secure city [Makkah],\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcii{%
We have certainly created man in the best of stature;\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmciii{%
Then We return him to the lowest of the low,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmciv{%
Except for those who believe and do righteous deeds, for they will have a reward uninterrupted.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcv{%
So what yet causes you to deny the Recompense?\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcvi{%
Is not Allah the most just of judges?\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcvii{%
\basmalahen Recite in the name of your Lord who created -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcviii{%
Created man from a clinging substance.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcix{%
Recite, and your Lord is the most Generous -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcx{%
Who taught by the pen -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxi{%
Taught man that which he knew not.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxii{%
No! [But] indeed, man transgresses\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiii{%
Because he sees himself self-sufficient.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxiv{%
Indeed, to your Lord is the return.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxv{%
Have you seen the one who forbids\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvi{%
A servant when he prays?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmcxvii{%
Have you seen if he is upon guidance\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmcxviii{%
Or enjoins righteousness?\qt@no{12}}%
\qt@newcmd\qurantrans@en@mmmmmmcxix{%
Have you seen if he denies and turns away -\qt@no{13}}%
\qt@newcmd\qurantrans@en@mmmmmmcxx{%
Does he not know that Allah sees?\qt@no{14}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxi{%
No! If he does not desist, We will surely drag him by the forelock -\qt@no{15}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxii{%
A lying, sinning forelock.\qt@no{16}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiii{%
Then let him call his associates;\qt@no{17}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxiv{%
We will call the angels of Hell.\qt@no{18}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxv{%
No! Do not obey him. But prostrate and draw near [to Allah].\qt@no{19}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvi{%
\basmalahen Indeed, We sent the Qur'an down during the Night of Decree.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxvii{%
And what can make you know what is the Night of Decree?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxviii{%
The Night of Decree is better than a thousand months.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxix{%
The angels and the Spirit descend therein by permission of their Lord for every matter.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxx{%
Peace it is until the emergence of dawn.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxi{%
\basmalahen Those who disbelieved among the People of the Scripture and the polytheists were not to be parted [from misbelief] until there came to them clear evidence -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxii{%
A Messenger from Allah, reciting purified scriptures\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiii{%
Within which are correct writings.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxiv{%
Nor did those who were given the Scripture become divided until after there had come to them clear evidence.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxv{%
And they were not commanded except to worship Allah, [being] sincere to Him in religion, inclining to truth, and to establish prayer and to give zakah. And that is the correct religion.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvi{%
Indeed, they who disbelieved among the People of the Scripture and the polytheists will be in the fire of Hell, abiding eternally therein. Those are the worst of creatures.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxvii{%
Indeed, they who have believed and done righteous deeds - those are the best of creatures.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxviii{%
Their reward with Allah will be gardens of perpetual residence beneath which rivers flow, wherein they will abide forever, Allah being pleased with them and they with Him. That is for whoever has feared his Lord.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxxxix{%
\basmalahen When the earth is shaken with its [final] earthquake\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxl{%
And the earth discharges its burdens\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxli{%
And man says, ``What is [wrong] with it?" -\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlii{%
That Day, it will report its news\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliii{%
Because your Lord has commanded it.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxliv{%
That Day, the people will depart separated [into categories] to be shown [the result of] their deeds.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlv{%
So whoever does an atom's weight of good will see it,\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvi{%
And whoever does an atom's weight of evil will see it.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlvii{%
\basmalahen By the racers, panting,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlviii{%
And the producers of sparks [when] striking\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxlix{%
And the chargers at dawn,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcl{%
Stirring up thereby [clouds of] dust,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcli{%
Arriving thereby in the center collectively,\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclii{%
Indeed mankind, to his Lord, is ungrateful.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcliii{%
And indeed, he is to that a witness.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmcliv{%
And indeed he is, in love of wealth, intense.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclv{%
But does he not know that when the contents of the graves are scattered\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclvi{%
And that within the breasts is obtained,\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclvii{%
Indeed, their Lord with them, that Day, is [fully] Acquainted.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclviii{%
\basmalahen The Striking Calamity -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclix{%
What is the Striking Calamity?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclx{%
And what can make you know what is the Striking Calamity?\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxi{%
It is the Day when people will be like moths, dispersed,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxii{%
And the mountains will be like wool, fluffed up.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiii{%
Then as for one whose scales are heavy [with good deeds],\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxiv{%
He will be in a pleasant life.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxv{%
But as for one whose scales are light,\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvi{%
His refuge will be an abyss.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxvii{%
And what can make you know what that is?\qt@no{10}}%
\qt@newcmd\qurantrans@en@mmmmmmclxviii{%
It is a Fire, intensely hot.\qt@no{11}}%
\qt@newcmd\qurantrans@en@mmmmmmclxix{%
\basmalahen Competition in [worldly] increase diverts you\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxx{%
Until you visit the graveyards.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxi{%
No! You are going to know.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxii{%
Then no! You are going to know.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiii{%
No! If you only knew with knowledge of certainty...\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxiv{%
You will surely see the Hellfire.\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxv{%
Then you will surely see it with the eye of certainty.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvi{%
Then you will surely be asked that Day about pleasure.\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxvii{%
\basmalahen By time,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxviii{%
Indeed, mankind is in loss,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxix{%
Except for those who have believed and done righteous deeds and advised each other to truth and advised each other to patience.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxx{%
\basmalahen Woe to every scorner and mocker\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxi{%
Who collects wealth and [continuously] counts it.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxii{%
He thinks that his wealth will make him immortal.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiii{%
No! He will surely be thrown into the Crusher.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxiv{%
And what can make you know what is the Crusher?\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxv{%
It is the fire of Allah, [eternally] fueled,\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvi{%
Which mounts directed at the hearts.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxvii{%
Indeed, Hellfire will be closed down upon them\qt@no{8}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxviii{%
In extended columns.\qt@no{9}}%
\qt@newcmd\qurantrans@en@mmmmmmclxxxix{%
\basmalahen Have you not considered, [O Muhammad], how your Lord dealt with the companions of the elephant?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxc{%
Did He not make their plan into misguidance?\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxci{%
And He sent against them birds in flocks,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcii{%
Striking them with stones of hard clay,\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciii{%
And He made them like eaten straw.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcxciv{%
\basmalahen For the accustomed security of the Quraysh -\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcv{%
Their accustomed security [in] the caravan of winter and summer -\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvi{%
Let them worship the Lord of this House,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcvii{%
Who has fed them, [saving them] from hunger and made them safe, [saving them] from fear.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcviii{%
\basmalahen Have you seen the one who denies the Recompense?\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmcxcix{%
For that is the one who drives away the orphan\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmcc{%
And does not encourage the feeding of the poor.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmcci{%
So woe to those who pray\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccii{%
[But] who are heedless of their prayer -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmcciii{%
Those who make show [of their deeds]\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmcciv{%
And withhold [simple] assistance.\qt@no{7}}%
\qt@newcmd\qurantrans@en@mmmmmmccv{%
\basmalahen Indeed, We have granted you, [O Muhammad], al-Kawthar.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccvi{%
So pray to your Lord and sacrifice [to Him alone].\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccvii{%
Indeed, your enemy is the one cut off.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccviii{%
\basmalahen Say, ``O disbelievers,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccix{%
I do not worship what you worship.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccx{%
Nor are you worshippers of what I worship.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxi{%
Nor will I be a worshipper of what you worship.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxii{%
Nor will you be worshippers of what I worship.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiii{%
For you is your religion, and for me is my religion."\qt@no{6}}%
\qt@newcmd\qurantrans@en@mmmmmmccxiv{%
\basmalahen When the victory of Allah has come and the conquest,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxv{%
And you see the people entering into the religion of Allah in multitudes,\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvi{%
Then exalt [Him] with praise of your Lord and ask forgiveness of Him. Indeed, He is ever Accepting of repentance.\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxvii{%
\basmalahen May the hands of Abu Lahab be ruined, and ruined is he.\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxviii{%
His wealth will not avail him or that which he gained.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxix{%
He will [enter to] burn in a Fire of [blazing] flame\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxx{%
And his wife [as well] - the carrier of firewood.\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxi{%
Around her neck is a rope of [twisted] fiber.\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxii{%
\basmalahen Say, ``He is Allah, [who is] One,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiii{%
Allah, the Eternal Refuge.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxiv{%
He neither begets nor is born,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxv{%
Nor is there to Him any equivalent."\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvi{%
\basmalahen Say, ``I seek refuge in the Lord of daybreak\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxvii{%
From the evil of that which He created\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxviii{%
And from the evil of darkness when it settles\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxix{%
And from the evil of the blowers in knots\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxx{%
And from the evil of an envier when he envies."\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxi{%
\basmalahen Say, ``I seek refuge in the Lord of mankind,\qt@no{1}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxii{%
The Sovereign of mankind.\qt@no{2}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiii{%
The God of mankind,\qt@no{3}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxiv{%
From the evil of the retreating whisperer -\qt@no{4}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxv{%
Who whispers [evil] into the breasts of mankind -\qt@no{5}}%
\qt@newcmd\qurantrans@en@mmmmmmccxxxvi{%
From among the jinn and mankind."\qt@no{6}}%
%% End of file `qurantext-enxii.translation.def'
